issue_client_leaf_certificate

Function issue_client_leaf_certificate 

pub fn issue_client_leaf_certificate(
    request: &LeafCertRequest,
    ca_cert: &X509,
    ca_privkey: &PKey<Private>,
) -> Result<(X509, PKey<Private>), Box<dyn Error + Sync + Send>>
Available on crate features boring and crypto and std only.
Issue a client-authentication leaf using the supplied CA. Unlike server issuance, a nonempty subject may be used without DNS/IP SANs.