issue_leaf_certificate

Function issue_leaf_certificate 

pub fn issue_leaf_certificate(
    request: &LeafCertRequest,
    ca_cert: &X509,
    ca_privkey: &PKey<Private>,
) -> Result<(X509, PKey<Private>), Box<dyn Error + Send + Sync>>
Available on crate features boring and crypto and std only.
Issue a server leaf using the supplied certificate authority.