Struct SelfSignedData
pub struct SelfSignedData {
pub organisation_name: Option<String>,
pub common_name: Option<Domain>,
pub subject_alternative_names: Option<Vec<Domain>>,
pub key_kind: SelfSignedKeyKind,
}Available on crate features
crypto and std only.Expand description
Data used to configure the generation of a self-signed certificate.
How a certificate is created is out of scope for the TLS layer: this lives
in rama-crypto and produces concrete DER material that the TLS layer then
simply stores and serves.
Fields
organisation_name: Option<String>name of the organisation
common_name: Option<Domain>common name (CN): server name protected by the certificate
subject_alternative_names: Option<Vec<Domain>>Subject Alternative Names (SAN) can be defined to create a cert which allows multiple hostnames or domains to be secured under one certificate.
key_kind: SelfSignedKeyKindKey algorithm used for the generated key pair (defaults to EC P-256).