Struct BufferUpdate
pub struct BufferUpdate<'a> { /* private fields */ }Available on crate features
crypto and aws-lc only.Expand description
A struct indicating the portion of a buffer written to, and/or not written to, during an encryption/decryption operation.
Implementations
impl BufferUpdate<'_>
impl BufferUpdate<'_>
pub fn written(&self) -> &[u8] ⓘ
pub fn written(&self) -> &[u8] ⓘ
Returns the slice from the buffer that was modified by the operation.
pub fn remainder(&self) -> &[u8] ⓘ
pub fn remainder(&self) -> &[u8] ⓘ
Returns the slice of the buffer that was not modified by the operation.
pub fn remainder_mut(&mut self) -> &mut [u8] ⓘ
pub fn remainder_mut(&mut self) -> &mut [u8] ⓘ
Returns a mutable slice of the buffer that was not modified by the operation.