Struct PublicEncryptingKey
pub struct PublicEncryptingKey(/* private fields */);Available on crate features
aws-lc and crypto and std only.Expand description
An RSA public key used for encrypting plaintext that is decrypted by a PrivateDecryptingKey.
Implementations
impl PublicEncryptingKey
impl PublicEncryptingKey
pub fn from_der(value: &[u8]) -> Result<PublicEncryptingKey, KeyRejected>
pub fn from_der(value: &[u8]) -> Result<PublicEncryptingKey, KeyRejected>
Construct a PublicEncryptingKey from X.509 SubjectPublicKeyInfo DER encoded bytes.
Errors
KeyRejectedif bytes do not encode a supported RSA public key or if the key is otherwise not acceptable.
pub fn key_size_bytes(&self) -> usize
pub fn key_size_bytes(&self) -> usize
Returns the RSA signature size in bytes.
pub fn key_size_bits(&self) -> usize
pub fn key_size_bits(&self) -> usize
Returns the RSA key size in bits.