MsbOption

Struct MsbOption 

pub struct MsbOption(/* private fields */);
Available on crate features boring and crypto and std only.
Options for the most significant bits of a randomly generated BigNum.

Implementations



impl MsbOption

pub const MAYBE_ZERO: MsbOption

The most significant bit of the number may be 0.

pub const ONE: MsbOption

The most significant bit of the number must be 1.

pub const TWO_ONES: MsbOption

The most significant two bits of the number must be 1.

The number of bits in the product of two such numbers will always be exactly twice the number of bits in the original numbers.