Struct Asn1Flag
pub struct Asn1Flag(/* private fields */);Available on crate features
boring and crypto and std only.Expand description
Named Curve or Explicit
This type acts as a boolean as to whether the EcGroup is named or explicit.
Implementations
impl Asn1Flag
impl Asn1Flag
pub const EXPLICIT_CURVE: Asn1Flag
pub const EXPLICIT_CURVE: Asn1Flag
Curve defined using polynomial parameters
Most applications use a named EC_GROUP curve, however, support is included to explicitly define the curve used to calculate keys This information would need to be known by both endpoint to make communication effective.
OPENSSL_EC_EXPLICIT_CURVE, but that was only added in 1.1. Man page documents that 0 can be used in older versions.
OpenSSL documentation at EC_GROUP
pub const NAMED_CURVE: Asn1Flag
pub const NAMED_CURVE: Asn1Flag
Standard Curves
Curves that make up the typical encryption use cases. The collection of curves are well known but extensible.
OpenSSL documentation at EC_GROUP