Struct Error
pub struct Error { /* private fields */ }boring and crypto and std only.Expand description
A detailed error reported as part of an ErrorStack.
Implementations
impl Error
impl Error
pub fn get() -> Option<Error>
pub fn get() -> Option<Error>
Pops the first error off the OpenSSL error stack.
This corresponds to ERR_get_error_line_data.
pub fn put(&self)
pub fn put(&self)
Pushes the error back onto the OpenSSL error stack.
This corresponds to ERR_put_error.
pub fn library_reason(&self, library_code: _bindgen_ty_1) -> Option<i32>
pub fn library_reason(&self, library_code: _bindgen_ty_1) -> Option<i32>
Get {lib}_R_{reason} reason code for the given library, or None if the error is from a different library.
Libraries are identified by [ERR_LIB_{name}(ffi::ERR_LIB_SSL) constants.
pub fn code(&self) -> u32
👎Deprecated: use library_reason() to compare error codes
pub fn code(&self) -> u32
use library_reason() to compare error codes
Returns a raw OpenSSL packed error code for this error, which can’t be reliably compared to any error constant.
Use Error::library_code() and Error::library_reason() instead.
Packed error codes are different than SSL error codes.
pub fn library(&self) -> Option<&'static str>
pub fn library(&self) -> Option<&'static str>
Returns the name of the library reporting the error, if available.
pub fn library_code(&self) -> i32
pub fn library_code(&self) -> i32
Returns the raw OpenSSL error constant for the library reporting the error (ERR_LIB_{name}).
Error reason codes are not globally unique, but scoped to each library.
pub fn reason_code(&self) -> i32
pub fn reason_code(&self) -> i32
Returns library-specific reason code corresponding to some of the {lib}_R_{reason} constants.
Reason codes are ambiguous, and different libraries reuse the same numeric values for different errors.
Use Error::library_reason to compare error codes.
For ERR_LIB_SYS the reason code is errno. ERR_LIB_USER can use any values.
Other libraries may use ERR_R_* or their own codes.