Struct ErrorStack
pub struct ErrorStack(/* private fields */);Available on crate features
boring and crypto and std only.Expand description
Collection of Errors from OpenSSL.
Implementations
impl ErrorStack
impl ErrorStack
pub fn get() -> ErrorStack
pub fn get() -> ErrorStack
Pops the contents of the OpenSSL error stack, and returns it.
This should be used only immediately after calling Boring FFI functions, otherwise the stack may be empty or a leftover from unrelated calls.
This corresponds to ERR_get_error_line_data.
pub fn put(&self)
pub fn put(&self)
Pushes the errors back onto the OpenSSL error stack.
This corresponds to ERR_put_error.
impl ErrorStack
impl ErrorStack