pub struct Hasher { /* private fields */ }Available on crate features
boring and crypto and std only.Expand description
Provides message digest (hash) computation.
Examples
Calculate a hash in one go:
use rama_boring::hash::{hash, MessageDigest};
let data = b"\x42\xF4\x97\xE0";
let spec = b"\x7c\x43\x0f\x17\x8a\xef\xdf\x14\x87\xfe\xe7\x14\x4e\x96\x41\xe2";
let res = hash(MessageDigest::md5(), data).unwrap();
assert_eq!(&*res, spec);Supply the input in chunks:
use rama_boring::hash::{Hasher, MessageDigest};
let data = [b"\x42\xF4", b"\x97\xE0"];
let spec = b"\x7c\x43\x0f\x17\x8a\xef\xdf\x14\x87\xfe\xe7\x14\x4e\x96\x41\xe2";
let mut h = Hasher::new(MessageDigest::md5()).unwrap();
h.update(data[0]).unwrap();
h.update(data[1]).unwrap();
let res = h.finish().unwrap();
assert_eq!(&*res, spec);Warning
Don’t actually use MD5 and SHA-1 hashes, they’re not secure anymore.
Don’t ever hash passwords, use the functions in the pkcs5 module or bcrypt/scrypt instead.
For extendable output functions (XOFs, i.e. SHAKE128/SHAKE256), you must use finish_xof instead of finish and provide a buf to store the hash. The hash will be as long as the buf.
Implementations
impl Hasher
impl Hasher
pub fn new(ty: MessageDigest) -> Result<Hasher, ErrorStack>
pub fn new(ty: MessageDigest) -> Result<Hasher, ErrorStack>
Creates a new Hasher with the specified hash type.
pub fn update(&mut self, data: &[u8]) -> Result<(), ErrorStack>
pub fn update(&mut self, data: &[u8]) -> Result<(), ErrorStack>
Feeds data into the hasher.
pub fn finish(&mut self) -> Result<DigestBytes, ErrorStack>
pub fn finish(&mut self) -> Result<DigestBytes, ErrorStack>
Returns the hash of the data written and resets the non-XOF hasher.
pub fn finish_xof(&mut self, buf: &mut [u8]) -> Result<(), ErrorStack>
pub fn finish_xof(&mut self, buf: &mut [u8]) -> Result<(), ErrorStack>
Writes the hash of the data into the supplied buf and resets the XOF hasher. The hash will be as long as the buf.