Struct CompliancePolicy
pub struct CompliancePolicy(/* private fields */);Available on crate features
boring and crypto and std only.Expand description
A compliance policy.
Implementations
impl CompliancePolicy
impl CompliancePolicy
pub const NONE: CompliancePolicy
pub const NONE: CompliancePolicy
Does nothing, however setting this does not undo other policies, so trying to set this is an error.
pub const FIPS_202205: CompliancePolicy
pub const FIPS_202205: CompliancePolicy
Configures a TLS connection to try and be compliant with NIST requirements, but does not guarantee success. This policy can be called even if Boring is not built with FIPS.
pub const WPA3_192_202304: CompliancePolicy
pub const WPA3_192_202304: CompliancePolicy
Partially configures a TLS connection to be compliant with WPA3. Callers must enforce certificate chain requirements themselves. Use of this policy is less secure than the default and not recommended.