Struct SslAcceptor
pub struct SslAcceptor(/* private fields */);boring and crypto and std only.Expand description
A type which wraps server-side streams in a TLS session.
OpenSSL’s default configuration is highly insecure. This connector manages the OpenSSL structures, configuring cipher suites, session options, and more.
Implementations
impl SslAcceptor
impl SslAcceptor
pub fn mozilla_intermediate_v5(
method: SslMethod,
) -> Result<SslAcceptorBuilder, ErrorStack>
pub fn mozilla_intermediate_v5( method: SslMethod, ) -> Result<SslAcceptorBuilder, ErrorStack>
Creates a new builder configured to connect to non-legacy clients. This should generally be considered a reasonable default choice.
This corresponds to the intermediate configuration of version 5 of Mozilla’s server side TLS recommendations. See its documentation for more details on specifics.
pub fn mozilla_intermediate(
method: SslMethod,
) -> Result<SslAcceptorBuilder, ErrorStack>
pub fn mozilla_intermediate( method: SslMethod, ) -> Result<SslAcceptorBuilder, ErrorStack>
Creates a new builder configured to connect to non-legacy clients. This should generally be considered a reasonable default choice.
This corresponds to the intermediate configuration of version 4 of Mozilla’s server side TLS recommendations. See its documentation for more details on specifics.
pub fn mozilla_modern(
method: SslMethod,
) -> Result<SslAcceptorBuilder, ErrorStack>
pub fn mozilla_modern( method: SslMethod, ) -> Result<SslAcceptorBuilder, ErrorStack>
Creates a new builder configured to connect to modern clients.
This corresponds to the modern configuration of version 4 of Mozilla’s server side TLS recommendations. See its documentation for more details on specifics.
pub fn setup_accept<S>(
&self,
stream: S,
) -> Result<MidHandshakeSslStream<S>, ErrorStack>
pub fn setup_accept<S>( &self, stream: S, ) -> Result<MidHandshakeSslStream<S>, ErrorStack>
Initiates a server-side TLS handshake on a stream.
See Ssl::setup_accept for more details.
pub fn accept<S>(&self, stream: S) -> Result<SslStream<S>, HandshakeError<S>>
pub fn accept<S>(&self, stream: S) -> Result<SslStream<S>, HandshakeError<S>>
Attempts a server-side TLS handshake on a stream.
This is a convenience method which combines Self::setup_accept and
MidHandshakeSslStream::handshake.
pub fn into_context(self) -> SslContext
pub fn into_context(self) -> SslContext
Consumes the SslAcceptor, returning the inner raw SslContext.
pub fn context(&self) -> &SslContextRef
pub fn context(&self) -> &SslContextRef
Returns a shared reference to the inner raw SslContext.