Struct SslContextRef
pub struct SslContextRef(/* private fields */);boring and crypto and std only.Expand description
A borrowed reference to a SslContext.
Implementations
impl SslContextRef
impl SslContextRef
pub fn certificate(&self) -> Option<&X509Ref>
pub fn certificate(&self) -> Option<&X509Ref>
Returns the certificate associated with this SslContext, if present.
This corresponds to SSL_CTX_get0_certificate.
pub fn private_key(&self) -> Option<&PKeyRef<Private>>
pub fn private_key(&self) -> Option<&PKeyRef<Private>>
Returns the private key associated with this SslContext, if present.
This corresponds to SSL_CTX_get0_privatekey.
pub fn cert_store(&self) -> &X509StoreRef
pub fn cert_store(&self) -> &X509StoreRef
Returns a shared reference to the certificate store used for verification.
This corresponds to SSL_CTX_get_cert_store.
pub fn extra_chain_certs(&self) -> &StackRef<X509>
pub fn extra_chain_certs(&self) -> &StackRef<X509>
Returns a shared reference to the stack of certificates making up the chain from the leaf.
This corresponds to SSL_CTX_get_extra_chain_certs.
pub fn ex_data<T>(&self, index: Index<SslContext, T>) -> Option<&T>
pub fn ex_data<T>(&self, index: Index<SslContext, T>) -> Option<&T>
Returns a reference to the extra data at the specified index.
This corresponds to SSL_CTX_get_ex_data.
pub unsafe fn add_session(&self, session: &SslSessionRef) -> bool
pub unsafe fn add_session(&self, session: &SslSessionRef) -> bool
Adds a session to the context’s cache.
Returns true if the session was successfully added to the cache, and false if it was already present.
Safety
The caller of this method is responsible for ensuring that the session has never been used with another
SslContext than this one.
This corresponds to SSL_CTX_add_session.
pub unsafe fn remove_session(&self, session: &SslSessionRef) -> bool
pub unsafe fn remove_session(&self, session: &SslSessionRef) -> bool
Removes a session from the context’s cache and marks it as non-resumable.
Returns true if the session was successfully found and removed, and false otherwise.
Safety
The caller of this method is responsible for ensuring that the session has never been used with another
SslContext than this one.
This corresponds to SSL_CTX_remove_session.
pub fn session_cache_size(&self) -> u64
pub fn session_cache_size(&self) -> u64
Returns the context’s session cache size limit.
A value of 0 means that the cache size is unbounded.
This corresponds to SSL_CTX_sess_get_cache_size.
pub fn verify_mode(&self) -> SslVerifyMode
pub fn verify_mode(&self) -> SslVerifyMode
Returns the verify mode that was set on this context from SslContextBuilder::set_verify.
This corresponds to SSL_CTX_get_verify_mode.
pub unsafe fn assume_x509(&mut self)
pub unsafe fn assume_x509(&mut self)
Assumes that this SslContext is configured for X.509 certificates.
Safety
BoringSSL will crash if the user calls a function that involves X.509 certificates with an object configured with this method. You most probably don’t need it.
pub fn has_x509_support(&self) -> bool
pub fn has_x509_support(&self) -> bool
Returns true if context is configured for X.509 certificates.
pub fn set_ech_keys(&self, keys: &SslEchKeys) -> Result<(), ErrorStack>
pub fn set_ech_keys(&self, keys: &SslEchKeys) -> Result<(), ErrorStack>
Registers a list of ECH keys on the context. This list should contain new and old
ECHConfigs to allow stale DNS caches to update. Unlike most SSL_CTX APIs, this function
is safe to call even after the SSL_CTX has been associated with connections on various
threads.
This corresponds to SSL_CTX_set1_ech_keys.