Struct SslCredentialBuilder
pub struct SslCredentialBuilder(/* private fields */);Available on crate features
boring and crypto and std only.Expand description
A builder for SslCredential
Implementations
impl SslCredentialBuilder
impl SslCredentialBuilder
pub fn replace_ex_data<T>(
&mut self,
index: Index<SslCredential, T>,
data: T,
) -> Option<T>
pub fn replace_ex_data<T>( &mut self, index: Index<SslCredential, T>, data: T, ) -> Option<T>
Sets or overwrites the extra data at the specified index.
This can be used to provide data to callbacks registered with the context. Use the
SslCredential::new_ex_index method to create an Index.
Any previous value will be returned and replaced by the new one.
This corresponds to SSL_CREDENTIAL_set_ex_data.
pub fn set_private_key(
&mut self,
private_key: &PKeyRef<Private>,
) -> Result<(), ErrorStack>
pub fn set_private_key( &mut self, private_key: &PKeyRef<Private>, ) -> Result<(), ErrorStack>
This corresponds to SSL_CREDENTIAL_set1_private_key.
pub fn set_private_key_method<M>(&mut self, method: M) -> Result<(), ErrorStack>where
M: PrivateKeyMethod,
pub fn set_private_key_method<M>(&mut self, method: M) -> Result<(), ErrorStack>where
M: PrivateKeyMethod,
Configures a custom private key method on the credential.
See PrivateKeyMethod for more details.
This corresponds to SSL_CREDENTIAL_set_private_key_method.
pub fn build(self) -> SslCredential