Struct SslMethod
pub struct SslMethod { /* private fields */ }boring and crypto and std only.Expand description
A type specifying the kind of protocol an SslContext will speak.
Implementations
impl SslMethod
impl SslMethod
pub fn tls() -> SslMethod
pub fn tls() -> SslMethod
Support all versions of the TLS protocol.
This corresponds to TLS_method.
pub unsafe fn tls_with_buffer() -> SslMethod
pub unsafe fn tls_with_buffer() -> SslMethod
Same as tls, but doesn’t create X.509 for certificates.
Safety
BoringSSL will crash if the user calls a function that involves X.509 certificates with an object configured with this method. You most probably don’t need it.
pub fn dtls() -> SslMethod
pub fn dtls() -> SslMethod
Support all versions of the DTLS protocol.
This corresponds to DTLS_method.
pub fn tls_client() -> SslMethod
pub fn tls_client() -> SslMethod
Support all versions of the TLS protocol, explicitly as a client.
This corresponds to TLS_client_method.
pub fn tls_server() -> SslMethod
pub fn tls_server() -> SslMethod
Support all versions of the TLS protocol, explicitly as a server.
This corresponds to TLS_server_method.
pub unsafe fn from_ptr(ptr: *const ssl_method_st) -> SslMethod
pub unsafe fn from_ptr(ptr: *const ssl_method_st) -> SslMethod
Constructs an SslMethod from a pointer to the underlying OpenSSL value.
This method assumes that the SslMethod is not configured for X.509
certificates. The user can call SslMethod::assume_x509_method
to change that.
Safety
The caller must ensure the pointer is valid.
This corresponds to TLS_server_method.
pub unsafe fn assume_x509(&mut self)
pub unsafe fn assume_x509(&mut self)
Assumes that this SslMethod is configured for X.509 certificates.
Safety
BoringSSL will crash if the user calls a function that involves X.509 certificates with an object configured with this method. You most probably don’t need it.