Struct SslSignatureAlgorithm
pub struct SslSignatureAlgorithm(/* private fields */);Available on crate features
boring and crypto and std only.Expand description
A signature verification algorithm.
WARNING: The current implementation of From is unsound, as it’s possible to create an
SslSignatureAlgorithm that is not defined by the impl. From will be deprecated in favor of
TryFrom in the next major bump of the library.
Implementations
impl SslSignatureAlgorithm
impl SslSignatureAlgorithm
pub const RSA_PKCS1_SHA1: SslSignatureAlgorithm
pub const RSA_PKCS1_SHA256: SslSignatureAlgorithm
pub const RSA_PKCS1_SHA384: SslSignatureAlgorithm
pub const RSA_PKCS1_SHA512: SslSignatureAlgorithm
pub const RSA_PKCS1_MD5_SHA1: SslSignatureAlgorithm
pub const ECDSA_SHA1: SslSignatureAlgorithm
pub const ECDSA_SECP256R1_SHA256: SslSignatureAlgorithm
pub const ECDSA_SECP384R1_SHA384: SslSignatureAlgorithm
pub const ECDSA_SECP521R1_SHA512: SslSignatureAlgorithm
pub const RSA_PSS_RSAE_SHA256: SslSignatureAlgorithm
pub const RSA_PSS_RSAE_SHA384: SslSignatureAlgorithm
pub const RSA_PSS_RSAE_SHA512: SslSignatureAlgorithm
pub const ED25519: SslSignatureAlgorithm