Struct AuthorityKeyIdentifier
pub struct AuthorityKeyIdentifier { /* private fields */ }Available on crate features
boring and crypto and std only.Expand description
An extension that provides a means of identifying the public key corresponding to the private key used to sign a CRL.
Implementations
impl AuthorityKeyIdentifier
impl AuthorityKeyIdentifier
pub fn new() -> AuthorityKeyIdentifier
pub fn new() -> AuthorityKeyIdentifier
Construct a new AuthorityKeyIdentifier extension.
pub fn critical(&mut self) -> &mut AuthorityKeyIdentifier
pub fn critical(&mut self) -> &mut AuthorityKeyIdentifier
Sets the critical flag to true. The extension will be critical.
pub fn keyid(&mut self, always: bool) -> &mut AuthorityKeyIdentifier
pub fn keyid(&mut self, always: bool) -> &mut AuthorityKeyIdentifier
Sets the keyid flag.
pub fn issuer(&mut self, always: bool) -> &mut AuthorityKeyIdentifier
pub fn issuer(&mut self, always: bool) -> &mut AuthorityKeyIdentifier
Sets the issuer flag.
pub fn build(
&self,
ctx: &X509v3Context<'_>,
) -> Result<X509Extension, ErrorStack>
pub fn build( &self, ctx: &X509v3Context<'_>, ) -> Result<X509Extension, ErrorStack>
Return a AuthorityKeyIdentifier extension as an X509Extension.