Struct SubjectAlternativeName
pub struct SubjectAlternativeName { /* private fields */ }Available on crate features
boring and crypto and std only.Expand description
An extension that allows additional identities to be bound to the subject of the certificate.
Implementations
impl SubjectAlternativeName
impl SubjectAlternativeName
pub fn new() -> SubjectAlternativeName
pub fn new() -> SubjectAlternativeName
Construct a new SubjectAlternativeName extension.
pub fn critical(&mut self) -> &mut SubjectAlternativeName
pub fn critical(&mut self) -> &mut SubjectAlternativeName
Sets the critical flag to true. The extension will be critical.
pub fn email(&mut self, email: &str) -> &mut SubjectAlternativeName
pub fn email(&mut self, email: &str) -> &mut SubjectAlternativeName
Sets the email flag.
pub fn uri(&mut self, uri: &str) -> &mut SubjectAlternativeName
pub fn uri(&mut self, uri: &str) -> &mut SubjectAlternativeName
Sets the uri flag.
pub fn dns(&mut self, dns: &str) -> &mut SubjectAlternativeName
pub fn dns(&mut self, dns: &str) -> &mut SubjectAlternativeName
Sets the dns flag.
pub fn rid(&mut self, rid: &str) -> &mut SubjectAlternativeName
pub fn rid(&mut self, rid: &str) -> &mut SubjectAlternativeName
Sets the rid flag.
pub fn ip(&mut self, ip: &str) -> &mut SubjectAlternativeName
pub fn ip(&mut self, ip: &str) -> &mut SubjectAlternativeName
Sets the ip flag.
pub fn dir_name(&mut self, _dir_name: &str) -> &mut SubjectAlternativeName
👎Deprecated: dir_name is deprecated and always panics. Please file a bug if you have a use case for this.
pub fn dir_name(&mut self, _dir_name: &str) -> &mut SubjectAlternativeName
dir_name is deprecated and always panics. Please file a bug if you have a use case for this.
Sets the dirName flag.
Not currently actually supported, always panics.
pub fn other_name(&mut self, _other_name: &str) -> &mut SubjectAlternativeName
👎Deprecated: other_name is deprecated and always panics. Please file a bug if you have a use case for this.
pub fn other_name(&mut self, _other_name: &str) -> &mut SubjectAlternativeName
other_name is deprecated and always panics. Please file a bug if you have a use case for this.
Sets the otherName flag.
Not currently actually supported, always panics.
pub fn build(
&self,
_ctx: &X509v3Context<'_>,
) -> Result<X509Extension, ErrorStack>
pub fn build( &self, _ctx: &X509v3Context<'_>, ) -> Result<X509Extension, ErrorStack>
Return a SubjectAlternativeName extension as an X509Extension.