Struct X509Store
pub struct X509Store(/* private fields */);Available on crate features
boring and crypto and std only.Expand description
A certificate store to hold trusted X509 certificates.
Methods from Deref<Target = X509StoreRef>
pub fn objects(&self) -> &StackRef<X509Object>
👎Deprecated: This method is unsound https://github.com/sfackler/rust-openssl/issues/2096
pub fn objects(&self) -> &StackRef<X509Object>
This method is unsound https://github.com/sfackler/rust-openssl/issues/2096
Warning: this method is unsound
Get a reference to the cache of certificates in this store.
Safety
References may be invalidated by any access to the shared cache.
This corresponds to X509_STORE_get0_objects.