Struct X509StoreBuilder
pub struct X509StoreBuilder(/* private fields */);boring and crypto and std only.Expand description
A builder type used to construct an X509Store.
Implementations
impl X509StoreBuilder
impl X509StoreBuilder
pub fn new() -> Result<X509StoreBuilder, ErrorStack>
pub fn new() -> Result<X509StoreBuilder, ErrorStack>
Returns a builder for a certificate store.
The store is initially empty.
Methods from Deref<Target = X509StoreBuilderRef>
pub fn add_cert(&mut self, cert: impl AsRef<X509Ref>) -> Result<(), ErrorStack>
pub fn add_cert(&mut self, cert: impl AsRef<X509Ref>) -> Result<(), ErrorStack>
Adds a certificate to the certificate store.
This corresponds to X509_STORE_add_cert.
pub fn set_default_paths(&mut self) -> Result<(), ErrorStack>
pub fn set_default_paths(&mut self) -> Result<(), ErrorStack>
Load certificates from their default locations.
These locations are read from the SSL_CERT_FILE and SSL_CERT_DIR
environment variables if present, or defaults specified at OpenSSL
build time otherwise.
This corresponds to X509_STORE_set_default_paths.
pub fn set_flags(&mut self, flags: X509VerifyFlags)
pub fn set_flags(&mut self, flags: X509VerifyFlags)
Sets certificate chain validation related flags.
This corresponds to X509_STORE_set_flags.
pub fn try_set_flags(
&mut self,
flags: X509VerifyFlags,
) -> Result<(), ErrorStack>
pub fn try_set_flags( &mut self, flags: X509VerifyFlags, ) -> Result<(), ErrorStack>
Sets certificate verification flags without panicking on native failure.
This corresponds to X509_STORE_set_flags.
pub fn verify_param_mut(&mut self) -> &mut X509VerifyParamRef
pub fn verify_param_mut(&mut self) -> &mut X509VerifyParamRef
Returns a mutable reference to the X509 verification configuration.
This corresponds to X509_STORE_get0_param.
pub fn set_param(
&mut self,
param: &X509VerifyParamRef,
) -> Result<(), ErrorStack>
pub fn set_param( &mut self, param: &X509VerifyParamRef, ) -> Result<(), ErrorStack>
Sets certificate chain validation related parameters.
This corresponds to X509_STORE_set1_param.