digest

Function digest 

pub fn digest(algorithm: &'static Algorithm, data: &[u8]) -> Digest
Available on crate features crypto and ring and std only.
Returns the digest of data using the given digest algorithm.