Struct PublicKey
pub struct PublicKey { /* private fields */ }Available on crate features
alloc and crypto and ring and std only.Expand description
An RSA Public Key.
Implementations
impl PublicKey
impl PublicKey
pub fn modulus_len(&self) -> usize
pub fn modulus_len(&self) -> usize
The length, in bytes, of the public modulus.
The modulus length is rounded up to a whole number of bytes if its bit length isn’t a multiple of 8.