Function oid_registry
pub fn oid_registry() -> &'static OidRegistry<'static>Available on crate features
crypto and std only.Expand description
Return a reference to the default registry of known OIDs
pub fn oid_registry() -> &'static OidRegistry<'static>crypto and std only.Return a reference to the default registry of known OIDs