take_while

Function take_while 

pub fn take_while<F, Input, Error>(cond: F) -> impl Fn(Input)
where Error: ParseError<Input>, Input: InputTakeAtPosition, F: Fn(<Input as InputTakeAtPosition>::Item) -> bool,
Available on crate features crypto and std only.
Returns the longest input slice (if any) that matches the predicate.

The parser will return the longest slice that matches the given predicate (a function that takes the input and returns a bool).

Example

use nom::bytes::complete::take_while;
use nom::character::is_alphabetic;

fn alpha(s: &[u8]) -> IResult<&[u8], &[u8]> {
  take_while(is_alphabetic)(s)
}

assert_eq!(alpha(b"latin123"), Ok((&b"123"[..], &b"latin"[..])));
assert_eq!(alpha(b"12345"), Ok((&b"12345"[..], &b""[..])));
assert_eq!(alpha(b"latin"), Ok((&b""[..], &b"latin"[..])));
assert_eq!(alpha(b""), Ok((&b""[..], &b""[..])));