Enum Err
pub enum Err<E> {
Incomplete(Needed),
Error(E),
Failure(E),
}Available on crate features
crypto and std only.Expand description
The Err enum indicates the parser was not successful
It has three cases:
Incompleteindicates that more data is needed to decide. TheNeededenum can contain how many additional bytes are necessary. If you are sure your parser is working on full data, you can wrap your parser with thecompletecombinator to transform that case inErrorErrormeans some parser did not succeed, but another one might (as an example, when testing different branches of analtcombinator)Failureindicates an unrecoverable error. As an example, if you recognize a prefix to decide on the next parser to apply, and that parser fails, you know there’s no need to try other parsers, you were already in the right branch, so the data is invalid
Variants
Incomplete(Needed)
There was not enough data
Error(E)
The parser had an error (recoverable)
Failure(E)
The parser had an unrecoverable error: we got to the right branch and we know other branches won’t work, so backtrack as fast as possible
Implementations
impl<E> Err<E>
impl<E> Err<E>
pub fn is_incomplete(&self) -> bool
pub fn is_incomplete(&self) -> bool
Tests if the result is Incomplete