ContextError

Trait ContextError 

pub trait ContextError<I>: Sized {
    // Provided method
    fn add_context(_input: I, _ctx: &'static str, other: Self) -> Self { ... }
}
Available on crate feature crypto only.
This trait is required by the context combinator to add a static string to an existing error

Provided Methods

fn add_context(_input: I, _ctx: &'static str, other: Self) -> Self

Creates a new error from an input position, a static string and an existing error. This is used mainly in the context combinator, to add user friendly information to errors when backtracking through a parse tree

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types



impl<I> ContextError<I> for ()



impl<I> ContextError<I> for (I, ErrorKind)

Implementors



impl<I> ContextError<I> for Error<I>



impl<I> ContextError<I> for VerboseError<I>

Available on crate feature alloc only.