Octal

Trait Octal 

1.0.0 · Source
pub trait Octal {
    // Required method
    fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>;
}
Available on crate features crypto and std only.
o formatting.

The Octal trait should format its output as a number in base-8.

For primitive signed integers (i8 to i128, and isize), negative values are formatted as the two’s complement representation.

The alternate flag, #, adds a 0o in front of the output.

For more information on formatters, see the module-level documentation.

Examples

Basic usage with i32:

let x = 42; // 42 is '52' in octal

assert_eq!(format!("{x:o}"), "52");
assert_eq!(format!("{x:#o}"), "0o52");

assert_eq!(format!("{:o}", -16), "37777777760");

Implementing Octal on a type:

use std::fmt;

struct Length(i32);

impl fmt::Octal for Length {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        let val = self.0;

        fmt::Octal::fmt(&val, f) // delegate to i32's implementation
    }
}

let l = Length(9);

assert_eq!(format!("l as octal is: {l:o}"), "l as octal is: 11");

assert_eq!(format!("l as octal is: {l:#06o}"), "l as octal is: 0o0011");

Required Methods

1.0.0 · Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Formats the value using the given formatter.

Errors

This function should return Err if, and only if, the provided Formatter returns Err. String formatting is considered an infallible operation; this function only returns a Result because writing to the underlying stream might fail and it must provide a way to propagate the fact that an error has occurred back up the stack.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors



impl Octal for Access



impl Octal for AtFlags

Source

impl Octal for BigInt

Source

impl Octal for BigUint



impl Octal for CreateFlags



impl Octal for DupFlags



impl Octal for FallocateFlags



impl Octal for FdFlags



impl Octal for Gid



impl Octal for IFlags



impl Octal for MemfdFlags



impl Octal for Mode



impl Octal for OFlags



impl Octal for ReadFlags



impl Octal for ReadWriteFlags



impl Octal for RenameFlags



impl Octal for ResolveFlags



impl Octal for SealFlags



impl Octal for ShutdownState



impl Octal for SslMode



impl Octal for SslOptions



impl Octal for SslSessionCacheMode



impl Octal for SslVerifyMode



impl Octal for StatVfsMountFlags



impl Octal for StatxAttributes



impl Octal for StatxFlags



impl Octal for Uid



impl Octal for WatchFlags



impl Octal for X509CheckFlags



impl Octal for X509VerifyFlags



impl Octal for XattrFlags

1.0.0 · Source

impl Octal for i8

1.0.0 · Source

impl Octal for i16

1.0.0 · Source

impl Octal for i32

1.0.0 · Source

impl Octal for i64

1.0.0 · Source

impl Octal for i128

1.0.0 · Source

impl Octal for isize

1.0.0 · Source

impl Octal for u8

1.0.0 · Source

impl Octal for u16

1.0.0 · Source

impl Octal for u32

1.0.0 · Source

impl Octal for u64

1.0.0 · Source

impl Octal for u128

1.0.0 · Source

impl Octal for usize



impl<'a, I> Octal for Format<'a, I>
where I: Iterator, <I as Iterator>::Item: Octal,



impl<'s, T> Octal for SliceVec<'s, T>
where T: Octal,



impl<A> Octal for ArrayVec<A>
where A: Array, <A as Array>::Item: Octal,



impl<A> Octal for TinyVec<A>
where A: Array, <A as Array>::Item: Octal,



impl<O> Octal for I16<O>
where O: ByteOrder,



impl<O> Octal for I32<O>
where O: ByteOrder,



impl<O> Octal for I64<O>
where O: ByteOrder,



impl<O> Octal for I128<O>
where O: ByteOrder,



impl<O> Octal for Isize<O>
where O: ByteOrder,



impl<O> Octal for U16<O>
where O: ByteOrder,



impl<O> Octal for U32<O>
where O: ByteOrder,



impl<O> Octal for U64<O>
where O: ByteOrder,



impl<O> Octal for U128<O>
where O: ByteOrder,



impl<O> Octal for Usize<O>
where O: ByteOrder,

1.0.0 · Source

impl<T> Octal for &T
where T: Octal + ?Sized,

1.0.0 · Source

impl<T> Octal for &mut T
where T: Octal + ?Sized,

1.28.0 · Source

impl<T> Octal for NonZero<T>

1.74.0 · Source

impl<T> Octal for Saturating<T>
where T: Octal,

1.11.0 · Source

impl<T> Octal for Wrapping<T>
where T: Octal,



impl<const MIN: i8, const MAX: i8> Octal for RangedI8<MIN, MAX>



impl<const MIN: i16, const MAX: i16> Octal for RangedI16<MIN, MAX>



impl<const MIN: i32, const MAX: i32> Octal for RangedI32<MIN, MAX>



impl<const MIN: i64, const MAX: i64> Octal for RangedI64<MIN, MAX>



impl<const MIN: i128, const MAX: i128> Octal for RangedI128<MIN, MAX>



impl<const MIN: isize, const MAX: isize> Octal for RangedIsize<MIN, MAX>



impl<const MIN: u8, const MAX: u8> Octal for RangedU8<MIN, MAX>



impl<const MIN: u16, const MAX: u16> Octal for RangedU16<MIN, MAX>



impl<const MIN: u32, const MAX: u32> Octal for RangedU32<MIN, MAX>



impl<const MIN: u64, const MAX: u64> Octal for RangedU64<MIN, MAX>



impl<const MIN: u128, const MAX: u128> Octal for RangedU128<MIN, MAX>



impl<const MIN: usize, const MAX: usize> Octal for RangedUsize<MIN, MAX>