IntoIterator

Trait IntoIterator 

1.0.0 · Source
pub trait IntoIterator {
    type Item;
    type IntoIter: Iterator<Item = Self::Item>;

    // Required method
    fn into_iter(self) -> Self::IntoIter;
}
Available on crate features crypto and std only.
Conversion into an Iterator.

By implementing IntoIterator for a type, you define how it will be converted to an iterator. This is common for types which describe a collection of some kind.

One benefit of implementing IntoIterator is that your type will work with Rust’s for loop syntax.

See also: FromIterator.

Examples

Basic usage:

let v = [1, 2, 3];
let mut iter = v.into_iter();

assert_eq!(Some(1), iter.next());
assert_eq!(Some(2), iter.next());
assert_eq!(Some(3), iter.next());
assert_eq!(None, iter.next());

Implementing IntoIterator for your type:

// A sample collection, that's just a wrapper over Vec<T>
#[derive(Debug)]
struct MyCollection(Vec<i32>);

// Let's give it some methods so we can create one and add things
// to it.
impl MyCollection {
    fn new() -> MyCollection {
        MyCollection(Vec::new())
    }

    fn add(&mut self, elem: i32) {
        self.0.push(elem);
    }
}

// and we'll implement IntoIterator
impl IntoIterator for MyCollection {
    type Item = i32;
    type IntoIter = std::vec::IntoIter<Self::Item>;

    fn into_iter(self) -> Self::IntoIter {
        self.0.into_iter()
    }
}

// Now we can make a new collection...
let mut c = MyCollection::new();

// ... add some stuff to it ...
c.add(0);
c.add(1);
c.add(2);

// ... and then turn it into an Iterator:
for (i, n) in c.into_iter().enumerate() {
    assert_eq!(i as i32, n);
}

It is common to use IntoIterator as a trait bound. This allows the input collection type to change, so long as it is still an iterator. Additional bounds can be specified by restricting on Item:

fn collect_as_strings<T>(collection: T) -> Vec<String>
where
    T: IntoIterator,
    T::Item: std::fmt::Debug,
{
    collection
        .into_iter()
        .map(|item| format!("{item:?}"))
        .collect()
}

Required Associated Types

1.0.0 · Source

type Item

The type of the elements being iterated over.

1.0.0 · Source

type IntoIter: Iterator<Item = Self::Item>

Which kind of iterator are we turning this into?

Required Methods

1.0.0 · Source

fn into_iter(self) -> Self::IntoIter

Creates an iterator from a value.

See the module-level documentation for more.

Examples
let v = [1, 2, 3];
let mut iter = v.into_iter();

assert_eq!(Some(1), iter.next());
assert_eq!(Some(2), iter.next());
assert_eq!(Some(3), iter.next());
assert_eq!(None, iter.next());

Implementors



impl IntoIterator for &FieldSet

Source

impl IntoIterator for IndexVec



impl IntoIterator for Bytes



impl IntoIterator for BytesMut



impl IntoIterator for CertLookup



impl IntoIterator for Ipv4Lookup



impl IntoIterator for Ipv6Lookup



impl IntoIterator for Lookup



impl IntoIterator for MxLookup



impl IntoIterator for NsLookup



impl IntoIterator for ReverseLookup



impl IntoIterator for SoaLookup



impl IntoIterator for SrvLookup



impl IntoIterator for TlsaLookup



impl IntoIterator for TxtLookup



impl IntoIterator for LookupIp



impl IntoIterator for RecordSet



impl IntoIterator for CFConnectingIp



type Item = ForwardedElement



type IntoIter = CFConnectingIpIterator



impl IntoIterator for ClientIp



type Item = ForwardedElement



type IntoIter = ClientIpIterator



impl IntoIterator for rama::http::headers::forwarded::Forwarded



impl IntoIterator for TrueClientIp



type Item = ForwardedElement



type IntoIter = TrueClientIpIterator



impl IntoIterator for Via



type Item = ForwardedElement



type IntoIter = ViaIterator



impl IntoIterator for XClientIp



type Item = ForwardedElement



type IntoIter = XClientIpIterator



impl IntoIterator for XForwardedFor



type Item = ForwardedElement



type IntoIter = XForwardedForIterator



impl IntoIterator for XForwardedHost



type Item = ForwardedElement



type IntoIter = XForwardedHostIterator



impl IntoIterator for XForwardedProto



type Item = ForwardedElement



type IntoIter = XForwardedProtoIterator



impl IntoIterator for XRealIp



type Item = ForwardedElement



type IntoIter = XRealIpIterator



impl IntoIterator for MimeGuess



type Item = Mime



type IntoIter = Iter



impl IntoIterator for OriginalHttp1Headers



impl IntoIterator for HeaderMapValueRemover



impl IntoIterator for Http1HeaderMap



impl IntoIterator for SettingOrder



type Item = SettingId



type IntoIter = IntoIter<[SettingId; 8]>



impl IntoIterator for PseudoHeaderOrder



impl IntoIterator for rama::net::forwarded::Forwarded



impl IntoIterator for SpanEvents



impl IntoIterator for ShutdownState



impl IntoIterator for SslMode



type Item = SslMode



type IntoIter = Iter<SslMode>



impl IntoIterator for SslOptions



impl IntoIterator for SslSessionCacheMode



impl IntoIterator for SslVerifyMode



impl IntoIterator for X509CheckFlags



impl IntoIterator for X509VerifyFlags



impl IntoIterator for rama::utils::thirdparty::regex::bytes::SetMatches



impl IntoIterator for rama::utils::thirdparty::regex::SetMatches

Source

impl IntoIterator for Map<String, Value>



impl IntoIterator for Targets



type Item = (String, LevelFilter)



type IntoIter = IntoIter



impl IntoIterator for Value



type Item = Subtag



type IntoIter = ShortBoxSliceIntoIter<Subtag>



impl<'a> IntoIterator for &'a Bytes



type Item = &'a u8



type IntoIter = Iter<'a, u8>



impl<'a> IntoIterator for &'a BytesMut



type Item = &'a u8



type IntoIter = Iter<'a, u8>



impl<'a> IntoIterator for &'a Name



type Item = &'a [u8]



type IntoIter = LabelIter<'a>



impl<'a> IntoIterator for &'a MimeGuess



type Item = Mime



type IntoIter = Iter



impl<'a> IntoIterator for &'a Baggage



type Item = (&'a Key, &'a (StringValue, BaggageMetadata))



type IntoIter = Iter<'a>



impl<'a> IntoIterator for &'a Resource



type Item = (&'a Key, &'a Value)



type IntoIter = Iter<'a>



impl<'a> IntoIterator for &'a rama::utils::thirdparty::regex::bytes::SetMatches



impl<'a> IntoIterator for &'a rama::utils::thirdparty::regex::SetMatches

1.10.0 · Source

impl<'a> IntoIterator for &'a UnixListener

1.6.0 · Source

impl<'a> IntoIterator for &'a Path

1.6.0 · Source

impl<'a> IntoIterator for &'a PathBuf

Source

impl<'a> IntoIterator for &'a Map<String, Value>

Source

type Item = (&'a String, &'a Value)

Source

type IntoIter = Iter<'a>



impl<'a> IntoIterator for &'a BorrowedCertRevocationList<'a>



type Item = Result<BorrowedRevokedCert<'a>, Error>



type IntoIter = DerIterator<'a, BorrowedRevokedCert<'a>>



impl<'a> IntoIterator for &'a Events



type Item = &'a Event



type IntoIter = Iter<'a>



impl<'a> IntoIterator for &'a StringRecord



type IntoIter = StringRecordIter<'a>



type Item = &'a str



impl<'a> IntoIterator for &'a Targets



type Item = (&'a str, LevelFilter)



type IntoIter = Iter<'a>



impl<'a> IntoIterator for &'a Utf8Sequence



type IntoIter = Iter<'a, Utf8Range>



type Item = &'a Utf8Range

Source

impl<'a> IntoIterator for &'a mut Map<String, Value>

Source

type Item = (&'a String, &'a mut Value)

Source

type IntoIter = IterMut<'a>



impl<'a> IntoIterator for BerObject<'a>



impl<'a, 'b, T> IntoIterator for &'b GetAll<'a, T>
where 'b: 'a,



type Item = &'a T



type IntoIter = ValueIter<'a, T>



impl<'a, 'b, T> IntoIterator for &'b OccupiedEntry<'a, T>
where 'b: 'a,



type Item = &'a T



type IntoIter = ValueIter<'a, T>



impl<'a, 'b, T> IntoIterator for &'b mut OccupiedEntry<'a, T>
where 'b: 'a,



impl<'a, A> IntoIterator for &'a ArrayVec<A>
where A: Array,



type Item = &'a <A as Array>::Item



type IntoIter = Iter<'a, <A as Array>::Item>



impl<'a, A> IntoIterator for &'a SmallVec<A>
where A: Array,



type IntoIter = Iter<'a, <A as Array>::Item>



type Item = &'a <A as Array>::Item



impl<'a, A> IntoIterator for &'a TinyVec<A>
where A: Array,



type Item = &'a <A as Array>::Item



type IntoIter = Iter<'a, <A as Array>::Item>



impl<'a, A> IntoIterator for &'a mut ArrayVec<A>
where A: Array,



type Item = &'a mut <A as Array>::Item



type IntoIter = IterMut<'a, <A as Array>::Item>



impl<'a, A> IntoIterator for &'a mut SmallVec<A>
where A: Array,



type IntoIter = IterMut<'a, <A as Array>::Item>



type Item = &'a mut <A as Array>::Item



impl<'a, A> IntoIterator for &'a mut TinyVec<A>
where A: Array,



type Item = &'a mut <A as Array>::Item



type IntoIter = IterMut<'a, <A as Array>::Item>



impl<'a, Fut> IntoIterator for &'a FuturesUnordered<Fut>
where Fut: Unpin,



type Item = &'a Fut



type IntoIter = Iter<'a, Fut>



impl<'a, Fut> IntoIterator for &'a mut FuturesUnordered<Fut>
where Fut: Unpin,



type Item = &'a mut Fut



type IntoIter = IterMut<'a, Fut>



impl<'a, I> IntoIterator for &'a IntoChunks<I>
where I: Iterator, <I as Iterator>::Item: 'a,



type Item = Chunk<'a, I>



type IntoIter = Chunks<'a, I>

1.80.0 · Source

impl<'a, I, A> IntoIterator for &'a Box<[I], A>
where A: Allocator,

1.80.0 · Source

impl<'a, I, A> IntoIterator for &'a mut Box<[I], A>
where A: Allocator,



impl<'a, K, I, F> IntoIterator for &'a ChunkBy<K, I, F>
where I: Iterator, <I as Iterator>::Item: 'a, F: FnMut(&<I as Iterator>::Item) -> K, K: PartialEq,



type Item = (K, Group<'a, K, I, F>)



type IntoIter = Groups<'a, K, I, F>



impl<'a, K, V> IntoIterator for &'a Slice<K, V>



type IntoIter = Iter<'a, K, V>



type Item = (&'a K, &'a V)



impl<'a, K, V> IntoIterator for &'a mut Slice<K, V>



type IntoIter = IterMut<'a, K, V>



type Item = (&'a K, &'a mut V)

1.0.0 · Source

impl<'a, K, V, A> IntoIterator for &'a BTreeMap<K, V, A>
where A: Allocator + Clone,

Source

type Item = (&'a K, &'a V)

Source

type IntoIter = Iter<'a, K, V>

1.0.0 · Source

impl<'a, K, V, A> IntoIterator for &'a mut BTreeMap<K, V, A>
where A: Allocator + Clone,

1.0.0 · Source

impl<'a, K, V, S> IntoIterator for &'a rama::crypto::dep::x509_parser::prelude::asn1_rs::nom::lib::std::collections::HashMap<K, V, S>

Source

type Item = (&'a K, &'a V)

Source

type IntoIter = Iter<'a, K, V>



impl<'a, K, V, S> IntoIterator for &'a AHashMap<K, V, S>



type Item = (&'a K, &'a V)



type IntoIter = Iter<'a, K, V>



impl<'a, K, V, S> IntoIterator for &'a Cache<K, V, S>
where K: Hash + Eq + Send + Sync + 'static, V: Clone + Send + Sync + 'static, S: BuildHasher + Clone + Send + Sync + 'static,



type Item = (Arc<K>, V)



type IntoIter = Iter<'a, K, V>



impl<'a, K, V, S> IntoIterator for &'a IndexMap<K, V, S>



type Item = (&'a K, &'a V)



type IntoIter = Iter<'a, K, V>



impl<'a, K, V, S> IntoIterator for &'a LiteMap<K, V, S>
where S: StoreIterable<'a, K, V>,



type Item = (&'a K, &'a V)



type IntoIter = <S as StoreIterable<'a, K, V>>::KeyValueIter



impl<'a, K, V, S> IntoIterator for &'a SegmentedCache<K, V, S>
where K: Hash + Eq + Send + Sync + 'static, V: Clone + Send + Sync + 'static, S: BuildHasher + Clone + Send + Sync + 'static,



type Item = (Arc<K>, V)



type IntoIter = Iter<'a, K, V>

1.0.0 · Source

impl<'a, K, V, S> IntoIterator for &'a mut rama::crypto::dep::x509_parser::prelude::asn1_rs::nom::lib::std::collections::HashMap<K, V, S>



impl<'a, K, V, S> IntoIterator for &'a mut AHashMap<K, V, S>



type Item = (&'a K, &'a mut V)



type IntoIter = IterMut<'a, K, V>



impl<'a, K, V, S> IntoIterator for &'a mut IndexMap<K, V, S>



type Item = (&'a K, &'a mut V)



type IntoIter = IterMut<'a, K, V>



impl<'a, K, V, S> IntoIterator for &'a mut LiteMap<K, V, S>
where S: StoreIterableMut<'a, K, V>,



type Item = (&'a K, &'a mut V)



type IntoIter = <S as StoreIterableMut<'a, K, V>>::KeyValueIterMut



impl<'a, K, V, S, A> IntoIterator for &'a HashMap<K, V, S, A>
where A: Allocator,



type Item = (&'a K, &'a V)



type IntoIter = Iter<'a, K, V>



impl<'a, K, V, S, A> IntoIterator for &'a mut HashMap<K, V, S, A>
where A: Allocator,



type Item = (&'a K, &'a mut V)



type IntoIter = IterMut<'a, K, V>



impl<'a, St> IntoIterator for &'a SelectAll<St>
where St: Stream + Unpin,



type Item = &'a St



type IntoIter = Iter<'a, St>



impl<'a, St> IntoIterator for &'a mut SelectAll<St>
where St: Stream + Unpin,



type Item = &'a mut St



type IntoIter = IterMut<'a, St>

1.4.0 · Source

impl<'a, T> IntoIterator for &'a Option<T>

1.0.0 · Source

impl<'a, T> IntoIterator for &'a [T]



impl<'a, T> IntoIterator for &'a HeaderMap<T>



type Item = (&'a HeaderName, &'a T)



type IntoIter = Iter<'a, T>



impl<'a, T> IntoIterator for &'a Stack<T>
where T: Stackable,



type Item = &'a <T as ForeignType>::Ref



type IntoIter = Iter<'a, T>



impl<'a, T> IntoIterator for &'a StackRef<T>
where T: Stackable,



type Item = &'a <T as ForeignType>::Ref



type IntoIter = Iter<'a, T>



impl<'a, T> IntoIterator for &'a NonEmptyVec<T>



type Item = &'a T



type IntoIter = Chain<Once<&'a T>, Iter<'a, T>>

Source

impl<'a, T> IntoIterator for &'a std::sync::mpmc::Receiver<T>

Source

type Item = T

Source

type IntoIter = Iter<'a, T>

1.1.0 · Source

impl<'a, T> IntoIterator for &'a std::sync::mpsc::Receiver<T>

Source

type Item = T

Source

type IntoIter = Iter<'a, T>



impl<'a, T> IntoIterator for &'a Receiver<T>

This exists as a shorthand for [Receiver::iter].



type Item = T



type IntoIter = Iter<'a, T>



impl<'a, T> IntoIterator for &'a Receiver<T>



type Item = T



type IntoIter = Iter<'a, T>



impl<'a, T> IntoIterator for &'a Slab<T>



type Item = (usize, &'a T)



type IntoIter = Iter<'a, T>



impl<'a, T> IntoIterator for &'a Slice<T>



type IntoIter = Iter<'a, T>



type Item = &'a T



impl<'a, T> IntoIterator for &'a ThreadLocal<T>
where T: Send + Sync,



type Item = &'a T



type IntoIter = Iter<'a, T>

1.4.0 · Source

impl<'a, T> IntoIterator for &'a mut Option<T>

1.0.0 · Source

impl<'a, T> IntoIterator for &'a mut [T]



impl<'a, T> IntoIterator for &'a mut HeaderMap<T>



type Item = (&'a HeaderName, &'a mut T)



type IntoIter = IterMut<'a, T>



impl<'a, T> IntoIterator for &'a mut Stack<T>
where T: Stackable,



type Item = &'a mut <T as ForeignType>::Ref



type IntoIter = IterMut<'a, T>



impl<'a, T> IntoIterator for &'a mut StackRef<T>
where T: Stackable,



type Item = &'a mut <T as ForeignType>::Ref



type IntoIter = IterMut<'a, T>



impl<'a, T> IntoIterator for &'a mut CachedThreadLocal<T>
where T: Send + 'a,



type Item = &'a mut T



type IntoIter = CachedIterMut<'a, T>



impl<'a, T> IntoIterator for &'a mut Slab<T>



type Item = (usize, &'a mut T)



type IntoIter = IterMut<'a, T>



impl<'a, T> IntoIterator for &'a mut ThreadLocal<T>
where T: Send,



type Item = &'a mut T



type IntoIter = IterMut<'a, T>



impl<'a, T> IntoIterator for GetAll<'a, T>



type Item = &'a T



type IntoIter = ValueIter<'a, T>



impl<'a, T> IntoIterator for OccupiedEntry<'a, T>

1.0.0 · Source

impl<'a, T, A> IntoIterator for &'a BTreeSet<T, A>
where A: Allocator + Clone,

1.0.0 · Source

impl<'a, T, A> IntoIterator for &'a BinaryHeap<T, A>
where A: Allocator,

1.0.0 · Source

impl<'a, T, A> IntoIterator for &'a LinkedList<T, A>
where A: Allocator,

1.0.0 · Source

impl<'a, T, A> IntoIterator for &'a VecDeque<T, A>
where A: Allocator,

1.0.0 · Source

impl<'a, T, A> IntoIterator for &'a rama::crypto::dep::x509_parser::prelude::asn1_rs::nom::lib::std::vec::Vec<T, A>
where A: Allocator,



impl<'a, T, A> IntoIterator for &'a HashTable<T, A>
where A: Allocator,



type Item = &'a T



type IntoIter = Iter<'a, T>



impl<'a, T, A> IntoIterator for &'a Vec<T, A>
where A: Allocator,



type Item = &'a T



type IntoIter = Iter<'a, T>

1.0.0 · Source

impl<'a, T, A> IntoIterator for &'a mut LinkedList<T, A>
where A: Allocator,

1.0.0 · Source

impl<'a, T, A> IntoIterator for &'a mut VecDeque<T, A>
where A: Allocator,

1.0.0 · Source

impl<'a, T, A> IntoIterator for &'a mut rama::crypto::dep::x509_parser::prelude::asn1_rs::nom::lib::std::vec::Vec<T, A>
where A: Allocator,



impl<'a, T, A> IntoIterator for &'a mut HashTable<T, A>
where A: Allocator,



type Item = &'a mut T



type IntoIter = IterMut<'a, T>



impl<'a, T, A> IntoIterator for &'a mut Vec<T, A>
where A: Allocator,



type Item = &'a mut T



type IntoIter = IterMut<'a, T>

1.4.0 · Source

impl<'a, T, E> IntoIterator for &'a Result<T, E>

1.4.0 · Source

impl<'a, T, E> IntoIterator for &'a mut Result<T, E>



impl<'a, T, N> IntoIterator for &'a GenericArray<T, N>
where T: 'a, N: ArrayLength<T>,



type IntoIter = Iter<'a, T>



type Item = &'a T



impl<'a, T, N> IntoIterator for &'a mut GenericArray<T, N>
where T: 'a, N: ArrayLength<T>,



type IntoIter = IterMut<'a, T>



type Item = &'a mut T

1.0.0 · Source

impl<'a, T, S> IntoIterator for &'a rama::crypto::dep::x509_parser::prelude::asn1_rs::nom::lib::std::collections::HashSet<T, S>



impl<'a, T, S> IntoIterator for &'a AHashSet<T, S>



type Item = &'a T



type IntoIter = Iter<'a, T>



impl<'a, T, S> IntoIterator for &'a IndexSet<T, S>



type Item = &'a T



type IntoIter = Iter<'a, T>



impl<'a, T, S, A> IntoIterator for &'a HashSet<T, S, A>
where A: Allocator,



type Item = &'a T



type IntoIter = Iter<'a, T>

1.0.0 · Source

impl<'a, T, const N: usize> IntoIterator for &'a [T; N]

1.0.0 · Source

impl<'a, T, const N: usize> IntoIterator for &'a mut [T; N]



impl<'r> IntoIterator for &'r ByteRecord



type IntoIter = ByteRecordIter<'r>



type Item = &'r [u8]



impl<'s, T> IntoIterator for SliceVec<'s, T>



type Item = &'s mut T



type IntoIter = IterMut<'s, T>

Source

impl<A> IntoIterator for Range<A>
where A: Step,

Source

impl<A> IntoIterator for RangeFrom<A>
where A: Step,

Source

impl<A> IntoIterator for RangeInclusive<A>
where A: Step,



impl<A> IntoIterator for ArrayVec<A>
where A: Array,



type Item = <A as Array>::Item



type IntoIter = ArrayVecIterator<A>



impl<A> IntoIterator for SmallVec<A>
where A: Array,



type IntoIter = IntoIter<A>



type Item = <A as Array>::Item



impl<A> IntoIterator for TinyVec<A>
where A: Array,



type Item = <A as Array>::Item



type IntoIter = TinyVecIterator<A>



impl<Fut> IntoIterator for FuturesUnordered<Fut>
where Fut: Unpin,



type Item = Fut



type IntoIter = IntoIter<Fut>



impl<I> IntoIterator for &RcIter<I>
where I: Iterator,

Return an iterator from &RcIter<I> (by simply cloning it).



type Item = <I as Iterator>::Item



type IntoIter = RcIter<I>

1.0.0 · Source

impl<I> IntoIterator for I
where I: Iterator,

1.80.0 · Source

impl<I, A> IntoIterator for Box<[I], A>
where A: Allocator,



impl<K, V> IntoIterator for Box<Slice<K, V>>



type IntoIter = IntoIter<K, V>



type Item = (K, V)

1.0.0 · Source

impl<K, V, A> IntoIterator for BTreeMap<K, V, A>
where A: Allocator + Clone,

1.0.0 · Source

impl<K, V, S> IntoIterator for rama::crypto::dep::x509_parser::prelude::asn1_rs::nom::lib::std::collections::HashMap<K, V, S>



impl<K, V, S> IntoIterator for AHashMap<K, V, S>



type Item = (K, V)



type IntoIter = IntoIter<K, V>



impl<K, V, S> IntoIterator for IndexMap<K, V, S>



type Item = (K, V)



type IntoIter = IntoIter<K, V>



impl<K, V, S> IntoIterator for LiteMap<K, V, S>
where S: StoreIntoIterator<K, V>,



type Item = (K, V)



type IntoIter = <S as StoreIntoIterator<K, V>>::KeyValueIntoIter



impl<K, V, S, A> IntoIterator for HashMap<K, V, S, A>
where A: Allocator,



type Item = (K, V)



type IntoIter = IntoIter<K, V, A>



impl<St> IntoIterator for SelectAll<St>
where St: Stream + Unpin,



type Item = St



type IntoIter = IntoIter<St>

1.0.0 · Source

impl<T> IntoIterator for Option<T>



impl<T> IntoIterator for HeaderMap<T>



impl<T> IntoIterator for Stack<T>
where T: Stackable,



type IntoIter = IntoIter<T>



type Item = T



impl<T> IntoIterator for NonEmptyVec<T>



impl<T> IntoIterator for Box<Slice<T>>



type IntoIter = IntoIter<T>



type Item = T

Source

impl<T> IntoIterator for std::sync::mpmc::Receiver<T>

1.1.0 · Source

impl<T> IntoIterator for std::sync::mpsc::Receiver<T>



impl<T> IntoIterator for CachedThreadLocal<T>
where T: Send,



type Item = T



type IntoIter = CachedIntoIter<T>



impl<T> IntoIterator for Receiver<T>



type Item = T



type IntoIter = IntoIter<T>



impl<T> IntoIterator for Receiver<T>



type Item = T



type IntoIter = IntoIter<T>



impl<T> IntoIterator for Slab<T>



type Item = (usize, T)



type IntoIter = IntoIter<T>



impl<T> IntoIterator for ThreadLocal<T>
where T: Send,



type Item = T



type IntoIter = IntoIter<T>

1.0.0 · Source

impl<T, A> IntoIterator for BTreeSet<T, A>
where A: Allocator + Clone,

1.0.0 · Source

impl<T, A> IntoIterator for BinaryHeap<T, A>
where A: Allocator,

1.0.0 · Source

impl<T, A> IntoIterator for LinkedList<T, A>
where A: Allocator,

1.0.0 · Source

impl<T, A> IntoIterator for VecDeque<T, A>
where A: Allocator,

1.0.0 · Source

impl<T, A> IntoIterator for rama::crypto::dep::x509_parser::prelude::asn1_rs::nom::lib::std::vec::Vec<T, A>
where A: Allocator,



impl<T, A> IntoIterator for HashTable<T, A>
where A: Allocator,



type Item = T



type IntoIter = IntoIter<T, A>



impl<T, A> IntoIterator for Vec<T, A>
where A: Allocator,



type Item = T



type IntoIter = IntoIter<T, A>

1.0.0 · Source

impl<T, E> IntoIterator for Result<T, E>



impl<T, N> IntoIterator for GenericArray<T, N>
where N: ArrayLength<T>,



type Item = T



type IntoIter = GenericArrayIter<T, N>

1.0.0 · Source

impl<T, S> IntoIterator for rama::crypto::dep::x509_parser::prelude::asn1_rs::nom::lib::std::collections::HashSet<T, S>



impl<T, S> IntoIterator for AHashSet<T, S>



type Item = T



type IntoIter = IntoIter<T>



impl<T, S> IntoIterator for IndexSet<T, S>



type Item = T



type IntoIter = IntoIter<T>



impl<T, S, A> IntoIterator for HashSet<T, S, A>
where A: Allocator,



type Item = T



type IntoIter = IntoIter<T, A>



impl<T, U> IntoIterator for Chain<T, U>
where T: Buf, U: Buf,



type Item = u8



type IntoIter = IntoIter<Chain<T, U>>

1.53.0 · Source

impl<T, const N: usize> IntoIterator for [T; N]



impl<T, const N: usize> IntoIterator for NichedOption<T, N>



type IntoIter = <Option<T> as IntoIterator>::IntoIter



type Item = T