Rem

Trait Rem 

1.0.0 (const: unstable) · Source
pub trait Rem<Rhs = Self> {
    type Output;

    // Required method
    fn rem(self, rhs: Rhs) -> Self::Output;
}
Available on crate features crypto and std only.
The remainder operator %.

Note that Rhs is Self by default, but this is not mandatory.

Examples

This example implements Rem on a SplitSlice object. After Rem is implemented, one can use the % operator to find out what the remaining elements of the slice would be after splitting it into equal slices of a given length.

use std::ops::Rem;

#[derive(PartialEq, Debug)]
struct SplitSlice<'a, T> {
    slice: &'a [T],
}

impl<'a, T> Rem<usize> for SplitSlice<'a, T> {
    type Output = Self;

    fn rem(self, modulus: usize) -> Self::Output {
        let len = self.slice.len();
        let rem = len % modulus;
        let start = len - rem;
        Self {slice: &self.slice[start..]}
    }
}

// If we were to divide &[0, 1, 2, 3, 4, 5, 6, 7] into slices of size 3,
// the remainder would be &[6, 7].
assert_eq!(SplitSlice { slice: &[0, 1, 2, 3, 4, 5, 6, 7] } % 3,
           SplitSlice { slice: &[6, 7] });

Required Associated Types

1.0.0 (const: unstable) · Source

type Output

The resulting type after applying the % operator.

Required Methods

1.0.0 (const: unstable) · Source

fn rem(self, rhs: Rhs) -> Self::Output

Performs the % operation.

Example
assert_eq!(12 % 10, 2);

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Rem for BigInt

Source

impl Rem for BigUint

1.74.0 (const: unstable) · Source

impl Rem for Saturating<i8>

1.74.0 (const: unstable) · Source

impl Rem for Saturating<i16>

1.74.0 (const: unstable) · Source

impl Rem for Saturating<i32>

1.74.0 (const: unstable) · Source

impl Rem for Saturating<i64>

1.74.0 (const: unstable) · Source

impl Rem for Saturating<i128>

1.74.0 (const: unstable) · Source

impl Rem for Saturating<isize>

1.74.0 (const: unstable) · Source

impl Rem for Saturating<u8>

1.74.0 (const: unstable) · Source

impl Rem for Saturating<u16>

1.74.0 (const: unstable) · Source

impl Rem for Saturating<u32>

1.74.0 (const: unstable) · Source

impl Rem for Saturating<u64>

1.74.0 (const: unstable) · Source

impl Rem for Saturating<u128>

1.74.0 (const: unstable) · Source

impl Rem for Saturating<usize>

1.7.0 (const: unstable) · Source

impl Rem for Wrapping<i8>

1.7.0 (const: unstable) · Source

impl Rem for Wrapping<i16>

1.7.0 (const: unstable) · Source

impl Rem for Wrapping<i32>

1.7.0 (const: unstable) · Source

impl Rem for Wrapping<i64>

1.7.0 (const: unstable) · Source

impl Rem for Wrapping<i128>

1.7.0 (const: unstable) · Source

impl Rem for Wrapping<isize>

1.7.0 (const: unstable) · Source

impl Rem for Wrapping<u8>

1.7.0 (const: unstable) · Source

impl Rem for Wrapping<u16>

1.7.0 (const: unstable) · Source

impl Rem for Wrapping<u32>

1.7.0 (const: unstable) · Source

impl Rem for Wrapping<u64>

1.7.0 (const: unstable) · Source

impl Rem for Wrapping<u128>

1.7.0 (const: unstable) · Source

impl Rem for Wrapping<usize>

1.0.0 (const: unstable) · Source

impl Rem for f16

The remainder from the division of two floats.

The remainder has the same sign as the dividend and is computed as: x - (x / y).trunc() * y.

Examples

let x: f32 = 50.50;
let y: f32 = 8.125;
let remainder = x - (x / y).trunc() * y;

// The answer to both operations is 1.75
assert_eq!(x % y, remainder);
1.0.0 (const: unstable) · Source

impl Rem for f32

The remainder from the division of two floats.

The remainder has the same sign as the dividend and is computed as: x - (x / y).trunc() * y.

Examples

let x: f32 = 50.50;
let y: f32 = 8.125;
let remainder = x - (x / y).trunc() * y;

// The answer to both operations is 1.75
assert_eq!(x % y, remainder);
1.0.0 (const: unstable) · Source

impl Rem for f64

The remainder from the division of two floats.

The remainder has the same sign as the dividend and is computed as: x - (x / y).trunc() * y.

Examples

let x: f32 = 50.50;
let y: f32 = 8.125;
let remainder = x - (x / y).trunc() * y;

// The answer to both operations is 1.75
assert_eq!(x % y, remainder);
1.0.0 (const: unstable) · Source

impl Rem for f128

The remainder from the division of two floats.

The remainder has the same sign as the dividend and is computed as: x - (x / y).trunc() * y.

Examples

let x: f32 = 50.50;
let y: f32 = 8.125;
let remainder = x - (x / y).trunc() * y;

// The answer to both operations is 1.75
assert_eq!(x % y, remainder);
1.0.0 (const: unstable) · Source

impl Rem for i8

This operation satisfies n % d == n - (n / d) * d. The result has the same sign as the left operand.

Panics

This operation will panic if other == 0 or if self / other results in overflow.

1.0.0 (const: unstable) · Source

impl Rem for i16

This operation satisfies n % d == n - (n / d) * d. The result has the same sign as the left operand.

Panics

This operation will panic if other == 0 or if self / other results in overflow.

1.0.0 (const: unstable) · Source

impl Rem for i32

This operation satisfies n % d == n - (n / d) * d. The result has the same sign as the left operand.

Panics

This operation will panic if other == 0 or if self / other results in overflow.

1.0.0 (const: unstable) · Source

impl Rem for i64

This operation satisfies n % d == n - (n / d) * d. The result has the same sign as the left operand.

Panics

This operation will panic if other == 0 or if self / other results in overflow.

1.0.0 (const: unstable) · Source

impl Rem for i128

This operation satisfies n % d == n - (n / d) * d. The result has the same sign as the left operand.

Panics

This operation will panic if other == 0 or if self / other results in overflow.

1.0.0 (const: unstable) · Source

impl Rem for isize

This operation satisfies n % d == n - (n / d) * d. The result has the same sign as the left operand.

Panics

This operation will panic if other == 0 or if self / other results in overflow.

1.0.0 (const: unstable) · Source

impl Rem for u8

This operation satisfies n % d == n - (n / d) * d. The result has the same sign as the left operand.

Panics

This operation will panic if other == 0.

1.0.0 (const: unstable) · Source

impl Rem for u16

This operation satisfies n % d == n - (n / d) * d. The result has the same sign as the left operand.

Panics

This operation will panic if other == 0.

1.0.0 (const: unstable) · Source

impl Rem for u32

This operation satisfies n % d == n - (n / d) * d. The result has the same sign as the left operand.

Panics

This operation will panic if other == 0.

1.0.0 (const: unstable) · Source

impl Rem for u64

This operation satisfies n % d == n - (n / d) * d. The result has the same sign as the left operand.

Panics

This operation will panic if other == 0.

1.0.0 (const: unstable) · Source

impl Rem for u128

This operation satisfies n % d == n - (n / d) * d. The result has the same sign as the left operand.

Panics

This operation will panic if other == 0.

1.0.0 (const: unstable) · Source

impl Rem for usize

This operation satisfies n % d == n - (n / d) * d. The result has the same sign as the left operand.

Panics

This operation will panic if other == 0.

Source

impl Rem<&BigInt> for &BigInt

Source

impl Rem<&BigInt> for &i8

Source

impl Rem<&BigInt> for &i16

Source

impl Rem<&BigInt> for &i32

Source

impl Rem<&BigInt> for &i64

Source

impl Rem<&BigInt> for &i128

Source

impl Rem<&BigInt> for &isize

Source

impl Rem<&BigInt> for &u8

Source

impl Rem<&BigInt> for &u16

Source

impl Rem<&BigInt> for &u32

Source

impl Rem<&BigInt> for &u64

Source

impl Rem<&BigInt> for &u128

Source

impl Rem<&BigInt> for &usize

Source

impl Rem<&BigInt> for BigInt

Source

impl Rem<&BigInt> for i8

Source

impl Rem<&BigInt> for i16

Source

impl Rem<&BigInt> for i32

Source

impl Rem<&BigInt> for i64

Source

impl Rem<&BigInt> for i128

Source

impl Rem<&BigInt> for isize

Source

impl Rem<&BigInt> for u8

Source

impl Rem<&BigInt> for u16

Source

impl Rem<&BigInt> for u32

Source

impl Rem<&BigInt> for u64

Source

impl Rem<&BigInt> for u128

Source

impl Rem<&BigInt> for usize

Source

impl Rem<&BigUint> for &BigUint

Source

impl Rem<&BigUint> for &u8

Source

impl Rem<&BigUint> for &u16

Source

impl Rem<&BigUint> for &u32

Source

impl Rem<&BigUint> for &u64

Source

impl Rem<&BigUint> for &u128

Source

impl Rem<&BigUint> for &usize

Source

impl Rem<&BigUint> for BigUint

Source

impl Rem<&BigUint> for u8

Source

impl Rem<&BigUint> for u16

Source

impl Rem<&BigUint> for u32

Source

impl Rem<&BigUint> for u64

Source

impl Rem<&BigUint> for u128

Source

impl Rem<&BigUint> for usize

1.74.0 (const: unstable) · Source

impl Rem<&Saturating<i8>> for &Saturating<i8>

1.74.0 (const: unstable) · Source

impl Rem<&Saturating<i8>> for Saturating<i8>

1.74.0 (const: unstable) · Source

impl Rem<&Saturating<i16>> for &Saturating<i16>

1.74.0 (const: unstable) · Source

impl Rem<&Saturating<i16>> for Saturating<i16>

1.74.0 (const: unstable) · Source

impl Rem<&Saturating<i32>> for &Saturating<i32>

1.74.0 (const: unstable) · Source

impl Rem<&Saturating<i32>> for Saturating<i32>

1.74.0 (const: unstable) · Source

impl Rem<&Saturating<i64>> for &Saturating<i64>

1.74.0 (const: unstable) · Source

impl Rem<&Saturating<i64>> for Saturating<i64>

1.74.0 (const: unstable) · Source

impl Rem<&Saturating<i128>> for &Saturating<i128>

1.74.0 (const: unstable) · Source

impl Rem<&Saturating<i128>> for Saturating<i128>

1.74.0 (const: unstable) · Source

impl Rem<&Saturating<isize>> for &Saturating<isize>

1.74.0 (const: unstable) · Source

impl Rem<&Saturating<isize>> for Saturating<isize>

1.74.0 (const: unstable) · Source

impl Rem<&Saturating<u8>> for &Saturating<u8>

1.74.0 (const: unstable) · Source

impl Rem<&Saturating<u8>> for Saturating<u8>

1.74.0 (const: unstable) · Source

impl Rem<&Saturating<u16>> for &Saturating<u16>

1.74.0 (const: unstable) · Source

impl Rem<&Saturating<u16>> for Saturating<u16>

1.74.0 (const: unstable) · Source

impl Rem<&Saturating<u32>> for &Saturating<u32>

1.74.0 (const: unstable) · Source

impl Rem<&Saturating<u32>> for Saturating<u32>

1.74.0 (const: unstable) · Source

impl Rem<&Saturating<u64>> for &Saturating<u64>

1.74.0 (const: unstable) · Source

impl Rem<&Saturating<u64>> for Saturating<u64>

1.74.0 (const: unstable) · Source

impl Rem<&Saturating<u128>> for &Saturating<u128>

1.74.0 (const: unstable) · Source

impl Rem<&Saturating<u128>> for Saturating<u128>

1.74.0 (const: unstable) · Source

impl Rem<&Saturating<usize>> for &Saturating<usize>

1.74.0 (const: unstable) · Source

impl Rem<&Saturating<usize>> for Saturating<usize>

1.14.0 (const: unstable) · Source

impl Rem<&Wrapping<i8>> for &Wrapping<i8>

1.14.0 (const: unstable) · Source

impl Rem<&Wrapping<i8>> for Wrapping<i8>

1.14.0 (const: unstable) · Source

impl Rem<&Wrapping<i16>> for &Wrapping<i16>

1.14.0 (const: unstable) · Source

impl Rem<&Wrapping<i16>> for Wrapping<i16>

1.14.0 (const: unstable) · Source

impl Rem<&Wrapping<i32>> for &Wrapping<i32>

1.14.0 (const: unstable) · Source

impl Rem<&Wrapping<i32>> for Wrapping<i32>

1.14.0 (const: unstable) · Source

impl Rem<&Wrapping<i64>> for &Wrapping<i64>

1.14.0 (const: unstable) · Source

impl Rem<&Wrapping<i64>> for Wrapping<i64>

1.14.0 (const: unstable) · Source

impl Rem<&Wrapping<i128>> for &Wrapping<i128>

1.14.0 (const: unstable) · Source

impl Rem<&Wrapping<i128>> for Wrapping<i128>

1.14.0 (const: unstable) · Source

impl Rem<&Wrapping<isize>> for &Wrapping<isize>

1.14.0 (const: unstable) · Source

impl Rem<&Wrapping<isize>> for Wrapping<isize>

1.14.0 (const: unstable) · Source

impl Rem<&Wrapping<u8>> for &Wrapping<u8>

1.14.0 (const: unstable) · Source

impl Rem<&Wrapping<u8>> for Wrapping<u8>

1.14.0 (const: unstable) · Source

impl Rem<&Wrapping<u16>> for &Wrapping<u16>

1.14.0 (const: unstable) · Source

impl Rem<&Wrapping<u16>> for Wrapping<u16>

1.14.0 (const: unstable) · Source

impl Rem<&Wrapping<u32>> for &Wrapping<u32>

1.14.0 (const: unstable) · Source

impl Rem<&Wrapping<u32>> for Wrapping<u32>

1.14.0 (const: unstable) · Source

impl Rem<&Wrapping<u64>> for &Wrapping<u64>

1.14.0 (const: unstable) · Source

impl Rem<&Wrapping<u64>> for Wrapping<u64>

1.14.0 (const: unstable) · Source

impl Rem<&Wrapping<u128>> for &Wrapping<u128>

1.14.0 (const: unstable) · Source

impl Rem<&Wrapping<u128>> for Wrapping<u128>

1.14.0 (const: unstable) · Source

impl Rem<&Wrapping<usize>> for &Wrapping<usize>

1.14.0 (const: unstable) · Source

impl Rem<&Wrapping<usize>> for Wrapping<usize>

1.0.0 (const: unstable) · Source

impl Rem<&f16> for &f16

1.0.0 (const: unstable) · Source

impl Rem<&f16> for f16

1.0.0 (const: unstable) · Source

impl Rem<&f32> for &f32

1.0.0 (const: unstable) · Source

impl Rem<&f32> for f32

1.0.0 (const: unstable) · Source

impl Rem<&f64> for &f64

1.0.0 (const: unstable) · Source

impl Rem<&f64> for f64

1.0.0 (const: unstable) · Source

impl Rem<&f128> for &f128

1.0.0 (const: unstable) · Source

impl Rem<&f128> for f128

Source

impl Rem<&i8> for &BigInt

1.0.0 (const: unstable) · Source

impl Rem<&i8> for &i8

Source

impl Rem<&i8> for BigInt

1.0.0 (const: unstable) · Source

impl Rem<&i8> for i8

Source

impl Rem<&i16> for &BigInt

1.0.0 (const: unstable) · Source

impl Rem<&i16> for &i16

Source

impl Rem<&i16> for BigInt

1.0.0 (const: unstable) · Source

impl Rem<&i16> for i16

Source

impl Rem<&i32> for &BigInt

1.0.0 (const: unstable) · Source

impl Rem<&i32> for &i32

Source

impl Rem<&i32> for BigInt

1.0.0 (const: unstable) · Source

impl Rem<&i32> for i32

Source

impl Rem<&i64> for &BigInt

1.0.0 (const: unstable) · Source

impl Rem<&i64> for &i64

Source

impl Rem<&i64> for BigInt

1.0.0 (const: unstable) · Source

impl Rem<&i64> for i64

Source

impl Rem<&i128> for &BigInt

1.0.0 (const: unstable) · Source

impl Rem<&i128> for &i128

Source

impl Rem<&i128> for BigInt

1.0.0 (const: unstable) · Source

impl Rem<&i128> for i128

Source

impl Rem<&isize> for &BigInt

1.0.0 (const: unstable) · Source

impl Rem<&isize> for &isize

Source

impl Rem<&isize> for BigInt

1.0.0 (const: unstable) · Source

impl Rem<&isize> for isize

Source

impl Rem<&u8> for &BigInt

Source

impl Rem<&u8> for &BigUint

1.0.0 (const: unstable) · Source

impl Rem<&u8> for &u8

Source

impl Rem<&u8> for BigInt

Source

impl Rem<&u8> for BigUint

1.0.0 (const: unstable) · Source

impl Rem<&u8> for u8

Source

impl Rem<&u16> for &BigInt

Source

impl Rem<&u16> for &BigUint

1.0.0 (const: unstable) · Source

impl Rem<&u16> for &u16

Source

impl Rem<&u16> for BigInt

Source

impl Rem<&u16> for BigUint

1.0.0 (const: unstable) · Source

impl Rem<&u16> for u16

Source

impl Rem<&u32> for &BigInt

Source

impl Rem<&u32> for &BigUint

1.0.0 (const: unstable) · Source

impl Rem<&u32> for &u32

Source

impl Rem<&u32> for BigInt

Source

impl Rem<&u32> for BigUint

1.0.0 (const: unstable) · Source

impl Rem<&u32> for u32

Source

impl Rem<&u64> for &BigInt

Source

impl Rem<&u64> for &BigUint

1.0.0 (const: unstable) · Source

impl Rem<&u64> for &u64

Source

impl Rem<&u64> for BigInt

Source

impl Rem<&u64> for BigUint

1.0.0 (const: unstable) · Source

impl Rem<&u64> for u64

Source

impl Rem<&u128> for &BigInt

Source

impl Rem<&u128> for &BigUint

1.0.0 (const: unstable) · Source

impl Rem<&u128> for &u128

Source

impl Rem<&u128> for BigInt

Source

impl Rem<&u128> for BigUint

1.0.0 (const: unstable) · Source

impl Rem<&u128> for u128

Source

impl Rem<&usize> for &BigInt

Source

impl Rem<&usize> for &BigUint

1.0.0 (const: unstable) · Source

impl Rem<&usize> for &usize

Source

impl Rem<&usize> for BigInt

Source

impl Rem<&usize> for BigUint

1.0.0 (const: unstable) · Source

impl Rem<&usize> for usize

Source

impl Rem<BigInt> for &BigInt

Source

impl Rem<BigInt> for &i8

Source

impl Rem<BigInt> for &i16

Source

impl Rem<BigInt> for &i32

Source

impl Rem<BigInt> for &i64

Source

impl Rem<BigInt> for &i128

Source

impl Rem<BigInt> for &isize

Source

impl Rem<BigInt> for &u8

Source

impl Rem<BigInt> for &u16

Source

impl Rem<BigInt> for &u32

Source

impl Rem<BigInt> for &u64

Source

impl Rem<BigInt> for &u128

Source

impl Rem<BigInt> for &usize

Source

impl Rem<BigInt> for i8

Source

impl Rem<BigInt> for i16

Source

impl Rem<BigInt> for i32

Source

impl Rem<BigInt> for i64

Source

impl Rem<BigInt> for i128

Source

impl Rem<BigInt> for isize

Source

impl Rem<BigInt> for u8

Source

impl Rem<BigInt> for u16

Source

impl Rem<BigInt> for u32

Source

impl Rem<BigInt> for u64

Source

impl Rem<BigInt> for u128

Source

impl Rem<BigInt> for usize

Source

impl Rem<BigUint> for &BigUint

Source

impl Rem<BigUint> for &u8

Source

impl Rem<BigUint> for &u16

Source

impl Rem<BigUint> for &u32

Source

impl Rem<BigUint> for &u64

Source

impl Rem<BigUint> for &u128

Source

impl Rem<BigUint> for &usize

Source

impl Rem<BigUint> for u8

Source

impl Rem<BigUint> for u16

Source

impl Rem<BigUint> for u32

Source

impl Rem<BigUint> for u64

Source

impl Rem<BigUint> for u128

Source

impl Rem<BigUint> for usize

1.51.0 (const: unstable) · Source

impl Rem<NonZero<u8>> for u8

1.51.0 (const: unstable) · Source

impl Rem<NonZero<u16>> for u16

1.51.0 (const: unstable) · Source

impl Rem<NonZero<u32>> for u32

1.51.0 (const: unstable) · Source

impl Rem<NonZero<u64>> for u64

1.51.0 (const: unstable) · Source

impl Rem<NonZero<u128>> for u128

1.51.0 (const: unstable) · Source

impl Rem<NonZero<usize>> for usize

1.74.0 (const: unstable) · Source

impl Rem<Saturating<i8>> for &Saturating<i8>

1.74.0 (const: unstable) · Source

impl Rem<Saturating<i16>> for &Saturating<i16>

1.74.0 (const: unstable) · Source

impl Rem<Saturating<i32>> for &Saturating<i32>

1.74.0 (const: unstable) · Source

impl Rem<Saturating<i64>> for &Saturating<i64>

1.74.0 (const: unstable) · Source

impl Rem<Saturating<i128>> for &Saturating<i128>

1.74.0 (const: unstable) · Source

impl Rem<Saturating<isize>> for &Saturating<isize>

1.74.0 (const: unstable) · Source

impl Rem<Saturating<u8>> for &Saturating<u8>

1.74.0 (const: unstable) · Source

impl Rem<Saturating<u16>> for &Saturating<u16>

1.74.0 (const: unstable) · Source

impl Rem<Saturating<u32>> for &Saturating<u32>

1.74.0 (const: unstable) · Source

impl Rem<Saturating<u64>> for &Saturating<u64>

1.74.0 (const: unstable) · Source

impl Rem<Saturating<u128>> for &Saturating<u128>

1.74.0 (const: unstable) · Source

impl Rem<Saturating<usize>> for &Saturating<usize>

1.14.0 (const: unstable) · Source

impl Rem<Wrapping<i8>> for &Wrapping<i8>

1.14.0 (const: unstable) · Source

impl Rem<Wrapping<i16>> for &Wrapping<i16>

1.14.0 (const: unstable) · Source

impl Rem<Wrapping<i32>> for &Wrapping<i32>

1.14.0 (const: unstable) · Source

impl Rem<Wrapping<i64>> for &Wrapping<i64>

1.14.0 (const: unstable) · Source

impl Rem<Wrapping<i128>> for &Wrapping<i128>

1.14.0 (const: unstable) · Source

impl Rem<Wrapping<isize>> for &Wrapping<isize>

1.14.0 (const: unstable) · Source

impl Rem<Wrapping<u8>> for &Wrapping<u8>

1.14.0 (const: unstable) · Source

impl Rem<Wrapping<u16>> for &Wrapping<u16>

1.14.0 (const: unstable) · Source

impl Rem<Wrapping<u32>> for &Wrapping<u32>

1.14.0 (const: unstable) · Source

impl Rem<Wrapping<u64>> for &Wrapping<u64>

1.14.0 (const: unstable) · Source

impl Rem<Wrapping<u128>> for &Wrapping<u128>

1.14.0 (const: unstable) · Source

impl Rem<Wrapping<usize>> for &Wrapping<usize>

1.0.0 (const: unstable) · Source

impl Rem<f16> for &f16

1.0.0 (const: unstable) · Source

impl Rem<f32> for &f32

1.0.0 (const: unstable) · Source

impl Rem<f64> for &f64

1.0.0 (const: unstable) · Source

impl Rem<f128> for &f128

Source

impl Rem<i8> for &BigInt

1.0.0 (const: unstable) · Source

impl Rem<i8> for &i8

Source

impl Rem<i8> for BigInt

Source

impl Rem<i16> for &BigInt

1.0.0 (const: unstable) · Source

impl Rem<i16> for &i16

Source

impl Rem<i16> for BigInt

Source

impl Rem<i32> for &BigInt

1.0.0 (const: unstable) · Source

impl Rem<i32> for &i32

Source

impl Rem<i32> for BigInt

Source

impl Rem<i64> for &BigInt

1.0.0 (const: unstable) · Source

impl Rem<i64> for &i64

Source

impl Rem<i64> for BigInt

Source

impl Rem<i128> for &BigInt

1.0.0 (const: unstable) · Source

impl Rem<i128> for &i128

Source

impl Rem<i128> for BigInt

Source

impl Rem<isize> for &BigInt

1.0.0 (const: unstable) · Source

impl Rem<isize> for &isize

Source

impl Rem<isize> for BigInt

Source

impl Rem<u8> for &BigInt

Source

impl Rem<u8> for &BigUint

1.0.0 (const: unstable) · Source

impl Rem<u8> for &u8

Source

impl Rem<u8> for BigInt

Source

impl Rem<u8> for BigUint

Source

impl Rem<u16> for &BigInt

Source

impl Rem<u16> for &BigUint

1.0.0 (const: unstable) · Source

impl Rem<u16> for &u16

Source

impl Rem<u16> for BigInt

Source

impl Rem<u16> for BigUint

Source

impl Rem<u32> for &BigInt

Source

impl Rem<u32> for &BigUint

1.0.0 (const: unstable) · Source

impl Rem<u32> for &u32

Source

impl Rem<u32> for BigInt

Source

impl Rem<u32> for BigUint

Source

impl Rem<u64> for &BigInt

Source

impl Rem<u64> for &BigUint

1.0.0 (const: unstable) · Source

impl Rem<u64> for &u64

Source

impl Rem<u64> for BigInt

Source

impl Rem<u64> for BigUint

Source

impl Rem<u128> for &BigInt

Source

impl Rem<u128> for &BigUint

1.0.0 (const: unstable) · Source

impl Rem<u128> for &u128

Source

impl Rem<u128> for BigInt

Source

impl Rem<u128> for BigUint

Source

impl Rem<usize> for &BigInt

Source

impl Rem<usize> for &BigUint

1.0.0 (const: unstable) · Source

impl Rem<usize> for &usize

Source

impl Rem<usize> for BigInt

Source

impl Rem<usize> for BigUint



impl<'a, 'b> Rem<&'b BigNum> for &'a BigNum



impl<'a, 'b> Rem<&'b BigNum> for &'a BigNumRef



impl<'a, 'b> Rem<&'b BigNumRef> for &'a BigNum



impl<'b> Rem<&'b BigNumRef> for &BigNumRef

Source

impl<'lhs, 'rhs, T, const N: usize> Rem<&'rhs Simd<T, N>> for &'lhs Simd<T, N>
where T: SimdElement, Simd<T, N>: Rem<Output = Simd<T, N>>,

Source

type Output = Simd<T, N>

Source

impl<I> Rem<I> for Z0
where I: Integer + NonZero,

Z0 % I = Z0 where I != 0



impl<O> Rem for F32<O>
where O: ByteOrder,



type Output = F32<O>



impl<O> Rem for F64<O>
where O: ByteOrder,



type Output = F64<O>



impl<O> Rem for I16<O>
where O: ByteOrder,



type Output = I16<O>



impl<O> Rem for I32<O>
where O: ByteOrder,



type Output = I32<O>



impl<O> Rem for I64<O>
where O: ByteOrder,



type Output = I64<O>



impl<O> Rem for I128<O>
where O: ByteOrder,



type Output = I128<O>



impl<O> Rem for Isize<O>
where O: ByteOrder,



type Output = Isize<O>



impl<O> Rem for U16<O>
where O: ByteOrder,



type Output = U16<O>



impl<O> Rem for U32<O>
where O: ByteOrder,



type Output = U32<O>



impl<O> Rem for U64<O>
where O: ByteOrder,



type Output = U64<O>



impl<O> Rem for U128<O>
where O: ByteOrder,



type Output = U128<O>



impl<O> Rem for Usize<O>
where O: ByteOrder,



type Output = Usize<O>



impl<O> Rem<F32<O>> for f32
where O: ByteOrder,



type Output = F32<O>



impl<O> Rem<F64<O>> for f64
where O: ByteOrder,



type Output = F64<O>



impl<O> Rem<I16<O>> for i16
where O: ByteOrder,



type Output = I16<O>



impl<O> Rem<I32<O>> for i32
where O: ByteOrder,



type Output = I32<O>



impl<O> Rem<I64<O>> for i64
where O: ByteOrder,



type Output = I64<O>



impl<O> Rem<I128<O>> for i128
where O: ByteOrder,



type Output = I128<O>



impl<O> Rem<Isize<O>> for isize
where O: ByteOrder,



type Output = Isize<O>



impl<O> Rem<U16<O>> for u16
where O: ByteOrder,



type Output = U16<O>



impl<O> Rem<U32<O>> for u32
where O: ByteOrder,



type Output = U32<O>



impl<O> Rem<U64<O>> for u64
where O: ByteOrder,



type Output = U64<O>



impl<O> Rem<U128<O>> for u128
where O: ByteOrder,



type Output = U128<O>



impl<O> Rem<Usize<O>> for usize
where O: ByteOrder,



type Output = Usize<O>



impl<O> Rem<f32> for F32<O>
where O: ByteOrder,



type Output = F32<O>



impl<O> Rem<f64> for F64<O>
where O: ByteOrder,



type Output = F64<O>



impl<O> Rem<i16> for I16<O>
where O: ByteOrder,



type Output = I16<O>



impl<O> Rem<i32> for I32<O>
where O: ByteOrder,



type Output = I32<O>



impl<O> Rem<i64> for I64<O>
where O: ByteOrder,



type Output = I64<O>



impl<O> Rem<i128> for I128<O>
where O: ByteOrder,



type Output = I128<O>



impl<O> Rem<isize> for Isize<O>
where O: ByteOrder,



type Output = Isize<O>



impl<O> Rem<u16> for U16<O>
where O: ByteOrder,



type Output = U16<O>



impl<O> Rem<u32> for U32<O>
where O: ByteOrder,



type Output = U32<O>



impl<O> Rem<u64> for U64<O>
where O: ByteOrder,



type Output = U64<O>



impl<O> Rem<u128> for U128<O>
where O: ByteOrder,



type Output = U128<O>



impl<O> Rem<usize> for Usize<O>
where O: ByteOrder,



type Output = Usize<O>

Source

impl<Rhs> Rem<Rhs> for ATerm

Source

impl<T, const N: usize> Rem<&Simd<T, N>> for Simd<T, N>
where T: SimdElement, Simd<T, N>: Rem<Output = Simd<T, N>>,

Source

type Output = Simd<T, N>

Source

impl<T, const N: usize> Rem<Simd<T, N>> for &Simd<T, N>
where T: SimdElement, Simd<T, N>: Rem<Output = Simd<T, N>>,

Source

type Output = Simd<T, N>

Source

impl<Ul, Bl, Ur, Br> Rem<UInt<Ur, Br>> for UInt<Ul, Bl>
where Ul: Unsigned, Bl: Bit, Ur: Unsigned, Br: Bit, UInt<Ul, Bl>: Len, <UInt<Ul, Bl> as Len>::Output: Sub<B1>, (): PrivateDiv<UInt<Ul, Bl>, UInt<Ur, Br>, UTerm, UTerm, <<UInt<Ul, Bl> as Len>::Output as Sub<B1>>::Output>,

Source

type Output = <() as PrivateDiv<UInt<Ul, Bl>, UInt<Ur, Br>, UTerm, UTerm, <<UInt<Ul, Bl> as Len>::Output as Sub<B1>>::Output>>::Remainder

Source

impl<Ul, Ur> Rem<NInt<Ur>> for NInt<Ul>
where Ul: Unsigned + NonZero + Rem<Ur>, Ur: Unsigned + NonZero, NInt<Ul>: PrivateRem<<Ul as Rem<Ur>>::Output, NInt<Ur>>,

$A<Ul> % $B<Ur> = $R<Ul % Ur>

Source

type Output = <NInt<Ul> as PrivateRem<<Ul as Rem<Ur>>::Output, NInt<Ur>>>::Output

Source

impl<Ul, Ur> Rem<NInt<Ur>> for PInt<Ul>
where Ul: Unsigned + NonZero + Rem<Ur>, Ur: Unsigned + NonZero, PInt<Ul>: PrivateRem<<Ul as Rem<Ur>>::Output, NInt<Ur>>,

$A<Ul> % $B<Ur> = $R<Ul % Ur>

Source

type Output = <PInt<Ul> as PrivateRem<<Ul as Rem<Ur>>::Output, NInt<Ur>>>::Output

Source

impl<Ul, Ur> Rem<PInt<Ur>> for NInt<Ul>
where Ul: Unsigned + NonZero + Rem<Ur>, Ur: Unsigned + NonZero, NInt<Ul>: PrivateRem<<Ul as Rem<Ur>>::Output, PInt<Ur>>,

$A<Ul> % $B<Ur> = $R<Ul % Ur>

Source

type Output = <NInt<Ul> as PrivateRem<<Ul as Rem<Ur>>::Output, PInt<Ur>>>::Output

Source

impl<Ul, Ur> Rem<PInt<Ur>> for PInt<Ul>
where Ul: Unsigned + NonZero + Rem<Ur>, Ur: Unsigned + NonZero, PInt<Ul>: PrivateRem<<Ul as Rem<Ur>>::Output, PInt<Ur>>,

$A<Ul> % $B<Ur> = $R<Ul % Ur>

Source

type Output = <PInt<Ul> as PrivateRem<<Ul as Rem<Ur>>::Output, PInt<Ur>>>::Output

Source

impl<Ur, Br> Rem<UInt<Ur, Br>> for UTerm
where Ur: Unsigned, Br: Bit,

Source

impl<V, A, Rhs> Rem<Rhs> for TArr<V, A>
where V: Rem<Rhs>, A: Rem<Rhs>, Rhs: Copy,

Source

type Output = TArr<<V as Rem<Rhs>>::Output, <A as Rem<Rhs>>::Output>

Source

impl<const N: usize> Rem for Simd<f16, N>

Source

impl<const N: usize> Rem for Simd<f32, N>

Source

impl<const N: usize> Rem for Simd<f64, N>

Source

impl<const N: usize> Rem for Simd<i8, N>
where i8: SimdElement,

Source

impl<const N: usize> Rem for Simd<i16, N>

Source

impl<const N: usize> Rem for Simd<i32, N>

Source

impl<const N: usize> Rem for Simd<i64, N>

Source

impl<const N: usize> Rem for Simd<isize, N>

Source

impl<const N: usize> Rem for Simd<u8, N>
where u8: SimdElement,

Source

impl<const N: usize> Rem for Simd<u16, N>

Source

impl<const N: usize> Rem for Simd<u32, N>

Source

impl<const N: usize> Rem for Simd<u64, N>

Source

impl<const N: usize> Rem for Simd<usize, N>