Sub

Trait Sub 

1.0.0 (const: unstable) · Source
pub trait Sub<Rhs = Self> {
    type Output;

    // Required method
    fn sub(self, rhs: Rhs) -> Self::Output;
}
The subtraction operator -.

Note that Rhs is Self by default, but this is not mandatory. For example, std::time::SystemTime implements Sub<Duration>, which permits operations of the form SystemTime = SystemTime - Duration.

Examples

Subtractable points

use std::ops::Sub;

#[derive(Debug, Copy, Clone, PartialEq)]
struct Point {
    x: i32,
    y: i32,
}

impl Sub for Point {
    type Output = Self;

    fn sub(self, other: Self) -> Self::Output {
        Self {
            x: self.x - other.x,
            y: self.y - other.y,
        }
    }
}

assert_eq!(Point { x: 3, y: 3 } - Point { x: 2, y: 3 },
           Point { x: 1, y: 0 });

Implementing Sub with generics

Here is an example of the same Point struct implementing the Sub trait using generics.

use std::ops::Sub;

#[derive(Debug, PartialEq)]
struct Point<T> {
    x: T,
    y: T,
}

// Notice that the implementation uses the associated type `Output`.
impl<T: Sub<Output = T>> Sub for Point<T> {
    type Output = Self;

    fn sub(self, other: Self) -> Self::Output {
        Point {
            x: self.x - other.x,
            y: self.y - other.y,
        }
    }
}

assert_eq!(Point { x: 2, y: 3 } - Point { x: 1, y: 0 },
           Point { x: 1, y: 3 });

Required Associated Types

1.0.0 · Source

type Output

The resulting type after applying the - operator.

Required Methods

1.0.0 · Source

fn sub(self, rhs: Rhs) -> Self::Output

Performs the - operation.

Example
assert_eq!(12 - 1, 11);

Implementors

1.0.0 (const: unstable) · Source

impl Sub for f16

1.0.0 (const: unstable) · Source

impl Sub for f32

1.0.0 (const: unstable) · Source

impl Sub for f64

1.0.0 (const: unstable) · Source

impl Sub for f128

1.0.0 (const: unstable) · Source

impl Sub for i8

1.0.0 (const: unstable) · Source

impl Sub for i16

1.0.0 (const: unstable) · Source

impl Sub for i32

1.0.0 (const: unstable) · Source

impl Sub for i64

1.0.0 (const: unstable) · Source

impl Sub for i128

1.0.0 (const: unstable) · Source

impl Sub for isize

1.0.0 (const: unstable) · Source

impl Sub for u8

1.0.0 (const: unstable) · Source

impl Sub for u16

1.0.0 (const: unstable) · Source

impl Sub for u32

1.0.0 (const: unstable) · Source

impl Sub for u64

1.0.0 (const: unstable) · Source

impl Sub for u128

1.0.0 (const: unstable) · Source

impl Sub for usize



impl Sub for ShutdownState



impl Sub for SslMode



impl Sub for SslOptions



impl Sub for SslSessionCacheMode



impl Sub for SslVerifyMode



impl Sub for X509CheckFlags



impl Sub for X509VerifyFlags

Source

impl Sub for BigInt

Source

impl Sub for BigUint



impl Sub for ASN1Time



type Output = Option<Duration>

Source

impl Sub for Assume

1.74.0 (const: unstable) · Source

impl Sub for Saturating<i8>

1.74.0 (const: unstable) · Source

impl Sub for Saturating<i16>

1.74.0 (const: unstable) · Source

impl Sub for Saturating<i32>

1.74.0 (const: unstable) · Source

impl Sub for Saturating<i64>

1.74.0 (const: unstable) · Source

impl Sub for Saturating<i128>

1.74.0 (const: unstable) · Source

impl Sub for Saturating<isize>

1.74.0 (const: unstable) · Source

impl Sub for Saturating<u8>

1.74.0 (const: unstable) · Source

impl Sub for Saturating<u16>

1.74.0 (const: unstable) · Source

impl Sub for Saturating<u32>

1.74.0 (const: unstable) · Source

impl Sub for Saturating<u64>

1.74.0 (const: unstable) · Source

impl Sub for Saturating<u128>

1.74.0 (const: unstable) · Source

impl Sub for Saturating<usize>

1.0.0 (const: unstable) · Source

impl Sub for Wrapping<i8>

1.0.0 (const: unstable) · Source

impl Sub for Wrapping<i16>

1.0.0 (const: unstable) · Source

impl Sub for Wrapping<i32>

1.0.0 (const: unstable) · Source

impl Sub for Wrapping<i64>

1.0.0 (const: unstable) · Source

impl Sub for Wrapping<i128>

1.0.0 (const: unstable) · Source

impl Sub for Wrapping<isize>

1.0.0 (const: unstable) · Source

impl Sub for Wrapping<u8>

1.0.0 (const: unstable) · Source

impl Sub for Wrapping<u16>

1.0.0 (const: unstable) · Source

impl Sub for Wrapping<u32>

1.0.0 (const: unstable) · Source

impl Sub for Wrapping<u64>

1.0.0 (const: unstable) · Source

impl Sub for Wrapping<u128>

1.0.0 (const: unstable) · Source

impl Sub for Wrapping<usize>

1.3.0 (const: unstable) · Source

impl Sub for core::time::Duration

1.8.0 · Source

impl Sub for std::time::Instant

Source

impl Sub for ATerm

Source

impl Sub for Z0

Z0 - Z0 = Z0

Source

impl Sub for UTerm

UTerm - UTerm = UTerm



impl Sub for Access



type Output = Access



impl Sub for AtFlags



type Output = AtFlags



impl Sub for CreateFlags



type Output = CreateFlags



impl Sub for Date



type Output = Duration



impl Sub for Date

Computes the span of time between two dates.

This will return a negative span when the date being subtracted is greater.

Since this uses the default configuration for calculating a span between two date (no rounding and largest units is days), this will never panic or fail in any way.

To configure the largest unit or enable rounding, use [Date::since].



type Output = Span



impl Sub for DateTime

Computes the span of time between two datetimes.

This will return a negative span when the datetime being subtracted is greater.

Since this uses the default configuration for calculating a span between two datetimes (no rounding and largest units is days), this will never panic or fail in any way. It is guaranteed that the largest non-zero unit in the Span returned will be days.

To configure the largest unit or enable rounding, use [DateTime::since].

If you need a [SignedDuration] representing the span between two civil datetimes, then use [DateTime::duration_since].



type Output = Span



impl Sub for DupFlags



type Output = DupFlags



impl Sub for Duration



type Output = Duration



impl Sub for FallocateFlags



type Output = FallocateFlags



impl Sub for FdFlags



type Output = FdFlags



impl Sub for IFlags



type Output = IFlags



impl Sub for Instant



impl Sub for MemfdFlags



type Output = MemfdFlags



impl Sub for Mode



type Output = Mode



impl Sub for OFlags



type Output = OFlags



impl Sub for Offset

Computes the span of time between two offsets.

This will return a negative span when the offset being subtracted is greater (i.e., more east with respect to the prime meridian).



type Output = Span



impl Sub for OffsetDateTime



type Output = Duration



impl Sub for PrimitiveDateTime



type Output = Duration



impl Sub for ReadFlags



type Output = ReadFlags



impl Sub for ReadWriteFlags



type Output = ReadWriteFlags



impl Sub for Ready



type Output = Ready



impl Sub for RenameFlags



type Output = RenameFlags



impl Sub for ResolveFlags



type Output = ResolveFlags



impl Sub for Rgb



type Output = Rgb



impl Sub for SealFlags



type Output = SealFlags



impl Sub for SignedDuration



type Output = SignedDuration



impl Sub for StatVfsMountFlags



type Output = StatVfsMountFlags



impl Sub for StatxAttributes



type Output = StatxAttributes



impl Sub for StatxFlags



type Output = StatxFlags



impl Sub for Time



type Output = Duration



impl Sub for Time

Computes the span of time between two times.

This will return a negative span when the time being subtracted is greater.

Since this uses the default configuration for calculating a span between two times (no rounding and largest units is hours), this will never panic or fail in any way.

To configure the largest unit or enable rounding, use [Time::since].



type Output = Span



impl Sub for Timespec



type Output = Timespec



impl Sub for Timestamp

Computes the span of time between two timestamps.

This will return a negative span when the timestamp being subtracted is greater.

Since this uses the default configuration for calculating a span between two timestamps (no rounding and largest units is seconds), this will never panic or fail in any way.

To configure the largest unit or enable rounding, use [Timestamp::since].



type Output = Span



impl Sub for UtcDateTime



type Output = Duration



impl Sub for WatchFlags



type Output = WatchFlags



impl Sub for XattrFlags



type Output = XattrFlags



impl Sub for Zoned

Computes the span of time between two zoned datetimes.

This will return a negative span when the zoned datetime being subtracted is greater.

Since this uses the default configuration for calculating a span between two zoned datetimes (no rounding and largest units is hours), this will never panic or fail in any way. It is guaranteed that the largest non-zero unit in the Span returned will be hours.

To configure the largest unit or enable rounding, use [Zoned::since].

Using this implementation will result in consuming the Zoned value. Since it is not Copy, this will prevent further use. If this is undesirable, consider using the trait implementation for &Zoned, Zoned::since, Zoned::until or cloning the Zoned value.



type Output = Span

1.0.0 (const: unstable) · Source

impl Sub<&f16> for &f16

1.0.0 (const: unstable) · Source

impl Sub<&f16> for f16

1.0.0 (const: unstable) · Source

impl Sub<&f32> for &f32

1.0.0 (const: unstable) · Source

impl Sub<&f32> for f32

1.0.0 (const: unstable) · Source

impl Sub<&f64> for &f64

1.0.0 (const: unstable) · Source

impl Sub<&f64> for f64

1.0.0 (const: unstable) · Source

impl Sub<&f128> for &f128

1.0.0 (const: unstable) · Source

impl Sub<&f128> for f128

1.0.0 (const: unstable) · Source

impl Sub<&i8> for &i8

Source

impl Sub<&i8> for &BigInt

1.0.0 (const: unstable) · Source

impl Sub<&i8> for i8

Source

impl Sub<&i8> for BigInt

1.0.0 (const: unstable) · Source

impl Sub<&i16> for &i16

Source

impl Sub<&i16> for &BigInt

1.0.0 (const: unstable) · Source

impl Sub<&i16> for i16

Source

impl Sub<&i16> for BigInt

1.0.0 (const: unstable) · Source

impl Sub<&i32> for &i32

Source

impl Sub<&i32> for &BigInt

1.0.0 (const: unstable) · Source

impl Sub<&i32> for i32

Source

impl Sub<&i32> for BigInt

1.0.0 (const: unstable) · Source

impl Sub<&i64> for &i64

Source

impl Sub<&i64> for &BigInt

1.0.0 (const: unstable) · Source

impl Sub<&i64> for i64

Source

impl Sub<&i64> for BigInt

1.0.0 (const: unstable) · Source

impl Sub<&i128> for &i128

Source

impl Sub<&i128> for &BigInt

1.0.0 (const: unstable) · Source

impl Sub<&i128> for i128

Source

impl Sub<&i128> for BigInt

1.0.0 (const: unstable) · Source

impl Sub<&isize> for &isize

Source

impl Sub<&isize> for &BigInt

1.0.0 (const: unstable) · Source

impl Sub<&isize> for isize

Source

impl Sub<&isize> for BigInt

1.0.0 (const: unstable) · Source

impl Sub<&u8> for &u8

Source

impl Sub<&u8> for &BigInt

Source

impl Sub<&u8> for &BigUint

1.0.0 (const: unstable) · Source

impl Sub<&u8> for u8

Source

impl Sub<&u8> for BigInt

Source

impl Sub<&u8> for BigUint

1.0.0 (const: unstable) · Source

impl Sub<&u16> for &u16

Source

impl Sub<&u16> for &BigInt

Source

impl Sub<&u16> for &BigUint

1.0.0 (const: unstable) · Source

impl Sub<&u16> for u16

Source

impl Sub<&u16> for BigInt

Source

impl Sub<&u16> for BigUint

1.0.0 (const: unstable) · Source

impl Sub<&u32> for &u32

Source

impl Sub<&u32> for &BigInt

Source

impl Sub<&u32> for &BigUint

1.0.0 (const: unstable) · Source

impl Sub<&u32> for u32

Source

impl Sub<&u32> for BigInt

Source

impl Sub<&u32> for BigUint

1.0.0 (const: unstable) · Source

impl Sub<&u64> for &u64

Source

impl Sub<&u64> for &BigInt

Source

impl Sub<&u64> for &BigUint

1.0.0 (const: unstable) · Source

impl Sub<&u64> for u64

Source

impl Sub<&u64> for BigInt

Source

impl Sub<&u64> for BigUint

1.0.0 (const: unstable) · Source

impl Sub<&u128> for &u128

Source

impl Sub<&u128> for &BigInt

Source

impl Sub<&u128> for &BigUint

1.0.0 (const: unstable) · Source

impl Sub<&u128> for u128

Source

impl Sub<&u128> for BigInt

Source

impl Sub<&u128> for BigUint

1.0.0 (const: unstable) · Source

impl Sub<&usize> for &usize

Source

impl Sub<&usize> for &BigInt

Source

impl Sub<&usize> for &BigUint

1.0.0 (const: unstable) · Source

impl Sub<&usize> for usize

Source

impl Sub<&usize> for BigInt

Source

impl Sub<&usize> for BigUint



impl Sub<&BigNumRef> for &BigNumRef

Source

impl Sub<&BigInt> for &i8

Source

impl Sub<&BigInt> for &i16

Source

impl Sub<&BigInt> for &i32

Source

impl Sub<&BigInt> for &i64

Source

impl Sub<&BigInt> for &i128

Source

impl Sub<&BigInt> for &isize

Source

impl Sub<&BigInt> for &u8

Source

impl Sub<&BigInt> for &u16

Source

impl Sub<&BigInt> for &u32

Source

impl Sub<&BigInt> for &u64

Source

impl Sub<&BigInt> for &u128

Source

impl Sub<&BigInt> for &usize

Source

impl Sub<&BigInt> for &BigInt

Source

impl Sub<&BigInt> for i8

Source

impl Sub<&BigInt> for i16

Source

impl Sub<&BigInt> for i32

Source

impl Sub<&BigInt> for i64

Source

impl Sub<&BigInt> for i128

Source

impl Sub<&BigInt> for isize

Source

impl Sub<&BigInt> for u8

Source

impl Sub<&BigInt> for u16

Source

impl Sub<&BigInt> for u32

Source

impl Sub<&BigInt> for u64

Source

impl Sub<&BigInt> for u128

Source

impl Sub<&BigInt> for usize

Source

impl Sub<&BigInt> for BigInt

Source

impl Sub<&BigUint> for &u8

Source

impl Sub<&BigUint> for &u16

Source

impl Sub<&BigUint> for &u32

Source

impl Sub<&BigUint> for &u64

Source

impl Sub<&BigUint> for &u128

Source

impl Sub<&BigUint> for &usize

Source

impl Sub<&BigUint> for &BigUint

Source

impl Sub<&BigUint> for u8

Source

impl Sub<&BigUint> for u16

Source

impl Sub<&BigUint> for u32

Source

impl Sub<&BigUint> for u64

Source

impl Sub<&BigUint> for u128

Source

impl Sub<&BigUint> for usize

Source

impl Sub<&BigUint> for BigUint

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<i8>> for &Saturating<i8>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<i8>> for Saturating<i8>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<i16>> for &Saturating<i16>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<i16>> for Saturating<i16>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<i32>> for &Saturating<i32>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<i32>> for Saturating<i32>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<i64>> for &Saturating<i64>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<i64>> for Saturating<i64>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<i128>> for &Saturating<i128>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<i128>> for Saturating<i128>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<isize>> for &Saturating<isize>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<isize>> for Saturating<isize>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<u8>> for &Saturating<u8>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<u8>> for Saturating<u8>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<u16>> for &Saturating<u16>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<u16>> for Saturating<u16>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<u32>> for &Saturating<u32>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<u32>> for Saturating<u32>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<u64>> for &Saturating<u64>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<u64>> for Saturating<u64>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<u128>> for &Saturating<u128>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<u128>> for Saturating<u128>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<usize>> for &Saturating<usize>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<usize>> for Saturating<usize>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<i8>> for &Wrapping<i8>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<i8>> for Wrapping<i8>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<i16>> for &Wrapping<i16>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<i16>> for Wrapping<i16>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<i32>> for &Wrapping<i32>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<i32>> for Wrapping<i32>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<i64>> for &Wrapping<i64>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<i64>> for Wrapping<i64>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<i128>> for &Wrapping<i128>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<i128>> for Wrapping<i128>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<isize>> for &Wrapping<isize>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<isize>> for Wrapping<isize>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<u8>> for &Wrapping<u8>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<u8>> for Wrapping<u8>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<u16>> for &Wrapping<u16>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<u16>> for Wrapping<u16>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<u32>> for &Wrapping<u32>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<u32>> for Wrapping<u32>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<u64>> for &Wrapping<u64>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<u64>> for Wrapping<u64>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<u128>> for &Wrapping<u128>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<u128>> for Wrapping<u128>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<usize>> for &Wrapping<usize>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<usize>> for Wrapping<usize>



impl Sub<&Rgb> for &Rgb



type Output = Rgb



impl Sub<&Rgb> for Rgb



type Output = Rgb

1.0.0 (const: unstable) · Source

impl Sub<f16> for &f16

1.0.0 (const: unstable) · Source

impl Sub<f32> for &f32

1.0.0 (const: unstable) · Source

impl Sub<f64> for &f64

1.0.0 (const: unstable) · Source

impl Sub<f128> for &f128

1.0.0 (const: unstable) · Source

impl Sub<i8> for &i8

Source

impl Sub<i8> for &BigInt

Source

impl Sub<i8> for BigInt



impl Sub<i8> for Weekday



type Output = Weekday

1.0.0 (const: unstable) · Source

impl Sub<i16> for &i16

Source

impl Sub<i16> for &BigInt

Source

impl Sub<i16> for BigInt



impl Sub<i16> for Weekday



type Output = Weekday

1.0.0 (const: unstable) · Source

impl Sub<i32> for &i32

Source

impl Sub<i32> for &BigInt

Source

impl Sub<i32> for BigInt



impl Sub<i32> for Weekday



type Output = Weekday

1.0.0 (const: unstable) · Source

impl Sub<i64> for &i64

Source

impl Sub<i64> for &BigInt

Source

impl Sub<i64> for BigInt



impl Sub<i64> for Weekday



type Output = Weekday

1.0.0 (const: unstable) · Source

impl Sub<i128> for &i128

Source

impl Sub<i128> for &BigInt

Source

impl Sub<i128> for BigInt

1.0.0 (const: unstable) · Source

impl Sub<isize> for &isize

Source

impl Sub<isize> for &BigInt

Source

impl Sub<isize> for BigInt

1.0.0 (const: unstable) · Source

impl Sub<u8> for &u8

Source

impl Sub<u8> for &BigInt

Source

impl Sub<u8> for &BigUint

Source

impl Sub<u8> for BigInt

Source

impl Sub<u8> for BigUint

1.0.0 (const: unstable) · Source

impl Sub<u16> for &u16

Source

impl Sub<u16> for &BigInt

Source

impl Sub<u16> for &BigUint

Source

impl Sub<u16> for BigInt

Source

impl Sub<u16> for BigUint

1.0.0 (const: unstable) · Source

impl Sub<u32> for &u32

Source

impl Sub<u32> for &BigInt

Source

impl Sub<u32> for &BigUint

Source

impl Sub<u32> for BigInt

Source

impl Sub<u32> for BigUint

1.0.0 (const: unstable) · Source

impl Sub<u64> for &u64

Source

impl Sub<u64> for &BigInt

Source

impl Sub<u64> for &BigUint

Source

impl Sub<u64> for BigInt

Source

impl Sub<u64> for BigUint

1.0.0 (const: unstable) · Source

impl Sub<u128> for &u128

Source

impl Sub<u128> for &BigInt

Source

impl Sub<u128> for &BigUint

Source

impl Sub<u128> for BigInt

Source

impl Sub<u128> for BigUint

1.0.0 (const: unstable) · Source

impl Sub<usize> for &usize

Source

impl Sub<usize> for &BigInt

Source

impl Sub<usize> for &BigUint

Source

impl Sub<usize> for BigInt

Source

impl Sub<usize> for BigUint

Source

impl Sub<BigInt> for &i8

Source

impl Sub<BigInt> for &i16

Source

impl Sub<BigInt> for &i32

Source

impl Sub<BigInt> for &i64

Source

impl Sub<BigInt> for &i128

Source

impl Sub<BigInt> for &isize

Source

impl Sub<BigInt> for &u8

Source

impl Sub<BigInt> for &u16

Source

impl Sub<BigInt> for &u32

Source

impl Sub<BigInt> for &u64

Source

impl Sub<BigInt> for &u128

Source

impl Sub<BigInt> for &usize

Source

impl Sub<BigInt> for &BigInt

Source

impl Sub<BigInt> for i8

Source

impl Sub<BigInt> for i16

Source

impl Sub<BigInt> for i32

Source

impl Sub<BigInt> for i64

Source

impl Sub<BigInt> for i128

Source

impl Sub<BigInt> for isize

Source

impl Sub<BigInt> for u8

Source

impl Sub<BigInt> for u16

Source

impl Sub<BigInt> for u32

Source

impl Sub<BigInt> for u64

Source

impl Sub<BigInt> for u128

Source

impl Sub<BigInt> for usize

Source

impl Sub<BigUint> for &u8

Source

impl Sub<BigUint> for &u16

Source

impl Sub<BigUint> for &u32

Source

impl Sub<BigUint> for &u64

Source

impl Sub<BigUint> for &u128

Source

impl Sub<BigUint> for &usize

Source

impl Sub<BigUint> for &BigUint

Source

impl Sub<BigUint> for u8

Source

impl Sub<BigUint> for u16

Source

impl Sub<BigUint> for u32

Source

impl Sub<BigUint> for u64

Source

impl Sub<BigUint> for u128

Source

impl Sub<BigUint> for usize

1.74.0 (const: unstable) · Source

impl Sub<Saturating<i8>> for &Saturating<i8>

1.74.0 (const: unstable) · Source

impl Sub<Saturating<i16>> for &Saturating<i16>

1.74.0 (const: unstable) · Source

impl Sub<Saturating<i32>> for &Saturating<i32>

1.74.0 (const: unstable) · Source

impl Sub<Saturating<i64>> for &Saturating<i64>

1.74.0 (const: unstable) · Source

impl Sub<Saturating<i128>> for &Saturating<i128>

1.74.0 (const: unstable) · Source

impl Sub<Saturating<isize>> for &Saturating<isize>

1.74.0 (const: unstable) · Source

impl Sub<Saturating<u8>> for &Saturating<u8>

1.74.0 (const: unstable) · Source

impl Sub<Saturating<u16>> for &Saturating<u16>

1.74.0 (const: unstable) · Source

impl Sub<Saturating<u32>> for &Saturating<u32>

1.74.0 (const: unstable) · Source

impl Sub<Saturating<u64>> for &Saturating<u64>

1.74.0 (const: unstable) · Source

impl Sub<Saturating<u128>> for &Saturating<u128>

1.74.0 (const: unstable) · Source

impl Sub<Saturating<usize>> for &Saturating<usize>

1.14.0 (const: unstable) · Source

impl Sub<Wrapping<i8>> for &Wrapping<i8>

1.14.0 (const: unstable) · Source

impl Sub<Wrapping<i16>> for &Wrapping<i16>

1.14.0 (const: unstable) · Source

impl Sub<Wrapping<i32>> for &Wrapping<i32>

1.14.0 (const: unstable) · Source

impl Sub<Wrapping<i64>> for &Wrapping<i64>

1.14.0 (const: unstable) · Source

impl Sub<Wrapping<i128>> for &Wrapping<i128>

1.14.0 (const: unstable) · Source

impl Sub<Wrapping<isize>> for &Wrapping<isize>

1.14.0 (const: unstable) · Source

impl Sub<Wrapping<u8>> for &Wrapping<u8>

1.14.0 (const: unstable) · Source

impl Sub<Wrapping<u16>> for &Wrapping<u16>

1.14.0 (const: unstable) · Source

impl Sub<Wrapping<u32>> for &Wrapping<u32>

1.14.0 (const: unstable) · Source

impl Sub<Wrapping<u64>> for &Wrapping<u64>

1.14.0 (const: unstable) · Source

impl Sub<Wrapping<u128>> for &Wrapping<u128>

1.14.0 (const: unstable) · Source

impl Sub<Wrapping<usize>> for &Wrapping<usize>

1.8.0 · Source

impl Sub<Duration> for std::time::Instant

1.8.0 · Source

impl Sub<Duration> for SystemTime



impl Sub<Duration> for Date



type Output = Date



impl Sub<Duration> for Date

Subtracts an unsigned duration of time from a date.

This uses checked arithmetic and panics on overflow. To handle overflow without panics, use [Date::checked_sub].



type Output = Date



impl Sub<Duration> for DateTime

Subtracts an unsigned duration of time from a datetime.

This uses checked arithmetic and panics on overflow. To handle overflow without panics, use [DateTime::checked_sub].



type Output = DateTime



impl Sub<Duration> for Duration



type Output = Duration



impl Sub<Duration> for Instant



type Output = Instant



impl Sub<Duration> for Offset

Subtracts an unsigned duration of time from an offset. This panics on overflow.

For checked arithmetic, see [Offset::checked_sub].



type Output = Offset



impl Sub<Duration> for OffsetDateTime



type Output = OffsetDateTime



impl Sub<Duration> for PrimitiveDateTime



type Output = PrimitiveDateTime



impl Sub<Duration> for Time



type Output = Time



impl Sub<Duration> for Time

Subtracts an unsigned duration of time. This uses wrapping arithmetic.

For checked arithmetic, see [Time::checked_sub].



type Output = Time



impl Sub<Duration> for Timestamp

Subtracts an unsigned duration of time from a timestamp.

This uses checked arithmetic and panics on overflow. To handle overflow without panics, use [Timestamp::checked_sub].



type Output = Timestamp



impl Sub<Duration> for UtcDateTime



type Output = UtcDateTime



impl Sub<Duration> for Zoned

Subtracts an unsigned duration of time from a zoned datetime.

This uses checked arithmetic and panics on overflow. To handle overflow without panics, use [Zoned::checked_sub].

Using this implementation will result in consuming the Zoned value. Since it is not Copy, this will prevent further use. If this is undesirable, consider using the trait implementation for &Zoned, Zoned::checked_sub or cloning the Zoned value.



type Output = Zoned



impl Sub<SystemTime> for OffsetDateTime



type Output = Duration



impl Sub<SystemTime> for UtcDateTime



type Output = Duration

Source

impl Sub<B0> for UTerm

UTerm - B0 = Term

Source

impl Sub<B1> for UInt<UTerm, B1>

UInt<UTerm, B1> - B1 = UTerm



impl Sub<Duration> for core::time::Duration



type Output = Duration



impl Sub<Duration> for std::time::Instant



impl Sub<Duration> for SystemTime

Available on crate feature std only.


impl Sub<Duration> for Date



type Output = Date



impl Sub<Duration> for OffsetDateTime



type Output = OffsetDateTime



impl Sub<Duration> for PrimitiveDateTime



type Output = PrimitiveDateTime



impl Sub<Duration> for Time



type Output = Time



impl Sub<Duration> for UtcDateTime



type Output = UtcDateTime



impl Sub<OffsetDateTime> for SystemTime



type Output = Duration



impl Sub<OffsetDateTime> for UtcDateTime



type Output = Duration



impl Sub<Rgb> for &Rgb



type Output = Rgb



impl Sub<SignedDuration> for Date

Subtracts a signed duration of time from a date.

This uses checked arithmetic and panics on overflow. To handle overflow without panics, use [Date::checked_sub].



type Output = Date



impl Sub<SignedDuration> for DateTime

Subtracts a signed duration of time from a datetime.

This uses checked arithmetic and panics on overflow. To handle overflow without panics, use [DateTime::checked_sub].



type Output = DateTime



impl Sub<SignedDuration> for Offset

Subtracts a signed duration of time from an offset. This panics on overflow.

For checked arithmetic, see [Offset::checked_sub].



type Output = Offset



impl Sub<SignedDuration> for Time

Subtracts a signed duration of time. This uses wrapping arithmetic.

For checked arithmetic, see [Time::checked_sub].



type Output = Time



impl Sub<SignedDuration> for Timestamp

Subtracts a signed duration of time from a timestamp.

This uses checked arithmetic and panics on overflow. To handle overflow without panics, use [Timestamp::checked_sub].



type Output = Timestamp



impl Sub<SignedDuration> for Zoned

Subtracts a signed duration of time from a zoned datetime.

This uses checked arithmetic and panics on overflow. To handle overflow without panics, use [Zoned::checked_sub].

Using this implementation will result in consuming the Zoned value. Since it is not Copy, this will prevent further use. If this is undesirable, consider using the trait implementation for &Zoned, Zoned::checked_sub or cloning the Zoned value.



type Output = Zoned



impl Sub<Span> for Date

Subtracts a span of time from a date.

This uses checked arithmetic and panics on overflow. To handle overflow without panics, use [Date::checked_sub].



type Output = Date



impl Sub<Span> for DateTime

Subtracts a span of time from a datetime.

This uses checked arithmetic and panics on overflow. To handle overflow without panics, use [DateTime::checked_sub].



type Output = DateTime



impl Sub<Span> for Offset

Subtracts a span of time from an offset. This panics on overflow.

For checked arithmetic, see [Offset::checked_sub].



type Output = Offset



impl Sub<Span> for Time

Subtracts a span of time. This uses wrapping arithmetic.

For checked arithmetic, see [Time::checked_sub].



type Output = Time



impl Sub<Span> for Timestamp

Subtracts a span of time from a timestamp.

This uses checked arithmetic and panics when it fails. To handle arithmetic without panics, use [Timestamp::checked_sub]. Note that the failure condition includes overflow and using a Span with non-zero units greater than hours.



type Output = Timestamp



impl Sub<UtcDateTime> for SystemTime



type Output = Duration



impl Sub<UtcDateTime> for OffsetDateTime



type Output = Duration



impl<'a> Sub for &'a Zoned

Computes the span of time between two borrowed zoned datetimes.

This will return a negative span when the zoned datetime being subtracted is greater.

Since this uses the default configuration for calculating a span between two zoned datetimes (no rounding and largest units is hours), this will never panic or fail in any way. It is guaranteed that the largest non-zero unit in the Span returned will be hours.

To configure the largest unit or enable rounding, use [Zoned::since].



type Output = Span



impl<'a> Sub<Duration> for &'a Zoned

Subtracts an unsigned duration of time from a borrowed zoned datetime.

This uses checked arithmetic and panics on overflow. To handle overflow without panics, use [Zoned::checked_sub].



type Output = Zoned



impl<'a> Sub<SignedDuration> for &'a Zoned

Subtracts a signed duration of time from a borrowed zoned datetime.

This uses checked arithmetic and panics on overflow. To handle overflow without panics, use [Zoned::checked_sub].



type Output = Zoned



impl<'a> Sub<Span> for &'a Zoned

Subtracts a span of time from a borrowed zoned datetime.

This uses checked arithmetic and panics on overflow. To handle overflow without panics, use [Zoned::checked_sub].



type Output = Zoned



impl<'a> Sub<Span> for Zoned

Subtracts a span of time from a zoned datetime.

This uses checked arithmetic and panics on overflow. To handle overflow without panics, use [Zoned::checked_sub].

Using this implementation will result in consuming the Zoned value. Since it is not Copy, this will prevent further use. If this is undesirable, consider using the trait implementation for &Zoned, Zoned::checked_sub or cloning the Zoned value.



type Output = Zoned



impl<'a, 'b> Sub<&'b BigNum> for &'a BigNum



impl<'a, 'b> Sub<&'b BigNum> for &'a BigNumRef



impl<'a, 'b> Sub<&'b BigNumRef> for &'a BigNum

Source

impl<'lhs, 'rhs, T, const N: usize> Sub<&'rhs Simd<T, N>> for &'lhs Simd<T, N>
where T: SimdElement, Simd<T, N>: Sub<Output = Simd<T, N>>,

Source

type Output = Simd<T, N>



impl<O> Sub for F32<O>
where O: ByteOrder,



type Output = F32<O>



impl<O> Sub for F64<O>
where O: ByteOrder,



type Output = F64<O>



impl<O> Sub for I16<O>
where O: ByteOrder,



type Output = I16<O>



impl<O> Sub for I32<O>
where O: ByteOrder,



type Output = I32<O>



impl<O> Sub for I64<O>
where O: ByteOrder,



type Output = I64<O>



impl<O> Sub for I128<O>
where O: ByteOrder,



type Output = I128<O>



impl<O> Sub for Isize<O>
where O: ByteOrder,



type Output = Isize<O>



impl<O> Sub for U16<O>
where O: ByteOrder,



type Output = U16<O>



impl<O> Sub for U32<O>
where O: ByteOrder,



type Output = U32<O>



impl<O> Sub for U64<O>
where O: ByteOrder,



type Output = U64<O>



impl<O> Sub for U128<O>
where O: ByteOrder,



type Output = U128<O>



impl<O> Sub for Usize<O>
where O: ByteOrder,



type Output = Usize<O>



impl<O> Sub<f32> for F32<O>
where O: ByteOrder,



type Output = F32<O>



impl<O> Sub<f64> for F64<O>
where O: ByteOrder,



type Output = F64<O>



impl<O> Sub<i16> for I16<O>
where O: ByteOrder,



type Output = I16<O>



impl<O> Sub<i32> for I32<O>
where O: ByteOrder,



type Output = I32<O>



impl<O> Sub<i64> for I64<O>
where O: ByteOrder,



type Output = I64<O>



impl<O> Sub<i128> for I128<O>
where O: ByteOrder,



type Output = I128<O>



impl<O> Sub<isize> for Isize<O>
where O: ByteOrder,



type Output = Isize<O>



impl<O> Sub<u16> for U16<O>
where O: ByteOrder,



type Output = U16<O>



impl<O> Sub<u32> for U32<O>
where O: ByteOrder,



type Output = U32<O>



impl<O> Sub<u64> for U64<O>
where O: ByteOrder,



type Output = U64<O>



impl<O> Sub<u128> for U128<O>
where O: ByteOrder,



type Output = U128<O>



impl<O> Sub<usize> for Usize<O>
where O: ByteOrder,



type Output = Usize<O>



impl<O> Sub<F32<O>> for f32
where O: ByteOrder,



type Output = F32<O>



impl<O> Sub<F64<O>> for f64
where O: ByteOrder,



type Output = F64<O>



impl<O> Sub<I16<O>> for i16
where O: ByteOrder,



type Output = I16<O>



impl<O> Sub<I32<O>> for i32
where O: ByteOrder,



type Output = I32<O>



impl<O> Sub<I64<O>> for i64
where O: ByteOrder,



type Output = I64<O>



impl<O> Sub<I128<O>> for i128
where O: ByteOrder,



type Output = I128<O>



impl<O> Sub<Isize<O>> for isize
where O: ByteOrder,



type Output = Isize<O>



impl<O> Sub<U16<O>> for u16
where O: ByteOrder,



type Output = U16<O>



impl<O> Sub<U32<O>> for u32
where O: ByteOrder,



type Output = U32<O>



impl<O> Sub<U64<O>> for u64
where O: ByteOrder,



type Output = U64<O>



impl<O> Sub<U128<O>> for u128
where O: ByteOrder,



type Output = U128<O>



impl<O> Sub<Usize<O>> for usize
where O: ByteOrder,



type Output = Usize<O>

1.0.0 · Source

impl<T, A> Sub<&BTreeSet<T, A>> for &BTreeSet<T, A>
where T: Ord + Clone, A: Allocator + Clone,



impl<T, S1, S2> Sub<&IndexSet<T, S2>> for &IndexSet<T, S1>
where T: Eq + Hash + Clone, S1: BuildHasher + Default, S2: BuildHasher,



type Output = IndexSet<T, S1>

1.0.0 · Source

impl<T, S> Sub<&HashSet<T, S>> for &rama::crypto::dep::x509_parser::prelude::asn1_rs::nom::lib::std::collections::HashSet<T, S>
where T: Eq + Hash + Clone, S: BuildHasher + Default,

Source

type Output = HashSet<T, S>



impl<T, S> Sub<&AHashSet<T, S>> for &AHashSet<T, S>
where T: Eq + Hash + Clone, S: BuildHasher + Default,



type Output = AHashSet<T, S>



impl<T, S, A> Sub<&HashSet<T, S, A>> for &HashSet<T, S, A>
where T: Eq + Hash + Clone, S: BuildHasher + Default, A: Allocator + Default,



type Output = HashSet<T, S, A>



impl<T, S, A> Sub<&HashSet<T, S, A>> for &HashSet<T, S, A>
where T: Eq + Hash + Clone, S: BuildHasher + Default, A: Allocator + Default,



type Output = HashSet<T, S, A>

Source

impl<T, const N: usize> Sub<&Simd<T, N>> for Simd<T, N>
where T: SimdElement, Simd<T, N>: Sub<Output = Simd<T, N>>,

Source

type Output = Simd<T, N>

Source

impl<T, const N: usize> Sub<Simd<T, N>> for &Simd<T, N>
where T: SimdElement, Simd<T, N>: Sub<Output = Simd<T, N>>,

Source

type Output = Simd<T, N>

Source

impl<U> Sub<B1> for UInt<U, B0>
where U: Unsigned + Sub<B1>, <U as Sub<B1>>::Output: Unsigned,

UInt<U, B0> - B1 = UInt<U - B1, B1>

Source

type Output = UInt<<U as Sub<B1>>::Output, B1>

Source

impl<U> Sub<NInt<U>> for Z0
where U: Unsigned + NonZero,

Z0 - N = P

Source

impl<U> Sub<PInt<U>> for Z0
where U: Unsigned + NonZero,

Z0 - P = N

Source

impl<U> Sub<Z0> for NInt<U>
where U: Unsigned + NonZero,

NInt - Z0 = NInt

Source

impl<U> Sub<Z0> for PInt<U>
where U: Unsigned + NonZero,

PInt - Z0 = PInt

Source

impl<U, B> Sub<B0> for UInt<U, B>
where U: Unsigned, B: Bit,

UInt - B0 = UInt

Source

type Output = UInt<U, B>

Source

impl<U, B> Sub<B1> for UInt<UInt<U, B>, B1>
where U: Unsigned, B: Bit,

UInt<U, B1> - B1 = UInt<U, B0>

Source

type Output = UInt<UInt<U, B>, B0>

Source

impl<Ul, Bl, Ur> Sub<Ur> for UInt<Ul, Bl>
where Ul: Unsigned, Bl: Bit, Ur: Unsigned, UInt<Ul, Bl>: PrivateSub<Ur>, <UInt<Ul, Bl> as PrivateSub<Ur>>::Output: Trim,

Subtracting unsigned integers. We just do our PrivateSub and then Trim the output.

Source

type Output = <<UInt<Ul, Bl> as PrivateSub<Ur>>::Output as Trim>::Output

Source

impl<Ul, Ur> Sub<NInt<Ur>> for NInt<Ul>
where Ul: Unsigned + NonZero, Ur: Unsigned + NonZero + Cmp<Ul> + PrivateIntegerAdd<<Ur as Cmp<Ul>>::Output, Ul>,

N(Ul) - N(Ur): We resolve this with our PrivateAdd

Source

type Output = <Ur as PrivateIntegerAdd<<Ur as Cmp<Ul>>::Output, Ul>>::Output

Source

impl<Ul, Ur> Sub<NInt<Ur>> for PInt<Ul>
where Ul: Unsigned + NonZero + Add<Ur>, Ur: Unsigned + NonZero, <Ul as Add<Ur>>::Output: Unsigned + NonZero,

P(Ul) - N(Ur) = P(Ul + Ur)

Source

type Output = PInt<<Ul as Add<Ur>>::Output>

Source

impl<Ul, Ur> Sub<PInt<Ur>> for NInt<Ul>
where Ul: Unsigned + NonZero + Add<Ur>, Ur: Unsigned + NonZero, <Ul as Add<Ur>>::Output: Unsigned + NonZero,

N(Ul) - P(Ur) = N(Ul + Ur)

Source

type Output = NInt<<Ul as Add<Ur>>::Output>

Source

impl<Ul, Ur> Sub<PInt<Ur>> for PInt<Ul>
where Ul: Unsigned + NonZero + Cmp<Ur> + PrivateIntegerAdd<<Ul as Cmp<Ur>>::Output, Ur>, Ur: Unsigned + NonZero,

P(Ul) - P(Ur): We resolve this with our PrivateAdd

Source

type Output = <Ul as PrivateIntegerAdd<<Ul as Cmp<Ur>>::Output, Ur>>::Output

Source

impl<Vl, Al, Vr, Ar> Sub<TArr<Vr, Ar>> for TArr<Vl, Al>
where Vl: Sub<Vr>, Al: Sub<Ar>,

Source

type Output = TArr<<Vl as Sub<Vr>>::Output, <Al as Sub<Ar>>::Output>

Source

impl<const N: usize> Sub for Simd<f32, N>

Source

impl<const N: usize> Sub for Simd<f64, N>

Source

impl<const N: usize> Sub for Simd<i8, N>
where i8: SimdElement,

Source

impl<const N: usize> Sub for Simd<i16, N>

Source

impl<const N: usize> Sub for Simd<i32, N>

Source

impl<const N: usize> Sub for Simd<i64, N>

Source

impl<const N: usize> Sub for Simd<isize, N>

Source

impl<const N: usize> Sub for Simd<u8, N>
where u8: SimdElement,

Source

impl<const N: usize> Sub for Simd<u16, N>

Source

impl<const N: usize> Sub for Simd<u32, N>

Source

impl<const N: usize> Sub for Simd<u64, N>

Source

impl<const N: usize> Sub for Simd<usize, N>