TaggedValue

Struct TaggedValue 

pub struct TaggedValue<T, E, TagKind, const CLASS: u8, const TAG: u32> { /* private fields */ }
Available on crate feature crypto only.
Helper object for creating FromBer/FromDer types for TAGGED OPTIONAL types

When parsing ContextSpecific (the most common class), see TaggedExplicit and TaggedImplicit alias types.

Notes

CLASS must be between 0 and 4. See Class for possible values for the CLASS parameter. Constants from this class can be used, but they must be wrapped in braces due to Rust syntax for generics (see example below).

Examples

To parse a [APPLICATION 0] EXPLICIT INTEGER object:

use asn1_rs::{Class, Error, Explicit, FromBer, Integer, TaggedValue};

let bytes = &[0x60, 0x03, 0x2, 0x1, 0x2];

// If tagged object is present (and has expected tag), parsing succeeds:
let (_, tagged) =
    TaggedValue::<Integer, Error, Explicit, {Class::APPLICATION}, 0>::from_ber(bytes)
        .unwrap();
assert_eq!(tagged, TaggedValue::explicit(Integer::from(2)));

Implementations



impl<T, E, TagKind, const CLASS: u8, const TAG: u32> TaggedValue<T, E, TagKind, CLASS, TAG>

pub fn into_inner(self) -> T

Consumes the TaggedParser, returning the wrapped value.

pub const fn tag(&self) -> Tag

Return the (outer) tag of this object

pub const fn class(&self) -> u8

Return the (outer) class of this object



impl<T, E, const CLASS: u8, const TAG: u32> TaggedValue<T, E, Explicit, CLASS, TAG>

pub const fn explicit(inner: T) -> TaggedValue<T, E, Explicit, CLASS, TAG>

Constructs a new EXPLICIT TaggedParser with the provided value



impl<T, E, const CLASS: u8, const TAG: u32> TaggedValue<T, E, Implicit, CLASS, TAG>

pub const fn implicit(inner: T) -> TaggedValue<T, E, Implicit, CLASS, TAG>

Constructs a new IMPLICIT TaggedParser with the provided value