Macro oid
macro_rules! oid {
($($args:tt)*) => { ... };
}Available on crate features
crypto and std only.Expand description
Procedural macro to get encoded oids, see the oid module.
macro_rules! oid {
($($args:tt)*) => { ... };
}crypto and std only.Procedural macro to get encoded oids, see the oid module.