Macro align32
macro_rules! align32 {
($x:expr) => { ... };
}Available on crate features
crypto and std only.Expand description
Align input value to the next multiple of 4 bytes
macro_rules! align32 {
($x:expr) => { ... };
}crypto and std only.Align input value to the next multiple of 4 bytes