Macro align_n2
macro_rules! align_n2 {
($x:expr, $n:expr) => { ... };
}Available on crate features
crypto and std only.Expand description
Align input value to the next multiple of n bytes Valid only if n is a power of 2