Struct Validity
pub struct Validity {
pub not_before: ASN1Time,
pub not_after: ASN1Time,
}Available on crate features
crypto and std only.Fields
not_before: ASN1Timenot_after: ASN1TimeImplementations
impl Validity
impl Validity
pub fn time_to_expiration(&self) -> Option<Duration>
pub fn time_to_expiration(&self) -> Option<Duration>
The time left before the certificate expires.
If the certificate is not currently valid, then None is
returned. Otherwise, the Duration until the certificate
expires is returned.
pub fn is_valid_at(&self, time: ASN1Time) -> bool
pub fn is_valid_at(&self, time: ASN1Time) -> bool
Check the certificate time validity for the provided date/time