Struct X509CertificationRequest
pub struct X509CertificationRequest<'a> {
pub certification_request_info: X509CertificationRequestInfo<'a>,
pub signature_algorithm: AlgorithmIdentifier<'a>,
pub signature_value: BitString<'a>,
/* private fields */
}Available on crate features
crypto and std only.Expand description
Certification Signing Request (CSR)
Fields
certification_request_info: X509CertificationRequestInfo<'a>signature_algorithm: AlgorithmIdentifier<'a>signature_value: BitString<'a>Implementations
impl<'a> X509CertificationRequest<'a>
impl<'a> X509CertificationRequest<'a>
pub fn as_raw(&self) -> &'a [u8] ⓘ
pub fn as_raw(&self) -> &'a [u8] ⓘ
Return the raw ASN.1 DER content of the complete signed certification request that was parsed.
This includes the certification request info, the signature algorithm, and the signature.
We avoid the AsRef trait in this instance to ensure the full lifetime of the X509CertificationRequest is used.
pub fn requested_extensions( &self, ) -> Option<impl Iterator<Item = &ParsedExtension<'_>>>
pub fn verify_signature(&self) -> Result<(), X509Error>
Available on crate features verify-aws or verify only.
pub fn verify_signature(&self) -> Result<(), X509Error>
verify-aws or verify only.Verify the cryptographic signature of this certification request
Uses the public key contained in the CSR, which must be the one of the entity requesting the certification for this verification to succeed.