Struct X509CertificationRequestInfo
pub struct X509CertificationRequestInfo<'a> {
pub version: X509Version,
pub subject: X509Name<'a>,
pub subject_pki: SubjectPublicKeyInfo<'a>,
pub raw: &'a [u8],
/* private fields */
}Available on crate features
crypto and std only.Expand description
Certification Request Info structure
Certification request information is defined by the following ASN.1 structure:
CertificationRequestInfo ::= SEQUENCE {
version INTEGER { v1(0) } (v1,...),
subject Name,
subjectPKInfo SubjectPublicKeyInfo{{ PKInfoAlgorithms }},
attributes [0] Attributes{{ CRIAttributes }}
}
version is the version number; subject is the distinguished name of the certificate subject; subject_pki contains information about the public key being certified, and attributes is a collection of attributes providing additional information about the subject of the certificate.
Fields
version: X509Versionsubject: X509Name<'a>subject_pki: SubjectPublicKeyInfo<'a>raw: &'a [u8]Implementations
impl X509CertificationRequestInfo<'_>
impl X509CertificationRequestInfo<'_>
pub fn attributes(&self) -> &[X509CriAttribute<'_>]
pub fn attributes(&self) -> &[X509CriAttribute<'_>]
Get the CRL entry extensions.
pub fn iter_attributes(&self) -> impl Iterator<Item = &X509CriAttribute<'_>>
pub fn iter_attributes(&self) -> impl Iterator<Item = &X509CriAttribute<'_>>
Returns an iterator over the CRL entry extensions
pub fn find_attribute(&self, oid: &Oid<'_>) -> Option<&X509CriAttribute<'_>>
pub fn find_attribute(&self, oid: &Oid<'_>) -> Option<&X509CriAttribute<'_>>
Searches for a CRL entry extension with the given Oid.
Note: if there are several extensions with the same Oid, the first one is returned.
pub fn attributes_map(
&self,
) -> Result<HashMap<Oid<'_>, &X509CriAttribute<'_>>, X509Error>
pub fn attributes_map( &self, ) -> Result<HashMap<Oid<'_>, &X509CriAttribute<'_>>, X509Error>
Builds and returns a map of CRL entry extensions.
If an extension is present twice, this will fail and return DuplicateExtensions.