Struct DecodedSignature
pub struct DecodedSignature { /* private fields */ }Available on crate features
crypto and aws-lc only.Expand description
Decode version of a Signature.
Data here has already been verified, so everything here is ready for usage
Implementations
impl DecodedSignature
impl DecodedSignature
pub fn protected_headers(&self) -> &Headers
pub fn protected_headers(&self) -> &Headers
Reference to the protected Headers
pub fn decode_protected_headers<'de, 'a, T>(
&'a self,
) -> Result<T, Box<dyn Error + Send + Sync>>where
'a: 'de,
T: Deserialize<'de>,
pub fn decode_protected_headers<'de, 'a, T>(
&'a self,
) -> Result<T, Box<dyn Error + Send + Sync>>where
'a: 'de,
T: Deserialize<'de>,
Trying decoding the protected headers to the provided T
pub fn unprotected_headers(&self) -> &Headers
pub fn unprotected_headers(&self) -> &Headers
Reference to the unprotected Headers
pub fn decode_unprotected_headers<'de, 'a, T>(
&'a self,
) -> Result<T, Box<dyn Error + Send + Sync>>where
'a: 'de,
T: Deserialize<'de>,
pub fn decode_unprotected_headers<'de, 'a, T>(
&'a self,
) -> Result<T, Box<dyn Error + Send + Sync>>where
'a: 'de,
T: Deserialize<'de>,
Trying decoding the unprotected headers to the provided T