Enum ErrorKind
#[non_exhaustive]pub enum ErrorKind {
Io {
inner: Error,
path: PathBuf,
},
Os(Box<dyn Error + Sync + Send>),
Pem(Error),
}Available on crate features
crypto and native-certs only.Expand description
The kinds of errors that can occur while loading native certificates.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Io
An I/O error while reading a certificate file or directory.
Os(Box<dyn Error + Sync + Send>)
A platform (OS keychain / cert store) error.
Pem(Error)
A PEM parsing error.