Enum ServerName
#[non_exhaustive]pub enum ServerName<'a> {
DnsName(DnsName<'a>),
IpAddress(IpAddr),
}crypto and std only.Expand description
Encodes ways a client can know the expected name of the server.
This currently covers knowing the DNS name of the server, but
will be extended in the future to supporting privacy-preserving names
for the server (“ECH”). For this reason this enum is non_exhaustive.
Making one
If you have a DNS name as a &str, this type implements TryFrom<&str>,
so you can do:
ServerName::try_from("example.com").expect("invalid DNS name");If you have an owned String, you can use TryFrom directly:
let name = "example.com".to_string();
#[cfg(feature = "alloc")]
ServerName::try_from(name).expect("invalid DNS name");which will yield a ServerName<'static> if successful.
or, alternatively…
let x: ServerName = "example.com".try_into().expect("invalid DNS name");Variants (Non-exhaustive)
This enum is marked as non-exhaustive
DnsName(DnsName<'a>)
The server is identified by a DNS name. The name is sent in the TLS Server Name Indication (SNI) extension.
IpAddress(IpAddr)
The server is identified by an IP address. SNI is not done.
Implementations
impl ServerName<'_>
impl ServerName<'_>
pub fn to_owned(&self) -> ServerName<'static>
Available on crate feature alloc only.
pub fn to_owned(&self) -> ServerName<'static>
alloc only.Produce an owned ServerName from this (potentially borrowed) ServerName.