Enum Error
#[non_exhaustive]pub enum Error {
MissingSectionEnd {
end_marker: Vec<u8>,
},
IllegalSectionStart {
line: Vec<u8>,
},
Base64Decode(String),
Io(Error),
NoItemsFound,
SectionTooLarge,
}Available on crate features
alloc and crypto and std only.Expand description
Errors that may arise when parsing the contents of a PEM file
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MissingSectionEnd
a section is missing its “END marker” line
IllegalSectionStart
syntax error found in the line that starts a new section
Base64Decode(String)
base64 decode error
Io(Error)
I/O errors, from APIs that accept std::io types.
NoItemsFound
No items found of desired type
SectionTooLarge
PEM section exceeds maximum allowed size of 256 MB