Struct UnixTime
pub struct UnixTime(/* private fields */);Available on crate features
crypto and std only.Expand description
A timestamp, tracking the number of non-leap seconds since the Unix epoch.
The Unix epoch is defined January 1, 1970 00:00:00 UTC.
Implementations
impl UnixTime
impl UnixTime
pub fn now() -> UnixTime
Available on target_family=wasm and target_os=unknown and crate feature web, or crate feature std and not (target_family=wasm and target_os=unknown) only.
pub fn now() -> UnixTime
target_family=wasm and target_os=unknown and crate feature web, or crate feature std and not (target_family=wasm and target_os=unknown) only.The current time, as a UnixTime
pub const fn since_unix_epoch(duration: Duration) -> UnixTime
pub const fn since_unix_epoch(duration: Duration) -> UnixTime
Convert a Duration since the start of 1970 to a UnixTime
The duration must be relative to the Unix epoch.