Enum OpportunisticEncryption
#[non_exhaustive]pub enum OpportunisticEncryption {
Disabled,
}Expand description
Configuration for enabling RFC 9539 opportunistic encryption.
Controls how a recursive resolver probes name servers to discover if they support encrypted transports.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Disabled
Opportunistic encryption will not be performed.
Implementations
impl OpportunisticEncryption
impl OpportunisticEncryption
pub fn is_enabled(&self) -> bool
pub fn is_enabled(&self) -> bool
Returns true if opportunistic encryption is enabled.
pub fn max_concurrent_probes(&self) -> Option<u8>
pub fn max_concurrent_probes(&self) -> Option<u8>
Returns the maximum number of concurrent probes if opportunistic encrypt is enabled.