Struct OpportunisticEncryptionConfig
pub struct OpportunisticEncryptionConfig {
pub persistence_period: Duration,
pub damping_period: Duration,
pub max_concurrent_probes: u8,
pub persistence: Option<OpportunisticEncryptionPersistence>,
}Expand description
Configuration parameters for opportunistic encryption.
Fields
persistence_period: DurationHow long the recursive resolver remembers a successful encrypted transport connection.
damping_period: DurationHow long the recursive resolver remembers a failed encrypted transport connection.
max_concurrent_probes: u8Maximum number of concurrent opportunistic encryption probes.
persistence: Option<OpportunisticEncryptionPersistence>Optional configuration for persistence of opportunistic encryption probe state.