ResolverConfig

Struct ResolverConfig 

#[non_exhaustive]
pub struct ResolverConfig { pub domain: Option<Name>, pub search: Vec<Name>, pub name_servers: Vec<NameServerConfig>, }
Available on crate features dns and hickory and std only.
Configuration for the upstream nameservers to use for resolution.

The Default implementation of this struct will be removed in a future version. Use Self::from_name_servers() instead. Note that a ResolverConfig with no name servers will produce a nonfunctional resolver.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
domain: Option<Name>

Base search domain

search: Vec<Name>

Search domains

name_servers: Vec<NameServerConfig>

Name servers to use for resolution

Implementations



impl ResolverConfig

pub fn udp_and_tcp(config: &ServerGroup<'_>) -> ResolverConfig

Create a new ResolverConfig from ServerGroup configuration.

Connects via UDP and TCP.

pub fn from_parts( domain: Option<Name>, search: Vec<Name>, name_servers: Vec<NameServerConfig>, ) -> ResolverConfig

Create a ResolverConfig with all parts specified

Arguments
  • domain - domain of the entity querying results. If the Name being looked up is not an FQDN, then this is the first part appended to attempt a lookup. ndots in the ResolverOption does take precedence over this.
  • search - additional search domains that are attempted if the Name is not found in domain, defaults to vec![]
  • name_servers - set of name servers to use for lookups

pub fn from_name_servers(name_servers: Vec<NameServerConfig>) -> ResolverConfig

Create a ResolverConfig from a list of name server configurations.

No base domain for relative names will be set, and no additional search domains will be set.

pub fn into_parts(self) -> (Option<Name>, Vec<Name>, Vec<NameServerConfig>)

Take the domain, search, and name_servers from the config.

pub fn domain(&self) -> Option<&Name>

Returns the local domain

By default any names will be appended to all non-fully-qualified-domain names, and searched for after any ndots rules

pub fn set_domain(&mut self, domain: Name)

Set the domain of the entity querying results.

pub fn search(&self) -> &[Name]

Returns the search domains

These will be queried after any local domain and then in the order of the set of search domains

Add a search domain

pub fn add_name_server(&mut self, name_server: NameServerConfig)

Add the configuration for a name server

pub fn name_servers(&self) -> &[NameServerConfig]

Returns a reference to the name servers