Struct Lookup
pub struct Lookup { /* private fields */ }Expand description
Result of a DNS query when querying for any record type supported by the Hickory DNS Proto library.
For IP resolution see LookupIp, as it has more features for A and AAAA lookups.
Implementations
impl Lookup
impl Lookup
pub fn from_rdata(query: Query, rdata: RData) -> Lookup
pub fn from_rdata(query: Query, rdata: RData) -> Lookup
Return new instance with given rdata and the maximum TTL.
pub fn new_with_max_ttl(
query: Query,
answers: impl IntoIterator<Item = Record>,
) -> Lookup
pub fn new_with_max_ttl( query: Query, answers: impl IntoIterator<Item = Record>, ) -> Lookup
Return new instance with given records and the maximum TTL.
pub fn new_with_deadline(
query: Query,
answers: impl IntoIterator<Item = Record>,
valid_until: Instant,
) -> Lookup
pub fn new_with_deadline( query: Query, answers: impl IntoIterator<Item = Record>, valid_until: Instant, ) -> Lookup
Return a new instance with the given records and deadline.
Returns a reference to the authority records from the message.
pub fn additionals(&self) -> &[Record]
pub fn additionals(&self) -> &[Record]
Returns a reference to the additional records from the message.
pub fn valid_until(&self) -> Instant
pub fn valid_until(&self) -> Instant
Returns the Instant at which this Lookup is no longer valid.