Enum NetError
#[non_exhaustive]pub enum NetError {
BadTransactionId,
Busy,
Dns(DnsError),
Message(&'static str),
Msg(String),
ParseInt(ParseIntError),
NoConnections,
Proto(ProtoError),
Io(Arc<Error>),
Timeout,
QueryCaseMismatch,
}Expand description
The error type for network protocol errors (UDP, TCP, QUIC, H2, H3)
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
BadTransactionId
A UDP response was received with an incorrect transaction id, likely indicating a cache-poisoning attempt.
Busy
The underlying resource is too busy
This is a signal that an internal resource is too busy. The intended action should be tried again, ideally after waiting for a little while for the situation to improve. Alternatively, the action could be tried on another resource (for example, in a name server pool).
Dns(DnsError)
Semantic DNS errors
Message(&'static str)
An error with an arbitrary message, referenced as &’static str
Msg(String)
An error with an arbitrary message, stored as String
ParseInt(ParseIntError)
Unable to parse header value as number
NoConnections
No connections available
Proto(ProtoError)
Protocol error from higher layers
Io(Arc<Error>)
An error got returned from IO
Timeout
A request timed out
QueryCaseMismatch
Case randomization is enabled, and a server did not echo a query name back with the same case.
Implementations