DnsResponse

Struct DnsResponse 

pub struct DnsResponse { /* private fields */ }
A DNS response object

For Most DNS requests, only one response is expected, the exception is a multicast request.

Implementations



impl DnsResponse

pub fn from_message(message: Message) -> Result<DnsResponse, ProtoError>

Constructs a new DnsResponse with a buffer synthesized from the message

pub fn from_buffer(buffer: Vec<u8>) -> Result<DnsResponse, ProtoError>

Constructs a new DnsResponse by parsing a message from a buffer.

Returns an error if the response message cannot be decoded.

pub fn soa(&self) -> Option<RecordRef<'_, SOA>>

Retrieves the SOA from the response. This will only exist if it was an authoritative response.

pub fn negative_ttl(&self) -> Option<u32>

Looks in the authority section for an SOA record from the response, and returns the negative_ttl, None if not available.

[RFC 2308](https://tools.ietf.org/html/rfc2308#section-5) DNS NCACHE March 1998

5 - Caching Negative Answers

  Like normal answers negative answers have a time to live (TTL).  As
  there is no record in the answer section to which this TTL can be
  applied, the TTL must be carried by another method.  This is done by
  including the SOA record from the zone in the authority section of
  the reply.  When the authoritative server creates this record its TTL
  is taken from the minimum of the SOA.MINIMUM field and SOA's TTL.
  This TTL decrements in a similar manner to a normal cached answer and
  upon reaching zero (0) indicates the cached negative answer MUST NOT
  be used again.

  A negative answer that resulted from a name error (NXDOMAIN) should
  be cached such that it can be retrieved and returned in response to
  another query for the same <QNAME, QCLASS> that resulted in the
  cached negative response.

  A negative answer that resulted from a no data error (NODATA) should
  be cached such that it can be retrieved and returned in response to
  another query for the same <QNAME, QTYPE, QCLASS> that resulted in
  the cached negative response.

  The NXT record, if it exists in the authority section of a negative
  answer received, MUST be stored such that it can be be located and
  returned with SOA record in the authority section, as should any SIG
  records in the authority section.  For NXDOMAIN answers there is no
  "necessary" obvious relationship between the NXT records and the
  QNAME.  The NXT record MUST have the same owner name as the query
  name for NODATA responses.

  Negative responses without SOA records SHOULD NOT be cached as there
  is no way to prevent the negative responses looping forever between a
  pair of servers even with a short TTL.

  Despite the DNS forming a tree of servers, with various mis-
  configurations it is possible to form a loop in the query graph, e.g.
  two servers listing each other as forwarders, various lame server
  configurations.  Without a TTL count down a cache negative response
  when received by the next server would have its TTL reset.  This
  negative indication could then live forever circulating between the
  servers involved.

  As with caching positive responses it is sensible for a resolver to
  limit for how long it will cache a negative response as the protocol
  supports caching for up to 68 years.  Such a limit should not be
  greater than that applied to positive answers and preferably be
  tunable.  Values of one to three hours have been found to work well
  and would make sensible a default.  Values exceeding one day have
  been found to be problematic.

pub fn contains_answer(&self) -> bool

Does the response contain any records matching the query name and type?

pub fn as_buffer(&self) -> &[u8]

Borrow the inner buffer from the response

pub fn into_buffer(self) -> Vec<u8>

Take the inner buffer from the response

pub fn into_message(self) -> Message

Take the inner Message from the response

pub fn into_parts(self) -> (Message, Vec<u8>)

Take the inner Message and buffer from the response

Methods from Deref<Target = Message>

pub fn truncate(&self) -> Message

Truncates a Message, this blindly removes all response fields and sets truncated to true

pub fn add_query(&mut self, query: Query) -> &mut Message

Add a query to the Message, either the query response from the server, or the request Query.

pub fn add_queries<Q, I>(&mut self, queries: Q) -> &mut Message
where Q: IntoIterator<Item = Query, IntoIter = I>, I: Iterator<Item = Query>,

Adds an iterator over a set of Queries to be added to the message

pub fn add_answer(&mut self, record: Record) -> &mut Message

Add a record to the Answer section.

pub fn add_answers<R, I>(&mut self, records: R) -> &mut Message
where R: IntoIterator<Item = Record, IntoIter = I>, I: Iterator<Item = Record>,

Add all the records from the iterator to the Answer section of the message.

pub fn insert_answers(&mut self, records: Vec<Record>)

Sets the Answer section to the specified set of records.

Panics

Will panic if the Answer section is already non-empty.

pub fn add_authority(&mut self, record: Record) -> &mut Message

Add a record to the Authority section.

pub fn add_authorities<R, I>(&mut self, records: R) -> &mut Message
where R: IntoIterator<Item = Record, IntoIter = I>, I: Iterator<Item = Record>,

Add all the records from the Iterator to the Authority section of the message.

pub fn insert_authorities(&mut self, records: Vec<Record>)

Sets the Authority section to the specified set of records.

Panics

Will panic if the Authority section is already non-empty.

pub fn add_additional(&mut self, record: Record) -> &mut Message

Add a record to the Additional section.

pub fn add_additionals<R, I>(&mut self, records: R) -> &mut Message
where R: IntoIterator<Item = Record, IntoIter = I>, I: Iterator<Item = Record>,

Add all the records from the iterator to the Additional section of the message.

pub fn insert_additionals(&mut self, records: Vec<Record>)

Sets the Additional to the specified set of records.

Panics

Will panic if additional records are already associated to the message.

pub fn set_edns(&mut self, edns: Edns) -> &mut Message

Add the EDNS OPT pseudo-RR to the Message

pub fn take_all_sections(&mut self) -> impl Iterator<Item = Record>

Consume the message, returning an iterator over records from all sections

pub fn all_sections(&self) -> impl Iterator<Item = &Record>

All sections chained

pub fn max_payload(&self) -> u16

Return value

the max payload value as it’s defined in the EDNS OPT pseudo-RR.

pub fn version(&self) -> u8

Return value

the version as defined in the EDNS record

pub fn signature(&self) -> Option<&Record<TSIG>>

Return value

the signature over the message, if any

pub fn take_signature(&mut self) -> Option<Box<Record<TSIG>>>

Remove signatures from the Message

pub fn to_vec(&self) -> Result<Vec<u8>, ProtoError>

Encodes the Message into a buffer

Methods from Deref<Target = Metadata>

pub fn flags(&self) -> Flags

A method to get all header flags (useful for Display purposes)