RegistryUsage

Enum RegistryUsage 

pub enum RegistryUsage {
    Normal,
    Reserved,
}
Available on crate features dns and hickory and std only.
DNS Registries/Registrars:

How should DNS Registries/Registrars treat requests to register this reserved domain name? Should such requests be denied? Should such requests be allowed, but only to a specially- designated entity? (For example, the name “www.example.org” is reserved for documentation examples and is not available for registration; however, the name is in fact registered; and there is even a web site at that name, which states circularly that the name is reserved for use in documentation and cannot be registered!)

Variants



Normal

Standard checks apply



Reserved

DNS Registries/Registrars MUST NOT grant requests to register test names in the normal way to any person or entity. Test names are reserved for use in private networks and fall outside the set of names available for allocation by registries/registrars. Attempting to allocate a test name as if it were a normal DNS domain name will probably not work as desired, for reasons 4, 5, and 6 above.

DNS Registries/Registrars MUST NOT grant requests to register localhost names in the normal way to any person or entity. Localhost names are defined by protocol specification and fall outside the set of names available for allocation by registries/ registrars. Attempting to allocate a localhost name as if it were a normal DNS domain name will probably not work as desired, for reasons 2, 3, 4, and 5 above.

DNS Registries/Registrars MUST NOT grant requests to register “invalid” names in the normal way to any person or entity. These “invalid” names are defined by protocol specification to be nonexistent, and they fall outside the set of names available for allocation by registries/registrars. Attempting to allocate a “invalid” name as if it were a normal DNS domain name will probably not work as desired, for reasons 2, 3, 4, and 5 above.

DNS Registries/Registrars MUST NOT grant requests to register example names in the normal way to any person or entity. All example names are registered in perpetuity to IANA: