Struct HTTPS
pub struct HTTPS(pub SVCB);Available on crate features
dns and hickory and std only.Expand description
HTTPS is really a derivation of the original SVCB record data. See SVCB for more documentation
Tuple Fields
0: SVCBTrait Implementations
impl BinEncodable for HTTPS
impl BinEncodable for HTTPS
fn emit(&self, encoder: &mut BinEncoder<'_>) -> Result<(), ProtoError>
fn emit(&self, encoder: &mut BinEncoder<'_>) -> Result<(), ProtoError>
Write the type to the stream
impl<'de> Deserialize<'de> for HTTPS
impl<'de> Deserialize<'de> for HTTPS
fn deserialize<__D>(
__deserializer: __D,
) -> Result<HTTPS, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<HTTPS, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for HTTPS
impl RecordData for HTTPS
impl RecordData for HTTPS
fn try_borrow(data: &RData) -> Option<&HTTPS>
fn try_borrow(data: &RData) -> Option<&HTTPS>
Attempts to borrow this RecordData from the RData type, if it is not the correct type the original is returned
fn record_type(&self) -> RecordType
fn record_type(&self) -> RecordType
Get the associated RecordType for the RecordData
fn into_rdata(self) -> RData
fn into_rdata(self) -> RData
Converts this RecordData into generic RecordData
impl Serialize for HTTPS
impl Serialize for HTTPS
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for HTTPS