Struct SMIMEA
pub struct SMIMEA(pub TLSA);Available on crate features
dns and hickory and std only.Expand description
Tuple Fields
0: TLSAImplementations
impl SMIMEA
impl SMIMEA
pub fn new(
cert_usage: CertUsage,
selector: Selector,
matching: Matching,
cert_data: Vec<u8>,
) -> SMIMEA
pub fn new( cert_usage: CertUsage, selector: Selector, matching: Matching, cert_data: Vec<u8>, ) -> SMIMEA
Construct a new SMIMEA
2. The SMIMEA Resource Record
The SMIMEA DNS resource record (RR) is used to associate an end
entity certificate or public key with the associated email address,
thus forming a "SMIMEA certificate association". The semantics of
how the SMIMEA resource record is interpreted are given later in this
document. Note that the information returned in the SMIMEA record
might be for the end entity certificate, or it might be for the trust
anchor or an intermediate certificate. This mechanism is similar to
the one given in [RFC7929] for OpenPGP.
The type value for the SMIMEA RRtype is defined in Section 8. The
SMIMEA resource record is class independent.Trait Implementations
impl BinEncodable for SMIMEA
impl BinEncodable for SMIMEA
fn emit(&self, encoder: &mut BinEncoder<'_>) -> Result<(), ProtoError>
fn emit(&self, encoder: &mut BinEncoder<'_>) -> Result<(), ProtoError>
Write the type to the stream
impl<'de> Deserialize<'de> for SMIMEA
impl<'de> Deserialize<'de> for SMIMEA
fn deserialize<__D>(
__deserializer: __D,
) -> Result<SMIMEA, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<SMIMEA, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SMIMEA
impl RecordData for SMIMEA
impl RecordData for SMIMEA
fn try_borrow(data: &RData) -> Option<&SMIMEA>
fn try_borrow(data: &RData) -> Option<&SMIMEA>
Attempts to borrow this RecordData from the RData type, if it is not the correct type the original is returned
fn record_type(&self) -> RecordType
fn record_type(&self) -> RecordType
Get the associated RecordType for the RecordData
fn into_rdata(self) -> RData
fn into_rdata(self) -> RData
Converts this RecordData into generic RecordData
impl Serialize for SMIMEA
impl Serialize for SMIMEA
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for SMIMEA