Struct SOA
#[non_exhaustive]pub struct SOA {
pub mname: Name,
pub rname: Name,
pub serial: u32,
pub refresh: i32,
pub retry: i32,
pub expire: i32,
pub minimum: u32,
}Expand description
RFC 1035, DOMAIN NAMES - IMPLEMENTATION AND SPECIFICATION, November 1987
3.3.13. SOA RDATA format
+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+
/ MNAME /
/ /
+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+
/ RNAME /
+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+
| SERIAL |
| |
+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+
| REFRESH |
| |
+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+
| RETRY |
| |
+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+
| EXPIRE |
| |
+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+
| MINIMUM |
| |
+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+
where:
SOA records cause no additional section processing.
All times are in units of seconds.
Most of these fields are pertinent only for name server maintenance
operations. However, MINIMUM is used in all query operations that
retrieve RRs from a zone. Whenever a RR is sent in a response to a
query, the TTL field is set to the maximum of the TTL field from the RR
and the MINIMUM field in the appropriate SOA. Thus MINIMUM is a lower
bound on the TTL field for all RRs in a zone. Note that this use of
MINIMUM should occur when the RRs are copied into the response and not
when the zone is loaded from a Zone File or via a zone transfer. The
reason for this provision is to allow future dynamic update facilities to
change the SOA RR with known semantics.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.mname: NameThe domain-name of the name server that was the original or primary source of data for
this zone, i.e. the Primary Name Server.
MNAME The <domain-name> of the name server that was the
original or primary source of data for this zone.rname: NameA domain-name which specifies the mailbox of the person responsible for this zone, i.e.
the responsible name.
RNAME A <domain-name> which specifies the mailbox of the
person responsible for this zone.serial: u32The unsigned 32 bit version number of the original copy of the zone. Zone transfers preserve this value. This value wraps and should be compared using sequence space arithmetic.
SERIAL The unsigned 32 bit version number of the original copy
of the zone. Zone transfers preserve this value. This
value wraps and should be compared using sequence space
arithmetic.refresh: i32A 32 bit time interval before the zone should be refreshed, in seconds.
REFRESH A 32 bit time interval before the zone should be
refreshed.retry: i32A 32 bit time interval that should elapse before a failed refresh should be retried, in seconds.
RETRY A 32 bit time interval that should elapse before a
failed refresh should be retried.expire: i32A 32 bit time value that specifies the upper limit on the time interval that can elapse before the zone is no longer authoritative, in seconds
EXPIRE A 32 bit time value that specifies the upper limit on
the time interval that can elapse before the zone is no
longer authoritative.minimum: u32The unsigned 32 bit minimum TTL field that should be exported with any RR from this zone.
MINIMUM The unsigned 32 bit minimum TTL field that should be
exported with any RR from this zone.Implementations
impl SOA
impl SOA
pub fn new(
mname: Name,
rname: Name,
serial: u32,
refresh: i32,
retry: i32,
expire: i32,
minimum: u32,
) -> SOA
pub fn new( mname: Name, rname: Name, serial: u32, refresh: i32, retry: i32, expire: i32, minimum: u32, ) -> SOA
Creates a new SOA record data.
Arguments
mname- the name of the primary or authority for this zone.rname- the name of the responsible party for this zone, e.g. an email address.serial- the serial number of the zone, used for caching purposes.refresh- the amount of time to wait before a zone is resynched.retry- the minimum period to wait if there is a failure during refresh.expire- the time until this primary is no longer authoritative for the zone.minimum- no zone records should have time-to-live values less than this minimum.
Return value
The newly created SOA record data.
pub fn increment_serial(&mut self)
pub fn increment_serial(&mut self)
Increments the serial number by one