Trait RecordData
pub trait RecordData:
Sized
+ Clone
+ PartialEq
+ Eq
+ Display
+ Debug
+ BinEncodable {
// Required methods
fn try_borrow(data: &RData) -> Option<&Self>;
fn record_type(&self) -> RecordType;
fn into_rdata(self) -> RData;
// Provided method
fn is_update(&self) -> bool { ... }
}Available on crate features
dns and hickory only.Expand description
RecordData that is stored in a DNS Record.
This trait allows for generic usage of RecordData types inside the Record type. Specific RecordData types can be used to enforce compile time constraints on a Record.
Required Methods
fn try_borrow(data: &RData) -> Option<&Self>
fn try_borrow(data: &RData) -> Option<&Self>
Attempts to borrow this RecordData from the RData type, if it is not the correct type the original is returned
fn record_type(&self) -> RecordType
fn record_type(&self) -> RecordType
Get the associated RecordType for the RecordData
fn into_rdata(self) -> RData
fn into_rdata(self) -> RData
Converts this RecordData into generic RecordData
Provided Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".