Enum ParseError
#[non_exhaustive]pub enum ParseError {
Show 14 variants
CharToInt(char),
Message(&'static str),
MissingToken(String),
Msg(String),
ParseTime(String),
UnexpectedToken(Token),
AddrParse(AddrParseError),
DataEncoding(DecodeError),
Io(Error),
Lexer(LexerError),
ParseInt(ParseIntError),
Proto(ProtoError),
UnknownRecordType(u16),
UnsupportedRecordType(RecordType),
}Expand description
The error kind for parse errors that get returned in the crate
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
CharToInt(char)
An invalid numerical character was found
Message(&'static str)
An error with an arbitrary message, referenced as &’static str
MissingToken(String)
A token is missing
Msg(String)
An error with an arbitrary message, stored as String
ParseTime(String)
A time string could not be parsed
UnexpectedToken(Token)
Found an unexpected token in a stream
AddrParse(AddrParseError)
An address parse error
DataEncoding(DecodeError)
A data encoding error
Io(Error)
An error got returned from IO
Lexer(LexerError)
An error from the lexer
ParseInt(ParseIntError)
A number parsing error
Proto(ProtoError)
An error got returned by the hickory-proto crate
UnknownRecordType(u16)
Unknown RecordType
UnsupportedRecordType(RecordType)
Unknown RecordType