Struct BufDnsStreamHandle
pub struct BufDnsStreamHandle { /* private fields */ }Available on crate features
dns and hickory only.Expand description
A buffered channel for outbound DNS messages on a connection.
Used to queue messages for sending over a DNS connection. On the client/resolver side, this buffers outbound queries to nameservers. On the server side, this buffers outbound responses to clients.
Implementations
impl BufDnsStreamHandle
impl BufDnsStreamHandle
pub fn new(
remote_addr: SocketAddr,
) -> (BufDnsStreamHandle, Peekable<Fuse<Receiver<SerialMessage>>>)
pub fn new( remote_addr: SocketAddr, ) -> (BufDnsStreamHandle, Peekable<Fuse<Receiver<SerialMessage>>>)
Constructs a new buffered stream handle with the default buffer size (32).
Arguments
remote_addr- address of the DNS peer (nameserver for clients, client for servers)
pub fn with_buffer_size(
remote_addr: SocketAddr,
buffer_size: usize,
) -> (BufDnsStreamHandle, Peekable<Fuse<Receiver<SerialMessage>>>)
pub fn with_buffer_size( remote_addr: SocketAddr, buffer_size: usize, ) -> (BufDnsStreamHandle, Peekable<Fuse<Receiver<SerialMessage>>>)
Constructs a new buffered stream handle with an explicit buffer size.
Use this when you need a larger buffer to handle high message rates without dropping messages due to backpressure.
Arguments
remote_addr- address of the DNS peer (nameserver for clients, client for servers)buffer_size- maximum number of messages that can be queued for sending
pub fn with_remote_addr(&self, remote_addr: SocketAddr) -> BufDnsStreamHandle
pub fn with_remote_addr(&self, remote_addr: SocketAddr) -> BufDnsStreamHandle
Associates a different remote address for any responses.
This is mainly useful in server use cases where the incoming address is only known after receiving a packet.