Struct DnsExchange
pub struct DnsExchange<P> { /* private fields */ }Expand description
This is a generic Exchange implemented over multiplexed DNS connection providers.
The underlying DnsRequestSender is expected to multiplex any I/O connections. DnsExchange assumes that the underlying stream is responsible for this.
Implementations
impl<P> DnsExchange<P>where
P: RuntimeProvider,
impl<P> DnsExchange<P>where
P: RuntimeProvider,
pub fn from_stream<S>(
stream: S,
) -> (DnsExchange<P>, DnsExchangeBackground<S, <P as RuntimeProvider>::Timer>)where
S: DnsRequestSender,
pub fn from_stream<S>(
stream: S,
) -> (DnsExchange<P>, DnsExchangeBackground<S, <P as RuntimeProvider>::Timer>)where
S: DnsRequestSender,
Initializes a TcpStream with an existing tcp::TcpStream.
This is intended for use with a TcpListener and Incoming.
Arguments
stream- the established IO stream for communication