Struct RetryDnsHandle
pub struct RetryDnsHandle<H> { /* private fields */ }Expand description
Can be used to reattempt queries if they fail
Note: this does not reattempt queries that fail with a negative response.
For example, if a query gets a NODATA response from a name server, the
query will not be retried. It only reattempts queries that effectively
failed to get a response, such as queries that resulted in IO or timeout
errors.
note Current value of this is not clear, it may be removed
Implementations
impl<H> RetryDnsHandle<H>
impl<H> RetryDnsHandle<H>
pub fn new(handle: H, attempts: usize) -> RetryDnsHandle<H>
pub fn new(handle: H, attempts: usize) -> RetryDnsHandle<H>
Creates a new Client handler for reattempting requests on failures.
Arguments
handle- handle to the dns connectionattempts- number of attempts before failing