Struct NameServer
pub struct NameServer<P>where
P: ConnectionProvider,{ /* private fields */ }Available on crate features
dns and hickory and std only.Expand description
A remote DNS server, identified by its IP address.
This potentially holds multiple open connections to the server, according to the configured protocols, and will make new connections as needed.
Implementations
impl<P> NameServer<P>where
P: ConnectionProvider,
impl<P> NameServer<P>where
P: ConnectionProvider,
pub fn new(
connections: impl IntoIterator<Item = (Protocol, <P as ConnectionProvider>::Conn)>,
config: NameServerConfig,
options: &ResolverOpts,
connection_provider: P,
) -> NameServer<P>
pub fn new( connections: impl IntoIterator<Item = (Protocol, <P as ConnectionProvider>::Conn)>, config: NameServerConfig, options: &ResolverOpts, connection_provider: P, ) -> NameServer<P>
Create a new NameServer with the given connections and configuration.
The connections will usually be empty.