Struct TlsConfig
pub struct TlsConfig {}Expand description
TLS configuration for the connection provider.
Implementations
impl TlsConfig
impl TlsConfig
pub fn insecure_skip_verify(&mut self)
pub fn insecure_skip_verify(&mut self)
Disable certificate verification.
This is typically unsafe and insecure, except in the context of RFC 9539 opportunistic encryption which requires the peer certificate not be verified.