RecordType

Enum RecordType 

#[non_exhaustive]
pub enum RecordType {
Show 38 variants A, AAAA, ANAME, ANY, AXFR, CAA, CDS, CDNSKEY, CERT, CNAME, CSYNC, DNSKEY, DS, HINFO, HTTPS, IXFR, KEY, MX, NAPTR, NS, NSEC, NSEC3, NSEC3PARAM, NULL, OPENPGPKEY, OPT, PTR, RRSIG, SIG, SOA, SRV, SSHFP, SVCB, TLSA, TSIG, TXT, Unknown(u16), ZERO,
}
The type of the resource record.

This specifies the type of data in the RData field of the Resource Record

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


A

RFC 1035 IPv4 Address record



AAAA

RFC 3596 IPv6 address record



ANAME



ANY

RFC 1035 All cached records, aka ANY



AXFR

RFC 1035 Authoritative Zone Transfer



CAA

RFC 6844 Certification Authority Authorization



CDS

RFC 7344 Child DS



CDNSKEY

RFC 7344 Child DNSKEY



CERT

RFC 4398 Storing Certificates in the Domain Name System (DNS)



CNAME

RFC 1035 Canonical name record



CSYNC

RFC 7477 Child-to-parent synchronization record



DNSKEY

RFC 4034 DNS Key record: RSASHA256 and RSASHA512, RFC5702



DS

RFC 4034 Delegation signer: RSASHA256 and RSASHA512, RFC5702



HINFO

RFC 1035 host information



HTTPS

RFC 9460 DNS SVCB and HTTPS RRs



IXFR

RFC 1996 Incremental Zone Transfer



KEY

RFC 2535 and RFC 2930 Key record



MX

RFC 1035 Mail exchange record



NAPTR

RFC 3403 Naming Authority Pointer



NS

RFC 1035 Name server record



NSEC

RFC 4034 Next-Secure record



NSEC3

RFC 5155 NSEC record version 3



NSEC3PARAM

RFC 5155 NSEC3 parameters



NULL

RFC 1035 Null server record, for testing



OPENPGPKEY

RFC 7929 OpenPGP public key



OPT

RFC 6891 Option



PTR

RFC 1035 Pointer record



RRSIG

RFC 4034 DNSSEC signature: RSASHA256 and RSASHA512, RFC5702



SIG

RFC 2535 (and RFC 2931) Signature, to support RFC 2137 Update.



SOA

RFC 1035 and RFC 2308 Start of [a zone of] authority record



SRV

RFC 2782 Service locator



SSHFP

RFC 4255 SSH Public Key Fingerprint



SVCB

RFC 9460 DNS SVCB and HTTPS RRs



TLSA

RFC 6698 TLSA certificate association



TSIG

RFC 8945 Transaction Signature



TXT

RFC 1035 Text record



Unknown(u16)

Unknown Record type, or unsupported



ZERO

This corresponds to a record type of 0, unspecified

Implementations



impl RecordType

pub fn is_any(self) -> bool

Returns true if this is an ANY

pub fn is_cert(self) -> bool

Returns true if this is a CERT

pub fn is_cname(self) -> bool

Returns true if this is a CNAME

pub fn is_ns(self) -> bool

Returns true if this is an NS

pub fn is_soa(self) -> bool

Returns true if this is an SOA

pub fn is_srv(self) -> bool

Returns true if this is an SRV

pub fn is_ip_addr(self) -> bool

Returns true if this is an A or an AAAA record

pub fn is_dnssec(self) -> bool

Returns true if this is a DNSSEC RecordType

pub fn is_rrsig(self) -> bool

Returns true if this is an RRSIG RecordType

pub fn is_zero(self) -> bool

Returns true if this is a Zero (unspecified) RecordType