Enum SvcParam
#[non_exhaustive]pub enum SvcParam {
Mandatory(Box<[SvcParamKey]>),
Alpn(AlpnList),
NoDefaultAlpn,
Port(u16),
Ipv4Hint(Box<[Ipv4Addr]>),
Ech(Bytes),
Ipv6Hint(Box<[Ipv6Addr]>),
Unknown {
key: SvcParamKey,
value: Bytes,
},
}Available on crate features
dns and std only.Expand description
A decoded service binding parameter.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Mandatory(Box<[SvcParamKey]>)
Keys that a client must understand in order to use this record.
Alpn(AlpnList)
ALPN protocol identifiers, each containing between 1 and 255 octets.
NoDefaultAlpn
Indicates that the protocol mapping’s default ALPN set is unsupported.
Port(u16)
TCP or UDP port for the alternative endpoint.
Ipv4Hint(Box<[Ipv4Addr]>)
IPv4 address hints.
Ech(Bytes)
An RFC 9848 ECHConfigList, including its redundant length prefix.
DNS validates the list framing but leaves version-specific ECHConfig interpretation to TLS.
Ipv6Hint(Box<[Ipv6Addr]>)
IPv6 address hints.
Unknown
A parameter whose key or wire format Rama does not yet understand.
Implementations
impl SvcParam
impl SvcParam
pub const fn key(&self) -> SvcParamKey
pub const fn key(&self) -> SvcParamKey
Return this parameter’s numeric key.