Enum SvcParamKey
#[non_exhaustive]pub enum SvcParamKey {
Mandatory,
Alpn,
NoDefaultAlpn,
Port,
Ipv4Hint,
Ech,
Ipv6Hint,
Invalid,
Unknown(u16),
}dns and std only.Expand description
Numeric key for a service binding parameter.
The values defined for this implementation are the parameters used by
RFC 9460 and RFC 9848. Other registry values are retained by
SvcParamKey::Unknown.
Registry keys from other protocols remain unknown until Rama supports
the protocol that defines their semantics.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Mandatory
Lists parameters that a client must understand.
Alpn
Lists supported application protocols.
NoDefaultAlpn
Suppresses the protocol mapping’s default ALPN set.
Port
Overrides the authority endpoint’s port.
Ipv4Hint
Carries IPv4 address hints.
Ech
Carries a TLS Encrypted ClientHello configuration list.
Ipv6Hint
Carries IPv6 address hints.
Invalid
Reserved by RFC 9460 as the invalid service parameter key.
Unknown(u16)
Retains an unrecognized numeric value.