Struct TracingErrorSink
pub struct TracingErrorSink { /* private fields */ }Expand description
An ErrorSink that emits errors via tracing at a configurable level.
This is the fallback sink used by rama components that accept an
ErrorSink: when none is configured they use TracingErrorSink::default,
which logs at tracing::Level::DEBUG.
Implementations
impl TracingErrorSink
impl TracingErrorSink
pub const fn new(level: Level) -> TracingErrorSink
pub const fn new(level: Level) -> TracingErrorSink
Create a TracingErrorSink emitting at the given tracing::Level.
pub const fn trace() -> TracingErrorSink
pub const fn trace() -> TracingErrorSink
Emit at tracing::Level::TRACE.
pub const fn debug() -> TracingErrorSink
pub const fn debug() -> TracingErrorSink
Emit at tracing::Level::DEBUG (the default).
pub const fn info() -> TracingErrorSink
pub const fn info() -> TracingErrorSink
Emit at tracing::Level::INFO.
pub const fn warn() -> TracingErrorSink
pub const fn warn() -> TracingErrorSink
Emit at tracing::Level::WARN.
pub const fn error() -> TracingErrorSink
pub const fn error() -> TracingErrorSink
Emit at tracing::Level::ERROR.