Struct TypeErasedExtension
pub struct TypeErasedExtension { /* private fields */ }Expand description
A TypeErasedExtension is a type erased item which can be stored in an Extensions
Internally the value is stored inside an Arc so this is cheap to clone
Implementations
impl TypeErasedExtension
impl TypeErasedExtension
pub fn new<T>(value: T) -> TypeErasedExtensionwhere
T: Extension,
pub fn new<T>(value: T) -> TypeErasedExtensionwhere
T: Extension,
Create a new TypeErasedExtension for T
If the value you are inserting is an Arc<T>, prefer using
Self::new_arc() to prevent the double indirection of storing
an Arc<Arc<T>>. This happens because internally we use a type erased
Arc to store the actual value.
pub fn new_arc<T>(value: Arc<T>) -> TypeErasedExtensionwhere
T: Extension,
pub fn new_arc<T>(value: Arc<T>) -> TypeErasedExtensionwhere
T: Extension,
Create a new TypeErasedExtension for Arc<T>
If the value you are inserting is not an Arc<T> prefer using
Self::new() instead.
pub fn cloned_downcast<T>(&self) -> Option<Arc<T>>where
T: Extension,
pub fn cloned_downcast<T>(&self) -> Option<Arc<T>>where
T: Extension,
Get a cloned Arc<T> of the internally stored type Arc<T>
This method will return None, if the internally stored
type S doesn’t match the requested type T
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: Extension,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: Extension,
Get a reference &T of the internally stored type T
This method will return None, if the internally stored
type S doesn’t match the requested type T