Trait ExtensionsMut
pub trait ExtensionsMut: ExtensionsRef {
// Required method
fn extensions_mut(&mut self) -> &mut Extensions;
}Expand description
Exclusive access to an owned input’s extension store.
Replacing the store permits request-local overlays without mutating stores shared by cloned inputs. Individual extension values remain shared.
Required Methods
fn extensions_mut(&mut self) -> &mut Extensions
fn extensions_mut(&mut self) -> &mut Extensions
Get the replaceable extension store owned by this input.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".