GetManyRef

Trait GetManyRef 

pub trait GetManyRef<'a>: Sized {
    type Output;
}
Helper trait powering Extensions::get_many_ref: implemented for tuples of Extension types (up to arity 12).

Required Associated Types

type Output

Tuple of Option<&'a T> mirroring the requested tuple of types.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types



impl<'a, A, B, C, D, E, F, G, H, I, J, K, L> GetManyRef<'a> for (A, B, C, D, E, F, G, H, I, J, K, L)



impl<'a, A, B, C, D, E, F, G, H, I, J, K> GetManyRef<'a> for (A, B, C, D, E, F, G, H, I, J, K)



impl<'a, A, B, C, D, E, F, G, H, I, J> GetManyRef<'a> for (A, B, C, D, E, F, G, H, I, J)



impl<'a, A, B, C, D, E, F, G, H, I> GetManyRef<'a> for (A, B, C, D, E, F, G, H, I)



impl<'a, A, B, C, D, E, F, G, H> GetManyRef<'a> for (A, B, C, D, E, F, G, H)



impl<'a, A, B, C, D, E, F, G> GetManyRef<'a> for (A, B, C, D, E, F, G)



impl<'a, A, B, C, D, E, F> GetManyRef<'a> for (A, B, C, D, E, F)



impl<'a, A, B, C, D, E> GetManyRef<'a> for (A, B, C, D, E)
where A: Extension, B: Extension, C: Extension, D: Extension, E: Extension,



impl<'a, A, B, C, D> GetManyRef<'a> for (A, B, C, D)
where A: Extension, B: Extension, C: Extension, D: Extension,



impl<'a, A, B, C> GetManyRef<'a> for (A, B, C)
where A: Extension, B: Extension, C: Extension,



impl<'a, A, B> GetManyRef<'a> for (A, B)
where A: Extension, B: Extension,



impl<'a, A> GetManyRef<'a> for (A,)
where A: Extension,



type Output = (Option<&'a A>,)

Implementors