Trait FusedFuture
pub trait FusedFuture: Future {
// Required method
fn is_terminated(&self) -> bool;
}Expand description
A future which tracks whether or not the underlying future should no longer be polled.
is_terminated will return true if a future should no longer be polled.
Usually, this state occurs after poll (or try_poll) returned
Poll::Ready. However, is_terminated may also return true if a future
has become inactive and can no longer make progress and should be ignored
or dropped rather than being polled again.
Required Methods
fn is_terminated(&self) -> bool
fn is_terminated(&self) -> bool
Returns true if the underlying future should no longer be polled.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
impl<'a, T> FusedFuture for RecvFut<'a, T>
impl<'a, T> FusedFuture for RecvFut<'a, T>
fn is_terminated(&self) -> bool
impl<'a, T> FusedFuture for SendFut<'a, T>
impl<'a, T> FusedFuture for SendFut<'a, T>
fn is_terminated(&self) -> bool
impl<F> FusedFuture for &mut F
impl<F> FusedFuture for &mut F
fn is_terminated(&self) -> bool
impl<F> FusedFuture for AssertUnwindSafe<F>where
F: FusedFuture,
Available on crate feature std only.
impl<F> FusedFuture for AssertUnwindSafe<F>where
F: FusedFuture,
Available on crate feature
std only.