Struct Scan
pub struct Scan<St, S, Fut, F>where
St: Stream,{ /* private fields */ }Expand description
Stream for the scan method.
Implementations
impl<B, St, S, Fut, F> Scan<St, S, Fut, F>
impl<B, St, S, Fut, F> Scan<St, S, Fut, F>
pub fn get_ref(&self) -> &St
pub fn get_ref(&self) -> &St
Acquires a reference to the underlying sink or stream that this combinator is pulling from.
pub fn get_mut(&mut self) -> &mut St
pub fn get_mut(&mut self) -> &mut St
Acquires a mutable reference to the underlying sink or stream that this combinator is pulling from.
Note that care must be taken to avoid tampering with the state of the sink or stream which may otherwise confuse this combinator.
pub fn get_pin_mut(self: Pin<&mut Scan<St, S, Fut, F>>) -> Pin<&mut St>
pub fn get_pin_mut(self: Pin<&mut Scan<St, S, Fut, F>>) -> Pin<&mut St>
Acquires a pinned mutable reference to the underlying sink or stream that this combinator is pulling from.
Note that care must be taken to avoid tampering with the state of the sink or stream which may otherwise confuse this combinator.
pub fn into_inner(self) -> St
pub fn into_inner(self) -> St
Consumes this combinator, returning the underlying sink or stream.
Note that this may discard intermediate state of this combinator, so care should be taken to avoid losing resources when this is called.