LanguageRef

Enum LanguageRef 

pub enum LanguageRef<'a> {
Show 184 variants Afar, Abkhazian, Avestan, Afrikaans, Akan, Amharic, Aragonese, Arabic, Assamese, Avaric, Aymara, Azerbaijani, Bashkir, Belarusian, Bulgarian, Bislama, Bambara, Bengali, Tibetan, Breton, Bosnian, Catalan, Chechen, Chamorro, Corsican, Cree, Czech, ChurchSlavic, Chuvash, Welsh, Danish, German, Divehi, Dzongkha, Ewe, Greek, English, Esperanto, Spanish, Estonian, Basque, Persian, Fulah, Finnish, Fijian, Faroese, French, WesternFrisian, Irish, Gaelic, Galician, Guarani, Gujarati, Manx, Hausa, Hebrew, Hindi, HiriMotu, Croatian, Haitian, Hungarian, Armenian, Herero, Interlingua, Indonesian, Interlingue, Igbo, SichuanYi, Inupiaq, Ido, Icelandic, Italian, Inuktitut, Japanese, Javanese, Georgian, Kongo, Kikuyu, Kuanyama, Kazakh, Kalaallisut, CentralKhmer, Kannada, Korean, Kanuri, Kashmiri, Kurdish, Komi, Cornish, Kirghiz, Latin, Luxembourgish, Ganda, Limburgan, Lingala, Lao, Lithuanian, LubaKatanga, Latvian, Malagasy, Marshallese, Maori, Macedonian, Malayalam, Mongolian, Marathi, Malay, Maltese, Burmese, Nauru, NorwegianBokmal, NorthNdebele, Nepali, Ndonga, Dutch, NorwegianNynorsk, Norwegian, SouthNdebele, Navajo, Chichewa, Occitan, Ojibwa, Oromo, Oriya, Ossetian, Panjabi, Pali, Polish, Pushto, Portuguese, Quechua, Romansh, Rundi, Romanian, Russian, Kinyarwanda, Sanskrit, Sardinian, Sindhi, NorthernSami, Sango, Sinhala, Slovak, Slovenian, Samoan, Shona, Somali, Albanian, Serbian, Swati, Sotho, Sundanese, Swedish, Swahili, Tamil, Telugu, Tajik, Thai, Tigrinya, Turkmen, Tagalog, Tswana, Tonga, Turkish, Tsonga, Tatar, Twi, Tahitian, Uighur, Ukrainian, Urdu, Uzbek, Venda, Vietnamese, Volapuk, Walloon, Wolof, Xhosa, Yiddish, Yoruba, Zhuang, Chinese, Zulu, Unknown(&'a str),
}
Borrowing, Copy counterpart of Language.

Variants



Afar

Afar (ISO 639-1 aa, ISO 639-2 aar)



Abkhazian

Abkhazian (ISO 639-1 ab, ISO 639-2 abk)



Avestan

Avestan (ISO 639-1 ae, ISO 639-2 ave)



Afrikaans

Afrikaans (ISO 639-1 af, ISO 639-2 afr)



Akan

Akan (ISO 639-1 ak, ISO 639-2 aka)



Amharic

Amharic (ISO 639-1 am, ISO 639-2 amh)



Aragonese

Aragonese (ISO 639-1 an, ISO 639-2 arg)



Arabic

Arabic (ISO 639-1 ar, ISO 639-2 ara)



Assamese

Assamese (ISO 639-1 as, ISO 639-2 asm)



Avaric

Avaric (ISO 639-1 av, ISO 639-2 ava)



Aymara

Aymara (ISO 639-1 ay, ISO 639-2 aym)



Azerbaijani

Azerbaijani (ISO 639-1 az, ISO 639-2 aze)



Bashkir

Bashkir (ISO 639-1 ba, ISO 639-2 bak)



Belarusian

Belarusian (ISO 639-1 be, ISO 639-2 bel)



Bulgarian

Bulgarian (ISO 639-1 bg, ISO 639-2 bul)



Bislama

Bislama (ISO 639-1 bi, ISO 639-2 bis)



Bambara

Bambara (ISO 639-1 bm, ISO 639-2 bam)



Bengali

Bengali (ISO 639-1 bn, ISO 639-2 ben)



Tibetan

Tibetan (ISO 639-1 bo, ISO 639-2 bod, /B tib)



Breton

Breton (ISO 639-1 br, ISO 639-2 bre)



Bosnian

Bosnian (ISO 639-1 bs, ISO 639-2 bos)



Catalan

Catalan; Valencian (ISO 639-1 ca, ISO 639-2 cat)



Chechen

Chechen (ISO 639-1 ce, ISO 639-2 che)



Chamorro

Chamorro (ISO 639-1 ch, ISO 639-2 cha)



Corsican

Corsican (ISO 639-1 co, ISO 639-2 cos)



Cree

Cree (ISO 639-1 cr, ISO 639-2 cre)



Czech

Czech (ISO 639-1 cs, ISO 639-2 ces, /B cze)



ChurchSlavic

Church Slavic; Old Slavonic; Church Slavonic; Old Bulgarian; Old Church Slavonic (ISO 639-1 cu, ISO 639-2 chu)



Chuvash

Chuvash (ISO 639-1 cv, ISO 639-2 chv)



Welsh

Welsh (ISO 639-1 cy, ISO 639-2 cym, /B wel)



Danish

Danish (ISO 639-1 da, ISO 639-2 dan)



German

German (ISO 639-1 de, ISO 639-2 deu, /B ger)



Divehi

Divehi; Dhivehi; Maldivian (ISO 639-1 dv, ISO 639-2 div)



Dzongkha

Dzongkha (ISO 639-1 dz, ISO 639-2 dzo)



Ewe

Ewe (ISO 639-1 ee, ISO 639-2 ewe)



Greek

Greek, Modern (1453-) (ISO 639-1 el, ISO 639-2 ell, /B gre)



English

English (ISO 639-1 en, ISO 639-2 eng)



Esperanto

Esperanto (ISO 639-1 eo, ISO 639-2 epo)



Spanish

Spanish; Castilian (ISO 639-1 es, ISO 639-2 spa)



Estonian

Estonian (ISO 639-1 et, ISO 639-2 est)



Basque

Basque (ISO 639-1 eu, ISO 639-2 eus, /B baq)



Persian

Persian (ISO 639-1 fa, ISO 639-2 fas, /B per)



Fulah

Fulah (ISO 639-1 ff, ISO 639-2 ful)



Finnish

Finnish (ISO 639-1 fi, ISO 639-2 fin)



Fijian

Fijian (ISO 639-1 fj, ISO 639-2 fij)



Faroese

Faroese (ISO 639-1 fo, ISO 639-2 fao)



French

French (ISO 639-1 fr, ISO 639-2 fra, /B fre)



WesternFrisian

Western Frisian (ISO 639-1 fy, ISO 639-2 fry)



Irish

Irish (ISO 639-1 ga, ISO 639-2 gle)



Gaelic

Gaelic; Scottish Gaelic (ISO 639-1 gd, ISO 639-2 gla)



Galician

Galician (ISO 639-1 gl, ISO 639-2 glg)



Guarani

Guarani (ISO 639-1 gn, ISO 639-2 grn)



Gujarati

Gujarati (ISO 639-1 gu, ISO 639-2 guj)



Manx

Manx (ISO 639-1 gv, ISO 639-2 glv)



Hausa

Hausa (ISO 639-1 ha, ISO 639-2 hau)



Hebrew

Hebrew (ISO 639-1 he, ISO 639-2 heb)



Hindi

Hindi (ISO 639-1 hi, ISO 639-2 hin)



HiriMotu

Hiri Motu (ISO 639-1 ho, ISO 639-2 hmo)



Croatian

Croatian (ISO 639-1 hr, ISO 639-2 hrv)



Haitian

Haitian; Haitian Creole (ISO 639-1 ht, ISO 639-2 hat)



Hungarian

Hungarian (ISO 639-1 hu, ISO 639-2 hun)



Armenian

Armenian (ISO 639-1 hy, ISO 639-2 hye, /B arm)



Herero

Herero (ISO 639-1 hz, ISO 639-2 her)



Interlingua

Interlingua (International Auxiliary Language Association) (ISO 639-1 ia, ISO 639-2 ina)



Indonesian

Indonesian (ISO 639-1 id, ISO 639-2 ind)



Interlingue

Interlingue; Occidental (ISO 639-1 ie, ISO 639-2 ile)



Igbo

Igbo (ISO 639-1 ig, ISO 639-2 ibo)



SichuanYi

Sichuan Yi; Nuosu (ISO 639-1 ii, ISO 639-2 iii)



Inupiaq

Inupiaq (ISO 639-1 ik, ISO 639-2 ipk)



Ido

Ido (ISO 639-1 io, ISO 639-2 ido)



Icelandic

Icelandic (ISO 639-1 is, ISO 639-2 isl, /B ice)



Italian

Italian (ISO 639-1 it, ISO 639-2 ita)



Inuktitut

Inuktitut (ISO 639-1 iu, ISO 639-2 iku)



Japanese

Japanese (ISO 639-1 ja, ISO 639-2 jpn)



Javanese

Javanese (ISO 639-1 jv, ISO 639-2 jav)



Georgian

Georgian (ISO 639-1 ka, ISO 639-2 kat, /B geo)



Kongo

Kongo (ISO 639-1 kg, ISO 639-2 kon)



Kikuyu

Kikuyu; Gikuyu (ISO 639-1 ki, ISO 639-2 kik)



Kuanyama

Kuanyama; Kwanyama (ISO 639-1 kj, ISO 639-2 kua)



Kazakh

Kazakh (ISO 639-1 kk, ISO 639-2 kaz)



Kalaallisut

Kalaallisut; Greenlandic (ISO 639-1 kl, ISO 639-2 kal)



CentralKhmer

Central Khmer (ISO 639-1 km, ISO 639-2 khm)



Kannada

Kannada (ISO 639-1 kn, ISO 639-2 kan)



Korean

Korean (ISO 639-1 ko, ISO 639-2 kor)



Kanuri

Kanuri (ISO 639-1 kr, ISO 639-2 kau)



Kashmiri

Kashmiri (ISO 639-1 ks, ISO 639-2 kas)



Kurdish

Kurdish (ISO 639-1 ku, ISO 639-2 kur)



Komi

Komi (ISO 639-1 kv, ISO 639-2 kom)



Cornish

Cornish (ISO 639-1 kw, ISO 639-2 cor)



Kirghiz

Kirghiz; Kyrgyz (ISO 639-1 ky, ISO 639-2 kir)



Latin

Latin (ISO 639-1 la, ISO 639-2 lat)



Luxembourgish

Luxembourgish; Letzeburgesch (ISO 639-1 lb, ISO 639-2 ltz)



Ganda

Ganda (ISO 639-1 lg, ISO 639-2 lug)



Limburgan

Limburgan; Limburger; Limburgish (ISO 639-1 li, ISO 639-2 lim)



Lingala

Lingala (ISO 639-1 ln, ISO 639-2 lin)



Lao

Lao (ISO 639-1 lo, ISO 639-2 lao)



Lithuanian

Lithuanian (ISO 639-1 lt, ISO 639-2 lit)



LubaKatanga

Luba-Katanga (ISO 639-1 lu, ISO 639-2 lub)



Latvian

Latvian (ISO 639-1 lv, ISO 639-2 lav)



Malagasy

Malagasy (ISO 639-1 mg, ISO 639-2 mlg)



Marshallese

Marshallese (ISO 639-1 mh, ISO 639-2 mah)



Maori

Maori (ISO 639-1 mi, ISO 639-2 mri, /B mao)



Macedonian

Macedonian (ISO 639-1 mk, ISO 639-2 mkd, /B mac)



Malayalam

Malayalam (ISO 639-1 ml, ISO 639-2 mal)



Mongolian

Mongolian (ISO 639-1 mn, ISO 639-2 mon)



Marathi

Marathi (ISO 639-1 mr, ISO 639-2 mar)



Malay

Malay (ISO 639-1 ms, ISO 639-2 msa, /B may)



Maltese

Maltese (ISO 639-1 mt, ISO 639-2 mlt)



Burmese

Burmese (ISO 639-1 my, ISO 639-2 mya, /B bur)



Nauru

Nauru (ISO 639-1 na, ISO 639-2 nau)



NorwegianBokmal

Norwegian Bokmål (ISO 639-1 nb, ISO 639-2 nob)



NorthNdebele

North Ndebele (ISO 639-1 nd, ISO 639-2 nde)



Nepali

Nepali (ISO 639-1 ne, ISO 639-2 nep)



Ndonga

Ndonga (ISO 639-1 ng, ISO 639-2 ndo)



Dutch

Dutch; Flemish (ISO 639-1 nl, ISO 639-2 nld, /B dut)



NorwegianNynorsk

Norwegian Nynorsk (ISO 639-1 nn, ISO 639-2 nno)



Norwegian

Norwegian (ISO 639-1 no, ISO 639-2 nor)



SouthNdebele

South Ndebele (ISO 639-1 nr, ISO 639-2 nbl)



Navajo

Navajo; Navaho (ISO 639-1 nv, ISO 639-2 nav)



Chichewa

Chichewa; Chewa; Nyanja (ISO 639-1 ny, ISO 639-2 nya)



Occitan

Occitan (post 1500) (ISO 639-1 oc, ISO 639-2 oci)



Ojibwa

Ojibwa (ISO 639-1 oj, ISO 639-2 oji)



Oromo

Oromo (ISO 639-1 om, ISO 639-2 orm)



Oriya

Oriya (ISO 639-1 or, ISO 639-2 ori)



Ossetian

Ossetian; Ossetic (ISO 639-1 os, ISO 639-2 oss)



Panjabi

Panjabi; Punjabi (ISO 639-1 pa, ISO 639-2 pan)



Pali

Pali (ISO 639-1 pi, ISO 639-2 pli)



Polish

Polish (ISO 639-1 pl, ISO 639-2 pol)



Pushto

Pushto; Pashto (ISO 639-1 ps, ISO 639-2 pus)



Portuguese

Portuguese (ISO 639-1 pt, ISO 639-2 por)



Quechua

Quechua (ISO 639-1 qu, ISO 639-2 que)



Romansh

Romansh (ISO 639-1 rm, ISO 639-2 roh)



Rundi

Rundi (ISO 639-1 rn, ISO 639-2 run)



Romanian

Romanian; Moldavian; Moldovan (ISO 639-1 ro, ISO 639-2 ron, /B rum)



Russian

Russian (ISO 639-1 ru, ISO 639-2 rus)



Kinyarwanda

Kinyarwanda (ISO 639-1 rw, ISO 639-2 kin)



Sanskrit

Sanskrit (ISO 639-1 sa, ISO 639-2 san)



Sardinian

Sardinian (ISO 639-1 sc, ISO 639-2 srd)



Sindhi

Sindhi (ISO 639-1 sd, ISO 639-2 snd)



NorthernSami

Northern Sami (ISO 639-1 se, ISO 639-2 sme)



Sango

Sango (ISO 639-1 sg, ISO 639-2 sag)



Sinhala

Sinhala; Sinhalese (ISO 639-1 si, ISO 639-2 sin)



Slovak

Slovak (ISO 639-1 sk, ISO 639-2 slk, /B slo)



Slovenian

Slovenian (ISO 639-1 sl, ISO 639-2 slv)



Samoan

Samoan (ISO 639-1 sm, ISO 639-2 smo)



Shona

Shona (ISO 639-1 sn, ISO 639-2 sna)



Somali

Somali (ISO 639-1 so, ISO 639-2 som)



Albanian

Albanian (ISO 639-1 sq, ISO 639-2 sqi, /B alb)



Serbian

Serbian (ISO 639-1 sr, ISO 639-2 srp)



Swati

Swati (ISO 639-1 ss, ISO 639-2 ssw)



Sotho

Sotho, Southern (ISO 639-1 st, ISO 639-2 sot)



Sundanese

Sundanese (ISO 639-1 su, ISO 639-2 sun)



Swedish

Swedish (ISO 639-1 sv, ISO 639-2 swe)



Swahili

Swahili (ISO 639-1 sw, ISO 639-2 swa)



Tamil

Tamil (ISO 639-1 ta, ISO 639-2 tam)



Telugu

Telugu (ISO 639-1 te, ISO 639-2 tel)



Tajik

Tajik (ISO 639-1 tg, ISO 639-2 tgk)



Thai

Thai (ISO 639-1 th, ISO 639-2 tha)



Tigrinya

Tigrinya (ISO 639-1 ti, ISO 639-2 tir)



Turkmen

Turkmen (ISO 639-1 tk, ISO 639-2 tuk)



Tagalog

Tagalog (ISO 639-1 tl, ISO 639-2 tgl)



Tswana

Tswana (ISO 639-1 tn, ISO 639-2 tsn)



Tonga

Tonga (Tonga Islands) (ISO 639-1 to, ISO 639-2 ton)



Turkish

Turkish (ISO 639-1 tr, ISO 639-2 tur)



Tsonga

Tsonga (ISO 639-1 ts, ISO 639-2 tso)



Tatar

Tatar (ISO 639-1 tt, ISO 639-2 tat)



Twi

Twi (ISO 639-1 tw, ISO 639-2 twi)



Tahitian

Tahitian (ISO 639-1 ty, ISO 639-2 tah)



Uighur

Uighur; Uyghur (ISO 639-1 ug, ISO 639-2 uig)



Ukrainian

Ukrainian (ISO 639-1 uk, ISO 639-2 ukr)



Urdu

Urdu (ISO 639-1 ur, ISO 639-2 urd)



Uzbek

Uzbek (ISO 639-1 uz, ISO 639-2 uzb)



Venda

Venda (ISO 639-1 ve, ISO 639-2 ven)



Vietnamese

Vietnamese (ISO 639-1 vi, ISO 639-2 vie)



Volapuk

Volapük (ISO 639-1 vo, ISO 639-2 vol)



Walloon

Walloon (ISO 639-1 wa, ISO 639-2 wln)



Wolof

Wolof (ISO 639-1 wo, ISO 639-2 wol)



Xhosa

Xhosa (ISO 639-1 xh, ISO 639-2 xho)



Yiddish

Yiddish (ISO 639-1 yi, ISO 639-2 yid)



Yoruba

Yoruba (ISO 639-1 yo, ISO 639-2 yor)



Zhuang

Zhuang; Chuang (ISO 639-1 za, ISO 639-2 zha)



Chinese

Chinese (ISO 639-1 zh, ISO 639-2 zho, /B chi)



Zulu

Zulu (ISO 639-1 zu, ISO 639-2 zul)



Unknown(&'a str)

A code not recognised by this version of rama, borrowed verbatim.

Implementations



impl<'a> LanguageRef<'a>

pub fn code(self) -> &'a str

The canonical code for this value (e.g. "BE").

pub fn name(self) -> Option<&'static str>

The English display name, or None for an unknown code.

pub fn from_code(code: &'a str) -> LanguageRef<'a>

Parse from a canonical code (case-sensitive), borrowing code for any unknown value.

pub fn is_known(self) -> bool

Whether this is a known (non-Unknown) value.

pub fn to_owned(self) -> Language

Convert into the owned form (allocates only for Unknown).



impl LanguageRef<'_>

pub fn alpha3(self) -> Option<&'static str>

The alpha3 metadata for this value, or None if unknown.

pub fn bibliographic(self) -> Option<&'static str>

The bibliographic metadata for this value, or None if unknown.