Struct PatchElements
pub struct PatchElements {
pub elements: Option<NonEmptyStr>,
pub selector: Option<NonEmptyStr>,
pub mode: ElementPatchMode,
pub use_view_transition: bool,
}http and std only.Expand description
PatchElements patches HTML elements into the DOM.
Fields
elements: Option<NonEmptyStr>The elements to be patched into the DOM.
selector: Option<NonEmptyStr>The CSS selector used to patch the elements.
mode: ElementPatchModeThe mode in which elements are patched into the DOM.
If not provided the Datastar client side will default to ElementPatchMode::Outer.
use_view_transition: boolWhether to use view transitions.
If not provided the Datastar client side will default to false.
Implementations
impl PatchElements
impl PatchElements
pub const TYPE: EventType = EventType::PatchElements
pub const fn new(elements: NonEmptyStr) -> PatchElements
pub const fn new(elements: NonEmptyStr) -> PatchElements
Create a new PatchElements data blob.
pub const fn new_remove(selector: NonEmptyStr) -> PatchElements
pub const fn new_remove(selector: NonEmptyStr) -> PatchElements
Create a new PatchElements data blob for removal
pub fn try_into_sse_event(self) -> Result<Event<PatchElements>, EventBuildError>
pub fn try_into_sse_event(self) -> Result<Event<PatchElements>, EventBuildError>
Consume self as an Event.
pub fn try_into_datastar_event<T>(
self,
) -> Result<Event<EventData<T>>, EventBuildError>
pub fn try_into_datastar_event<T>( self, ) -> Result<Event<EventData<T>>, EventBuildError>
Consume self as a super::DatastarEvent.
pub fn with_selector(self, selector: NonEmptyStr) -> PatchElements
pub fn with_selector(self, selector: NonEmptyStr) -> PatchElements
Set the CSS selector used to patch the elements.
pub fn set_selector(&mut self, selector: NonEmptyStr) -> &mut PatchElements
pub fn set_selector(&mut self, selector: NonEmptyStr) -> &mut PatchElements
Set the CSS selector used to patch the elements.
pub fn with_mode(self, mode: ElementPatchMode) -> PatchElements
pub fn with_mode(self, mode: ElementPatchMode) -> PatchElements
Set mode in which elements are patched into the DOM.
pub fn set_mode(&mut self, mode: ElementPatchMode) -> &mut PatchElements
pub fn set_mode(&mut self, mode: ElementPatchMode) -> &mut PatchElements
Set mode in which elements are patched into the DOM.
pub fn with_use_view_transition(
self,
use_view_transition: bool,
) -> PatchElements
pub fn with_use_view_transition( self, use_view_transition: bool, ) -> PatchElements
Sets whether to use view transitions.
pub fn set_use_view_transition(
&mut self,
use_view_transition: bool,
) -> &mut PatchElements
pub fn set_use_view_transition( &mut self, use_view_transition: bool, ) -> &mut PatchElements
Sets whether to use view transitions.