Struct EventStream
pub struct EventStream<S, T = String>where
T: EventDataRead,{ /* private fields */ }http and std only.Expand description
Decode a stream of byte chunks into SSE events.
Wraps EventDecoder, which can also inspect borrowed chunks directly.
Input is unlimited by default. Set max_line_len
and max_event_len for limits per line and event.
BodyLimit or Body::limited instead caps the entire body, terminating
even a long-lived stream once that budget is exhausted.
Implementations
impl<S, T> EventStream<S, T>where
T: EventDataRead,
impl<S, T> EventStream<S, T>where
T: EventDataRead,
pub fn new(stream: S) -> EventStream<S, T>
pub fn new(stream: S) -> EventStream<S, T>
Initialize the EventStream with a Stream
pub fn maybe_with_max_line_len(self, max: Option<usize>) -> EventStream<S, T>
pub fn maybe_with_max_line_len(self, max: Option<usize>) -> EventStream<S, T>
Fail decoding once a single line grows past max bytes,
terminator excluded.
pub fn maybe_set_max_line_len(
&mut self,
max: Option<usize>,
) -> &mut EventStream<S, T>
pub fn maybe_set_max_line_len( &mut self, max: Option<usize>, ) -> &mut EventStream<S, T>
Fail decoding once a single line grows past max bytes,
terminator excluded.
pub fn with_max_line_len(self, max: usize) -> EventStream<S, T>
pub fn with_max_line_len(self, max: usize) -> EventStream<S, T>
Fail decoding once a single line grows past max bytes,
terminator excluded.
pub fn set_max_line_len(&mut self, max: usize) -> &mut EventStream<S, T>
pub fn set_max_line_len(&mut self, max: usize) -> &mut EventStream<S, T>
Fail decoding once a single line grows past max bytes,
terminator excluded.
pub fn without_max_line_len(self) -> EventStream<S, T>
pub fn without_max_line_len(self) -> EventStream<S, T>
Fail decoding once a single line grows past max bytes,
terminator excluded.
pub fn unset_max_line_len(&mut self) -> &mut EventStream<S, T>
pub fn unset_max_line_len(&mut self) -> &mut EventStream<S, T>
Fail decoding once a single line grows past max bytes,
terminator excluded.
pub fn maybe_with_max_event_len(self, max: Option<usize>) -> EventStream<S, T>
pub fn maybe_with_max_event_len(self, max: Option<usize>) -> EventStream<S, T>
Fail decoding once the lines accumulated into one event grow
past max bytes.
pub fn maybe_set_max_event_len(
&mut self,
max: Option<usize>,
) -> &mut EventStream<S, T>
pub fn maybe_set_max_event_len( &mut self, max: Option<usize>, ) -> &mut EventStream<S, T>
Fail decoding once the lines accumulated into one event grow
past max bytes.
pub fn with_max_event_len(self, max: usize) -> EventStream<S, T>
pub fn with_max_event_len(self, max: usize) -> EventStream<S, T>
Fail decoding once the lines accumulated into one event grow
past max bytes.
pub fn set_max_event_len(&mut self, max: usize) -> &mut EventStream<S, T>
pub fn set_max_event_len(&mut self, max: usize) -> &mut EventStream<S, T>
Fail decoding once the lines accumulated into one event grow
past max bytes.
pub fn without_max_event_len(self) -> EventStream<S, T>
pub fn without_max_event_len(self) -> EventStream<S, T>
Fail decoding once the lines accumulated into one event grow
past max bytes.
pub fn unset_max_event_len(&mut self) -> &mut EventStream<S, T>
pub fn unset_max_event_len(&mut self) -> &mut EventStream<S, T>
Fail decoding once the lines accumulated into one event grow
past max bytes.
pub fn maybe_with_on_incomplete(
self,
cb: Option<Box<dyn FnOnce(Vec<u8>) + Sync + Send>>,
) -> EventStream<S, T>
pub fn maybe_with_on_incomplete( self, cb: Option<Box<dyn FnOnce(Vec<u8>) + Sync + Send>>, ) -> EventStream<S, T>
Pass a nonempty buffered partial line to cb at most once,
when the body ends or the stream is dropped.
pub fn maybe_set_on_incomplete(
&mut self,
cb: Option<Box<dyn FnOnce(Vec<u8>) + Sync + Send>>,
) -> &mut EventStream<S, T>
pub fn maybe_set_on_incomplete( &mut self, cb: Option<Box<dyn FnOnce(Vec<u8>) + Sync + Send>>, ) -> &mut EventStream<S, T>
Pass a nonempty buffered partial line to cb at most once,
when the body ends or the stream is dropped.
pub fn with_on_incomplete(
self,
cb: Box<dyn FnOnce(Vec<u8>) + Sync + Send>,
) -> EventStream<S, T>
pub fn with_on_incomplete( self, cb: Box<dyn FnOnce(Vec<u8>) + Sync + Send>, ) -> EventStream<S, T>
Pass a nonempty buffered partial line to cb at most once,
when the body ends or the stream is dropped.
pub fn set_on_incomplete(
&mut self,
cb: Box<dyn FnOnce(Vec<u8>) + Sync + Send>,
) -> &mut EventStream<S, T>
pub fn set_on_incomplete( &mut self, cb: Box<dyn FnOnce(Vec<u8>) + Sync + Send>, ) -> &mut EventStream<S, T>
Pass a nonempty buffered partial line to cb at most once,
when the body ends or the stream is dropped.
pub fn without_on_incomplete(self) -> EventStream<S, T>
pub fn without_on_incomplete(self) -> EventStream<S, T>
Pass a nonempty buffered partial line to cb at most once,
when the body ends or the stream is dropped.
pub fn unset_on_incomplete(&mut self) -> &mut EventStream<S, T>
pub fn unset_on_incomplete(&mut self) -> &mut EventStream<S, T>
Pass a nonempty buffered partial line to cb at most once,
when the body ends or the stream is dropped.
pub fn with_lenient(self, lenient: bool) -> EventStream<S, T>
pub fn with_lenient(self, lenient: bool) -> EventStream<S, T>
Recover from a decode fault instead of ending the stream, skipping to the next event boundary.
pub fn set_lenient(&mut self, lenient: bool) -> &mut EventStream<S, T>
pub fn set_lenient(&mut self, lenient: bool) -> &mut EventStream<S, T>
Recover from a decode fault instead of ending the stream, skipping to the next event boundary.
pub fn maybe_with_on_resync(
self,
sink: Option<Arc<dyn ErrorSink>>,
) -> EventStream<S, T>
pub fn maybe_with_on_resync( self, sink: Option<Arc<dyn ErrorSink>>, ) -> EventStream<S, T>
pub fn maybe_set_on_resync(
&mut self,
sink: Option<Arc<dyn ErrorSink>>,
) -> &mut EventStream<S, T>
pub fn maybe_set_on_resync( &mut self, sink: Option<Arc<dyn ErrorSink>>, ) -> &mut EventStream<S, T>
pub fn with_on_resync(self, sink: Arc<dyn ErrorSink>) -> EventStream<S, T>
pub fn with_on_resync(self, sink: Arc<dyn ErrorSink>) -> EventStream<S, T>
pub fn set_on_resync(
&mut self,
sink: Arc<dyn ErrorSink>,
) -> &mut EventStream<S, T>
pub fn set_on_resync( &mut self, sink: Arc<dyn ErrorSink>, ) -> &mut EventStream<S, T>
pub fn without_on_resync(self) -> EventStream<S, T>
pub fn without_on_resync(self) -> EventStream<S, T>
pub fn unset_on_resync(&mut self) -> &mut EventStream<S, T>
pub fn unset_on_resync(&mut self) -> &mut EventStream<S, T>
pub fn try_set_last_event_id(
&mut self,
id: impl Into<SmolStr>,
) -> Result<(), Box<dyn Error + Sync + Send>>
pub fn try_set_last_event_id( &mut self, id: impl Into<SmolStr>, ) -> Result<(), Box<dyn Error + Sync + Send>>
Set the last event ID of the stream. Useful for initializing the stream with a previous last event ID
pub fn last_event_id(&self) -> Option<&str>
pub fn last_event_id(&self) -> Option<&str>
Get the last event ID of the stream
pub fn resync_count(&self) -> usize
pub fn resync_count(&self) -> usize
How many resyncs have happened in lenient mode.