Struct Sender
pub struct Sender<D, E = Infallible> { /* private fields */ }http and std only.Expand description
A sender half created through Channel::new.
Implementations
impl<D, E> Sender<D, E>
impl<D, E> Sender<D, E>
pub async fn send_trailers(
&mut self,
trailers: HeaderMap,
) -> Result<(), SendError>
pub async fn send_trailers( &mut self, trailers: HeaderMap, ) -> Result<(), SendError>
Send trailers on trailers channel.
pub fn try_send(&mut self, frame: Frame<D>) -> Result<(), Frame<D>>
pub fn try_send(&mut self, frame: Frame<D>) -> Result<(), Frame<D>>
Attempts to send a frame on this channel.
This function returns the unsent frame back as an Err(_) if the channel could not
currently accept another frame.
pub fn capacity(&mut self) -> usize
pub fn capacity(&mut self) -> usize
Returns the current capacity of the channel.
The capacity goes down when Frame<T>s are sent. The capacity goes up when these frames
are received by the corresponding Channel<D, E>. This is distinct from
max_capacity(), which always returns the buffer capacity initially
specified when Channel::new() was called.
pub fn max_capacity(&mut self) -> usize
pub fn max_capacity(&mut self) -> usize
Returns the maximum capacity of the channel.
This function always returns the buffer capacity initially specified when
Channel::new() was called. This is distinct from
capacity(), which returns the currently available capacity.
pub fn abort(self, error: E)
pub fn abort(self, error: E)
Aborts the body in an abnormal fashion.