Struct HttpProxyConnectorLayer
pub struct HttpProxyConnectorLayer { /* private fields */ }dns and http-backend and http and std and tcp only.Expand description
A Layer which wraps the given service with a HttpProxyConnector.
See HttpProxyConnector for more information.
Implementations
impl HttpProxyConnectorLayer
impl HttpProxyConnectorLayer
pub fn optional() -> HttpProxyConnectorLayer
pub fn optional() -> HttpProxyConnectorLayer
Create a new HttpProxyConnectorLayer which creates a HttpProxyConnector
which will only connect via an HTTP proxy when a proxied ProxyRoute is available
in the Extensions.
pub fn required() -> HttpProxyConnectorLayer
pub fn required() -> HttpProxyConnectorLayer
Create a new HttpProxyConnectorLayer which creates a HttpProxyConnector
which will always connect via an HTTP proxy, but fail when a proxied ProxyRoute is
not available in the Extensions.
pub fn with_tls_proxy_support(self, supported: bool) -> HttpProxyConnectorLayer
pub fn with_tls_proxy_support(self, supported: bool) -> HttpProxyConnectorLayer
Set whether the inner connector supports TLS to an HTTPS proxy.
pub fn set_tls_proxy_support(
&mut self,
supported: bool,
) -> &mut HttpProxyConnectorLayer
pub fn set_tls_proxy_support( &mut self, supported: bool, ) -> &mut HttpProxyConnectorLayer
Set whether the inner connector supports TLS to an HTTPS proxy.
pub fn with_version(self, version: Version) -> HttpProxyConnectorLayer
pub fn with_version(self, version: Version) -> HttpProxyConnectorLayer
Set the HTTP version to use for the CONNECT request.
By default this is set to HTTP/1.1.
pub fn set_version(&mut self, version: Version) -> &mut HttpProxyConnectorLayer
pub fn set_version(&mut self, version: Version) -> &mut HttpProxyConnectorLayer
Set the HTTP version to use for the CONNECT request.
By default this is set to HTTP/1.1.
pub fn with_custom_header(
self,
name: impl IntoHeaderName,
value: HeaderValue,
) -> HttpProxyConnectorLayer
pub fn with_custom_header( self, name: impl IntoHeaderName, value: HeaderValue, ) -> HttpProxyConnectorLayer
Append a custom header to use for the CONNECT request.
pub fn set_custom_header(
&mut self,
name: impl IntoHeaderName,
value: HeaderValue,
) -> &mut HttpProxyConnectorLayer
pub fn set_custom_header( &mut self, name: impl IntoHeaderName, value: HeaderValue, ) -> &mut HttpProxyConnectorLayer
Append a custom header to use for the CONNECT request.