Struct BindBodyToConn
pub struct BindBodyToConn<C> { /* private fields */ }dns and http-backend and http and std and tcp only.Expand description
A connection wrapper that binds the connection to the lifetime of the response body it produces.
A connector returns its connection at response headers, but the
connection is logically still in use until the response body has been
read off the wire. On serve, this wrapper moves the connection whole into
the returned response body (via GuardedBody), so the connection’s Drop
(freeing a stream slot, returning it to the pool, …) fires when the body
reaches end-of-stream or is dropped, instead of at headers.
The connection is moved into the response body on serve (it is served
exactly once per request), so there is no shared ownership of it.
Warning: the connection returned by this service should only be used for a single request, since it will be transferred to the response body and not be useable after that.
Implementations
impl<C> BindBodyToConn<C>where
C: ExtensionsRef,
impl<C> BindBodyToConn<C>where
C: ExtensionsRef,
pub fn new(conn: C) -> BindBodyToConn<C>
pub fn new(conn: C) -> BindBodyToConn<C>
Wrap conn so its lifetime extends to the response body of its serve.