pub struct EasyHttpWebClient<BodyIn, ConnResponse, L> { /* private fields */ }dns and http-backend and http and std and tcp only.Expand description
An opiniated http client that can be used to serve HTTP requests.
Use EasyHttpWebClient::connector_builder() to easily create a client with
a common Http connector setup (tcp + proxy + tls + http) or bring your
own http connector.
Default uses Rama’s default multiplexing connection pool. Build the
connector explicitly with
EasyHttpConnectorBuilder::without_connection_pool when connection reuse
is unwanted.
You can fork this http client in case you have use cases not possible with this service example. E.g. perhaps you wish to have middleware in into outbound requests, after they passed through your “connector” setup. All this and more is possible by defining your own http client. Rama is here to empower you, the building blocks are there, go crazy with your own service fork and use the full power of Rust at your fingertips ;)
Implementations
Sourceimpl EasyHttpWebClient<(), (), ()>
impl EasyHttpWebClient<(), (), ()>
Sourcepub fn connector_builder() -> EasyHttpConnectorBuilder
pub fn connector_builder() -> EasyHttpConnectorBuilder
Create a EasyHttpConnectorBuilder to easily create a EasyHttpWebClient with a custom connector
Sourcepub fn try_blocking() -> Result<BlockingHttpWebClient>
pub fn try_blocking() -> Result<BlockingHttpWebClient>
Create a cloneable blocking HTTP(S) client with its own dedicated runtime thread and Rama’s default web connector stack.
use rama::http::client::EasyHttpWebClient;
let client = EasyHttpWebClient::try_blocking()?;
let client_for_worker = client.clone();
let text = client_for_worker
.get("https://example.com/")
.send()?
.try_into_string()?;Sourceimpl<Body> EasyHttpWebClient<Body, EstablishedClientConnection<BindBodyToConn<MultiplexedConnection<HttpClientService<Body>, HttpConnId>>, Request<Body>>, ()>
impl<Body> EasyHttpWebClient<Body, EstablishedClientConnection<BindBodyToConn<MultiplexedConnection<HttpClientService<Body>, HttpConnId>>, Request<Body>>, ()>
pub fn default_with_executor(exec: Executor) -> Self
Sourceimpl<BodyIn, ConnResponse> EasyHttpWebClient<BodyIn, ConnResponse, ()>where
BodyIn: Send + 'static,
impl<BodyIn, ConnResponse> EasyHttpWebClient<BodyIn, ConnResponse, ()>where
BodyIn: Send + 'static,
Sourcepub fn new<S>(connector: S) -> Self
pub fn new<S>(connector: S) -> Self
Create a new EasyHttpWebClient using the provided connector.
Custom proxy connectors must honor PlaintextHttpProxyMode and publish
EstablishedProxyRoute.
Connection wrappers must preserve that metadata through ExtensionsRef.
Sourceimpl<BodyIn, ConnResponse, L> EasyHttpWebClient<BodyIn, ConnResponse, L>
impl<BodyIn, ConnResponse, L> EasyHttpWebClient<BodyIn, ConnResponse, L>
Sourcepub fn try_into_blocking(self) -> Result<BlockingHttpClient<Self>>
pub fn try_into_blocking(self) -> Result<BlockingHttpClient<Self>>
Convert this asynchronous web client into a cloneable blocking client with its own dedicated runtime thread.
Sourcepub fn into_blocking_with_runtime(
self,
runtime: &Runtime,
) -> BlockingHttpClient<Self>
pub fn into_blocking_with_runtime( self, runtime: &Runtime, ) -> BlockingHttpClient<Self>
Convert this asynchronous web client into a blocking client using a caller-supplied runtime.
Sourcepub fn with_connector<S, BodyInNew, ConnResponseNew>(
self,
connector: S,
) -> EasyHttpWebClient<BodyInNew, ConnResponseNew, L>
pub fn with_connector<S, BodyInNew, ConnResponseNew>( self, connector: S, ) -> EasyHttpWebClient<BodyInNew, ConnResponseNew, L>
Set the connector that this EasyHttpWebClient will use.
Custom proxy connectors follow the metadata contract described in Self::new.
Sourcepub fn with_jit_layer<T>(
self,
jit_layers: T,
) -> EasyHttpWebClient<BodyIn, ConnResponse, T>
pub fn with_jit_layer<T>( self, jit_layers: T, ) -> EasyHttpWebClient<BodyIn, ConnResponse, T>
Layer which will be applied just in time (JIT) before the request is sent, but after
the connection has been established. Rama’s built-in forward-proxy
policy is the innermost JIT service so it can act on the actual
connection after caller middleware has processed the request, and can
isolate a proxy challenge before caller middleware sees the response.
Simplified flow of how the EasyHttpWebClient works:
- External: let response = client.serve(request)
- Internal: let http_connection = self.connector.serve(request)
- Internal: wrap the connection in Rama’s forward-proxy policy
- Internal: let response = jit_layers.layer(http_connection).serve(request)
Sourcepub fn with_forward_proxy_auth(self, enabled: bool) -> Self
pub fn with_forward_proxy_auth(self, enabled: bool) -> Self
Enable or disable automatic Basic or Bearer credentials on requests sent directly to an HTTP forward proxy.
This is enabled by default and acts only when the established connection is positively identified as an HTTP forward-proxy connection. It never adds credentials to direct, SOCKS, or HTTP CONNECT-tunneled requests.
Disabling this only disables insertion. Caller-provided
Proxy-Authorization headers are preserved on established HTTP
forward routes and always stripped on every other route, including
connections without established route metadata.
Sourcepub fn set_forward_proxy_auth(&mut self, enabled: bool) -> &mut Self
pub fn set_forward_proxy_auth(&mut self, enabled: bool) -> &mut Self
Enable or disable automatic Basic or Bearer credentials on requests sent directly to an HTTP forward proxy.
This is enabled by default and acts only when the established connection is positively identified as an HTTP forward-proxy connection. It never adds credentials to direct, SOCKS, or HTTP CONNECT-tunneled requests.
Disabling this only disables insertion. Caller-provided
Proxy-Authorization headers are preserved on established HTTP
forward routes and always stripped on every other route, including
connections without established route metadata.
Sourcepub fn without_forward_proxy_auth(self) -> Self
pub fn without_forward_proxy_auth(self) -> Self
Disable automatic Basic or Bearer credentials on HTTP forward-proxy
requests. The credential-stripping policy described by
Self::with_forward_proxy_auth still applies.
Sourcepub fn with_tunnel_plaintext_http(self, enabled: bool) -> Self
pub fn with_tunnel_plaintext_http(self, enabled: bool) -> Self
Enable or disable carrying plaintext HTTP through an HTTP(S) proxy with CONNECT instead of using ordinary forward-proxy semantics (absolute-form on HTTP/1).
If this method is not called, a request-level
PlaintextHttpProxyMode
is honored and
otherwise forwarding is the connector default. Calling this method
explicitly selects Tunnel (true) or Forward (false) for the client.
Tunneling does not encrypt the origin traffic: a plaintext http://
request remains plaintext inside the proxy tunnel.
Sourcepub fn set_tunnel_plaintext_http(&mut self, enabled: bool) -> &mut Self
pub fn set_tunnel_plaintext_http(&mut self, enabled: bool) -> &mut Self
Enable or disable carrying plaintext HTTP through an HTTP(S) proxy with CONNECT instead of using ordinary forward-proxy semantics (absolute-form on HTTP/1).
If this method is not called, a request-level
PlaintextHttpProxyMode
is honored and
otherwise forwarding is the connector default. Calling this method
explicitly selects Tunnel (true) or Forward (false) for the client.
Tunneling does not encrypt the origin traffic: a plaintext http://
request remains plaintext inside the proxy tunnel.
Sourcepub fn with_isolate_forward_proxy_auth_error(self, enabled: bool) -> Self
pub fn with_isolate_forward_proxy_auth_error(self, enabled: bool) -> Self
Enable or disable isolation of 407 Proxy Authentication Required
responses received from an established HTTP forward proxy.
Ordinary clients expose such responses by default. Intermediaries should enable this option so an upstream proxy’s challenge, headers, and body cannot be forwarded to a different downstream proxy client.
Sourcepub fn set_isolate_forward_proxy_auth_error(
&mut self,
enabled: bool,
) -> &mut Self
pub fn set_isolate_forward_proxy_auth_error( &mut self, enabled: bool, ) -> &mut Self
Enable or disable isolation of 407 Proxy Authentication Required
responses received from an established HTTP forward proxy.
Ordinary clients expose such responses by default. Intermediaries should enable this option so an upstream proxy’s challenge, headers, and body cannot be forwarded to a different downstream proxy client.