ProxyConnector

Struct ProxyConnector 

pub struct ProxyConnector<S> { /* private fields */ }
Available on crate features http and http-full and socks5 only.
Proxy connector which supports http(s) and socks5(h) proxy address

Connector will look at ProxyAddress to determine which proxy connector to use if one is configured

Implementations

Source

impl<S: Clone> ProxyConnector<S>

pub fn required( inner: S, socks_proxy_layer: Socks5ProxyConnectorLayer, http_proxy_layer: HttpProxyConnectorLayer, ) -> Self

Creates a new required ProxyConnector.

This connector will fail if no ProxyAddress is configured

pub fn optional( inner: S, socks_proxy_layer: Socks5ProxyConnectorLayer, http_proxy_layer: HttpProxyConnectorLayer, ) -> Self

Creates a new optional ProxyConnector.

This connector will forward to the inner connector if no ProxyAddress is configured