pub struct H2ClientContextParams {
pub headers_pseudo_order: Option<PseudoHeaderOrder>,
pub headers_priority: Option<StreamDependencyParams>,
pub priority: Option<Vec<PriorityParams>>,
pub setting_config: Option<SettingsConfig>,
}Available on crate feature
http only.Expand description
Optional parameters that can be set in the [Context] of a (h2) request
to customise the connection of the h2 connection.
Can be used by Http connector services, especially in the context of proxies, where there might not be one static config that is to be applied to all client connections.
Fields
headers_pseudo_order: Option<PseudoHeaderOrder>Pseudo order of the headers stream
headers_priority: Option<StreamDependencyParams>Priority of the headers stream
priority: Option<Vec<PriorityParams>>Priority stream list
setting_config: Option<SettingsConfig>Config for h2 settings