Struct HttpOrigin
pub struct HttpOrigin { /* private fields */ }Available on crate features
http and std only.Expand description
An HTTP origin, including its scheme and effective port.
Alternative services change the dial target, never this authentication and request identity. HTTP and HTTPS origins remain distinct even at the same port.
Implementations
impl HttpOrigin
impl HttpOrigin
pub fn new(
protocol: Protocol,
authority: HostWithPort,
) -> Result<HttpOrigin, Box<dyn Error + Sync + Send>>
pub fn new( protocol: Protocol, authority: HostWithPort, ) -> Result<HttpOrigin, Box<dyn Error + Sync + Send>>
Validate an HTTP(S) scheme and network-usable origin authority.
Logical host and effective port, independently of the dial target.