Struct Incoming
pub struct Incoming { /* private fields */ }Available on crate features
http-backend and http and std only.Expand description
A stream of Bytes, used when receiving bodies from the network.
Note that Users should not instantiate this struct directly. When working with the client,
Incoming is returned to you in responses. Similarly, when operating with the server,
it is provided within requests.