Struct SendRequest
pub struct SendRequest<B> { /* private fields */ }http-full and http only.Expand description
The sender side of an established connection.
Implementations
impl<B> SendRequest<B>
impl<B> SendRequest<B>
pub fn poll_ready(&mut self, _cx: &mut Context<'_>) -> Poll<Result<(), Error>>
pub fn poll_ready(&mut self, _cx: &mut Context<'_>) -> Poll<Result<(), Error>>
Polls to determine whether this sender can be used yet for a request.
If the associated connection is closed, this returns an Error.
pub async fn ready(&mut self) -> Result<(), Error>
pub async fn ready(&mut self) -> Result<(), Error>
Waits until the dispatcher is ready.
If the associated connection is closed, this returns an Error.
impl<B> SendRequest<B>
impl<B> SendRequest<B>
pub fn send_request(
&mut self,
req: Request<B>,
) -> impl Future<Output = Result<Response<Incoming>, Error>>
pub fn send_request( &mut self, req: Request<B>, ) -> impl Future<Output = Result<Response<Incoming>, Error>>
Sends a Request on the associated connection.
Returns a future that if successful, yields the Response.
req must have a Host header.
Absolute-form Uris are not required. If received, they will be serialized
as-is.
Cancel safety
Dropping the returned future is the supported way to cancel an
in-flight HTTP/2 request. The stream is reset with RST_STREAM
(CANCEL error code); the shared connection remains usable for
other in-flight and future requests. The peer is notified
immediately rather than continuing to send a response body that
would be discarded.
pub fn try_send_request(
&mut self,
req: Request<B>,
) -> impl Future<Output = Result<Response<Incoming>, TrySendError<Request<B>>>>
pub fn try_send_request( &mut self, req: Request<B>, ) -> impl Future<Output = Result<Response<Incoming>, TrySendError<Request<B>>>>
Sends a Request on the associated connection.
Returns a future that if successful, yields the Response.
Error
If there was an error before trying to serialize the request to the connection, the message will be returned as part of this error.