pub struct Handshake<T, B = Bytes>where
B: Buf,{ /* private fields */ }Available on crate features
http-backend and http and std only.Expand description
In progress HTTP/2 connection handshake future.
This type implements Future, yielding a Connection instance once the
handshake has completed.
The handshake is completed once the connection preface is fully received from the client and the initial settings frame is sent to the client.
The handshake future does not wait for the initial settings frame from the client.
See module level docs for more details.