Struct Pushes
pub struct Pushes { /* private fields */ }Available on crate features
http-backend and http and std only.Expand description
Application consumer for the connection’s opt-in push quota. Drop unwanted pushes to cancel them. The quota is a lifetime limit for this connection, bounding even reordered promises and retained duplicate state.
Implementations