Enum CapsuleError
pub enum CapsuleError {
TooLarge {
ty: CapsuleType,
length: u64,
},
Truncated,
InputNotDrained,
}Available on crate features
http and std only.Expand description
A Capsule Protocol violation. The data stream must be treated as a malformed or incomplete message (RFC 9297 3.3).
Variants
TooLarge
A registered control capsule exceeded CapsuleConfig::max_capsule_size.
Truncated
The data stream ended inside a capsule.
InputNotDrained
The previous input has not been drained with CapsuleDecoder::poll. This is a
local usage error, not a peer violation.