Enum UnknownCapsules
pub enum UnknownCapsules {
Skip,
Forward,
}Available on crate features
http and std only.Expand description
Handling of capsule types the application did not register.
Variants
Skip
Silently skip them, as endpoints must (RFC 9297 3.2).
Forward
Emit them unmodified and incrementally, as forwarding intermediaries should.