Struct Extensions

pub struct Extensions { /* private fields */ }
Available on crate feature http only.
A type map of protocol extensions.

Extensions can be used by Request and Response to store extra data derived from the underlying protocol.

Implementations

Source

impl Extensions

pub const fn new() -> Extensions

Create an empty Extensions.

pub fn insert<T>(&mut self, val: T) -> Option<T>
where T: Clone + Send + Sync + 'static,

Insert a type into this Extensions.

If a extension of this type already existed, it will be returned.

pub fn maybe_insert<T>(&mut self, val: Option<T>) -> Option<T>
where T: Clone + Send + Sync + 'static,

Insert a type only into this Extensions, if the value is Some(T).

See Self::insert for more information.

pub fn extend(&mut self, other: Extensions)

Extend these extensions with another Extensions.

pub fn clear(&mut self)

Clear the Extensions of all inserted extensions.

pub fn contains<T>(&self) -> bool
where T: Send + Sync + 'static,

Returns true if the Extensions contains the given type.

pub fn get<T>(&self) -> Option<&T>
where T: Send + Sync + 'static,

Get a shared reference to a type previously inserted on this Extensions.

pub fn get_mut<T>(&mut self) -> Option<&mut T>
where T: Send + Sync + 'static,

Get an exclusive reference to a type previously inserted on this Extensions.

pub fn get_or_insert_with_ext<T>( &mut self, f: impl FnOnce(&Extensions) -> T, ) -> &mut T
where T: Clone + Send + Sync + 'static,

Inserts a value into the map computed from f into if it is None, then returns an exclusive reference to the contained value.

Use the cheaper Self::get_or_insert_with in case you do not need access to the extensions for the creation of T, as this function comes with an extra cost.

pub fn get_or_insert_with<T>(&mut self, f: impl FnOnce() -> T) -> &mut T
where T: Send + Sync + Clone + 'static,

Inserts a value into the map computed from f into if it is None, then returns an exclusive reference to the contained value.

pub fn get_or_insert_from<T, U>(&mut self, src: U) -> &mut T
where T: Send + Sync + Clone + 'static, U: Into<T>,

Inserts a value into the map computed by converting U into T if it is None then returns an exclusive reference to the contained value.

pub fn get_or_insert<T>(&mut self, fallback: T) -> &mut T
where T: Clone + Send + Sync + 'static,

Retrieves a value of type T from the context.

If the value does not exist, the given value is inserted and an exclusive reference to it is returned.

pub fn get_or_insert_default<T>(&mut self) -> &mut T
where T: Default + Clone + Send + Sync + 'static,

Get an extension or T’s Default.

see Extensions::get for more details.

pub fn remove<T>(&mut self) -> Option<T>
where T: Clone + Send + Sync + 'static,

Remove a type from this Extensions.