pub struct OpaqueError(/* private fields */);Available on crate feature
http only.Expand description
A type-erased error type that can be used as a trait object.
Note this type is not intended to be used directly,
it is used by rama to hide the concrete error type.
See the module level documentation for more information.
Implementations
Sourceimpl OpaqueError
impl OpaqueError
Sourcepub fn from_std(error: impl Error + Send + Sync + 'static) -> OpaqueError
pub fn from_std(error: impl Error + Send + Sync + 'static) -> OpaqueError
create an OpaqueError from an std error
Sourcepub fn from_display(
msg: impl Display + Debug + Send + Sync + 'static,
) -> OpaqueError
pub fn from_display( msg: impl Display + Debug + Send + Sync + 'static, ) -> OpaqueError
create an OpaqueError from a display object
Sourcepub fn from_boxed(inner: Box<dyn Error + Send + Sync>) -> OpaqueError
pub fn from_boxed(inner: Box<dyn Error + Send + Sync>) -> OpaqueError
create an OpaqueError from a boxed error
Sourcepub fn is<T>(&self) -> boolwhere
T: Error + 'static,
pub fn is<T>(&self) -> boolwhere
T: Error + 'static,
Returns true if the underlying error is of type T.
Sourcepub fn into_boxed(self) -> Box<dyn Error + Send + Sync>
pub fn into_boxed(self) -> Box<dyn Error + Send + Sync>
Consumes the OpaqueError and returns it as a BoxError.
Sourcepub fn downcast<T>(self) -> Result<T, OpaqueError>where
T: Error + 'static,
pub fn downcast<T>(self) -> Result<T, OpaqueError>where
T: Error + 'static,
Attempts to downcast the error to the concrete type T.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: Error + 'static,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: Error + 'static,
Attempts to downcast the error to a shared reference
of the concrete type T.
Sourcepub fn downcast_mut<T>(&mut self) -> Option<&mut T>where
T: Error + 'static,
pub fn downcast_mut<T>(&mut self) -> Option<&mut T>where
T: Error + 'static,
Attempts to downcast the error to the exclusive reference
of the concrete type T.