pub struct LimitLayer<P, F = ()> { /* private fields */ }Available on crate feature
http only.Expand description
Limit requests based on a Policy.
Implementations
Sourceimpl<P> LimitLayer<P>
impl<P> LimitLayer<P>
Sourcepub const fn new(policy: P) -> LimitLayer<P>
pub const fn new(policy: P) -> LimitLayer<P>
Creates a new LimitLayer from a crate::layer::limit::Policy.
Sourcepub fn with_error_into_response_fn<F>(
self,
f: F,
) -> LimitLayer<P, ErrorIntoResponseFn<F>>
pub fn with_error_into_response_fn<F>( self, f: F, ) -> LimitLayer<P, ErrorIntoResponseFn<F>>
Attach a function to this LimitLayer to allow you to turn the Policy error
into a Result fully compatible with the inner Service Result.
Sourceimpl LimitLayer<UnlimitedPolicy>
impl LimitLayer<UnlimitedPolicy>
Sourcepub fn unlimited() -> LimitLayer<UnlimitedPolicy>
pub fn unlimited() -> LimitLayer<UnlimitedPolicy>
Creates a new LimitLayer with an unlimited policy.
Meaning that all requests are allowed to proceed.