naive_snake_case

Function naive_snake_case 

pub fn naive_snake_case(name: &str) -> String
Available on crate features grpc and http and std only.
Convert a name in PascalCase, as used for gRPC methods and services, into the snake_case used for the matching Rust identifiers.

Naive in the sense that it does not know about acronyms: ABCServiceX becomes a_b_c_service_x.