pub enum Entry<'a, K, V, A = Global>{
Vacant(VacantEntry<'a, K, V, A>),
Occupied(OccupiedEntry<'a, K, V, A>),
}http and grpc and protobuf only.Expand description
Variants
Vacant(VacantEntry<'a, K, V, A>)
A vacant entry.
Occupied(OccupiedEntry<'a, K, V, A>)
An occupied entry.
Implementations
Sourceimpl<'a, K, V, A> Entry<'a, K, V, A>
impl<'a, K, V, A> Entry<'a, K, V, A>
1.0.0 · Sourcepub fn or_insert(self, default: V) -> &'a mut V
Available on crate feature rustls and crate feature std and non-no_global_oom_handling only.
pub fn or_insert(self, default: V) -> &'a mut V
rustls and crate feature std and non-no_global_oom_handling only.Ensures a value is in the entry by inserting the default if empty, and returns a mutable reference to the value in the entry.
Examples
use std::collections::BTreeMap;
let mut map: BTreeMap<&str, usize> = BTreeMap::new();
map.entry("poneyland").or_insert(12);
assert_eq!(map["poneyland"], 12);1.0.0 · Sourcepub fn or_insert_with<F>(self, default: F) -> &'a mut Vwhere
F: FnOnce() -> V,
Available on crate feature rustls and crate feature std and non-no_global_oom_handling only.
pub fn or_insert_with<F>(self, default: F) -> &'a mut Vwhere
F: FnOnce() -> V,
rustls and crate feature std and non-no_global_oom_handling only.Ensures a value is in the entry by inserting the result of the default function if empty, and returns a mutable reference to the value in the entry.
Examples
use std::collections::BTreeMap;
let mut map: BTreeMap<&str, String> = BTreeMap::new();
let s = "hoho".to_string();
map.entry("poneyland").or_insert_with(|| s);
assert_eq!(map["poneyland"], "hoho".to_string());1.50.0 · Sourcepub fn or_insert_with_key<F>(self, default: F) -> &'a mut V
Available on crate feature rustls and crate feature std and non-no_global_oom_handling only.
pub fn or_insert_with_key<F>(self, default: F) -> &'a mut V
rustls and crate feature std and non-no_global_oom_handling only.Ensures a value is in the entry by inserting, if empty, the result of the default function.
This method allows for generating key-derived values for insertion by providing the default
function a reference to the key that was moved during the .entry(key) method call.
The reference to the moved key is provided so that cloning or copying the key is
unnecessary, unlike with .or_insert_with(|| ... ).
Examples
use std::collections::BTreeMap;
let mut map: BTreeMap<&str, usize> = BTreeMap::new();
map.entry("poneyland").or_insert_with_key(|key| key.chars().count());
assert_eq!(map["poneyland"], 9);1.10.0 · Sourcepub fn key(&self) -> &K
Available on crate feature rustls and crate feature std and non-no_global_oom_handling only.
pub fn key(&self) -> &K
rustls and crate feature std and non-no_global_oom_handling only.Returns a reference to this entry’s key.
Examples
use std::collections::BTreeMap;
let mut map: BTreeMap<&str, usize> = BTreeMap::new();
assert_eq!(map.entry("poneyland").key(), &"poneyland");1.26.0 · Sourcepub fn and_modify<F>(self, f: F) -> Entry<'a, K, V, A>
Available on crate feature rustls and crate feature std and non-no_global_oom_handling only.
pub fn and_modify<F>(self, f: F) -> Entry<'a, K, V, A>
rustls and crate feature std and non-no_global_oom_handling only.Provides in-place mutable access to an occupied entry before any potential inserts into the map.
Examples
use std::collections::BTreeMap;
let mut map: BTreeMap<&str, usize> = BTreeMap::new();
map.entry("poneyland")
.and_modify(|e| { *e += 1 })
.or_insert(42);
assert_eq!(map["poneyland"], 42);
map.entry("poneyland")
.and_modify(|e| { *e += 1 })
.or_insert(42);
assert_eq!(map["poneyland"], 43);1.92.0 · Sourcepub fn insert_entry(self, value: V) -> OccupiedEntry<'a, K, V, A>
Available on crate feature rustls and crate feature std and non-no_global_oom_handling only.
pub fn insert_entry(self, value: V) -> OccupiedEntry<'a, K, V, A>
rustls and crate feature std and non-no_global_oom_handling only.Sets the value of the entry, and returns an OccupiedEntry.
Examples
use std::collections::BTreeMap;
let mut map: BTreeMap<&str, String> = BTreeMap::new();
let entry = map.entry("poneyland").insert_entry("hoho".to_string());
assert_eq!(entry.key(), &"poneyland");Sourceimpl<'a, K, V, A> Entry<'a, K, V, A>
impl<'a, K, V, A> Entry<'a, K, V, A>
1.28.0 · Sourcepub fn or_default(self) -> &'a mut V
Available on crate feature rustls and crate feature std and non-no_global_oom_handling only.
pub fn or_default(self) -> &'a mut V
rustls and crate feature std and non-no_global_oom_handling only.Ensures a value is in the entry by inserting the default value if empty, and returns a mutable reference to the value in the entry.
Examples
use std::collections::BTreeMap;
let mut map: BTreeMap<&str, Option<usize>> = BTreeMap::new();
map.entry("poneyland").or_default();
assert_eq!(map["poneyland"], None);Trait Implementations