pub struct Cursor<'a, K>where
K: 'a,{ /* private fields */ }btree_cursors)http and grpc and protobuf only.Expand description
A cursor over a BTreeSet.
A Cursor is like an iterator, except that it can freely seek back-and-forth.
Cursors always point to a gap between two elements in the set, and can operate on the two immediately adjacent elements.
A Cursor is created with the BTreeSet::lower_bound and BTreeSet::upper_bound methods.
Implementations
Sourceimpl<'a, K> Cursor<'a, K>
impl<'a, K> Cursor<'a, K>
Sourcepub fn next(&mut self) -> Option<&'a K>
🔬This is a nightly-only experimental API. (btree_cursors)Available on crate feature rustls and crate feature std and non-no_global_oom_handling only.
pub fn next(&mut self) -> Option<&'a K>
btree_cursors)rustls and crate feature std and non-no_global_oom_handling only.Advances the cursor to the next gap, returning the element that it moved over.
If the cursor is already at the end of the set then None is returned
and the cursor is not moved.
Sourcepub fn prev(&mut self) -> Option<&'a K>
🔬This is a nightly-only experimental API. (btree_cursors)Available on crate feature rustls and crate feature std and non-no_global_oom_handling only.
pub fn prev(&mut self) -> Option<&'a K>
btree_cursors)rustls and crate feature std and non-no_global_oom_handling only.Advances the cursor to the previous gap, returning the element that it moved over.
If the cursor is already at the start of the set then None is returned
and the cursor is not moved.
Sourcepub fn peek_next(&self) -> Option<&'a K>
🔬This is a nightly-only experimental API. (btree_cursors)Available on crate feature rustls and crate feature std and non-no_global_oom_handling only.
pub fn peek_next(&self) -> Option<&'a K>
btree_cursors)rustls and crate feature std and non-no_global_oom_handling only.Returns a reference to next element without moving the cursor.
If the cursor is at the end of the set then None is returned
Sourcepub fn peek_prev(&self) -> Option<&'a K>
🔬This is a nightly-only experimental API. (btree_cursors)Available on crate feature rustls and crate feature std and non-no_global_oom_handling only.
pub fn peek_prev(&self) -> Option<&'a K>
btree_cursors)rustls and crate feature std and non-no_global_oom_handling only.Returns a reference to the previous element without moving the cursor.
If the cursor is at the start of the set then None is returned.