pub struct Cursor<'a, T, A = Global>where
T: 'a,
A: Allocator,{ /* private fields */ }linked_list_cursors)http and grpc and protobuf only.Expand description
A cursor over a LinkedList.
A Cursor is like an iterator, except that it can freely seek back-and-forth.
Cursors always rest between two elements in the list, and index in a logically circular way.
To accommodate this, there is a “ghost” non-element that yields None between the head and
tail of the list.
When created, cursors start at the front of the list, or the “ghost” non-element if the list is empty.
Implementations
Sourceimpl<'a, T, A> Cursor<'a, T, A>where
A: Allocator,
impl<'a, T, A> Cursor<'a, T, A>where
A: Allocator,
Sourcepub fn index(&self) -> Option<usize>
🔬This is a nightly-only experimental API. (linked_list_cursors)Available on crate feature rustls and crate feature std and non-no_global_oom_handling only.
pub fn index(&self) -> Option<usize>
linked_list_cursors)rustls and crate feature std and non-no_global_oom_handling only.Returns the cursor position index within the LinkedList.
This returns None if the cursor is currently pointing to the
“ghost” non-element.
Sourcepub fn move_next(&mut self)
🔬This is a nightly-only experimental API. (linked_list_cursors)Available on crate feature rustls and crate feature std and non-no_global_oom_handling only.
pub fn move_next(&mut self)
linked_list_cursors)rustls and crate feature std and non-no_global_oom_handling only.Moves the cursor to the next element of the LinkedList.
If the cursor is pointing to the “ghost” non-element then this will move it to
the first element of the LinkedList. If it is pointing to the last
element of the LinkedList then this will move it to the “ghost” non-element.
Sourcepub fn move_prev(&mut self)
🔬This is a nightly-only experimental API. (linked_list_cursors)Available on crate feature rustls and crate feature std and non-no_global_oom_handling only.
pub fn move_prev(&mut self)
linked_list_cursors)rustls and crate feature std and non-no_global_oom_handling only.Moves the cursor to the previous element of the LinkedList.
If the cursor is pointing to the “ghost” non-element then this will move it to
the last element of the LinkedList. If it is pointing to the first
element of the LinkedList then this will move it to the “ghost” non-element.
Sourcepub fn current(&self) -> Option<&'a T>
🔬This is a nightly-only experimental API. (linked_list_cursors)Available on crate feature rustls and crate feature std and non-no_global_oom_handling only.
pub fn current(&self) -> Option<&'a T>
linked_list_cursors)rustls and crate feature std and non-no_global_oom_handling only.Returns a reference to the element that the cursor is currently pointing to.
This returns None if the cursor is currently pointing to the
“ghost” non-element.
Sourcepub fn peek_next(&self) -> Option<&'a T>
🔬This is a nightly-only experimental API. (linked_list_cursors)Available on crate feature rustls and crate feature std and non-no_global_oom_handling only.
pub fn peek_next(&self) -> Option<&'a T>
linked_list_cursors)rustls and crate feature std and non-no_global_oom_handling only.Returns a reference to the next element.
If the cursor is pointing to the “ghost” non-element then this returns
the first element of the LinkedList. If it is pointing to the last
element of the LinkedList then this returns None.
Sourcepub fn peek_prev(&self) -> Option<&'a T>
🔬This is a nightly-only experimental API. (linked_list_cursors)Available on crate feature rustls and crate feature std and non-no_global_oom_handling only.
pub fn peek_prev(&self) -> Option<&'a T>
linked_list_cursors)rustls and crate feature std and non-no_global_oom_handling only.Returns a reference to the previous element.
If the cursor is pointing to the “ghost” non-element then this returns
the last element of the LinkedList. If it is pointing to the first
element of the LinkedList then this returns None.
Sourcepub fn front(&self) -> Option<&'a T>
🔬This is a nightly-only experimental API. (linked_list_cursors)Available on crate feature rustls and crate feature std and non-no_global_oom_handling only.
pub fn front(&self) -> Option<&'a T>
linked_list_cursors)rustls and crate feature std and non-no_global_oom_handling only.Provides a reference to the front element of the cursor’s parent list, or None if the list is empty.
Sourcepub fn back(&self) -> Option<&'a T>
🔬This is a nightly-only experimental API. (linked_list_cursors)Available on crate feature rustls and crate feature std and non-no_global_oom_handling only.
pub fn back(&self) -> Option<&'a T>
linked_list_cursors)rustls and crate feature std and non-no_global_oom_handling only.Provides a reference to the back element of the cursor’s parent list, or None if the list is empty.
Sourcepub fn as_list(&self) -> &'a LinkedList<T, A>
🔬This is a nightly-only experimental API. (linked_list_cursors)Available on crate feature rustls and crate feature std and non-no_global_oom_handling only.
pub fn as_list(&self) -> &'a LinkedList<T, A>
linked_list_cursors)rustls and crate feature std and non-no_global_oom_handling only.Provides a reference to the cursor’s parent list.