pub fn format(args: Arguments<'_>) -> StringAvailable on crate features
grpc and http and protobuf and std only.Expand description
Takes an Arguments struct and returns the resulting formatted string.
The Arguments instance can be created with the format_args! macro.
Examples
Basic usage:
use std::fmt;
let s = fmt::format(format_args!("Hello, {}!", "world"));
assert_eq!(s, "Hello, world!");Please note that using format! might be preferable.
Example:
let s = format!("Hello, {}!", "world");
assert_eq!(s, "Hello, world!");