#[non_exhaustive]pub enum DurationError {
ParseFailure,
NegativeDuration(Duration),
OutOfRange,
}Available on crate features
grpc and http and protobuf only.Expand description
A duration handling error.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ParseFailure
Indicates failure to parse a Duration from a string.
The Duration string format is specified in the Protobuf JSON mapping specification.
NegativeDuration(Duration)
Indicates failure to convert a prost_types::Duration to a std::time::Duration because
the duration is negative. The included std::time::Duration matches the magnitude of the
original negative prost_types::Duration.
OutOfRange
Indicates failure to convert a std::time::Duration to a prost_types::Duration.
Converting a std::time::Duration to a prost_types::Duration fails if the magnitude
exceeds that representable by prost_types::Duration.