#[non_exhaustive]pub enum TimestampError {
OutOfSystemRange(Timestamp),
ParseFailure,
InvalidDateTime,
}Available on crate features
grpc and http and protobuf only.Expand description
A timestamp handling error.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
OutOfSystemRange(Timestamp)
Indicates that a Timestamp could not be converted to
SystemTime because it is out of range.
The range of times that can be represented by SystemTime depends on the platform. All
Timestamps are likely representable on 64-bit Unix-like platforms, but other platforms,
such as Windows and 32-bit Linux, may not be able to represent the full range of
Timestamps.
ParseFailure
An error indicating failure to parse a timestamp in RFC-3339 format.
InvalidDateTime
Indicates an error when constructing a timestamp due to invalid date or time data.