Annotation

Struct Annotation 

pub struct Annotation {
    pub path: Vec<i32>,
    pub source_file: Option<String>,
    pub begin: Option<i32>,
    pub end: Option<i32>,
}
Available on crate features http and grpc and protobuf only.

Fields

path: Vec<i32>

Identifies the element in the original source .proto file. This field is formatted the same as SourceCodeInfo.Location.path.

source_file: Option<String>

Identifies the filesystem path to the original source .proto.

begin: Option<i32>

Identifies the starting offset in bytes in the generated code that relates to the identified object.

end: Option<i32>

Identifies the ending offset in bytes in the generated code that relates to the identified offset. The end offset should be one past the last relevant byte (so the length of the text = end - begin).

Implementations

Source

impl Annotation

pub fn source_file(&self) -> &str

Returns the value of source_file, or the default value if source_file is unset.

pub fn begin(&self) -> i32

Returns the value of begin, or the default value if begin is unset.

pub fn end(&self) -> i32

Returns the value of end, or the default value if end is unset.