Struct Status
pub struct Status {
pub code: i32,
pub message: String,
pub details: Vec<Any>,
}grpc and http and protobuf and std only.Expand description
The Status type defines a logical error model that is suitable for
different programming environments, including REST APIs and RPC APIs. It is
used by gRPC. Each Status message contains
three pieces of data: error code, error message, and error details.
You can find out more about this error model and how to work with it in the API Design Guide.
Fields
code: i32The status code, which should be an enum value of [google.rpc.Code][google.rpc.Code].
message: StringA developer-facing error message, which should be in English. Any user-facing error message should be localized and sent in the [google.rpc.Status.details][google.rpc.Status.details] field, or localized by the client.
details: Vec<Any>A list of messages that carry the error details. There is a common set of message types for APIs to use.