Struct LogsServiceServer
pub struct LogsServiceServer<T> { /* private fields */ }Available on crate features
grpc and http and opentelemetry and std only.Expand description
Service that can be used to push logs between one Application instrumented with OpenTelemetry and an collector, or between an collector and a central collector (in this case logs are sent/received to/from multiple Applications).
Implementations
impl<T> LogsServiceServer<T>
impl<T> LogsServiceServer<T>
pub fn new(inner: T) -> LogsServiceServer<T>
pub fn from_arc(inner: Arc<T>) -> LogsServiceServer<T>
pub fn with_accept_compressed(
self,
encoding: CompressionEncoding,
) -> LogsServiceServer<T>
pub fn with_accept_compressed( self, encoding: CompressionEncoding, ) -> LogsServiceServer<T>
Enable decompressing requests with the given encoding.
pub fn set_accept_compressed(
&mut self,
encoding: CompressionEncoding,
) -> &mut LogsServiceServer<T>
pub fn set_accept_compressed( &mut self, encoding: CompressionEncoding, ) -> &mut LogsServiceServer<T>
Enable decompressing requests with the given encoding.
pub fn with_send_compressed(
self,
encoding: CompressionEncoding,
) -> LogsServiceServer<T>
pub fn with_send_compressed( self, encoding: CompressionEncoding, ) -> LogsServiceServer<T>
Compress responses with the given encoding, if the client supports it.
pub fn set_send_compressed(
&mut self,
encoding: CompressionEncoding,
) -> &mut LogsServiceServer<T>
pub fn set_send_compressed( &mut self, encoding: CompressionEncoding, ) -> &mut LogsServiceServer<T>
Compress responses with the given encoding, if the client supports it.
pub fn with_max_decoding_message_size(
self,
limit: usize,
) -> LogsServiceServer<T>
pub fn with_max_decoding_message_size( self, limit: usize, ) -> LogsServiceServer<T>
Limits the maximum size of a decoded message.
Default: 4MB
pub fn set_max_decoding_message_size(
&mut self,
limit: usize,
) -> &mut LogsServiceServer<T>
pub fn set_max_decoding_message_size( &mut self, limit: usize, ) -> &mut LogsServiceServer<T>
Limits the maximum size of a decoded message.
Default: 4MB
pub fn with_max_encoding_message_size(
self,
limit: usize,
) -> LogsServiceServer<T>
pub fn with_max_encoding_message_size( self, limit: usize, ) -> LogsServiceServer<T>
Limits the maximum size of an encoded message.
Default: usize::MAX
pub fn set_max_encoding_message_size(
&mut self,
limit: usize,
) -> &mut LogsServiceServer<T>
pub fn set_max_encoding_message_size( &mut self, limit: usize, ) -> &mut LogsServiceServer<T>
Limits the maximum size of an encoded message.
Default: usize::MAX