LogsService

Trait LogsService 

pub trait LogsService:
    Send
    + Sync
    + 'static {
    // Required method
    fn export(
        &self,
        request: Request<ExportLogsServiceRequest>,
    ) -> impl Future<Output = Result<Response<ExportLogsServiceResponse>, Status>> + Send;
}
Available on crate features grpc and http and opentelemetry and std only.
Generated trait containing gRPC methods that should be implemented for use with LogsServiceServer.

Required Methods

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors