Struct ExportTraceServiceResponse
pub struct ExportTraceServiceResponse {
pub partial_success: Option<ExportTracePartialSuccess>,
}Available on crate features
http and grpc and opentelemetry only.Fields
partial_success: Option<ExportTracePartialSuccess>Trait Implementations
impl Clone for ExportTraceServiceResponse
impl Clone for ExportTraceServiceResponse
fn clone(&self) -> ExportTraceServiceResponse
fn clone(&self) -> ExportTraceServiceResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for ExportTraceServiceResponse
impl Debug for ExportTraceServiceResponse
impl Default for ExportTraceServiceResponse
impl Default for ExportTraceServiceResponse
fn default() -> ExportTraceServiceResponse
fn default() -> ExportTraceServiceResponse
Returns the “default value” for a type. Read more
impl Hash for ExportTraceServiceResponse
impl Hash for ExportTraceServiceResponse
impl Message for ExportTraceServiceResponse
impl Message for ExportTraceServiceResponse
fn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl PartialEq for ExportTraceServiceResponse
impl PartialEq for ExportTraceServiceResponse
fn eq(&self, other: &ExportTraceServiceResponse) -> bool
fn eq(&self, other: &ExportTraceServiceResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for ExportTraceServiceResponse
impl StructuralPartialEq for ExportTraceServiceResponse