Enum Value
pub enum Value {
StringValue(String),
BoolValue(bool),
IntValue(i64),
DoubleValue(f64),
ArrayValue(ArrayValue),
KvlistValue(KeyValueList),
BytesValue(Vec<u8>),
StringValueStrindex(i32),
}Available on crate features
http and grpc and opentelemetry only.Variants
StringValue(String)
BoolValue(bool)
IntValue(i64)
DoubleValue(f64)
ArrayValue(ArrayValue)
KvlistValue(KeyValueList)
BytesValue(Vec<u8>)
StringValueStrindex(i32)
Implementations
impl Value
impl Value
pub fn merge(
field: &mut Option<Value>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Value>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
pub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.