Enum SeverityNumber
#[repr(i32)]pub enum SeverityNumber {
Show 25 variants
Unspecified = 0,
Trace = 1,
Trace2 = 2,
Trace3 = 3,
Trace4 = 4,
Debug = 5,
Debug2 = 6,
Debug3 = 7,
Debug4 = 8,
Info = 9,
Info2 = 10,
Info3 = 11,
Info4 = 12,
Warn = 13,
Warn2 = 14,
Warn3 = 15,
Warn4 = 16,
Error = 17,
Error2 = 18,
Error3 = 19,
Error4 = 20,
Fatal = 21,
Fatal2 = 22,
Fatal3 = 23,
Fatal4 = 24,
}Available on crate features
http and grpc and opentelemetry only.Variants
Unspecified = 0
Trace = 1
Trace2 = 2
Trace3 = 3
Trace4 = 4
Debug = 5
Debug2 = 6
Debug3 = 7
Debug4 = 8
Info = 9
Info2 = 10
Info3 = 11
Info4 = 12
Warn = 13
Warn2 = 14
Warn3 = 15
Warn4 = 16
Error = 17
Error2 = 18
Error3 = 19
Error4 = 20
Fatal = 21
Fatal2 = 22
Fatal3 = 23
Fatal4 = 24
Implementations
impl SeverityNumber
impl SeverityNumber
impl SeverityNumber
impl SeverityNumber
pub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
pub fn from_str_name(value: &str) -> Option<SeverityNumber>
pub fn from_str_name(value: &str) -> Option<SeverityNumber>
Creates an enum from field names used in the ProtoBuf definition.