Enum AggregationTemporality
#[repr(i32)]pub enum AggregationTemporality {
Unspecified = 0,
Delta = 1,
Cumulative = 2,
}Available on crate features
http and grpc and opentelemetry only.Variants
Implementations
impl AggregationTemporality
impl AggregationTemporality
pub fn from_i32(value: i32) -> Option<AggregationTemporality>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<AggregationTemporality>
Use the TryFrom<i32> implementation instead
Converts an i32 to a AggregationTemporality, or None if value is not a valid variant.
impl AggregationTemporality
impl AggregationTemporality
pub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
pub fn from_str_name(value: &str) -> Option<AggregationTemporality>
pub fn from_str_name(value: &str) -> Option<AggregationTemporality>
Creates an enum from field names used in the ProtoBuf definition.