Enum DataPointFlags
#[repr(i32)]pub enum DataPointFlags {
DoNotUse = 0,
NoRecordedValueMask = 1,
}Available on crate features
http and grpc and opentelemetry only.Variants
Implementations
impl DataPointFlags
impl DataPointFlags
impl DataPointFlags
impl DataPointFlags
pub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
pub fn from_str_name(value: &str) -> Option<DataPointFlags>
pub fn from_str_name(value: &str) -> Option<DataPointFlags>
Creates an enum from field names used in the ProtoBuf definition.