Enum Data
pub enum Data {
Gauge(Gauge),
Sum(Sum),
Histogram(Histogram),
ExponentialHistogram(ExponentialHistogram),
Summary(Summary),
}Available on crate features
http and grpc and opentelemetry only.Variants
Gauge(Gauge)
Sum(Sum)
Histogram(Histogram)
ExponentialHistogram(ExponentialHistogram)
Summary(Summary)
Implementations
impl Data
impl Data
pub fn merge(
field: &mut Option<Data>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Data>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
pub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.