Struct Status
pub struct Status {
pub message: String,
pub code: i32,
}Available on crate features
http and grpc and opentelemetry only.Fields
message: Stringcode: i32Implementations
impl Status
impl Status
pub fn code(&self) -> StatusCode
pub fn code(&self) -> StatusCode
Returns the enum value of code, or the default if the field is set to an invalid enum value.
pub fn set_code(&mut self, value: StatusCode)
pub fn set_code(&mut self, value: StatusCode)
Sets code to the provided enum value.