Struct Response
pub struct Response<T> { /* private fields */ }Available on crate features
http and grpc only.Expand description
A gRPC response and metadata from an RPC call.
Implementations
impl<T> Response<T>
impl<T> Response<T>
pub fn new(message: T) -> Response<T>
pub fn new(message: T) -> Response<T>
Create a new gRPC response.
Response::new(HelloReply {
message: format!("Hello, {name}!").into(),
});pub fn metadata(&self) -> &MetadataMap
pub fn metadata(&self) -> &MetadataMap
Get a reference to the custom response metadata.
pub fn metadata_mut(&mut self) -> &mut MetadataMap
pub fn metadata_mut(&mut self) -> &mut MetadataMap
Get a mutable reference to the response metadata.
pub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Consumes self, returning the message
pub fn into_parts(self) -> (MetadataMap, T, Extensions)
pub fn into_parts(self) -> (MetadataMap, T, Extensions)
Consumes self returning the parts of the response.
pub fn from_parts(
metadata: MetadataMap,
message: T,
extensions: Extensions,
) -> Response<T>
pub fn from_parts( metadata: MetadataMap, message: T, extensions: Extensions, ) -> Response<T>
Create a new gRPC response from metadata, message and extensions.
pub fn disable_compression(&mut self)
Available on crate feature compression only.
pub fn disable_compression(&mut self)
compression only.Disable compression of the response body.
This disables compression of the body of this response, even if compression is enabled on the server.
Note: This only has effect on responses to unary requests and responses to client to server streams. Response streams (server to client stream and bidirectional streams) will still be compressed according to the configuration of the server.