pub type Result<T, E = Status> = Result<T, E>;
http
grpc
Result is a type that represents either success (Ok) or failure (Err). By default, the Err value is of type Status but this can be overridden if desired.
Result
Ok
Err
Status
pub enum Result<T, E = Status> { Ok(T), Err(E), }
Contains the success value
Contains the error value