remove_hop_by_hop_headers

Function remove_hop_by_hop_headers 

pub fn remove_hop_by_hop_headers(headers: &mut HeaderMap)
Available on crate features http and std only.
Remove all hop-by-hop headers from an HTTP message.

In addition to the known connection-specific fields, this removes every field nominated by Connection. Use HopByHopHeaderContext::take when upgrade, trailer, or TE: trailers metadata has to be restored for a newly originated hop.