SecFetchSite

Enum SecFetchSite 

pub enum SecFetchSite {
    SameOrigin,
    SameSite,
    CrossSite,
    None,
    Unknown(String),
}
Available on crate feature http only.
The Sec-Fetch-Site fetch metadata request header.

Sent by browsers to indicate the relationship between the origin that initiated the request and the origin of the requested resource. It is the primary signal used by modern CSRF protection (see CsrfLayer).

Example values

  • same-origin
  • same-site
  • cross-site
  • none

Variants



SameOrigin

The request initiator and the target share the same origin.



SameSite

The request initiator and the target share the same site (registrable domain) but not the same origin.



CrossSite

The request initiator and the target are cross-site.



None

The request was initiated by the user (e.g. typing a URL), not by another origin.



Unknown(String)

Implementations



impl SecFetchSite

pub fn as_str(&self) -> &str

pub fn as_static_str(&self) -> Cow<'static, str>

pub fn as_smol_str(&self) -> SmolStr



impl SecFetchSite

pub fn strict_parse(s: &str) -> Option<SecFetchSite>

Same as FromStr or From<&str> but returning None for unknown values