pub struct XForwardedFor(/* private fields */);Available on crate feature
http only.Expand description
The X-Forwarded-For (XFF) request header is a de-facto standard header for
identifying the originating IP address of a client connecting to a web server through a proxy server.
It is recommended to use the Forwarded header instead if you can.
More info can be found at https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/X-Forwarded-For.
Syntax
X-Forwarded-For: <client>, <proxy1>, <proxy2>Example values
2001:db8:85a3:8d3:1319:8a2e:370:7348203.0.113.195203.0.113.195,2001:db8:85a3:8d3:1319:8a2e:370:7348,198.51.100.178
Implementations