Struct SecWebSocketProtocol
pub struct SecWebSocketProtocol(pub NonEmptySmallVec<3, NonEmptyStr>);Available on crate features
http and std only.Expand description
The Sec-WebSocket-Protocol header, containing one or multiple protocols.
Sub protocols are advertised by the client, and the server has to match it if defined.
Tuple Fields
0: NonEmptySmallVec<3, NonEmptyStr>Implementations
impl SecWebSocketProtocol
impl SecWebSocketProtocol
pub fn new(value: NonEmptyStr) -> SecWebSocketProtocol
impl SecWebSocketProtocol
impl SecWebSocketProtocol
pub fn accept_first_protocol(&self) -> AcceptedWebSocketProtocol
pub fn accept_first_protocol(&self) -> AcceptedWebSocketProtocol
Return the first protocol in this SecWebSocketProtocol as the AcceptedWebSocketProtocol.
pub fn contains(
&self,
protocol: impl AsRef<str>,
) -> Option<AcceptedWebSocketProtocol>
pub fn contains( &self, protocol: impl AsRef<str>, ) -> Option<AcceptedWebSocketProtocol>
returns true if the given protocol is found in this SecWebSocketProtocol
pub fn contains_any(
&self,
protocols: impl IntoIterator- >,
) -> Option<AcceptedWebSocketProtocol>
pub fn contains_any(
&self,
protocols: impl IntoIterator- >,
) -> Option<AcceptedWebSocketProtocol>
returns true if any of the given protocol is found in this SecWebSocketProtocol
Searched in order.
pub fn iter(&self) -> impl Iterator<Item = &str>