Struct Accept
pub struct Accept(pub NonEmptySmallVec<7, QualityValue<Mime>>);Available on crate features
http and std only.Expand description
Accept header, defined in RFC7231
The Accept header field can be used by user agents to specify
response media types that are acceptable. Accept header fields can
be used to indicate that the request is specifically limited to a
small set of desired types, as in the case of a request for an
in-line image
ABNF
Accept = #( media-range [ accept-params ] )
media-range = ( "*/*"
/ ( type "/" "*" )
/ ( type "/" subtype )
) *( OWS ";" OWS parameter )
accept-params = weight *( accept-ext )
accept-ext = OWS ";" OWS token [ "=" ( token / quoted-string ) ]Example values
audio/*; q=0.2, audio/basictext/plain; q=0.5, text/html, text/x-dvi; q=0.8, text/x-c
Examples
use std::iter::FromIterator;
use rama_http_headers::{Accept, specifier::QualityValue, HeaderMapExt};
use rama_http_types::mime;
let mut headers = rama_http_types::HeaderMap::new();
headers.typed_insert(
Accept::new(
QualityValue::new(mime::TEXT_HTML, Default::default()),
)
);use std::iter::FromIterator;
use rama_http_headers::{Accept, specifier::QualityValue, HeaderMapExt};
use rama_http_types::mime;
let mut headers = rama_http_types::HeaderMap::new();
headers.typed_insert(
Accept::new(
QualityValue::new(mime::APPLICATION_JSON, Default::default()),
)
);use std::iter::FromIterator;
use rama_utils::collections::non_empty_smallvec;
use rama_http_headers::{Accept, specifier::QualityValue, HeaderMapExt};
use rama_http_types::mime;
let mut headers = rama_http_types::HeaderMap::new();
headers.typed_insert(
Accept(non_empty_smallvec![
QualityValue::from(mime::TEXT_HTML),
QualityValue::from("application/xhtml+xml".parse::<mime::Mime>().unwrap()),
QualityValue::new(
mime::TEXT_XML,
900.into()
),
QualityValue::from("image/webp".parse::<mime::Mime>().unwrap()),
QualityValue::new(
mime::STAR_STAR,
800.into()
),
])
);Tuple Fields
0: NonEmptySmallVec<7, QualityValue<Mime>>Implementations
impl Accept
impl Accept
pub fn new_from_mime(mime: Mime) -> Accept
pub fn sort_quality_values(&mut self)
pub fn sort_quality_values(&mut self)
Sort (stable) the inner quality values by quality.