Struct AccessControlRequestPrivateNetwork
#[non_exhaustive]pub struct AccessControlRequestPrivateNetwork;Available on crate features
http and std only.Expand description
Access-Control-Request-Private-Network header, as documented in
this draft of WICG.
Not an official standard but widely used. This CORS header to allow a public origin make a cross site request to a server hosted on a private network (e.g. behind a firewall).
ABNF
Access-Control-Request-Private-Network: "Access-Control-Request-Private-Network" ":" "true"Since there is only one acceptable field value, the header struct does not accept
any values at all. Setting an empty AccessControlRequestPrivateNetwork header is
sufficient. See the examples below.
Example values
- “true”
Examples
use rama_http_headers::AccessControlRequestPrivateNetwork;
let allow_creds = AccessControlRequestPrivateNetwork::default();Implementations
impl AccessControlRequestPrivateNetwork
impl AccessControlRequestPrivateNetwork
pub fn new() -> AccessControlRequestPrivateNetwork