Struct AlternativeService
pub struct AlternativeService { /* private fields */ }http and std only.Expand description
One RFC 7838 alternative service.
The optional host is absent when the alternative uses the origin host.
max_age defaults to 24 hours and persist defaults to false.
Implementations
impl AlternativeService
impl AlternativeService
pub fn new(
protocol: ApplicationProtocol,
port: u16,
) -> Result<AlternativeService, Box<dyn Error + Sync + Send>>
pub fn new( protocol: ApplicationProtocol, port: u16, ) -> Result<AlternativeService, Box<dyn Error + Sync + Send>>
Create an alternative on the origin host.
Errors
Returns an error when the ALPN protocol identifier is empty or exceeds the one-octet ALPN length limit.
pub fn try_with_host(
self,
host: impl Into<Host>,
) -> Result<AlternativeService, Box<dyn Error + Sync + Send>>
pub fn try_with_host( self, host: impl Into<Host>, ) -> Result<AlternativeService, Box<dyn Error + Sync + Send>>
Try to use a different host than the origin.
An empty host is normalized to the origin host.
Errors
Returns an error when host has no strict RFC 3986 presentation.
pub fn try_set_host(
&mut self,
host: impl Into<Host>,
) -> Result<&mut AlternativeService, Box<dyn Error + Sync + Send>>
pub fn try_set_host( &mut self, host: impl Into<Host>, ) -> Result<&mut AlternativeService, Box<dyn Error + Sync + Send>>
Try to use a different host than the origin.
An empty host is normalized to the origin host.
Errors
Returns an error when host has no strict RFC 3986 presentation.
pub fn with_max_age_seconds(self, max_age: u64) -> AlternativeService
pub fn with_max_age_seconds(self, max_age: u64) -> AlternativeService
Set the alternative-service freshness lifetime in whole seconds.
pub fn set_max_age_seconds(&mut self, max_age: u64) -> &mut AlternativeService
pub fn set_max_age_seconds(&mut self, max_age: u64) -> &mut AlternativeService
Set the alternative-service freshness lifetime in whole seconds.
pub fn with_persist(self, persist: bool) -> AlternativeService
pub fn with_persist(self, persist: bool) -> AlternativeService
Set whether this service may survive network changes.
pub fn set_persist(&mut self, persist: bool) -> &mut AlternativeService
pub fn set_persist(&mut self, persist: bool) -> &mut AlternativeService
Set whether this service may survive network changes.
pub fn protocol(&self) -> &ApplicationProtocol
pub fn protocol(&self) -> &ApplicationProtocol
Return the ALPN protocol identifier.