Struct CapsuleProtocol
pub struct CapsuleProtocol(/* private fields */);Available on crate features
http and std only.Expand description
Whether a request’s data stream uses the Capsule Protocol.
The field is a Boolean Structured Field Item; parameters are ignored. A false value has the same meaning as an absent field. Any other value type, including a repeated field (which combines into a List), fails to decode and must be treated as absent.
Implementations
impl CapsuleProtocol
impl CapsuleProtocol
pub const ENABLED: CapsuleProtocol
pub const ENABLED: CapsuleProtocol
Capsule-Protocol: ?1.
pub const fn new(enabled: bool) -> CapsuleProtocol
pub const fn new(enabled: bool) -> CapsuleProtocol
Construct from the Boolean value.
pub const fn is_enabled(self) -> bool
pub const fn is_enabled(self) -> bool
Whether the Capsule Protocol is in use.