Struct Cookie
pub struct Cookie(pub NonEmptyVec<ArcStr>);Available on crate features
http and std only.Expand description
Cookie header, defined in RFC6265
If the user agent does attach a Cookie header field to an HTTP request, the user agent must send the cookie-string as the value of the header field.
When the user agent generates an HTTP request, the user agent MUST NOT attach more than one Cookie header field.
Example values
SID=31d4d96e407aad42SID=31d4d96e407aad42; lang=en-US
Tuple Fields
0: NonEmptyVec<ArcStr>Implementations
impl Cookie
impl Cookie
pub fn get(&self, name: &str) -> Option<&str>
pub fn get(&self, name: &str) -> Option<&str>
Lookup a value for a cookie name.
Example
use rama_http_headers::{HeaderMapExt, Cookie};
use rama_http_types::{HeaderMap, HeaderValue};
// Setup the header map with strings...
let mut headers = HeaderMap::new();
headers.insert("cookie", HeaderValue::from_static("lang=en-US"));
// Parse a `Cookie` so we can play with it...
let cookie = headers
.typed_get::<Cookie>()
.expect("we just inserted a valid Cookie");
assert_eq!(cookie.get("lang"), Some("en-US"));
assert_eq!(cookie.get("SID"), None);Trait Implementations
impl HeaderDecode for Cookie
impl HeaderDecode for Cookie
fn decode<'i, I>(values: &mut I) -> Result<Cookie, Error>where
I: Iterator<Item = &'i HeaderValue>,
fn decode<'i, I>(values: &mut I) -> Result<Cookie, Error>where
I: Iterator<Item = &'i HeaderValue>,
Decode this type from an iterator of
HeaderValues.impl HeaderEncode for Cookie
impl HeaderEncode for Cookie
fn encode<E>(&self, values: &mut E)where
E: Extend<HeaderValue>,
fn encode<E>(&self, values: &mut E)where
E: Extend<HeaderValue>,
Encode this type to a
HeaderValue, and add it to a container
which has HeaderValue type as each element. Read morefn encode_to_value(&self) -> Option<HeaderValue>
fn encode_to_value(&self) -> Option<HeaderValue>
Encode this header to
HeaderValue. Read moreimpl StructuralPartialEq for Cookie
impl TypedHeader for Cookie
impl TypedHeader for Cookie
fn name() -> &'static HeaderName
fn name() -> &'static HeaderName
The name of this header.