DatastarRequest

Struct DatastarRequest 

#[non_exhaustive]
pub struct DatastarRequest;
Available on crate features http and std only.
Datastar-Request header, sent by the ๐Ÿš€ Datastar client on every request it makes (e.g. through @get or @post actions).

Servers use it to tell Datastar fetches apart from regular browser navigations, e.g. to reply with a 401 instead of a redirect to a sign-in page, or to only read Datastar signals when present.

Datastar always sends the value true, but this header is treated as a presence marker: decoding succeeds for any value, as the mere presence of the header is what identifies a Datastar request. Encoding always writes true.

Example values

  • โ€œtrueโ€

Examples

use rama_http_headers::{DatastarRequest, HeaderMapExt};
use rama_http_types::HeaderMap;

let mut headers = HeaderMap::new();
assert!(headers.typed_get::<DatastarRequest>().is_none());

headers.typed_insert(DatastarRequest::new());
assert!(headers.typed_get::<DatastarRequest>().is_some());

Implementations



impl DatastarRequest

pub fn new() -> DatastarRequest

Create a new DatastarRequest typed header.