Struct LastEventId
pub struct LastEventId(/* private fields */);Available on crate features
http and std only.Expand description
Last-Event-ID header, defined in
WhatWG’s SSE spec
The Last-Event-ID` HTTP request header reports an EventSource object’s last event ID string to the server when the user agent is to reestablish the connection.
The spec is a String with the id of the last event, it can be an empty string which acts a sort of “reset”.
Implementations
impl LastEventId
impl LastEventId
impl LastEventId
impl LastEventId
pub fn from_static(s: &'static str) -> LastEventId
pub fn from_static(s: &'static str) -> LastEventId