Struct Origin
pub struct Origin(/* private fields */);Available on crate features
http and std only.Expand description
The Origin header.
The Origin header is a version of the Referer header that is used for all HTTP fetches and POSTs whose CORS flag is set.
This header is often used to inform recipients of the security context of where the request was initiated.
Following the spec, https://fetch.spec.whatwg.org/#origin-header, the value of this header is composed of a String (scheme), Host (host/port)
Examples
use rama_http_headers::Origin;
let origin = Origin::NULL;Implementations
impl Origin
impl Origin
pub fn try_from_parts(
scheme: &str,
host: &str,
port: impl Into<Option<u16>>,
) -> Result<Origin, InvalidOrigin>
pub fn try_from_parts( scheme: &str, host: &str, port: impl Into<Option<u16>>, ) -> Result<Origin, InvalidOrigin>
Tries to build a Origin from three parts, the scheme, the host and an optional port.
pub fn try_from_header_value(value: &HeaderValue) -> Option<Origin>
pub fn try_from_header_value(value: &HeaderValue) -> Option<Origin>
Try to parse an Origin header value.
Returns None for invalid origins, including values with a path other
than /, query, or fragment.