Struct DirectiveDateTime
pub struct DirectiveDateTime { /* private fields */ }Expand description
Date-time value used by the unavailable_after X-Robots-Tag directive.
This aims to support the practical date formats documented by Google and MDN
for unavailable_after, namely widely adopted formats such as RFC 822/2822,
RFC 850, and ISO 8601. It is intentionally a compatibility-oriented parser,
not a claim of exhaustive support for every date syntax a crawler might
accept in the wild.
Implementations
impl DirectiveDateTime
impl DirectiveDateTime
pub fn try_new_ymd_and_hms( year: i32, month: u32, day: u32, hour: u32, min: u32, sec: u32, ) -> Result<DirectiveDateTime, Box<dyn Error + Send + Sync>>
pub fn try_new_ymd( year: i32, month: u32, day: u32, ) -> Result<DirectiveDateTime, Box<dyn Error + Send + Sync>>
pub fn with_format_rfc3339(self) -> DirectiveDateTime
pub fn set_format_rfc3339(&mut self) -> &mut DirectiveDateTime
pub fn with_format_rfc2822(self) -> DirectiveDateTime
pub fn set_format_rfc2822(&mut self) -> &mut DirectiveDateTime
pub fn with_format_rfc855(self) -> DirectiveDateTime
pub fn set_format_rfc855(&mut self) -> &mut DirectiveDateTime
pub fn with_format_default(self) -> DirectiveDateTime
pub fn set_format_default(&mut self) -> &mut DirectiveDateTime
pub fn date_time(&self) -> &Timestamp
pub fn into_date_time(self) -> Timestamp