a

Macro a 

a!() { /* proc-macro */ }
Available on crate features http and html only.
Together with its href attribute, creates a hyperlink to web pages, files, email addresses, locations within the current page, or anything else a URL can address.