Macro audio
audio!() { /* proc-macro */ }Available on crate features
html and http only.Expand description
Used to embed sound content in documents. It may contain one or more audio sources, represented using the src attribute or the source! element: the browser will choose the most suitable one. It can also be the destination for streamed media, using a MediaStream.