Macro bdo
bdo!() { /* proc-macro */ }Available on crate features
html and http only.Expand description
Overrides the current directionality of text, so that the text within is rendered in a different direction.
bdo!() { /* proc-macro */ }html and http only.Overrides the current directionality of text, so that the text within is rendered in a different direction.