blockquote

Macro blockquote 

blockquote!() { /* proc-macro */ }
Available on crate features http and html only.
Indicates that the enclosed text is an extended quotation. Usually, this is rendered visually by indentation. A URL for the source of the quotation may be given using the cite attribute, while a text representation of the source can be given using the cite! element.