Macro body
body!() { /* proc-macro */ }Available on crate features
html and http only.Expand description
Represents the content of an HTML document. There can be only one such element in a document.
body!() { /* proc-macro */ }html and http only.Represents the content of an HTML document. There can be only one such element in a document.