div

Macro div 

div!() { /* proc-macro */ }
Available on crate features http and html only.
The generic container for flow content. It has no effect on the content or layout until styled in some way using CSS (e.g., styling is directly applied to it, or some kind of layout model like flexbox is applied to its parent element).