dl

Macro dl 

dl!() { /* proc-macro */ }
Available on crate features http and html only.
Represents a description list. The element encloses a list of groups of terms (specified using the dt! element) and descriptions (provided by dd! elements). Common uses for this element are to implement a glossary or to display metadata (a list of key-value pairs).