dt

Macro dt 

dt!() { /* proc-macro */ }
Available on crate features http and html only.
Specifies a term in a description or definition list, and as such must be used inside a dl! element. It is usually followed by a dd! element; however, multiple dt! elements in a row indicate several terms that are all defined by the immediate next dd! element.