embed

Macro embed 

embed!() { /* proc-macro */ }
Available on crate features http and html only.
Embeds external content at the specified point in the document. This content is provided by an external application or other source of interactive content such as a browser plug-in.