Macro fieldset
fieldset!() { /* proc-macro */ }Available on crate features
html and http only.Expand description
Used to group several controls as well as labels (label!) within a web form.
fieldset!() { /* proc-macro */ }html and http only.Used to group several controls as well as labels (label!) within a web form.