figure

Macro figure 

figure!() { /* proc-macro */ }
Available on crate features http and html only.
Represents self-contained content, potentially with an optional caption, which is specified using the figcaption! element. The figure, its caption, and its contents are referenced as a single unit.