html

Macro html 

html!() { /* proc-macro */ }
Available on crate features http and html only.
Represents the root (top-level element) of an HTML document, so it is also referred to as the root element. All other elements must be descendants of this element.