Macro label
label!() { /* proc-macro */ }Available on crate features
html and http only.Expand description
Represents a caption for an item in a user interface.
label!() { /* proc-macro */ }html and http only.Represents a caption for an item in a user interface.