noscript

Macro noscript 

noscript!() { /* proc-macro */ }
Available on crate features http and html only.
Defines a section of HTML to be inserted if a script type on the page is unsupported or if scripting is currently turned off in the browser.