Macro object
object!() { /* proc-macro */ }Available on crate features
html and http only.Expand description
Represents an external resource, which can be treated as an image, a nested browsing context, or a resource to be handled by a plugin.