output

Macro output 

output!() { /* proc-macro */ }
Available on crate features http and html only.
Container element into which a site or app can inject the results of a calculation or the outcome of a user action.