script

Macro script 

script!() { /* proc-macro */ }
Available on crate features http and html only.
Used to embed executable code or data; this is typically used to embed or refer to JavaScript code. The script! element can also be used with other languages, such as WebGL’s GLSL shader programming language and JSON.