svg

Macro svg 

svg!() { /* proc-macro */ }
Available on crate features http and html only.
Container defining a new coordinate system and viewport. It is used as the outermost element of SVG documents, but it can also be used to embed an SVG fragment inside an SVG or HTML document.