textarea

Macro textarea 

textarea!() { /* proc-macro */ }
Available on crate features http and html only.
Represents a multi-line plain-text editing control, useful when you want to allow users to enter a sizeable amount of free-form text, for example, a comment on a review or feedback form.