Struct CaptureMetadata
pub struct CaptureMetadata {
pub connection: Observations,
pub exchange: Observations,
pub upstream: Observations,
}Available on crate features
http and inspect and std only.Expand description
Distinct ownership scopes for captured protocol observations.
Fields
connection: ObservationsObservations shared by exchanges on the same downstream connection.
exchange: ObservationsObservations belonging to this HTTP exchange.
upstream: ObservationsObservations of the upstream connection used for the response.
Implementations
impl CaptureMetadata
impl CaptureMetadata
pub fn request_fingerprint(&self, parts: &Parts) -> Option<Arc<Ja4H>>
pub fn request_fingerprint(&self, parts: &Parts) -> Option<Arc<Ja4H>>
Compute once and share the observed HTTP fingerprint with protocol adapters.