Struct CaptureQuery
pub struct CaptureQuery {
pub filter: CaptureFilter,
pub selected_connections: BTreeSet<u64>,
pub before_connection_id: Option<u64>,
pub connection_limit: usize,
pub exchange_limit: usize,
}Available on crate features
http and inspect and std only.Expand description
A bounded view suitable for an API, native GUI, or TUI. A cursor pages older connections.
Fields
filter: CaptureFilterselected_connections: BTreeSet<u64>before_connection_id: Option<u64>connection_limit: usizeexchange_limit: usizeTrait Implementations
impl Clone for CaptureQuery
impl Clone for CaptureQuery
fn clone(&self) -> CaptureQuery
fn clone(&self) -> CaptureQuery
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for CaptureQuery
impl Debug for CaptureQuery
impl Default for CaptureQuery
impl Default for CaptureQuery
fn default() -> CaptureQuery
fn default() -> CaptureQuery
Returns the “default value” for a type. Read more
impl Service<CaptureQuery> for CaptureStore
impl Service<CaptureQuery> for CaptureStore
type Output = CaptureSnapshot
type Output = CaptureSnapshot
The type of the output returned by the service.
async fn serve(
&self,
query: CaptureQuery,
) -> Result<<CaptureStore as Service<CaptureQuery>>::Output, <CaptureStore as Service<CaptureQuery>>::Error>
async fn serve( &self, query: CaptureQuery, ) -> Result<<CaptureStore as Service<CaptureQuery>>::Output, <CaptureStore as Service<CaptureQuery>>::Error>
Serve an output or an error for the given input
fn boxed(self) -> BoxService<Input, Self::Output, Self::Error>
fn boxed(self) -> BoxService<Input, Self::Output, Self::Error>
Box this service to allow for dynamic dispatch.