Struct CaptureSelection
pub struct CaptureSelection { /* private fields */ }Available on crate features
http and inspect and std only.Expand description
A stable selection that retains its storage and can be read one exchange at a time, without materializing every selected body in memory.
Implementations
impl CaptureSelection
impl CaptureSelection
pub fn is_empty(&self) -> bool
pub fn next_capture(&mut self) -> Option<ExchangeCapture>
pub async fn next_details( &mut self, ) -> Result<Option<CaptureDetails>, Box<dyn Error + Send + Sync>>