Struct CapturedRecordStream
pub struct CapturedRecordStream<M> {
pub metadata: M,
pub payload: Pin<Box<dyn AsyncRead + Send>>,
}Available on crate features
http and inspect and std only.Expand description
Typed metadata and a reader over the raw payload. Downloads, exporters and protocol consumers can pipe this reader directly without a decode buffer.
Fields
metadata: Mpayload: Pin<Box<dyn AsyncRead + Send>>Implementations
impl<M> CapturedRecordStream<M>
impl<M> CapturedRecordStream<M>
pub async fn into_record<T>(self) -> Result<T, Box<dyn Error + Send + Sync>>where
T: CapturedRecord<Metadata = M>,
pub async fn into_record<T>(self) -> Result<T, Box<dyn Error + Send + Sync>>where
T: CapturedRecord<Metadata = M>,
Explicitly materialize an owned record, for APIs such as message replay.
Streaming consumers should read payload instead.