Struct ConnectionQuery
pub struct ConnectionQuery(pub u64);Available on crate features
http and inspect and std only.Expand description
A human-visible connection number, optionally entered with a leading #.
Tuple Fields
0: u64Trait Implementations
impl Clone for ConnectionQuery
impl Clone for ConnectionQuery
fn clone(&self) -> ConnectionQuery
fn clone(&self) -> ConnectionQuery
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ConnectionQuery
impl Debug for ConnectionQuery
impl Debug for ConnectionQuery
impl Display for ConnectionQuery
impl Display for ConnectionQuery
impl Eq for ConnectionQuery
impl FromStr for ConnectionQuery
impl FromStr for ConnectionQuery
type Err = ParseIntError
type Err = ParseIntError
The associated error which can be returned from parsing.
fn from_str(
s: &str,
) -> Result<ConnectionQuery, <ConnectionQuery as FromStr>::Err>
fn from_str( s: &str, ) -> Result<ConnectionQuery, <ConnectionQuery as FromStr>::Err>
Parses a string
s to return a value of this type. Read moreimpl PartialEq for ConnectionQuery
impl PartialEq for ConnectionQuery
impl StructuralPartialEq for ConnectionQuery