Struct Parts
#[non_exhaustive]pub struct Parts<T> {
pub io: T,
pub read_buf: Bytes,
pub read_err: Option<Error>,
pub extensions: Extensions,
/* private fields */
}http and std only.Expand description
The deconstructed parts of an Upgraded type.
Includes the original IO type, and a read buffer of bytes that the HTTP state machine may have already read before completing an upgrade.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.io: TThe original IO object used before the upgrade.
read_buf: BytesA buffer of bytes that have been read but not processed as HTTP.
For instance, if the Connection is used for an HTTP upgrade request,
it is possible the server sent back the first bytes of the new protocol
along with the response upgrade.
You will want to check for any existing bytes if you plan to continue communicating on the IO object.
read_err: Option<Error>A read error the upgraded stream already hit on io.
It follows read_buf and comes before any further
read of io, which may not report it again (some
sockets report a reset only once).
extensions: ExtensionsExtensions associated with this upgrade