Struct AltSvcBody
pub struct AltSvcBody<B> { /* private fields */ }Available on crate features
http and std only.Expand description
Response body preserving the underlying frames and errors while recording complete responses and remote failures of a discovered alternative. Dropping an unread body is not evidence of success or endpoint failure. The wrapper does not allocate.
Implementations
impl AltSvcBody<Body>
impl AltSvcBody<Body>