Struct AddAuthorizationLayer
pub struct AddAuthorizationLayer { /* private fields */ }http and std only.Expand description
Layer that applies AddAuthorization which adds authorization to all requests using the
Authorization header.
See the module docs for an example.
You can also use SetRequestHeader if you have a use case that isn’t supported by this
middleware.
Implementations
impl AddAuthorizationLayer
impl AddAuthorizationLayer
pub fn none() -> AddAuthorizationLayer
pub fn none() -> AddAuthorizationLayer
Create a new AddAuthorizationLayer that does not add any authorization.
Can be useful if you only want to add authorization for some branches of your service.
pub fn new(credential: impl Credentials) -> AddAuthorizationLayer
pub fn new(credential: impl Credentials) -> AddAuthorizationLayer
Authorize requests using the given Credentials.
pub fn with_sensitive(self, sensitive: bool) -> AddAuthorizationLayer
pub fn with_sensitive(self, sensitive: bool) -> AddAuthorizationLayer
Mark the header as sensitive.
This can for example be used to hide the header value from logs.
pub fn set_sensitive(&mut self, sensitive: bool) -> &mut AddAuthorizationLayer
pub fn set_sensitive(&mut self, sensitive: bool) -> &mut AddAuthorizationLayer
Mark the header as sensitive.
This can for example be used to hide the header value from logs.
pub fn with_if_not_present(self, value: bool) -> AddAuthorizationLayer
pub fn with_if_not_present(self, value: bool) -> AddAuthorizationLayer
Preserve the existing Authorization header if it exists.
This can be useful if you want to use different authorization headers for different requests.
pub fn set_if_not_present(&mut self, value: bool) -> &mut AddAuthorizationLayer
pub fn set_if_not_present(&mut self, value: bool) -> &mut AddAuthorizationLayer
Preserve the existing Authorization header if it exists.
This can be useful if you want to use different authorization headers for different requests.