pub struct AddAuthorizationLayer { /* private fields */ }http only.Expand description
Layer that applies AddAuthorization which adds authorization to all requests using the
Authorization header.
See the module docs for an example.
You can also use SetRequestHeader if you have a use case that isn’t supported by this
middleware.
Implementations
Sourceimpl AddAuthorizationLayer
impl AddAuthorizationLayer
Sourcepub fn none() -> AddAuthorizationLayer
pub fn none() -> AddAuthorizationLayer
Create a new AddAuthorizationLayer that does not add any authorization.
Can be useful if you only want to add authorization for some branches of your service.
Sourcepub fn basic(username: &str, password: &str) -> AddAuthorizationLayer
pub fn basic(username: &str, password: &str) -> AddAuthorizationLayer
Authorize requests using a username and password pair.
The Authorization header will be set to Basic {credentials} where credentials is
base64_encode("{username}:{password}").
Since the username and password is sent in clear text it is recommended to use HTTPS/TLS with this method. However use of HTTPS/TLS is not enforced by this middleware.
Sourcepub fn bearer(token: &str) -> AddAuthorizationLayer
pub fn bearer(token: &str) -> AddAuthorizationLayer
Authorize requests using a “bearer token”. Commonly used for OAuth 2.
The Authorization header will be set to Bearer {token}.
Panics
Panics if the token is not a valid HeaderValue.
Sourcepub fn as_sensitive(self, sensitive: bool) -> AddAuthorizationLayer
pub fn as_sensitive(self, sensitive: bool) -> AddAuthorizationLayer
Mark the header as sensitive.
This can for example be used to hide the header value from logs.
Sourcepub fn set_as_sensitive(
&mut self,
sensitive: bool,
) -> &mut AddAuthorizationLayer
pub fn set_as_sensitive( &mut self, sensitive: bool, ) -> &mut AddAuthorizationLayer
Mark the header as sensitive.
This can for example be used to hide the header value from logs.
Sourcepub fn if_not_present(self, value: bool) -> AddAuthorizationLayer
pub fn if_not_present(self, value: bool) -> AddAuthorizationLayer
Preserve the existing Authorization header if it exists.
This can be useful if you want to use different authorization headers for different requests.
Sourcepub fn set_if_not_present(&mut self, value: bool) -> &mut AddAuthorizationLayer
pub fn set_if_not_present(&mut self, value: bool) -> &mut AddAuthorizationLayer
Preserve the existing Authorization header if it exists.
This can be useful if you want to use different authorization headers for different requests.