HttpAuthorizer

Struct HttpAuthorizer 

pub struct HttpAuthorizer<A, C> { /* private fields */ }
Available on crate features http and std only.
Utility type to allow you to use any Authorizer that works with Credentials to authorize the Authorization header, and return StatusCode::UNAUTHORIZED response with header::WWW_AUTHENTICATE for unauthorized request, tracing the original error for your convenience.

Implementations



impl<A, C> HttpAuthorizer<A, C>

pub fn new(authorizer: A) -> HttpAuthorizer<A, C>

pub fn with_allow_anonymous(self, allow: bool) -> HttpAuthorizer<A, C>

Defines whether or not to allow anonymous.

This means that the request is will be authorized automatically, if no Authorization header was passed in.

pub fn set_allow_anonymous(&mut self, allow: bool) -> &mut HttpAuthorizer<A, C>

Defines whether or not to allow anonymous.

This means that the request is will be authorized automatically, if no Authorization header was passed in.