pub struct GrpcErrorsAsFailures { /* private fields */ }http only.Expand description
Response classifier for gRPC responses.
gRPC doesn’t use normal HTTP statuses for indicating success or failure but instead a special header that might appear in a trailer.
Responses are considered successful if
grpc-statusheader value contains a success value.grpc-statusheader is missing.grpc-statusheader value isn’t a validString.grpc-statusheader value can’t parsed into ani32.
All others are considered failures.
Implementations
Sourceimpl GrpcErrorsAsFailures
impl GrpcErrorsAsFailures
Sourcepub const fn new() -> GrpcErrorsAsFailures
pub const fn new() -> GrpcErrorsAsFailures
Create a new GrpcErrorsAsFailures.
Sourcepub fn with_success(self, code: GrpcCode) -> GrpcErrorsAsFailures
pub fn with_success(self, code: GrpcCode) -> GrpcErrorsAsFailures
Change which gRPC codes are considered success.
Defaults to only considering Ok as success.
Ok will always be considered a success.
Example
Servers might not want to consider Invalid Argument or Not Found as failures since
thats likely the clients fault:
use rama_http::layer::classify::{GrpcErrorsAsFailures, GrpcCode};
let classifier = GrpcErrorsAsFailures::new()
.with_success(GrpcCode::InvalidArgument)
.with_success(GrpcCode::NotFound);Sourcepub fn set_success(&mut self, code: GrpcCode) -> &mut GrpcErrorsAsFailures
pub fn set_success(&mut self, code: GrpcCode) -> &mut GrpcErrorsAsFailures
Change which gRPC codes are considered success.
Same as Self::with_success but without consuming self.
Sourcepub fn make_classifier() -> SharedClassifier<GrpcErrorsAsFailures>
pub fn make_classifier() -> SharedClassifier<GrpcErrorsAsFailures>
Returns a MakeClassifier that produces GrpcErrorsAsFailures.
This is a convenience function that simply calls SharedClassifier::new.