StreamCompression

Struct StreamCompression 

pub struct StreamCompression<S, P = DefaultStreamPredicate> { /* private fields */ }
Available on crate features compression and http only.
Compress response bodies of the underlying service.

This uses the Accept-Encoding header to pick an appropriate encoding and adds the Content-Encoding header to responses.

See the module docs for more details.

Implementations



impl<S> StreamCompression<S>

pub fn new(service: S) -> StreamCompression<S>

Creates a new StreamCompression wrapping the service.



impl<S, P> StreamCompression<S, P>

pub fn get_ref(&self) -> &S

Gets a reference to the underlying service.

pub fn into_inner(self) -> S

Consumes self, returning the underlying service.

pub fn with_gzip(self, enable: bool) -> StreamCompression<S, P>

Sets whether to enable the gzip encoding.

pub fn set_gzip(&mut self, enable: bool) -> &mut StreamCompression<S, P>

Sets whether to enable the gzip encoding.

pub fn with_deflate(self, enable: bool) -> StreamCompression<S, P>

Sets whether to enable the Deflate encoding.

pub fn set_deflate(&mut self, enable: bool) -> &mut StreamCompression<S, P>

Sets whether to enable the Deflate encoding.

pub fn with_br(self, enable: bool) -> StreamCompression<S, P>

Sets whether to enable the Brotli encoding.

pub fn set_br(&mut self, enable: bool) -> &mut StreamCompression<S, P>

Sets whether to enable the Brotli encoding.

pub fn with_zstd(self, enable: bool) -> StreamCompression<S, P>

Sets whether to enable the Zstd encoding.

pub fn set_zstd(&mut self, enable: bool) -> &mut StreamCompression<S, P>

Sets whether to enable the Zstd encoding.

pub fn with_quality(self, quality: CompressionLevel) -> StreamCompression<S, P>

Sets the StreamCompression quality.

pub fn set_quality( &mut self, quality: CompressionLevel, ) -> &mut StreamCompression<S, P>

Sets the StreamCompression quality.

pub fn with_enforce_not_acceptable( self, enable: bool, ) -> StreamCompression<S, P>

Sets whether to respond with 406 Not Acceptable when the client’s Accept-Encoding header rejects every available representation (e.g. *;q=0 or a lone identity;q=0), as recommended by RFC 9110 12.5.3.

Enabled by default. Disable to opt out and instead fall back to sending an uncompressed (identity) response regardless of the client’s stated preference.

pub fn set_enforce_not_acceptable( &mut self, enable: bool, ) -> &mut StreamCompression<S, P>

Sets whether to respond with 406 Not Acceptable when the client’s Accept-Encoding header rejects every available representation (e.g. *;q=0 or a lone identity;q=0), as recommended by RFC 9110 12.5.3.

Enabled by default. Disable to opt out and instead fall back to sending an uncompressed (identity) response regardless of the client’s stated preference.

pub fn with_compress_predicate<C>(self, predicate: C) -> StreamCompression<S, C>
where C: Predicate,

Replace the current StreamCompression predicate.

Predicates are used to determine whether a response should be compressed or not.

The default predicate is DefaultPredicate. See its documentation for more details on which responses it wont compress.