Struct StreamCompressionLayer
pub struct StreamCompressionLayer<P = DefaultStreamPredicate> { /* private fields */ }compression and http only.Expand description
Compress response bodies of the underlying service.
This uses the Accept-Encoding header to pick an appropriate encoding and adds the
Content-Encoding header to responses.
See the module docs for more details.
Implementations
impl StreamCompressionLayer
impl StreamCompressionLayer
pub fn new() -> StreamCompressionLayer
pub fn new() -> StreamCompressionLayer
Creates a new StreamCompressionLayer.
pub fn with_compress_predicate<C>(
self,
predicate: C,
) -> StreamCompressionLayer<C>where
C: Predicate,
pub fn with_compress_predicate<C>(
self,
predicate: C,
) -> StreamCompressionLayer<C>where
C: Predicate,
Replace the current compression predicate.
impl<P> StreamCompressionLayer<P>
impl<P> StreamCompressionLayer<P>
pub fn with_gzip(self, enable: bool) -> StreamCompressionLayer<P>
pub fn with_gzip(self, enable: bool) -> StreamCompressionLayer<P>
Sets whether to enable the gzip encoding.
pub fn set_gzip(&mut self, enable: bool) -> &mut StreamCompressionLayer<P>
pub fn set_gzip(&mut self, enable: bool) -> &mut StreamCompressionLayer<P>
Sets whether to enable the gzip encoding.
pub fn with_deflate(self, enable: bool) -> StreamCompressionLayer<P>
pub fn with_deflate(self, enable: bool) -> StreamCompressionLayer<P>
Sets whether to enable the Deflate encoding.
pub fn set_deflate(&mut self, enable: bool) -> &mut StreamCompressionLayer<P>
pub fn set_deflate(&mut self, enable: bool) -> &mut StreamCompressionLayer<P>
Sets whether to enable the Deflate encoding.
pub fn with_br(self, enable: bool) -> StreamCompressionLayer<P>
pub fn with_br(self, enable: bool) -> StreamCompressionLayer<P>
Sets whether to enable the Brotli encoding.
pub fn set_br(&mut self, enable: bool) -> &mut StreamCompressionLayer<P>
pub fn set_br(&mut self, enable: bool) -> &mut StreamCompressionLayer<P>
Sets whether to enable the Brotli encoding.
pub fn with_zstd(self, enable: bool) -> StreamCompressionLayer<P>
pub fn with_zstd(self, enable: bool) -> StreamCompressionLayer<P>
Sets whether to enable the Zstd encoding.
pub fn set_zstd(&mut self, enable: bool) -> &mut StreamCompressionLayer<P>
pub fn set_zstd(&mut self, enable: bool) -> &mut StreamCompressionLayer<P>
Sets whether to enable the Zstd encoding.
pub fn with_quality(
self,
quality: CompressionLevel,
) -> StreamCompressionLayer<P>
pub fn with_quality( self, quality: CompressionLevel, ) -> StreamCompressionLayer<P>
Sets the compression quality.
pub fn set_quality(
&mut self,
quality: CompressionLevel,
) -> &mut StreamCompressionLayer<P>
pub fn set_quality( &mut self, quality: CompressionLevel, ) -> &mut StreamCompressionLayer<P>
Sets the compression quality.
pub fn with_enforce_not_acceptable(
self,
enable: bool,
) -> StreamCompressionLayer<P>
pub fn with_enforce_not_acceptable( self, enable: bool, ) -> StreamCompressionLayer<P>
Sets whether to respond with 406 Not Acceptable when the client’s
Accept-Encoding header rejects every available representation
(e.g. *;q=0 or a lone identity;q=0), as recommended by RFC 9110 12.5.3.
Enabled by default. Disable to opt out and instead fall back to sending an uncompressed (identity) response regardless of the client’s stated preference.
pub fn set_enforce_not_acceptable(
&mut self,
enable: bool,
) -> &mut StreamCompressionLayer<P>
pub fn set_enforce_not_acceptable( &mut self, enable: bool, ) -> &mut StreamCompressionLayer<P>
Sets whether to respond with 406 Not Acceptable when the client’s
Accept-Encoding header rejects every available representation
(e.g. *;q=0 or a lone identity;q=0), as recommended by RFC 9110 12.5.3.
Enabled by default. Disable to opt out and instead fall back to sending an uncompressed (identity) response regardless of the client’s stated preference.