Trait Predicate
pub trait Predicate: Clone {
// Required method
fn should_compress<B>(&self, response: &mut Response<B>) -> bool
where B: Body;
// Provided method
fn and<Other>(self, other: Other) -> And<Self, Other>
where Self: Sized,
Other: Predicate { ... }
}Expand description
Predicate used to determine if a response should be compressed or not.
Required Methods
fn should_compress<B>(&self, response: &mut Response<B>) -> boolwhere
B: Body,
fn should_compress<B>(&self, response: &mut Response<B>) -> boolwhere
B: Body,
Should this response be compressed or not?
The response is mutable so predicates can attach extensions used later during response-time compression negotiation.
Provided Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.