Struct Content
pub struct Content {
pub size: i64,
pub compression: Option<i64>,
pub mime_type: Option<Mime>,
pub text: Option<ArcStr>,
pub encoding: Option<ContentEncodingDirective>,
pub comment: Option<ArcStr>,
}Expand description
This object describes details about response content
(embedded in <response> object).
Before setting the text field, the HTTP response is decoded (decompressed & unchunked), than trans-coded from its original character set into UTF-8. Additionally, it can be encoded using e.g. base64. Ideally, the application should be able to unencode a base64 blob and get a byte-for-byte identical resource to what the browser operated on.
Fields
size: i64Length of the returned content in bytes.
Should be equal to response.bodySize if there is no compression and bigger when the content has been compressed.
compression: Option<i64>Number of bytes saved.
Leave out this field if the information is not available.
mime_type: Option<Mime>MIME type of the response text
(value of the Content-Type response header).
The charset attribute of the MIME type is included (if available).
text: Option<ArcStr>encoding: Option<ContentEncodingDirective>Response body sent from the server or loaded from the browser cache.
This field is populated with textual content only. The text field is either HTTP decoded text or a encoded (e.g. “base64”) representation of the response body.
Leave out this field if the information is not available.
comment: Option<ArcStr>A comment provided by the user or the application.