Struct Timings
pub struct Timings {
pub blocked: Option<i64>,
pub dns: Option<i64>,
pub connect: Option<i64>,
pub send: i64,
pub wait: i64,
pub receive: i64,
pub ssl: Option<i64>,
pub comment: Option<ArcStr>,
}Expand description
This object describes various phases within request-response round trip.
All times are specified in milliseconds.
Fields
blocked: Option<i64>Time spent in a queue waiting for a network connection.
Use -1 if the timing does not apply to the current request.
dns: Option<i64>DNS resolution time.
The time required to resolve a host name.
Use -1 if the timing does not apply to the current request.
connect: Option<i64>Time required to create TCP connection.
Use -1 if the timing does not apply to the current request.
send: i64Time required to send HTTP request to the server.
wait: i64Waiting for a response from the server.
receive: i64Time required to read entire response from the server (or cache).
ssl: Option<i64>Time required for SSL/TLS negotiation.
If this field is defined then the time is also included in the connect field (to ensure backward compatibility with HAR 1.1).
Use -1 if the timing does not apply to the current request.
comment: Option<ArcStr>A comment provided by the user or the application.