Function extract_header_config
pub fn extract_header_config<H, T, G>(
request: &G,
header_name: H,
) -> Result<T, HeaderValueErr>Expand description
Extract a header config from a request or response without consuming it.
pub fn extract_header_config<H, T, G>(
request: &G,
header_name: H,
) -> Result<T, HeaderValueErr>Extract a header config from a request or response without consuming it.