Struct ProxyAuthLayer
pub struct ProxyAuthLayer<A, C, L = ()> { /* private fields */ }http and std only.Expand description
Layer that applies the ProxyAuthService middleware which apply a timeout to requests.
See the module docs for an example.
Implementations
impl<A, C> ProxyAuthLayer<A, C>
impl<A, C> ProxyAuthLayer<A, C>
pub const fn new(proxy_auth: A) -> ProxyAuthLayer<A, C>
pub const fn new(proxy_auth: A) -> ProxyAuthLayer<A, C>
Creates a new ProxyAuthLayer.
pub fn with_allow_anonymous(self, allow_anonymous: bool) -> ProxyAuthLayer<A, C>
pub fn with_allow_anonymous(self, allow_anonymous: bool) -> ProxyAuthLayer<A, C>
Allow anonymous requests.
pub fn set_allow_anonymous(
&mut self,
allow_anonymous: bool,
) -> &mut ProxyAuthLayer<A, C>
pub fn set_allow_anonymous( &mut self, allow_anonymous: bool, ) -> &mut ProxyAuthLayer<A, C>
Allow anonymous requests.
pub fn with_preserve_header(self, preserve_header: bool) -> ProxyAuthLayer<A, C>
pub fn with_preserve_header(self, preserve_header: bool) -> ProxyAuthLayer<A, C>
Preserve Proxy-Authorization after authenticating the request.
This is disabled by default so credentials addressed to this proxy cannot leak to an inner service or a different upstream proxy.
pub fn set_preserve_header(
&mut self,
preserve_header: bool,
) -> &mut ProxyAuthLayer<A, C>
pub fn set_preserve_header( &mut self, preserve_header: bool, ) -> &mut ProxyAuthLayer<A, C>
Preserve Proxy-Authorization after authenticating the request.
This is disabled by default so credentials addressed to this proxy cannot leak to an inner service or a different upstream proxy.
impl<A, C, L> ProxyAuthLayer<A, C, L>
impl<A, C, L> ProxyAuthLayer<A, C, L>
pub fn with_labels<L2>(self) -> ProxyAuthLayer<A, C, L2>
pub fn with_labels<L2>(self) -> ProxyAuthLayer<A, C, L2>
Overwrite the Labels extract type
This is used if the username contains labels that you need to extract out.
Example implementation is the UsernameOpaqueLabelParser.
You can provide your own extractor by implementing the UsernameLabelParser trait.