Function remove_hop_by_hop_request_headers
pub fn remove_hop_by_hop_request_headers(headers: &mut HeaderMap)Available on crate features
http and std only.Expand description
Remove hop by hop headers from an outbound request.
This function applies the rules from RFC 9110 for hop by hop headers before forwarding a request to another hop.
This should be called when acting as a forward proxy, reverse proxy, or gateway that forwards requests to an upstream server.
End-to-end forwarding metadata is preserved unless explicitly named by the
Connection header. Use remove_forwarding_metadata_request_headers when
that metadata must be scrubbed as a separate policy decision.