pub struct AddRequiredResponseHeadersLayer { /* private fields */ }Available on crate feature
http only.Expand description
Layer that applies AddRequiredResponseHeaders which adds a request header.
See AddRequiredResponseHeaders for more details.
Implementations
Sourceimpl AddRequiredResponseHeadersLayer
impl AddRequiredResponseHeadersLayer
Sourcepub const fn new() -> AddRequiredResponseHeadersLayer
pub const fn new() -> AddRequiredResponseHeadersLayer
Create a new AddRequiredResponseHeadersLayer.
Sourcepub const fn overwrite(self, overwrite: bool) -> AddRequiredResponseHeadersLayer
pub const fn overwrite(self, overwrite: bool) -> AddRequiredResponseHeadersLayer
Set whether to overwrite the existing headers.
If set to true, the headers will be overwritten.
Default is false.
Sourcepub fn set_overwrite(
&mut self,
overwrite: bool,
) -> &mut AddRequiredResponseHeadersLayer
pub fn set_overwrite( &mut self, overwrite: bool, ) -> &mut AddRequiredResponseHeadersLayer
Set whether to overwrite the existing headers.
If set to true, the headers will be overwritten.
Default is false.
Sourcepub fn server_header_value(
self,
value: HeaderValue,
) -> AddRequiredResponseHeadersLayer
pub fn server_header_value( self, value: HeaderValue, ) -> AddRequiredResponseHeadersLayer
Set a custom SERVER header value.
By default a versioned rama value is used.
Sourcepub fn maybe_server_header_value(
self,
value: Option<HeaderValue>,
) -> AddRequiredResponseHeadersLayer
pub fn maybe_server_header_value( self, value: Option<HeaderValue>, ) -> AddRequiredResponseHeadersLayer
Maybe set a custom SERVER header value.
By default a versioned rama value is used.
Sourcepub fn set_server_header_value(
&mut self,
value: HeaderValue,
) -> &mut AddRequiredResponseHeadersLayer
pub fn set_server_header_value( &mut self, value: HeaderValue, ) -> &mut AddRequiredResponseHeadersLayer
Set a custom SERVER header value.
By default a versioned rama value is used.