RequestWriterLayer

Struct RequestWriterLayer 

pub struct RequestWriterLayer<W> { /* private fields */ }
Available on crate features http and std only.
Middleware to print Http request in std format.

Request bodies are observed while they stream to the inner service. The writer receives an owned body stream and processes frames concurrently.

See the module docs for more details.

Implementations



impl<W> RequestWriterLayer<W>

pub const fn new(writer: W) -> RequestWriterLayer<W>

Create a new RequestWriterLayer with a custom RequestWriter.

Use Self::new_with_executor when streaming writer tasks must participate in graceful shutdown.

pub const fn new_with_executor( writer: W, executor: Executor, ) -> RequestWriterLayer<W>

Create a new RequestWriterLayer with a custom RequestWriter and executor for streaming writer tasks.



impl RequestWriterLayer<UnboundedSender<Request>>

pub fn writer_unbounded<W>( executor: &Executor, writer: W, mode: Option<WriterMode>, ) -> RequestWriterLayer<UnboundedSender<Request>>
where W: AsyncWrite + Unpin + Send + Sync + 'static,

Create a new RequestWriterLayer that prints requests to an [AsyncWrite]r over an unbounded channel

pub fn stdout_unbounded( executor: &Executor, mode: Option<WriterMode>, ) -> RequestWriterLayer<UnboundedSender<Request>>

Create a new RequestWriterService that prints requests to stdout over an unbounded channel.

pub fn stderr_unbounded( executor: &Executor, mode: Option<WriterMode>, ) -> RequestWriterLayer<UnboundedSender<Request>>

Create a new RequestWriterService that prints requests to stderr over an unbounded channel.



impl RequestWriterLayer<PerMessageFileWriter>

pub async fn file_per_request( executor: &Executor, directory: impl Into<PathBuf>, prefix: impl AsRef<str>, mode: Option<WriterMode>, ) -> Result<RequestWriterLayer<PerMessageFileWriter>, Error>

Create a layer that streams every request into a unique file below directory using the portable filename prefix.



impl RequestWriterLayer<Sender<Request>>

pub fn writer<W>( executor: &Executor, writer: W, buffer_size: usize, mode: Option<WriterMode>, ) -> RequestWriterLayer<Sender<Request>>
where W: AsyncWrite + Unpin + Send + Sync + 'static,

Create a new RequestWriterLayer that prints requests to an [AsyncWrite]r over a bounded channel with a fixed buffer size.

pub fn stdout( executor: &Executor, buffer_size: usize, mode: Option<WriterMode>, ) -> RequestWriterLayer<Sender<Request>>

Create a new RequestWriterService that prints requests to stdout over a bounded channel with a fixed buffer size.

pub fn stderr( executor: &Executor, buffer_size: usize, mode: Option<WriterMode>, ) -> RequestWriterLayer<Sender<Request>>

Create a new RequestWriterService that prints requests to stderr over a bounded channel with a fixed buffer size.