Struct RequestWriterService
pub struct RequestWriterService<S, W> { /* private fields */ }http and std only.Expand description
Middleware to print Http request in std format.
Request bodies are observed while they stream to the inner service. The writer receives an owned body stream and processes frames concurrently.
See the module docs for more details.
Implementations
impl<S, W> RequestWriterService<S, W>
impl<S, W> RequestWriterService<S, W>
pub fn new(inner: S, writer: W) -> RequestWriterService<S, W>
pub fn new(inner: S, writer: W) -> RequestWriterService<S, W>
Create a new RequestWriterService with a custom RequestWriter.
Use Self::new_with_executor when streaming writer tasks must
participate in graceful shutdown.
pub fn new_with_executor(
inner: S,
writer: W,
executor: Executor,
) -> RequestWriterService<S, W>
pub fn new_with_executor( inner: S, writer: W, executor: Executor, ) -> RequestWriterService<S, W>
Create a new RequestWriterService with a custom RequestWriter
and executor for streaming writer tasks.
impl<S> RequestWriterService<S, UnboundedSender<Request>>
impl<S> RequestWriterService<S, UnboundedSender<Request>>
pub fn writer_unbounded<W>(
inner: S,
executor: &Executor,
writer: W,
mode: Option<WriterMode>,
) -> RequestWriterService<S, UnboundedSender<Request>>
pub fn writer_unbounded<W>( inner: S, executor: &Executor, writer: W, mode: Option<WriterMode>, ) -> RequestWriterService<S, UnboundedSender<Request>>
Create a new RequestWriterService that prints requests to an [AsyncWrite]r
over an unbounded channel
pub fn stdout_unbounded(
inner: S,
executor: &Executor,
mode: Option<WriterMode>,
) -> RequestWriterService<S, UnboundedSender<Request>>
pub fn stdout_unbounded( inner: S, executor: &Executor, mode: Option<WriterMode>, ) -> RequestWriterService<S, UnboundedSender<Request>>
Create a new RequestWriterService that prints requests to stdout
over an unbounded channel.
pub fn stderr_unbounded(
inner: S,
executor: &Executor,
mode: Option<WriterMode>,
) -> RequestWriterService<S, UnboundedSender<Request>>
pub fn stderr_unbounded( inner: S, executor: &Executor, mode: Option<WriterMode>, ) -> RequestWriterService<S, UnboundedSender<Request>>
Create a new RequestWriterService that prints requests to stderr
over an unbounded channel.
impl<S> RequestWriterService<S, PerMessageFileWriter>
impl<S> RequestWriterService<S, PerMessageFileWriter>
pub async fn file_per_request(
inner: S,
executor: &Executor,
directory: impl Into<PathBuf>,
prefix: impl AsRef<str>,
mode: Option<WriterMode>,
) -> Result<RequestWriterService<S, PerMessageFileWriter>, Error>
pub async fn file_per_request( inner: S, executor: &Executor, directory: impl Into<PathBuf>, prefix: impl AsRef<str>, mode: Option<WriterMode>, ) -> Result<RequestWriterService<S, PerMessageFileWriter>, Error>
Create a service that streams every request into a unique file below
directory using the portable filename prefix.
impl<S> RequestWriterService<S, Sender<Request>>
impl<S> RequestWriterService<S, Sender<Request>>
pub fn writer<W>(
inner: S,
executor: &Executor,
writer: W,
buffer_size: usize,
mode: Option<WriterMode>,
) -> RequestWriterService<S, Sender<Request>>
pub fn writer<W>( inner: S, executor: &Executor, writer: W, buffer_size: usize, mode: Option<WriterMode>, ) -> RequestWriterService<S, Sender<Request>>
Create a new RequestWriterService that prints requests to an [AsyncWrite]r
over a bounded channel with a fixed buffer size.
pub fn stdout(
inner: S,
executor: &Executor,
buffer_size: usize,
mode: Option<WriterMode>,
) -> RequestWriterService<S, Sender<Request>>
pub fn stdout( inner: S, executor: &Executor, buffer_size: usize, mode: Option<WriterMode>, ) -> RequestWriterService<S, Sender<Request>>
Create a new RequestWriterService that prints requests to stdout
over a bounded channel with a fixed buffer size.
pub fn stderr(
inner: S,
executor: &Executor,
buffer_size: usize,
mode: Option<WriterMode>,
) -> RequestWriterService<S, Sender<Request>>
pub fn stderr( inner: S, executor: &Executor, buffer_size: usize, mode: Option<WriterMode>, ) -> RequestWriterService<S, Sender<Request>>
Create a new RequestWriterService that prints requests to stderr
over a bounded channel with a fixed buffer size.