Struct ResponseWriterLayer
pub struct ResponseWriterLayer<W> { /* private fields */ }http and std only.Expand description
Layer that applies ResponseWriterService which prints the http response in std format.
Response bodies are observed while they stream to the caller. The writer receives an owned body stream and processes frames concurrently.
Implementations
impl<W> ResponseWriterLayer<W>
impl<W> ResponseWriterLayer<W>
pub const fn new(writer: W) -> ResponseWriterLayer<W>
pub const fn new(writer: W) -> ResponseWriterLayer<W>
Create a new ResponseWriterLayer with a custom ResponseWriter.
Use Self::new_with_executor when streaming writer tasks must participate
in graceful shutdown.
pub const fn new_with_executor(
writer: W,
executor: Executor,
) -> ResponseWriterLayer<W>
pub const fn new_with_executor( writer: W, executor: Executor, ) -> ResponseWriterLayer<W>
Create a new ResponseWriterLayer with a custom ResponseWriter
and executor for streaming writer tasks.
impl ResponseWriterLayer<UnboundedSender<Response>>
impl ResponseWriterLayer<UnboundedSender<Response>>
pub fn writer_unbounded<W>(
executor: &Executor,
writer: W,
mode: Option<WriterMode>,
) -> ResponseWriterLayer<UnboundedSender<Response>>
pub fn writer_unbounded<W>( executor: &Executor, writer: W, mode: Option<WriterMode>, ) -> ResponseWriterLayer<UnboundedSender<Response>>
Create a new ResponseWriterLayer that prints responses to an [AsyncWrite]r
over an unbounded channel
pub fn stdout_unbounded(
executor: &Executor,
mode: Option<WriterMode>,
) -> ResponseWriterLayer<UnboundedSender<Response>>
pub fn stdout_unbounded( executor: &Executor, mode: Option<WriterMode>, ) -> ResponseWriterLayer<UnboundedSender<Response>>
Create a new ResponseWriterLayer that prints responses to stdout
over an unbounded channel.
pub fn stderr_unbounded(
executor: &Executor,
mode: Option<WriterMode>,
) -> ResponseWriterLayer<UnboundedSender<Response>>
pub fn stderr_unbounded( executor: &Executor, mode: Option<WriterMode>, ) -> ResponseWriterLayer<UnboundedSender<Response>>
Create a new ResponseWriterLayer that prints responses to stderr
over an unbounded channel.
impl ResponseWriterLayer<PerMessageFileWriter>
impl ResponseWriterLayer<PerMessageFileWriter>
pub async fn file_per_response(
executor: &Executor,
directory: impl Into<PathBuf>,
prefix: impl AsRef<str>,
mode: Option<WriterMode>,
) -> Result<ResponseWriterLayer<PerMessageFileWriter>, Error>
pub async fn file_per_response( executor: &Executor, directory: impl Into<PathBuf>, prefix: impl AsRef<str>, mode: Option<WriterMode>, ) -> Result<ResponseWriterLayer<PerMessageFileWriter>, Error>
Create a layer that streams every response into a unique file below
directory using the portable filename prefix.
impl ResponseWriterLayer<Sender<Response>>
impl ResponseWriterLayer<Sender<Response>>
pub fn writer<W>(
executor: &Executor,
writer: W,
buffer_size: usize,
mode: Option<WriterMode>,
) -> ResponseWriterLayer<Sender<Response>>
pub fn writer<W>( executor: &Executor, writer: W, buffer_size: usize, mode: Option<WriterMode>, ) -> ResponseWriterLayer<Sender<Response>>
Create a new ResponseWriterLayer that prints responses to an [AsyncWrite]r
over a bounded channel with a fixed buffer size.
pub fn stdout(
executor: &Executor,
buffer_size: usize,
mode: Option<WriterMode>,
) -> ResponseWriterLayer<Sender<Response>>
pub fn stdout( executor: &Executor, buffer_size: usize, mode: Option<WriterMode>, ) -> ResponseWriterLayer<Sender<Response>>
Create a new ResponseWriterLayer that prints responses to stdout
over a bounded channel with a fixed buffer size.
pub fn stderr(
executor: &Executor,
buffer_size: usize,
mode: Option<WriterMode>,
) -> ResponseWriterLayer<Sender<Response>>
pub fn stderr( executor: &Executor, buffer_size: usize, mode: Option<WriterMode>, ) -> ResponseWriterLayer<Sender<Response>>
Create a new ResponseWriterLayer that prints responses to stderr
over a bounded channel with a fixed buffer size.