Struct HttpUpgradeMitmRelay
pub struct HttpUpgradeMitmRelay<M, S> { /* private fields */ }http and std only.Expand description
Http middleware that can be used by MITM proxies, such as transparent (L4) proxies to relay a HTTP upgrade-request as-is and pipe the upgraded upgrade request on both ends via the upgrade (bridgeIo) svc.
Matchers and response middleware select protocol metadata with
HttpUpgradeMitmRelayExtensions. Request selections reach the ingress
transport and response selections reach the egress transport, after both
upgrades succeed. Each upgraded transport otherwise retains its own
connection or HTTP/2 stream state.
See HttpUpgradeMitmRelayExtensions for an example of selecting metadata.
Implementations
impl<M, S> HttpUpgradeMitmRelay<M, S>
impl<M, S> HttpUpgradeMitmRelay<M, S>
pub fn new(
exec: Executor,
nested_matcher_svc: M,
inner_svc: S,
) -> HttpUpgradeMitmRelay<M, S>
pub fn new( exec: Executor, nested_matcher_svc: M, inner_svc: S, ) -> HttpUpgradeMitmRelay<M, S>
Create a new HttpUpgradeMitmRelay.
pub fn with_error_sink(self, sink: impl ErrorSink) -> HttpUpgradeMitmRelay<M, S>
pub fn with_error_sink(self, sink: impl ErrorSink) -> HttpUpgradeMitmRelay<M, S>
Set a custom ErrorSink used to observe errors from the detached
relay task (relay-service failures and upgrade failures on either side).
Defaults to TracingErrorSink::default (traces at DEBUG level).