Struct UpgradeResponse
pub struct UpgradeResponse<I, O> {
pub response: O,
pub request: I,
pub extensions: Extensions,
}http and std only.Expand description
Handshake response produced by the responder in a
UpgradeLayer::new_with_services
configuration.
Call Self::with_handler to attach a response-local continuation and turn
it into the UpgradeOutput expected by UpgradeLayer::new.
Fields
response: OResponse that should be returned
request: IRequest that caused this upgrade
extensions: ExtensionsExtensions which will be applied to the Upgraded io
if the upgrade was successful
Implementations
impl<I, O> UpgradeResponse<I, O>
impl<I, O> UpgradeResponse<I, O>
pub fn new(request: I, response: O) -> UpgradeResponse<I, O>
pub fn new(request: I, response: O) -> UpgradeResponse<I, O>
Create an upgrade response without extra extensions.
pub fn with_extension<T>(self, extension: T) -> UpgradeResponse<I, O>where
T: Extension,
pub fn with_extension<T>(self, extension: T) -> UpgradeResponse<I, O>where
T: Extension,
Add an extension which will be applied to the Upgraded I/O.
pub fn with_handler<F, Fut, T, E>(self, handler: F) -> UpgradeOutput<I, O>
pub fn with_handler<F, Fut, T, E>(self, handler: F) -> UpgradeOutput<I, O>
Attach a response-local, one-shot handler for the upgraded connection.
The returned UpgradeOutput is accepted by UpgradeLayer::new.
The handler can own resources established while producing this response,
such as an egress connection, without storing them in Extensions.