Struct Upgraded
pub struct Upgraded { /* private fields */ }http and std only.Expand description
An upgraded HTTP connection.
This type holds a trait object internally of the original IO that
was used to speak HTTP before the upgrade. It can be used directly
as a [AsyncRead] or [AsyncWrite] for convenience.
Alternatively, if the exact type is known, this can be deconstructed into its parts.
Implementations
impl Upgraded
impl Upgraded
pub fn new<T>(io: T, read_buf: Bytes) -> Upgraded
pub fn new<T>(io: T, read_buf: Bytes) -> Upgraded
Create a new Upgraded from an IO stream and existing buffer.
The Upgraded starts with the io Extensionss. Message extensions
are not copied by handle_upgrade: they can contain structural
Ingress / Egress links back to this same io. A protocol-specific
upgrade handler can explicitly transfer the typed message extensions it
needs.
pub fn with_extensions(self, extensions: Extensions) -> Upgraded
pub fn set_extensions(&mut self, extensions: Extensions) -> &mut Upgraded
pub fn with_guard<G>(self, guard: G) -> Upgradedwhere
G: Send + 'static,
pub fn with_guard<G>(self, guard: G) -> Upgradedwhere
G: Send + 'static,
Bind an opaque resource to the lifetime of this upgraded transport.
The resource is retained when the transport is downcast into Parts
and is released when the upgraded transport, or those parts, are
dropped. This is useful for leases that must remain active for as long
as the upgraded protocol is using the underlying connection.