Struct FileUriLayer
pub struct FileUriLayer { /* private fields */ }Available on crate features
http and std only.Expand description
Serve file:// request URIs from the local filesystem.
See the module docs for an example.
Implementations
impl FileUriLayer
impl FileUriLayer
pub fn new() -> FileUriLayer
pub fn new() -> FileUriLayer
Create a new FileUriLayer.
pub fn maybe_with_jail(self, jail: Option<PathBuf>) -> FileUriLayer
pub fn maybe_with_jail(self, jail: Option<PathBuf>) -> FileUriLayer
Confine served files to within this root directory, rejecting any path resolving outside it.
pub fn maybe_set_jail(&mut self, jail: Option<PathBuf>) -> &mut FileUriLayer
pub fn maybe_set_jail(&mut self, jail: Option<PathBuf>) -> &mut FileUriLayer
Confine served files to within this root directory, rejecting any path resolving outside it.
pub fn with_jail(self, jail: PathBuf) -> FileUriLayer
pub fn with_jail(self, jail: PathBuf) -> FileUriLayer
Confine served files to within this root directory, rejecting any path resolving outside it.
pub fn set_jail(&mut self, jail: PathBuf) -> &mut FileUriLayer
pub fn set_jail(&mut self, jail: PathBuf) -> &mut FileUriLayer
Confine served files to within this root directory, rejecting any path resolving outside it.
pub fn without_jail(self) -> FileUriLayer
pub fn without_jail(self) -> FileUriLayer
Confine served files to within this root directory, rejecting any path resolving outside it.
pub fn unset_jail(&mut self) -> &mut FileUriLayer
pub fn unset_jail(&mut self) -> &mut FileUriLayer
Confine served files to within this root directory, rejecting any path resolving outside it.