adapt_response_version

Function adapt_response_version 

pub fn adapt_response_version<Body>(
    response: &mut Response<Body>,
    request_ctx: &ResponseVersionAdaptCtx,
) -> Result<(), Box<dyn Error + Sync + Send>>
Available on crate features http and std only.
Adapt response to match the provided Version, using ResponseVersionAdaptCtx captured from the original request to translate handshake responses.