Struct RequestVersionAdapter
pub struct RequestVersionAdapter<S> { /* private fields */ }http and std only.Expand description
ConnectorService which will adapt the request version if needed.
It will adapt the request version to TargetHttpVersion, or the configured
default version
Implementations
impl<S> RequestVersionAdapter<S>
impl<S> RequestVersionAdapter<S>
pub fn get_ref(&self) -> &S
Available on crate features dns and http-backend and tcp only.
pub fn get_ref(&self) -> &S
dns and http-backend and tcp only.Gets a reference to the underlying service.
pub fn into_inner(self) -> S
Available on crate features dns and http-backend and tcp only.
pub fn into_inner(self) -> S
dns and http-backend and tcp only.Consumes self, returning the underlying service.
pub fn get_mut(&mut self) -> &mut S
Available on crate features dns and http-backend and tcp only.
pub fn get_mut(&mut self) -> &mut S
dns and http-backend and tcp only.Configure the wrapped connector before sharing the adapter.
pub fn new(inner: S) -> RequestVersionAdapter<S>
dns and http-backend and tcp only.pub fn maybe_with_default_version(
self,
version: Option<Version>,
) -> RequestVersionAdapter<S>
Available on crate features dns and http-backend and tcp only.
pub fn maybe_with_default_version( self, version: Option<Version>, ) -> RequestVersionAdapter<S>
dns and http-backend and tcp only.Set default request Version which will be used if TargetHttpVersion is
is not present in extensions
pub fn maybe_set_default_version(
&mut self,
version: Option<Version>,
) -> &mut RequestVersionAdapter<S>
Available on crate features dns and http-backend and tcp only.
pub fn maybe_set_default_version( &mut self, version: Option<Version>, ) -> &mut RequestVersionAdapter<S>
dns and http-backend and tcp only.Set default request Version which will be used if TargetHttpVersion is
is not present in extensions
pub fn with_default_version(self, version: Version) -> RequestVersionAdapter<S>
Available on crate features dns and http-backend and tcp only.
pub fn with_default_version(self, version: Version) -> RequestVersionAdapter<S>
dns and http-backend and tcp only.Set default request Version which will be used if TargetHttpVersion is
is not present in extensions
pub fn set_default_version(
&mut self,
version: Version,
) -> &mut RequestVersionAdapter<S>
Available on crate features dns and http-backend and tcp only.
pub fn set_default_version( &mut self, version: Version, ) -> &mut RequestVersionAdapter<S>
dns and http-backend and tcp only.Set default request Version which will be used if TargetHttpVersion is
is not present in extensions
pub fn without_default_version(self) -> RequestVersionAdapter<S>
Available on crate features dns and http-backend and tcp only.
pub fn without_default_version(self) -> RequestVersionAdapter<S>
dns and http-backend and tcp only.Set default request Version which will be used if TargetHttpVersion is
is not present in extensions
pub fn unset_default_version(&mut self) -> &mut RequestVersionAdapter<S>
Available on crate features dns and http-backend and tcp only.
pub fn unset_default_version(&mut self) -> &mut RequestVersionAdapter<S>
dns and http-backend and tcp only.Set default request Version which will be used if TargetHttpVersion is
is not present in extensions