Enum PathDecoding
#[non_exhaustive]pub enum PathDecoding {
Raw,
PercentDecoded,
}Available on crate features
http and std only.Expand description
Percent-escape handling policy for HTTP request paths and captures.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Raw
Match and capture the URI path’s encoded spelling.
Well-formed escapes preserve their spelling, including hex-digit case.
The URI encoded view canonicalizes malformed escapes by encoding the
stray percent sign, so % is observed as %25 in a raw capture.
PercentDecoded
Decode valid percent escapes once before matching and capture the decoded value.