Struct CapsuleType
pub struct CapsuleType(/* private fields */);Available on crate features
http and std only.Expand description
A Capsule Type (RFC 9297 3.2, 5.4).
Implementations
impl CapsuleType
impl CapsuleType
pub const DATAGRAM: CapsuleType
pub const DATAGRAM: CapsuleType
DATAGRAM (RFC 9297 3.5): carries one HTTP Datagram payload.
pub const fn new(value: u64) -> Result<CapsuleType, InvalidCapsule>
pub const fn new(value: u64) -> Result<CapsuleType, InvalidCapsule>
Construct from its raw value, which must fit a variable-length integer.
pub const fn is_reserved(self) -> bool
pub const fn is_reserved(self) -> bool
Whether this is a reserved greasing type of the form 0x29 * N + 0x17 (RFC 9297 5.4).