Enum HeadErrorKind
#[non_exhaustive]pub enum HeadErrorKind {
Incomplete,
TrailingBytes,
TooManyHeaders,
InvalidSyntax,
InvalidMethod,
InvalidTarget,
InvalidVersion,
InvalidStatus,
InvalidHeader,
UnsupportedVersion,
}Available on crate features
http and std only.Expand description
Classification for standalone HTTP/1 message-head failures.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Incomplete
The input ended before a complete head was available.
TrailingBytes
Bytes followed the terminating empty line.
TooManyHeaders
The configured header count bound was exceeded.
InvalidSyntax
The request or response head syntax was invalid.
InvalidMethod
The request method was absent or invalid.
InvalidTarget
The HTTP request-target was absent or invalid.
InvalidVersion
The HTTP version was absent or invalid.
InvalidStatus
The response status was absent or invalid.
InvalidHeader
A header name or value was invalid.
UnsupportedVersion
The typed version cannot be represented by this HTTP/1 codec.