encode_header_fields

Function encode_header_fields 

pub fn encode_header_fields<B>(headers: &HeaderMap, output: &mut B)
where B: BufMut,
Available on crate features http and std only.
Append HTTP header fields in their insertion order and original casing.

This emits the terminating CRLF of each field, but not the final empty line that terminates a complete HTTP head.