Struct HeadParser
pub struct HeadParser { /* private fields */ }Available on crate features
http and std only.Expand description
Standalone HTTP/1 message-head parser configuration.
Implementations
impl HeadParser
impl HeadParser
pub const fn new() -> HeadParser
pub const fn new() -> HeadParser
Construct a strict parser with bounded header storage.
pub const fn with_max_headers(self, max_headers: usize) -> HeadParser
pub const fn with_max_headers(self, max_headers: usize) -> HeadParser
Set the maximum number of header fields in one head.
pub fn set_max_headers(&mut self, max_headers: usize) -> &mut HeadParser
pub fn set_max_headers(&mut self, max_headers: usize) -> &mut HeadParser
Set the maximum number of header fields in one head.
pub fn parse_request(&self, input: &Bytes) -> Result<Request<()>, HeadError>
pub fn parse_request(&self, input: &Bytes) -> Result<Request<()>, HeadError>
Parse one complete HTTP/1 request head.