Struct AltSvcEvent
pub struct AltSvcEvent {
pub origin: AltSvcOrigin,
pub field_value: Bytes,
pub received_at: Instant,
pub sequence: u64,
}Available on crate features
http and std only.Expand description
An advertisement received on this connection, never a relay instruction.
Fields
origin: AltSvcOriginfield_value: Bytesreceived_at: Instantsequence: u64Tie-breaker for receipts within the same monotonic clock tick.