Macro body
body!() { /* proc-macro */ }Available on crate features
html and http and std only.Expand description
Represents the content of an HTML document. There can be only one such element in a document.
body!() { /* proc-macro */ }html and http and std only.Represents the content of an HTML document. There can be only one such element in a document.