canvas

Macro canvas 

canvas!() { /* proc-macro */ }
Available on crate features html and http and std only.
Container element to use with either the canvas scripting API or the WebGL API to draw graphics and animations.