Macro label
label!() { /* proc-macro */ }Available on crate features
html and http and std only.Expand description
Represents a caption for an item in a user interface.
label!() { /* proc-macro */ }html and http and std only.Represents a caption for an item in a user interface.