Macro ruby
ruby!() { /* proc-macro */ }Available on crate features
html and http and std only.Expand description
Represents small annotations that are rendered above, below, or next to base text, usually used for showing the pronunciation of East Asian characters. It can also be used for annotating other kinds of text, but this usage is less common.