sup

Macro sup 

sup!() { /* proc-macro */ }
Available on crate features html and http and std only.
Specifies inline text which is to be displayed as superscript for solely typographical reasons. Superscripts are usually rendered with a raised baseline using smaller text.