Struct JsonLd
pub struct JsonLd(/* private fields */);http and std only.Expand description
A valid, script-data-safe JSON-LD document.
This type guarantees JSON syntax and safe HTML embedding. It does not process JSON-LD semantics such as @context, expansion, or compaction.
Implementations
impl JsonLd
impl JsonLd
pub fn serialize<T>(value: &T) -> Result<JsonLd, Error>
pub fn serialize<T>(value: &T) -> Result<JsonLd, Error>
Serialize value directly into script-data-safe JSON.
Every literal less-than sign emitted by the serializer is encoded as a JSON Unicode escape so strings containing a script end tag cannot terminate an enclosing HTML script element.
pub fn from_value(value: &Value) -> JsonLd
pub fn from_value(value: &Value) -> JsonLd
Serialize an existing serde_json::Value.
Unlike arbitrary Serialize implementations, a Value cannot reject serialization, and the in-memory writer used here cannot fail.
pub fn from_bytes(bytes: Bytes) -> Result<JsonLd, Error>
pub fn from_bytes(bytes: Bytes) -> Result<JsonLd, Error>
Validate and prepare existing JSON bytes.
The original allocation is retained when the input contains no literal less-than sign. Otherwise only those bytes are rewritten into JSON Unicode escapes.
pub fn deserialize<T>(&self) -> Result<T, Error>where
T: DeserializeOwned,
pub fn deserialize<T>(&self) -> Result<T, Error>where
T: DeserializeOwned,
Deserialize the document into T.
pub fn into_bytes(self) -> Bytes
pub fn into_bytes(self) -> Bytes
Consume the document into its cheaply-shareable encoded bytes.
pub fn script(&self) -> JsonLdScript
Available on crate feature html only.
pub fn script(&self) -> JsonLdScript
html only.Render this document as an HTML JSON-LD data block.