AtomFeedBuilder

Struct AtomFeedBuilder 

pub struct AtomFeedBuilder<I, T, U> { /* private fields */ }
Available on crate features http and rss only.
Type-state builder for AtomFeed.

I, T, and U track whether id, title, and updated have been provided. build is only available once all three are Present.

Implementations



impl<I, T, U> AtomFeedBuilder<I, T, U>

pub fn with_author(self, author: AtomPerson) -> AtomFeedBuilder<I, T, U>

Append a feed-level author. Call multiple times to add more.

pub fn set_author( &mut self, author: AtomPerson, ) -> &mut AtomFeedBuilder<I, T, U>

Append a feed-level author. Call multiple times to add more.

Append a feed-level <link>. Call multiple times to add more.

Append a feed-level <link>. Call multiple times to add more.

pub fn with_category(self, cat: AtomCategory) -> AtomFeedBuilder<I, T, U>

Append a feed-level category. Call multiple times to add more.

pub fn set_category( &mut self, cat: AtomCategory, ) -> &mut AtomFeedBuilder<I, T, U>

Append a feed-level category. Call multiple times to add more.

pub fn with_contributor(self, c: AtomPerson) -> AtomFeedBuilder<I, T, U>

Append a feed-level contributor. Call multiple times to add more.

pub fn set_contributor( &mut self, c: AtomPerson, ) -> &mut AtomFeedBuilder<I, T, U>

Append a feed-level contributor. Call multiple times to add more.

pub fn with_generator( self, generator: AtomGenerator, ) -> AtomFeedBuilder<I, T, U>

pub fn set_generator( &mut self, generator: AtomGenerator, ) -> &mut AtomFeedBuilder<I, T, U>

pub fn with_icon(self, icon: impl Into<String>) -> AtomFeedBuilder<I, T, U>

pub fn set_icon( &mut self, icon: impl Into<String>, ) -> &mut AtomFeedBuilder<I, T, U>

pub fn with_rights( self, rights: impl Into<AtomText>, ) -> AtomFeedBuilder<I, T, U>

pub fn set_rights( &mut self, rights: impl Into<AtomText>, ) -> &mut AtomFeedBuilder<I, T, U>

pub fn with_subtitle( self, subtitle: impl Into<AtomText>, ) -> AtomFeedBuilder<I, T, U>

pub fn set_subtitle( &mut self, subtitle: impl Into<AtomText>, ) -> &mut AtomFeedBuilder<I, T, U>

pub fn with_entry(self, entry: AtomEntry) -> AtomFeedBuilder<I, T, U>

Append a single entry. Call multiple times to attach more.

pub fn set_entry(&mut self, entry: AtomEntry) -> &mut AtomFeedBuilder<I, T, U>

Append a single entry. Call multiple times to attach more.

pub fn with_entries( self, entries: impl IntoIterator<Item = AtomEntry>, ) -> AtomFeedBuilder<I, T, U>

pub fn set_entries( &mut self, entries: impl IntoIterator<Item = AtomEntry>, ) -> &mut AtomFeedBuilder<I, T, U>

pub fn with_feed_extensions( self, ext: FeedExtensions, ) -> AtomFeedBuilder<I, T, U>

pub fn set_feed_extensions( &mut self, ext: FeedExtensions, ) -> &mut AtomFeedBuilder<I, T, U>