Struct DublinCoreTerms
pub struct DublinCoreTerms {Show 15 fields
pub relation: Vec<Uri>,
pub conforms_to: Vec<Uri>,
pub has_format: Vec<Uri>,
pub is_format_of: Vec<Uri>,
pub has_part: Vec<Uri>,
pub is_part_of: Vec<Uri>,
pub has_version: Vec<Uri>,
pub is_version_of: Vec<Uri>,
pub references: Vec<Uri>,
pub is_referenced_by: Vec<Uri>,
pub replaces: Vec<Uri>,
pub is_replaced_by: Vec<Uri>,
pub requires: Vec<Uri>,
pub is_required_by: Vec<Uri>,
pub source: Vec<Uri>,
}http and rss and std only.Expand description
DCMI Metadata Terms relationship fields for a feed item or Atom entry.
Fields
relation: Vec<Uri>A related resource.
conforms_to: Vec<Uri>An established standard to which the described resource conforms.
has_format: Vec<Uri>A substantially equivalent resource in another format.
is_format_of: Vec<Uri>A resource that is substantially equivalent but in another format.
has_part: Vec<Uri>A resource included physically or logically in the described resource.
is_part_of: Vec<Uri>A resource that physically or logically includes the described resource.
has_version: Vec<Uri>A version, edition, or adaptation of the described resource.
is_version_of: Vec<Uri>A resource of which the described resource is a version, edition, or adaptation.
references: Vec<Uri>A resource referenced, cited, or otherwise pointed to by the described resource.
is_referenced_by: Vec<Uri>A resource that references, cites, or otherwise points to the described resource.
replaces: Vec<Uri>A resource supplanted, displaced, or superseded by the described resource.
is_replaced_by: Vec<Uri>A resource that supplants, displaces, or supersedes the described resource.
requires: Vec<Uri>A resource required by the described resource for its function, delivery, or coherence.
is_required_by: Vec<Uri>A resource that requires the described resource for its function, delivery, or coherence.
source: Vec<Uri>A related resource from which the described resource is derived.
Implementations
impl DublinCoreTerms
impl DublinCoreTerms