Rss2FeedBuilder

Struct Rss2FeedBuilder 

pub struct Rss2FeedBuilder<T, L, D> { /* private fields */ }
Available on crate features http and rss only.
Type-state builder for Rss2Feed.

T, L, and D track whether title, link, and description have been provided. build is only available once all three are Present.

Implementations



impl<T, L, D> Rss2FeedBuilder<T, L, D>

pub fn with_language(self, lang: impl Into<String>) -> Rss2FeedBuilder<T, L, D>

pub fn set_language( &mut self, lang: impl Into<String>, ) -> &mut Rss2FeedBuilder<T, L, D>

pub fn with_managing_editor( self, editor: impl Into<String>, ) -> Rss2FeedBuilder<T, L, D>

pub fn set_managing_editor( &mut self, editor: impl Into<String>, ) -> &mut Rss2FeedBuilder<T, L, D>

pub fn with_web_master(self, wm: impl Into<String>) -> Rss2FeedBuilder<T, L, D>

pub fn set_web_master( &mut self, wm: impl Into<String>, ) -> &mut Rss2FeedBuilder<T, L, D>

pub fn with_pub_date(self, date: Timestamp) -> Rss2FeedBuilder<T, L, D>

pub fn set_pub_date(&mut self, date: Timestamp) -> &mut Rss2FeedBuilder<T, L, D>

pub fn with_last_build_date(self, date: Timestamp) -> Rss2FeedBuilder<T, L, D>

pub fn set_last_build_date( &mut self, date: Timestamp, ) -> &mut Rss2FeedBuilder<T, L, D>

pub fn with_category(self, cat: Rss2Category) -> Rss2FeedBuilder<T, L, D>

Append a channel-level category. Call multiple times to attach more.

pub fn set_category( &mut self, cat: Rss2Category, ) -> &mut Rss2FeedBuilder<T, L, D>

Append a channel-level category. Call multiple times to attach more.

pub fn with_generator( self, generator: impl Into<String>, ) -> Rss2FeedBuilder<T, L, D>

pub fn set_generator( &mut self, generator: impl Into<String>, ) -> &mut Rss2FeedBuilder<T, L, D>

pub fn with_docs(self, docs: impl Into<String>) -> Rss2FeedBuilder<T, L, D>

RSS 2.0 <docs> — URL pointing at the RSS specification this document conforms to. Optional; the conventional value is https://www.rssboard.org/rss-specification.

pub fn set_docs( &mut self, docs: impl Into<String>, ) -> &mut Rss2FeedBuilder<T, L, D>

RSS 2.0 <docs> — URL pointing at the RSS specification this document conforms to. Optional; the conventional value is https://www.rssboard.org/rss-specification.

pub fn with_ttl(self, ttl: u32) -> Rss2FeedBuilder<T, L, D>

pub fn set_ttl(&mut self, ttl: u32) -> &mut Rss2FeedBuilder<T, L, D>

pub fn with_image(self, image: Rss2Image) -> Rss2FeedBuilder<T, L, D>

pub fn set_image(&mut self, image: Rss2Image) -> &mut Rss2FeedBuilder<T, L, D>

Append a channel-level <atom:link>. The conventional rel="self" element required by podcast directories is built via AtomLink::self_link.

Append a channel-level <atom:link>. The conventional rel="self" element required by podcast directories is built via AtomLink::self_link.

pub fn with_item(self, item: Rss2Item) -> Rss2FeedBuilder<T, L, D>

Append a single item. Call multiple times to attach more.

pub fn set_item(&mut self, item: Rss2Item) -> &mut Rss2FeedBuilder<T, L, D>

Append a single item. Call multiple times to attach more.

pub fn with_items( self, items: impl IntoIterator<Item = Rss2Item>, ) -> Rss2FeedBuilder<T, L, D>

pub fn set_items( &mut self, items: impl IntoIterator<Item = Rss2Item>, ) -> &mut Rss2FeedBuilder<T, L, D>

pub fn with_feed_extensions( self, ext: FeedExtensions, ) -> Rss2FeedBuilder<T, L, D>

pub fn set_feed_extensions( &mut self, ext: FeedExtensions, ) -> &mut Rss2FeedBuilder<T, L, D>