Struct DefaultHttpProxyConnectReplyService
#[non_exhaustive]pub struct DefaultHttpProxyConnectReplyService;Expand description
A default Service which responds on an http (proxy) connect with
a default http response and which injects
the destination address as the proxy target.
It can also be used for other HTTP connect purposes, but that is not what the service is intended for.
Implementations
impl DefaultHttpProxyConnectReplyService
impl DefaultHttpProxyConnectReplyService
pub fn new() -> DefaultHttpProxyConnectReplyService
pub fn new() -> DefaultHttpProxyConnectReplyService
Create a new DefaultHttpProxyConnectReplyService.