Struct HttpProxyConnectRelayServiceRequestMatcher
pub struct HttpProxyConnectRelayServiceRequestMatcher<S = IoForwardService> { /* private fields */ }Expand description
Default matcher that can be used for Http proxy connects.
Request matches for an http proxy connect request return
a HttpProxyConnectRelayServiceResponseMatcher instance which
will match on any success responses…
Implementations
impl<S> HttpProxyConnectRelayServiceRequestMatcher<S>
impl<S> HttpProxyConnectRelayServiceRequestMatcher<S>
pub fn new(relay_svc: S) -> HttpProxyConnectRelayServiceRequestMatcher<S>
pub fn new(relay_svc: S) -> HttpProxyConnectRelayServiceRequestMatcher<S>
Create a new HttpProxyConnectRelayServiceRequestMatcher.