IntoHeaderName

Trait IntoHeaderName 

pub trait IntoHeaderName: IntoHeaderNameSealed { }
Available on crate feature http only.
A trait to try to convert some type into a HeaderName.

This trait is “sealed”, such that only types within rama can implement it.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types



impl IntoHeaderName for &[u8]



impl IntoHeaderName for &str

Implementors