IntoUrl

Trait IntoUrl 

pub trait IntoUrl: IntoUrlSealed { }
Available on crate feature http only.
A trait to try to convert some type into a Url.

This trait is “sealed”, such that only types within rama can implement it.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types



impl IntoUrl for &str

Implementors



impl IntoUrl for &String



impl IntoUrl for String



impl IntoUrl for Uri