RequestBuilder

Struct RequestBuilder 

pub struct RequestBuilder<'a, S, Response> { /* private fields */ }
Available on crate features http and std only.
A builder to construct the properties of a Request.

Constructed using HttpClientExt.

Implementations



impl<S, Body> RequestBuilder<'_, S, Response<Body>>
where S: Service<Request, Output = Response<Body>>, <S as Service<Request>>::Error: Into<Box<dyn Error + Sync + Send>>,

pub fn header<K, V>( self, key: K, value: V, ) -> RequestBuilder<'_, S, Response<Body>>

Add a Header to this Request.

pub fn typed_header<H>(self, header: H) -> RequestBuilder<'_, S, Response<Body>>
where H: HeaderEncode,

Add a typed HeaderEncode to this Request.

pub fn headers( self, headers: HeaderMap, ) -> RequestBuilder<'_, S, Response<Body>>

Add all Headers from the HeaderMap to this Request.

pub fn overwrite_header<K, V>( self, key: K, value: V, ) -> RequestBuilder<'_, S, Response<Body>>

Overwrite a Header to this Request.

pub fn overwrite_typed_header<H>( self, header: H, ) -> RequestBuilder<'_, S, Response<Body>>
where H: HeaderEncode,

Overwrite a typed HeaderEncode to this Request.

pub fn auth( self, credentials: impl Credentials, ) -> RequestBuilder<'_, S, Response<Body>>

Enable HTTP authentication.

pub fn extension<T>(self, extension: T) -> RequestBuilder<'_, S, Response<Body>>
where T: Extension,

Adds an extension to this builder

pub fn extensions(&self) -> Option<&Extensions>

Get access to the underlying Extensions

This function will return None if Extensions are not available, or if this builder is in an error state

pub fn body<T>(self, body: T) -> RequestBuilder<'_, S, Response<Body>>
where T: TryInto<Body>, <T as TryInto<Body>>::Error: Into<Box<dyn Error + Sync + Send>>,

Set the Request’s Body.

Re-syncs Content-Length with the new body: when the body has a known exact size, Content-Length is set to that value, replacing any prior value. When the size is unknown, any pre-set Content-Length is removed so the request doesn’t ship with stale framing.

pub fn form<T>(self, form: &T) -> RequestBuilder<'_, S, Response<Body>>
where T: Serialize + ?Sized,

Set the given value as a URL-Encoded Form Body in the Request.

Sets Content-Type: application/x-www-form-urlencoded if no Content-Type header is already set. Sets Content-Length to the encoded body’s size, replacing any prior value.

pub fn json<T>(self, json: &T) -> RequestBuilder<'_, S, Response<Body>>
where T: Serialize + ?Sized,

Set the given value as a JSON Body in the Request.

Sets Content-Type: application/json if no Content-Type header is already set. Sets Content-Length to the encoded body’s size, replacing any prior value.

pub fn multipart(self, form: Form) -> RequestBuilder<'_, S, Response<Body>>

Available on crate feature multipart only.

Set a multipart::Form as the body of this Request.

Sets the Content-Type header to multipart/form-data; boundary={boundary} and, when every part has a known size, the Content-Length header. An existing Content-Type header is overwritten.

pub fn octet_stream<T>(self, bytes: T) -> RequestBuilder<'_, S, Response<Body>>
where T: Into<Bytes>,

Set the given bytes as an application/octet-stream Body in the Request.

Sets Content-Type: application/octet-stream if no Content-Type header is already set on the request. Sets Content-Length to the payload’s size, replacing any prior value.

pub fn version(self, version: Version) -> RequestBuilder<'_, S, Response<Body>>

Set the http Version of this Request.

pub async fn try_into_request( self, ) -> Result<Request, Box<dyn Error + Sync + Send>>

Constructs the Request.

Errors

This method fails if there was an error while constructing the Request.

pub async fn send(self) -> Result<Response<Body>, Box<dyn Error + Sync + Send>>

Constructs the Request and sends it to the target Uri, returning a future Response.

Errors

This method fails if there was an error while sending Request.

pub async fn send_with_timeout( self, t: Duration, ) -> Result<Response<Body>, Box<dyn Error + Sync + Send>>

Constructs the Request and sends it to the target Uri, returning a Response with a timeout that aborts with an error if the roundtrip does not complete in time.

Note that this does not apply to the collection of the response payload, if there is any at all. The roundtrip is considered complete after the response headers are received.

Errors

This method fails if there was an error while sending Request.