Struct RobotsTxt
pub struct RobotsTxt {
pub groups: Vec<RobotsGroup>,
pub sitemaps: Vec<String>,
}Expand description
A typed robots.txt payload that can be parsed, inspected, serialized, and returned as a response.
Fields
groups: Vec<RobotsGroup>sitemaps: Vec<String>Implementations
impl RobotsTxt
impl RobotsTxt
pub fn parse(input: &str) -> RobotsTxt
pub fn parse(input: &str) -> RobotsTxt
Parse a robots.txt payload, ignoring malformed or invalid directives.
pub fn parse_strict(input: &str) -> Result<RobotsTxt, RobotsDirectiveParseError>
pub fn parse_strict(input: &str) -> Result<RobotsTxt, RobotsDirectiveParseError>
Parse a robots.txt payload strictly.
Unlike Self::parse, this returns an error when a supported directive
is malformed or has an invalid value.
pub fn with_group(self, group: RobotsGroup) -> RobotsTxt
pub fn with_group(self, group: RobotsGroup) -> RobotsTxt
Add a group to this robots.txt document.
pub fn set_group(&mut self, group: RobotsGroup) -> &mut RobotsTxt
pub fn set_group(&mut self, group: RobotsGroup) -> &mut RobotsTxt
Add a group to this robots.txt document.
pub fn with_sitemap(self, sitemap: impl Into<String>) -> RobotsTxt
pub fn with_sitemap(self, sitemap: impl Into<String>) -> RobotsTxt
Add a sitemap entry to this robots.txt document.
pub fn set_sitemap(&mut self, sitemap: impl Into<String>) -> &mut RobotsTxt
pub fn set_sitemap(&mut self, sitemap: impl Into<String>) -> &mut RobotsTxt
Add a sitemap entry to this robots.txt document.
pub fn rules_for(&self, user_agent: &str) -> RobotsClientRules<'_>
pub fn rules_for(&self, user_agent: &str) -> RobotsClientRules<'_>
Resolve the effective rules for the given user-agent.
pub fn is_url_allowed(&self, user_agent: &str, uri: &Uri) -> bool
pub fn is_url_allowed(&self, user_agent: &str, uri: &Uri) -> bool
Returns true if the given URL is allowed for the user-agent.