Struct IntoResponseFailed
pub struct IntoResponseFailed;Available on crate features
http and std only.Expand description
Marks a response produced because converting a response value failed.
Tuple response implementations use this marker to avoid replacing an inner error status with an outer status code. Custom fallible response types can add it as a response part for the same behavior.