Struct Router
pub struct Router<State = (), Layer = DefaultEndpointLayer, O = Response, E = RouterError> { /* private fields */ }http only.Expand description
A basic router that can be used to route requests to different services based on the request path.
This router uses matchit::Router to efficiently match incoming requests
to predefined routes. Each route is associated with an HttpMatcher
and a corresponding service handler.
Implementations
impl<O, E> Router<(), DefaultEndpointLayer, O, E>
impl<O, E> Router<(), DefaultEndpointLayer, O, E>
pub fn new() -> Router<(), DefaultEndpointLayer, O, E>
pub fn new() -> Router<(), DefaultEndpointLayer, O, E>
create a new router.
impl<State, O, E> Router<State, DefaultEndpointLayer, O, E>
impl<State, O, E> Router<State, DefaultEndpointLayer, O, E>
pub fn new_with_state(state: State) -> Router<State, DefaultEndpointLayer, O, E>
pub fn new_with_state(state: State) -> Router<State, DefaultEndpointLayer, O, E>
Create a new router with state
impl<State, L, O, E> Router<State, L, O, E>
impl<State, L, O, E> Router<State, L, O, E>
pub fn with_endpoint_layer<N>(self, layer: N) -> Router<State, N, O, E>
pub fn with_endpoint_layer<N>(self, layer: N) -> Router<State, N, O, E>
Apply layer to every endpoint registered after this call.
Routes registered before this call keep whatever layer was in effect at the time of registration.
pub fn with_default_endpoint_layer(
self,
) -> Router<State, DefaultEndpointLayer, O, E>
pub fn with_default_endpoint_layer( self, ) -> Router<State, DefaultEndpointLayer, O, E>
Apply DefaultEndpointLayer to every endpoint registered after this call.
Routes registered before this call keep whatever layer was in effect at the time of registration.
pub fn with_get<I, T>(
self,
path: impl AsRef<str>,
service: I,
) -> Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
pub fn with_get<I, T>(
self,
path: impl AsRef<str>,
service: I,
) -> Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
add a GET route to the router.
the path can contain parameters, e.g. /users/{id}.
the path can also contain a catch call, e.g. /assets/{*path}.
pub fn set_get<I, T>(
&mut self,
path: impl AsRef<str>,
service: I,
) -> &mut Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
pub fn set_get<I, T>(
&mut self,
path: impl AsRef<str>,
service: I,
) -> &mut Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
add a GET route to the router.
the path can contain parameters, e.g. /users/{id}.
the path can also contain a catch call, e.g. /assets/{*path}.
pub fn with_post<I, T>(
self,
path: impl AsRef<str>,
service: I,
) -> Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
pub fn with_post<I, T>(
self,
path: impl AsRef<str>,
service: I,
) -> Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
add a POST route to the router.
pub fn set_post<I, T>(
&mut self,
path: impl AsRef<str>,
service: I,
) -> &mut Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
pub fn set_post<I, T>(
&mut self,
path: impl AsRef<str>,
service: I,
) -> &mut Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
add a POST route to the router.
pub fn with_put<I, T>(
self,
path: impl AsRef<str>,
service: I,
) -> Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
pub fn with_put<I, T>(
self,
path: impl AsRef<str>,
service: I,
) -> Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
add a PUT route to the router.
pub fn set_put<I, T>(
&mut self,
path: impl AsRef<str>,
service: I,
) -> &mut Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
pub fn set_put<I, T>(
&mut self,
path: impl AsRef<str>,
service: I,
) -> &mut Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
add a PUT route to the router.
pub fn with_delete<I, T>(
self,
path: impl AsRef<str>,
service: I,
) -> Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
pub fn with_delete<I, T>(
self,
path: impl AsRef<str>,
service: I,
) -> Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
add a DELETE route to the router.
pub fn set_delete<I, T>(
&mut self,
path: impl AsRef<str>,
service: I,
) -> &mut Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
pub fn set_delete<I, T>(
&mut self,
path: impl AsRef<str>,
service: I,
) -> &mut Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
add a DELETE route to the router.
pub fn with_patch<I, T>(
self,
path: impl AsRef<str>,
service: I,
) -> Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
pub fn with_patch<I, T>(
self,
path: impl AsRef<str>,
service: I,
) -> Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
add a PATCH route to the router.
pub fn set_patch<I, T>(
&mut self,
path: impl AsRef<str>,
service: I,
) -> &mut Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
pub fn set_patch<I, T>(
&mut self,
path: impl AsRef<str>,
service: I,
) -> &mut Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
add a PATCH route to the router.
pub fn with_head<I, T>(
self,
path: impl AsRef<str>,
service: I,
) -> Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
pub fn with_head<I, T>(
self,
path: impl AsRef<str>,
service: I,
) -> Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
add a HEAD route to the router.
pub fn set_head<I, T>(
&mut self,
path: impl AsRef<str>,
service: I,
) -> &mut Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
pub fn set_head<I, T>(
&mut self,
path: impl AsRef<str>,
service: I,
) -> &mut Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
add a HEAD route to the router.
pub fn with_options<I, T>(
self,
path: impl AsRef<str>,
service: I,
) -> Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
pub fn with_options<I, T>(
self,
path: impl AsRef<str>,
service: I,
) -> Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
add a OPTIONS route to the router.
pub fn set_options<I, T>(
&mut self,
path: impl AsRef<str>,
service: I,
) -> &mut Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
pub fn set_options<I, T>(
&mut self,
path: impl AsRef<str>,
service: I,
) -> &mut Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
add a OPTIONS route to the router.
pub fn with_trace<I, T>(
self,
path: impl AsRef<str>,
service: I,
) -> Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
pub fn with_trace<I, T>(
self,
path: impl AsRef<str>,
service: I,
) -> Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
add a TRACE route to the router.
pub fn set_trace<I, T>(
&mut self,
path: impl AsRef<str>,
service: I,
) -> &mut Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
pub fn set_trace<I, T>(
&mut self,
path: impl AsRef<str>,
service: I,
) -> &mut Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
add a TRACE route to the router.
pub fn with_connect<I, T>(
self,
path: impl AsRef<str>,
service: I,
) -> Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
pub fn with_connect<I, T>(
self,
path: impl AsRef<str>,
service: I,
) -> Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
add a CONNECT route to the router.
pub fn set_connect<I, T>(
&mut self,
path: impl AsRef<str>,
service: I,
) -> &mut Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
pub fn set_connect<I, T>(
&mut self,
path: impl AsRef<str>,
service: I,
) -> &mut Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
add a CONNECT route to the router.
pub fn with_sub_router_make_fn<Layer>(
self,
prefix: impl AsRef<str>,
configure_router: impl FnOnce(Router<State, L, O, E>) -> Router<State, Layer, O, E>,
) -> Router<State, L, O, E>
pub fn with_sub_router_make_fn<Layer>( self, prefix: impl AsRef<str>, configure_router: impl FnOnce(Router<State, L, O, E>) -> Router<State, Layer, O, E>, ) -> Router<State, L, O, E>
register a nested router under a prefix (path).
The prefix is used to match the request path and strip it from the request URI.
Note: this sub-router is configured with the same State this router has.
pub fn set_sub_router_make_fn<Layer>(
&mut self,
prefix: impl AsRef<str>,
configure_router: impl FnOnce(Router<State, L, O, E>) -> Router<State, Layer, O, E>,
) -> &mut Router<State, L, O, E>
pub fn set_sub_router_make_fn<Layer>( &mut self, prefix: impl AsRef<str>, configure_router: impl FnOnce(Router<State, L, O, E>) -> Router<State, Layer, O, E>, ) -> &mut Router<State, L, O, E>
register a nested router under a prefix (path).
The prefix is used to match the request path and strip it from the request URI.
Note: this sub-router is configured with the same State this router has.
pub fn with_endpoint_service<I, T>(
self,
prefix: impl AsRef<str>,
service: I,
) -> Router<State, L, O, E>where
I: IntoEndpointService<T>,
L: Layer<<I as IntoEndpointService<T>>::Service>,
<L as Layer<<I as IntoEndpointService<T>>::Service>>::Service: Service<Request, Output = O, Error = E>,
pub fn with_endpoint_service<I, T>(
self,
prefix: impl AsRef<str>,
service: I,
) -> Router<State, L, O, E>where
I: IntoEndpointService<T>,
L: Layer<<I as IntoEndpointService<T>>::Service>,
<L as Layer<<I as IntoEndpointService<T>>::Service>>::Service: Service<Request, Output = O, Error = E>,
Register a nested endpoint service under a prefix (path).
The prefix is used to match the request path and strip it from the request URI. Endpoint layer is applied to this sub-service.
Warning: If a sub-service is a plain Service, not an endpoint function,
it has no notion of the state this router has. If you want to create a sub-router
that shares the same state this router has, use Router::with_sub_router_make_fn instead.
pub fn set_endpoint_service<I, T>(
&mut self,
prefix: impl AsRef<str>,
service: I,
) -> &mut Router<State, L, O, E>where
I: IntoEndpointService<T>,
L: Layer<<I as IntoEndpointService<T>>::Service>,
<L as Layer<<I as IntoEndpointService<T>>::Service>>::Service: Service<Request, Output = O, Error = E>,
pub fn set_endpoint_service<I, T>(
&mut self,
prefix: impl AsRef<str>,
service: I,
) -> &mut Router<State, L, O, E>where
I: IntoEndpointService<T>,
L: Layer<<I as IntoEndpointService<T>>::Service>,
<L as Layer<<I as IntoEndpointService<T>>::Service>>::Service: Service<Request, Output = O, Error = E>,
Register a nested endpoint service under a prefix (path).
The prefix is used to match the request path and strip it from the request URI. Endpoint layer is applied to this sub-service.
Warning: If a sub-service is a plain Service, not an endpoint function,
it has no notion of the state this router has. If you want to create a sub-router
that shares the same state this router has, use Router::with_sub_router_make_fn instead.
pub fn with_sub_service<S>(
self,
prefix: impl AsRef<str>,
service: S,
) -> Router<State, L, O, E>
pub fn with_sub_service<S>( self, prefix: impl AsRef<str>, service: S, ) -> Router<State, L, O, E>
Register a nested service under a prefix (path).
The prefix is used to match the request path and strip it from the request URI.
Warning: This sub-service has no notion of the state this router has. If you want
to create a sub-router that shares the same state this router has, use Router::with_sub_router_make_fn instead.
Also, the endpoint layer is not applied to it, so its Output / Error must match those of the Router
If you need its type conversions, consider Router::with_endpoint_service
pub fn set_sub_service<S>(
&mut self,
prefix: impl AsRef<str>,
service: S,
) -> &mut Router<State, L, O, E>
pub fn set_sub_service<S>( &mut self, prefix: impl AsRef<str>, service: S, ) -> &mut Router<State, L, O, E>
Register a nested service under a prefix.
The prefix is used to match the request path and strip it from the request URI.
Warning: This sub-service has no notion of the state this router has. If you want
to create a sub-router that shares the same state this router has, use Router::with_sub_router_make_fn instead.
Also, the endpoint layer is not applied to it, so its Output / Error must match those of the Router
If you need its type conversions, consider Router::set_endpoint_service
pub fn with_match_route<I, T>(
self,
path: impl AsRef<str>,
matcher: HttpMatcher<Body>,
service: I,
) -> Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
pub fn with_match_route<I, T>(
self,
path: impl AsRef<str>,
matcher: HttpMatcher<Body>,
service: I,
) -> Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
add a route to the router with it’s matcher and service.
pub fn set_match_route<I, T>(
&mut self,
path: impl AsRef<str>,
matcher: HttpMatcher<Body>,
service: I,
) -> &mut Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
pub fn set_match_route<I, T>(
&mut self,
path: impl AsRef<str>,
matcher: HttpMatcher<Body>,
service: I,
) -> &mut Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
add a route to the router with it’s matcher and service.
pub fn with_not_found<I, T>(self, service: I) -> Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
pub fn with_not_found<I, T>(self, service: I) -> Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
use the provided service when no route matches the request.
pub fn set_not_found<I, T>(&mut self, service: I) -> &mut Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
pub fn set_not_found<I, T>(&mut self, service: I) -> &mut Router<State, L, O, E>where
I: IntoEndpointServiceWithState<T, State>,
L: Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>,
<L as Layer<<I as IntoEndpointServiceWithState<T, State>>::Service>>::Service: Service<Request, Output = O, Error = E>,
use the provided service when no route matches the request.