Struct WebService
pub struct WebService<State = ()> { /* private fields */ }http only.Expand description
A basic web service that can be used to serve HTTP requests.
Note that this service boxes all the internal services, so it is not as efficient as it could be.
For those locations where you need do not desire the convenience over performance,
you can instead use a tuple of (M, S) tuples, where M is a matcher and S is a service,
e.g. ((MethodMatcher::GET, service_a), (MethodMatcher::POST, service_b), service_fallback).
Implementations
impl WebService
impl WebService
pub fn new() -> WebService
pub fn new() -> WebService
create a new web service
impl<State> WebService<State>
impl<State> WebService<State>
pub fn new_with_state(state: State) -> WebService<State>
pub fn with_get<I, T>(self, path: &str, service: I) -> WebService<State>where
I: IntoEndpointServiceWithState<T, State>,
<I as IntoEndpointServiceWithState<T, State>>::Service: Service<Request>,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Output: IntoResponse,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Error: Into<ErrorResponse>,
pub fn with_get<I, T>(self, path: &str, service: I) -> WebService<State>where
I: IntoEndpointServiceWithState<T, State>,
<I as IntoEndpointServiceWithState<T, State>>::Service: Service<Request>,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Output: IntoResponse,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Error: Into<ErrorResponse>,
add a GET route to the web service, using the given service.
pub fn set_get<I, T>(
&mut self,
path: &str,
service: I,
) -> &mut WebService<State>where
I: IntoEndpointServiceWithState<T, State>,
<I as IntoEndpointServiceWithState<T, State>>::Service: Service<Request>,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Output: IntoResponse,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Error: Into<ErrorResponse>,
pub fn set_get<I, T>(
&mut self,
path: &str,
service: I,
) -> &mut WebService<State>where
I: IntoEndpointServiceWithState<T, State>,
<I as IntoEndpointServiceWithState<T, State>>::Service: Service<Request>,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Output: IntoResponse,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Error: Into<ErrorResponse>,
add a GET route to the web service, using the given service.
pub fn with_post<I, T>(self, path: &str, service: I) -> WebService<State>where
I: IntoEndpointServiceWithState<T, State>,
<I as IntoEndpointServiceWithState<T, State>>::Service: Service<Request>,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Output: IntoResponse,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Error: Into<ErrorResponse>,
pub fn with_post<I, T>(self, path: &str, service: I) -> WebService<State>where
I: IntoEndpointServiceWithState<T, State>,
<I as IntoEndpointServiceWithState<T, State>>::Service: Service<Request>,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Output: IntoResponse,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Error: Into<ErrorResponse>,
add a POST route to the web service, using the given service.
pub fn set_post<I, T>(
&mut self,
path: &str,
service: I,
) -> &mut WebService<State>where
I: IntoEndpointServiceWithState<T, State>,
<I as IntoEndpointServiceWithState<T, State>>::Service: Service<Request>,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Output: IntoResponse,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Error: Into<ErrorResponse>,
pub fn set_post<I, T>(
&mut self,
path: &str,
service: I,
) -> &mut WebService<State>where
I: IntoEndpointServiceWithState<T, State>,
<I as IntoEndpointServiceWithState<T, State>>::Service: Service<Request>,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Output: IntoResponse,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Error: Into<ErrorResponse>,
add a POST route to the web service, using the given service.
pub fn with_put<I, T>(self, path: &str, service: I) -> WebService<State>where
I: IntoEndpointServiceWithState<T, State>,
<I as IntoEndpointServiceWithState<T, State>>::Service: Service<Request>,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Output: IntoResponse,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Error: Into<ErrorResponse>,
pub fn with_put<I, T>(self, path: &str, service: I) -> WebService<State>where
I: IntoEndpointServiceWithState<T, State>,
<I as IntoEndpointServiceWithState<T, State>>::Service: Service<Request>,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Output: IntoResponse,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Error: Into<ErrorResponse>,
add a PUT route to the web service, using the given service.
pub fn set_put<I, T>(
&mut self,
path: &str,
service: I,
) -> &mut WebService<State>where
I: IntoEndpointServiceWithState<T, State>,
<I as IntoEndpointServiceWithState<T, State>>::Service: Service<Request>,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Output: IntoResponse,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Error: Into<ErrorResponse>,
pub fn set_put<I, T>(
&mut self,
path: &str,
service: I,
) -> &mut WebService<State>where
I: IntoEndpointServiceWithState<T, State>,
<I as IntoEndpointServiceWithState<T, State>>::Service: Service<Request>,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Output: IntoResponse,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Error: Into<ErrorResponse>,
add a PUT route to the web service, using the given service.
pub fn with_delete<I, T>(self, path: &str, service: I) -> WebService<State>where
I: IntoEndpointServiceWithState<T, State>,
<I as IntoEndpointServiceWithState<T, State>>::Service: Service<Request>,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Output: IntoResponse,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Error: Into<ErrorResponse>,
pub fn with_delete<I, T>(self, path: &str, service: I) -> WebService<State>where
I: IntoEndpointServiceWithState<T, State>,
<I as IntoEndpointServiceWithState<T, State>>::Service: Service<Request>,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Output: IntoResponse,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Error: Into<ErrorResponse>,
add a DELETE route to the web service, using the given service.
pub fn set_delete<I, T>(
&mut self,
path: &str,
service: I,
) -> &mut WebService<State>where
I: IntoEndpointServiceWithState<T, State>,
<I as IntoEndpointServiceWithState<T, State>>::Service: Service<Request>,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Output: IntoResponse,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Error: Into<ErrorResponse>,
pub fn set_delete<I, T>(
&mut self,
path: &str,
service: I,
) -> &mut WebService<State>where
I: IntoEndpointServiceWithState<T, State>,
<I as IntoEndpointServiceWithState<T, State>>::Service: Service<Request>,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Output: IntoResponse,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Error: Into<ErrorResponse>,
add a DELETE route to the web service, using the given service.
pub fn with_patch<I, T>(self, path: &str, service: I) -> WebService<State>where
I: IntoEndpointServiceWithState<T, State>,
<I as IntoEndpointServiceWithState<T, State>>::Service: Service<Request>,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Output: IntoResponse,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Error: Into<ErrorResponse>,
pub fn with_patch<I, T>(self, path: &str, service: I) -> WebService<State>where
I: IntoEndpointServiceWithState<T, State>,
<I as IntoEndpointServiceWithState<T, State>>::Service: Service<Request>,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Output: IntoResponse,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Error: Into<ErrorResponse>,
add a PATCH route to the web service, using the given service.
pub fn set_patch<I, T>(
&mut self,
path: &str,
service: I,
) -> &mut WebService<State>where
I: IntoEndpointServiceWithState<T, State>,
<I as IntoEndpointServiceWithState<T, State>>::Service: Service<Request>,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Output: IntoResponse,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Error: Into<ErrorResponse>,
pub fn set_patch<I, T>(
&mut self,
path: &str,
service: I,
) -> &mut WebService<State>where
I: IntoEndpointServiceWithState<T, State>,
<I as IntoEndpointServiceWithState<T, State>>::Service: Service<Request>,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Output: IntoResponse,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Error: Into<ErrorResponse>,
add a PATCH route to the web service, using the given service.
pub fn with_head<I, T>(self, path: &str, service: I) -> WebService<State>where
I: IntoEndpointServiceWithState<T, State>,
<I as IntoEndpointServiceWithState<T, State>>::Service: Service<Request>,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Output: IntoResponse,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Error: Into<ErrorResponse>,
pub fn with_head<I, T>(self, path: &str, service: I) -> WebService<State>where
I: IntoEndpointServiceWithState<T, State>,
<I as IntoEndpointServiceWithState<T, State>>::Service: Service<Request>,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Output: IntoResponse,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Error: Into<ErrorResponse>,
add a HEAD route to the web service, using the given service.
pub fn set_head<I, T>(
&mut self,
path: &str,
service: I,
) -> &mut WebService<State>where
I: IntoEndpointServiceWithState<T, State>,
<I as IntoEndpointServiceWithState<T, State>>::Service: Service<Request>,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Output: IntoResponse,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Error: Into<ErrorResponse>,
pub fn set_head<I, T>(
&mut self,
path: &str,
service: I,
) -> &mut WebService<State>where
I: IntoEndpointServiceWithState<T, State>,
<I as IntoEndpointServiceWithState<T, State>>::Service: Service<Request>,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Output: IntoResponse,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Error: Into<ErrorResponse>,
add a HEAD route to the web service, using the given service.
pub fn with_options<I, T>(self, path: &str, service: I) -> WebService<State>where
I: IntoEndpointServiceWithState<T, State>,
<I as IntoEndpointServiceWithState<T, State>>::Service: Service<Request>,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Output: IntoResponse,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Error: Into<ErrorResponse>,
pub fn with_options<I, T>(self, path: &str, service: I) -> WebService<State>where
I: IntoEndpointServiceWithState<T, State>,
<I as IntoEndpointServiceWithState<T, State>>::Service: Service<Request>,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Output: IntoResponse,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Error: Into<ErrorResponse>,
add a OPTIONS route to the web service, using the given service.
pub fn set_options<I, T>(
&mut self,
path: &str,
service: I,
) -> &mut WebService<State>where
I: IntoEndpointServiceWithState<T, State>,
<I as IntoEndpointServiceWithState<T, State>>::Service: Service<Request>,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Output: IntoResponse,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Error: Into<ErrorResponse>,
pub fn set_options<I, T>(
&mut self,
path: &str,
service: I,
) -> &mut WebService<State>where
I: IntoEndpointServiceWithState<T, State>,
<I as IntoEndpointServiceWithState<T, State>>::Service: Service<Request>,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Output: IntoResponse,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Error: Into<ErrorResponse>,
add a OPTIONS route to the web service, using the given service.
pub fn with_trace<I, T>(self, path: &str, service: I) -> WebService<State>where
I: IntoEndpointServiceWithState<T, State>,
<I as IntoEndpointServiceWithState<T, State>>::Service: Service<Request>,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Output: IntoResponse,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Error: Into<ErrorResponse>,
pub fn with_trace<I, T>(self, path: &str, service: I) -> WebService<State>where
I: IntoEndpointServiceWithState<T, State>,
<I as IntoEndpointServiceWithState<T, State>>::Service: Service<Request>,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Output: IntoResponse,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Error: Into<ErrorResponse>,
add a TRACE route to the web service, using the given service.
pub fn set_trace<I, T>(
&mut self,
path: &str,
service: I,
) -> &mut WebService<State>where
I: IntoEndpointServiceWithState<T, State>,
<I as IntoEndpointServiceWithState<T, State>>::Service: Service<Request>,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Output: IntoResponse,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Error: Into<ErrorResponse>,
pub fn set_trace<I, T>(
&mut self,
path: &str,
service: I,
) -> &mut WebService<State>where
I: IntoEndpointServiceWithState<T, State>,
<I as IntoEndpointServiceWithState<T, State>>::Service: Service<Request>,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Output: IntoResponse,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Error: Into<ErrorResponse>,
add a TRACE route to the web service, using the given service.
pub fn with_nest_make_fn(
self,
prefix: &str,
configure_svc: impl FnOnce(WebService<State>) -> WebService<State>,
) -> WebService<State>
pub fn with_nest_make_fn( self, prefix: &str, configure_svc: impl FnOnce(WebService<State>) -> WebService<State>, ) -> WebService<State>
Nest a web service under the given path.
The nested service will receive a request with the path prefix removed.
Note: this sub-webservice is configured with the same State this router has.
pub fn set_nest_make_fn(
&mut self,
prefix: &str,
configure_svc: impl FnOnce(WebService<State>) -> WebService<State>,
) -> &mut WebService<State>
pub fn set_nest_make_fn( &mut self, prefix: &str, configure_svc: impl FnOnce(WebService<State>) -> WebService<State>, ) -> &mut WebService<State>
Nest a web service under the given path.
The nested service will receive a request with the path prefix removed.
Note: this sub-webservice is configured with the same State this router has.
pub fn with_nest_service<I, T>(
self,
prefix: impl AsRef<str>,
service: I,
) -> WebService<State>where
I: IntoEndpointService<T>,
<I as IntoEndpointService<T>>::Service: Service<Request, Output = Response, Error = Infallible>,
pub fn with_nest_service<I, T>(
self,
prefix: impl AsRef<str>,
service: I,
) -> WebService<State>where
I: IntoEndpointService<T>,
<I as IntoEndpointService<T>>::Service: Service<Request, Output = Response, Error = Infallible>,
Nest a web service under the given path.
The nested service will receive a request with the path prefix removed.
Warning: This sub-service has no notion of the state this webservice has. If you want to create a nested-service that shares the same state this webservice has, use WebService::set_nest_make_fn instead.
pub fn set_nest_service<I, T>(
&mut self,
prefix: impl AsRef<str>,
service: I,
) -> &mut WebService<State>where
I: IntoEndpointService<T>,
<I as IntoEndpointService<T>>::Service: Service<Request, Output = Response, Error = Infallible>,
pub fn set_nest_service<I, T>(
&mut self,
prefix: impl AsRef<str>,
service: I,
) -> &mut WebService<State>where
I: IntoEndpointService<T>,
<I as IntoEndpointService<T>>::Service: Service<Request, Output = Response, Error = Infallible>,
Nest a web service under the given path.
The nested service will receive a request with the path prefix removed.
Warning: This sub-service has no notion of the state this webservice has. If you want to create a nested-service that shares the same state this webservice has, use WebService::set_nest_make_fn instead.
pub fn with_file(
self,
prefix: &str,
path: impl AsRef<Path>,
mime: Mime,
) -> WebService<State>
pub fn with_file( self, prefix: &str, path: impl AsRef<Path>, mime: Mime, ) -> WebService<State>
serve the given file under the given path.
pub fn set_file(
&mut self,
prefix: &str,
path: impl AsRef<Path>,
mime: Mime,
) -> &mut WebService<State>
pub fn set_file( &mut self, prefix: &str, path: impl AsRef<Path>, mime: Mime, ) -> &mut WebService<State>
serve the given file under the given path.
pub fn with_dir(self, prefix: &str, path: impl AsRef<Path>) -> WebService<State>
pub fn with_dir(self, prefix: &str, path: impl AsRef<Path>) -> WebService<State>
serve the given directory under the given path.
pub fn set_dir(
&mut self,
prefix: &str,
path: impl AsRef<Path>,
) -> &mut WebService<State>
pub fn set_dir( &mut self, prefix: &str, path: impl AsRef<Path>, ) -> &mut WebService<State>
serve the given directory under the given path.
pub fn with_dir_with_serve_mode(
self,
prefix: &str,
path: impl AsRef<Path>,
mode: DirectoryServeMode,
) -> WebService<State>
pub fn with_dir_with_serve_mode( self, prefix: &str, path: impl AsRef<Path>, mode: DirectoryServeMode, ) -> WebService<State>
serve the given directory under the given path, with a custom serve move.
pub fn set_dir_with_serve_mode(
&mut self,
prefix: &str,
path: impl AsRef<Path>,
mode: DirectoryServeMode,
) -> &mut WebService<State>
pub fn set_dir_with_serve_mode( &mut self, prefix: &str, path: impl AsRef<Path>, mode: DirectoryServeMode, ) -> &mut WebService<State>
serve the given directory under the given path, with a custom serve move.
pub fn with_dir_embed(
self,
prefix: &str,
dir: Dir<'static>,
) -> WebService<State>
pub fn with_dir_embed( self, prefix: &str, dir: Dir<'static>, ) -> WebService<State>
serve the given embedded directory under the given path.
pub fn set_dir_embed(
&mut self,
prefix: &str,
dir: Dir<'static>,
) -> &mut WebService<State>
pub fn set_dir_embed( &mut self, prefix: &str, dir: Dir<'static>, ) -> &mut WebService<State>
serve the given embedded directory under the given path.
pub fn with_dir_embed_with_serve_mode(
self,
prefix: &str,
dir: Dir<'static>,
mode: DirectoryServeMode,
) -> WebService<State>
pub fn with_dir_embed_with_serve_mode( self, prefix: &str, dir: Dir<'static>, mode: DirectoryServeMode, ) -> WebService<State>
serve the given embedded directory under the given path with a custom serve move.
pub fn set_dir_embed_with_serve_mode(
&mut self,
prefix: &str,
dir: Dir<'static>,
mode: DirectoryServeMode,
) -> &mut WebService<State>
pub fn set_dir_embed_with_serve_mode( &mut self, prefix: &str, dir: Dir<'static>, mode: DirectoryServeMode, ) -> &mut WebService<State>
serve the given embedded directory under the given path with a custom serve move.
pub fn with_matcher<I, T>(
self,
matcher: HttpMatcher<Body>,
service: I,
) -> WebService<State>where
I: IntoEndpointServiceWithState<T, State>,
<I as IntoEndpointServiceWithState<T, State>>::Service: Service<Request>,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Output: IntoResponse,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Error: Into<ErrorResponse>,
pub fn with_matcher<I, T>(
self,
matcher: HttpMatcher<Body>,
service: I,
) -> WebService<State>where
I: IntoEndpointServiceWithState<T, State>,
<I as IntoEndpointServiceWithState<T, State>>::Service: Service<Request>,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Output: IntoResponse,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Error: Into<ErrorResponse>,
add a route to the web service which matches the given matcher, using the given service.
pub fn set_matcher<I, T>(
&mut self,
matcher: HttpMatcher<Body>,
service: I,
) -> &mut WebService<State>where
I: IntoEndpointServiceWithState<T, State>,
<I as IntoEndpointServiceWithState<T, State>>::Service: Service<Request>,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Output: IntoResponse,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Error: Into<ErrorResponse>,
pub fn set_matcher<I, T>(
&mut self,
matcher: HttpMatcher<Body>,
service: I,
) -> &mut WebService<State>where
I: IntoEndpointServiceWithState<T, State>,
<I as IntoEndpointServiceWithState<T, State>>::Service: Service<Request>,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Output: IntoResponse,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Error: Into<ErrorResponse>,
add a route to the web service which matches the given matcher, using the given service.
pub fn with_not_found<I, T>(self, service: I) -> WebService<State>where
I: IntoEndpointServiceWithState<T, State>,
<I as IntoEndpointServiceWithState<T, State>>::Service: Service<Request>,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Output: IntoResponse,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Error: Into<ErrorResponse>,
pub fn with_not_found<I, T>(self, service: I) -> WebService<State>where
I: IntoEndpointServiceWithState<T, State>,
<I as IntoEndpointServiceWithState<T, State>>::Service: Service<Request>,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Output: IntoResponse,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Error: Into<ErrorResponse>,
use the given service in case no match could be found.
pub fn set_not_found<I, T>(&mut self, service: I) -> &mut WebService<State>where
I: IntoEndpointServiceWithState<T, State>,
<I as IntoEndpointServiceWithState<T, State>>::Service: Service<Request>,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Output: IntoResponse,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Error: Into<ErrorResponse>,
pub fn set_not_found<I, T>(&mut self, service: I) -> &mut WebService<State>where
I: IntoEndpointServiceWithState<T, State>,
<I as IntoEndpointServiceWithState<T, State>>::Service: Service<Request>,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Output: IntoResponse,
<<I as IntoEndpointServiceWithState<T, State>>::Service as Service<Request>>::Error: Into<ErrorResponse>,
use the given service in case no match could be found.