Struct AsciiSet
pub struct AsciiSet { /* private fields */ }Available on crate feature
http only.Expand description
Represents a set of characters or bytes in the ASCII range.
This is used in percent_encode and utf8_percent_encode.
This is similar to percent-encode sets.
Use the add method of an existing set to define a new set. For example:
use percent_encoding::{AsciiSet, CONTROLS};
/// https://url.spec.whatwg.org/#fragment-percent-encode-set
const FRAGMENT: &AsciiSet = &CONTROLS.add(b' ').add(b'"').add(b'<').add(b'>').add(b'`');Implementations
impl AsciiSet
impl AsciiSet
pub const fn add(&self, byte: u8) -> AsciiSet
Available on crate feature
net only.pub const fn remove(&self, byte: u8) -> AsciiSet
Available on crate feature
net only.pub const fn union(&self, other: AsciiSet) -> AsciiSet
Available on crate feature net only.
pub const fn union(&self, other: AsciiSet) -> AsciiSet
net only.Return the union of two sets.
pub const fn complement(&self) -> AsciiSet
Available on crate feature net only.
pub const fn complement(&self) -> AsciiSet
net only.Return the negation of the set.