BlockingWebSocketRequestBuilder

Type Alias BlockingWebSocketRequestBuilder 

pub type BlockingWebSocketRequestBuilder<'a, S, Body> = WebSocketRequestBuilder<WithService<'a, S, Body, Blocking<S>>>;
Available on crate features http and std and ws only.
A WebSocket request builder whose terminal handshake operations block the calling thread.

Aliased Type

pub struct BlockingWebSocketRequestBuilder<'a, S, Body> { /* private fields */ }