HttpWebSocketRelayServiceRequestMatcher

Struct HttpWebSocketRelayServiceRequestMatcher 

pub struct HttpWebSocketRelayServiceRequestMatcher<S = IoForwardService> { /* private fields */ }
Default matcher that can be used for Http websocket relays.

Request matches for an http websocket request return a HttpWebSocketRelayServiceResponseMatcher instance which will match on 101 status code responses…

Note

This matcher does NOT validate if client <-> server handshake flow is compatible with one another. This in contrast to Rama’s pure client / server implementations, the MITM flow typically should not botter with that, given there are always those odd balls out there which have RFC incompatible definitions of reality. Fork this file if you have more advanced needs… or feel free to make a proposal on improvements to this file while still respecting its spirit.

Implementations



impl<S> HttpWebSocketRelayServiceRequestMatcher<S>

pub fn new(relay_svc: S) -> HttpWebSocketRelayServiceRequestMatcher<S>

pub fn maybe_with_websocket_config( self, cfg: Option<WebSocketConfig>, ) -> HttpWebSocketRelayServiceRequestMatcher<S>

Set the base WebSocketConfig, used for both sides, overwriting the previous config if already set.

pub fn maybe_set_websocket_config( &mut self, cfg: Option<WebSocketConfig>, ) -> &mut HttpWebSocketRelayServiceRequestMatcher<S>

Set the base WebSocketConfig, used for both sides, overwriting the previous config if already set.

pub fn with_websocket_config( self, cfg: WebSocketConfig, ) -> HttpWebSocketRelayServiceRequestMatcher<S>

Set the base WebSocketConfig, used for both sides, overwriting the previous config if already set.

pub fn set_websocket_config( &mut self, cfg: WebSocketConfig, ) -> &mut HttpWebSocketRelayServiceRequestMatcher<S>

Set the base WebSocketConfig, used for both sides, overwriting the previous config if already set.

pub fn without_websocket_config( self, ) -> HttpWebSocketRelayServiceRequestMatcher<S>

Set the base WebSocketConfig, used for both sides, overwriting the previous config if already set.

pub fn unset_websocket_config( &mut self, ) -> &mut HttpWebSocketRelayServiceRequestMatcher<S>

Set the base WebSocketConfig, used for both sides, overwriting the previous config if already set.

pub fn with_store_handshake_request_header( self, store: bool, ) -> HttpWebSocketRelayServiceRequestMatcher<S>

Define if the handshake (http) request headers needs to be stored in the Ingress Io extensions.

By default it is not stored.

Note

It is only stored if requested AND the request is matched.

pub fn set_store_handshake_request_header( &mut self, store: bool, ) -> &mut HttpWebSocketRelayServiceRequestMatcher<S>

Define if the handshake (http) request headers needs to be stored in the Ingress Io extensions.

By default it is not stored.

Note

It is only stored if requested AND the request is matched.

pub fn with_store_handshake_response_header( self, store: bool, ) -> HttpWebSocketRelayServiceRequestMatcher<S>

Define if the handshake (http) response headers needs to be stored in the Ingress Io extensions.

By default it is not stored.

Note

It is only stored if requested AND the response is matched.

pub fn set_store_handshake_response_header( &mut self, store: bool, ) -> &mut HttpWebSocketRelayServiceRequestMatcher<S>

Define if the handshake (http) response headers needs to be stored in the Ingress Io extensions.

By default it is not stored.

Note

It is only stored if requested AND the response is matched.