read_details

Function read_details 

pub async fn read_details(
    exchange: &ExchangeCapture,
    page: usize,
    page_size: usize,
) -> Result<WebSocketDetails, Box<dyn Error + Send + Sync>>
Available on crate features http and inspect and std and ws only.
Read a page from a retained exchange, including after it leaves the live capture list.