Enum EncodeError
#[non_exhaustive]pub enum EncodeError {
BufferTooSmall,
InvalidInput,
}Available on crate feature
icap only.Expand description
An ICAP value could not be encoded.
On error, bytes already written to the destination are unspecified. A caller reusing a scratch buffer must discard its contents.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
BufferTooSmall
The fixed output buffer was too small.
InvalidInput
The supplied protocol values form an invalid message.