Enum ParseError
#[non_exhaustive]pub enum ParseError {
InvalidStartLine,
InvalidMethod,
InvalidUri,
InvalidVersion,
InvalidStatus,
InvalidReason,
InvalidHeader,
InvalidComposition,
ObsoleteLineFolding,
TooManyHeaders,
HeadTooLarge,
InvalidLineEnding,
}Available on crate feature
icap only.Expand description
A malformed ICAP message head.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidStartLine
The start line does not have the required shape.
InvalidMethod
The method is not a valid token.
InvalidUri
The request target is not an absolute ICAP URI.
InvalidVersion
The protocol version is malformed or unsupported.
InvalidStatus
The response status is not a three-digit number.
InvalidReason
The response reason phrase contains prohibited bytes.
InvalidHeader
A header field is malformed.
InvalidComposition
The encapsulated sections do not fit the method and status.
ObsoleteLineFolding
Obsolete header line folding is disabled by the parser policy.
TooManyHeaders
The supplied header capacity was exceeded.
HeadTooLarge
The configured encoded head size was exceeded.
InvalidLineEnding
A line did not end with CRLF.