Struct TrailerScanner
pub struct TrailerScanner(/* private fields */);Available on crate feature
icap only.Expand description
Incremental scanner for one trailer field block.
Unlike an ICAP head, an empty trailer block is framed by one CRLF. Each call consumes only bytes received since the previous call.
Implementations
impl TrailerScanner
impl TrailerScanner
pub const fn new() -> TrailerScanner
pub const fn new() -> TrailerScanner
Construct an empty trailer scanner.
pub fn scan(
self,
src: &[u8],
config: HeadParserConfig,
) -> Result<ScanStatus<TrailerScanner>, ParseError>
pub fn scan( self, src: &[u8], config: HeadParserConfig, ) -> Result<ScanStatus<TrailerScanner>, ParseError>
Scan the next stream bytes for the end of the trailer block.