Struct ClientRequest
pub struct ClientRequest { /* private fields */ }Available on crate features
http and icap only.Expand description
A typed HTTP request prepared for a streaming ICAP client transaction.
Preview bytes are retained as cheap Bytes/header-map clones so a 204 or
206 result can replay the original message. Advertising Allow: 204
outside Preview retains streamed original frames until the ICAP decision,
within finite configurable ReplayLimits.
Implementations
impl ClientRequest
impl ClientRequest
pub fn reqmod<B>(
line: RequestLine<'_>,
headers: &[Header<'_>],
request: Request<B>,
preview: Option<Preview>,
) -> Result<ClientRequest, Error>
pub fn reqmod<B>( line: RequestLine<'_>, headers: &[Header<'_>], request: Request<B>, preview: Option<Preview>, ) -> Result<ClientRequest, Error>
Build a REQMOD request around one streaming HTTP request.
pub fn respmod<R, B>(
line: RequestLine<'_>,
headers: &[Header<'_>],
request: &Request<R>,
response: Response<B>,
preview: Option<Preview>,
) -> Result<ClientRequest, Error>
pub fn respmod<R, B>( line: RequestLine<'_>, headers: &[Header<'_>], request: &Request<R>, response: Response<B>, preview: Option<Preview>, ) -> Result<ClientRequest, Error>
Build a RESPMOD request around original request and response heads.
pub const fn with_replay_limits(self, limits: ReplayLimits) -> ClientRequest
pub const fn with_replay_limits(self, limits: ReplayLimits) -> ClientRequest
Set the finite bounds used while retaining original body frames.
pub fn set_replay_limits(&mut self, limits: ReplayLimits) -> &mut ClientRequest
pub fn set_replay_limits(&mut self, limits: ReplayLimits) -> &mut ClientRequest
Set the finite bounds used while retaining original body frames.
pub const fn replay_limits(&self) -> ReplayLimits
pub const fn replay_limits(&self) -> ReplayLimits
Return the original-body replay bounds.
pub fn original_request(&self) -> Option<&Request<()>>
pub fn original_request(&self) -> Option<&Request<()>>
Return the original HTTP request head for REQMOD.
pub fn original_response(&self) -> Option<&Response<()>>
pub fn original_response(&self) -> Option<&Response<()>>
Return the original HTTP response head for RESPMOD.