Struct ReplayLimits
pub struct ReplayLimits { /* private fields */ }Available on crate features
http and icap only.Expand description
Bounds for original HTTP frames retained for 204/206 replay.
Implementations
impl ReplayLimits
impl ReplayLimits
pub const fn new() -> ReplayLimits
pub const fn new() -> ReplayLimits
Construct the default finite in-memory replay bounds.
pub const fn with_max_bytes(self, max_bytes: usize) -> ReplayLimits
pub const fn with_max_bytes(self, max_bytes: usize) -> ReplayLimits
Set the aggregate retained data and trailer byte limit.
pub fn set_max_bytes(&mut self, max_bytes: usize) -> &mut ReplayLimits
pub fn set_max_bytes(&mut self, max_bytes: usize) -> &mut ReplayLimits
Set the aggregate retained data and trailer byte limit.
pub const fn with_max_frames(self, max_frames: usize) -> ReplayLimits
pub const fn with_max_frames(self, max_frames: usize) -> ReplayLimits
Set the retained frame-count limit.
pub fn set_max_frames(&mut self, max_frames: usize) -> &mut ReplayLimits
pub fn set_max_frames(&mut self, max_frames: usize) -> &mut ReplayLimits
Set the retained frame-count limit.
pub const fn max_frames(&self) -> usize
pub const fn max_frames(&self) -> usize
Return the retained frame-count limit.