Struct ExtensionMethodNotImplemented
pub struct ExtensionMethodNotImplemented;Available on crate features
icap and std only.Expand description
Signal that an ICAP extension method is not implemented by a service.
Returning this error for an extension request makes Server send a
closing 501 response. Other service errors retain their ordinary error
semantics and are propagated to the server caller.
The current codec accepts extension methods only for bodyless exchanges.