Struct IncomingRequest
pub struct IncomingRequest { /* private fields */ }Available on crate features
icap and std only.Expand description
An owned ICAP request dispatched by Server.
Its metadata and body handle are lifetime-independent so ordinary Rama
Service layers can wrap the request service. Entity
bytes remain bounded, backpressured, and streaming through IncomingBody.
Implementations
impl IncomingRequest
impl IncomingRequest
pub fn into_http(self) -> Result<IncomingRequest, Error>
pub fn into_http(self) -> Result<IncomingRequest, Error>
Parse the encapsulated HTTP heads and retain its streaming body.
pub fn into_http_with(
self,
parser: &HeadParser,
) -> Result<IncomingRequest, Error>
pub fn into_http_with( self, parser: &HeadParser, ) -> Result<IncomingRequest, Error>
Parse HTTP heads using explicit bounds and retain the streaming body.
impl IncomingRequest
impl IncomingRequest
pub const fn request(&self) -> &Request
pub const fn request(&self) -> &Request
Return the owned ICAP request metadata and encapsulated HTTP heads.
pub const fn body(&self) -> &IncomingBody
pub const fn body(&self) -> &IncomingBody
Return the streaming request body.
pub const fn body_mut(&mut self) -> &mut IncomingBody
pub const fn body_mut(&mut self) -> &mut IncomingBody
Return the mutable streaming request body.
pub fn into_parts(self) -> (IncomingRequestParts, IncomingBody)
pub fn into_parts(self) -> (IncomingRequestParts, IncomingBody)
Split the request into named metadata and its body.