Struct CollectionReader
pub struct CollectionReader { /* private fields */ }Available on crate feature
inspect only.Expand description
Read-only access to a collection, independent of append serialization. Both this handle and its readers retain the underlying storage.
Implementations