Struct CollectionWriter
pub struct CollectionWriter { /* private fields */ }Available on crate feature
inspect only.Expand description
Append access to a collection. Keep this capability behind a lock when publication of application indexes must remain ordered with storage writes.
Implementations