Struct CreateCollection
pub struct CreateCollection {
pub id: u64,
}Available on crate feature
inspect only.Expand description
Create a collection with an application-assigned, instance-unique identifier.
Fields
id: u64Trait Implementations
impl Clone for CreateCollection
impl Clone for CreateCollection
fn clone(&self) -> CreateCollection
fn clone(&self) -> CreateCollection
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for CreateCollection
impl Debug for CreateCollection
impl Debug for CreateCollection
impl Service<CreateCollection> for MemoryStore
impl Service<CreateCollection> for MemoryStore
type Output = Collection
type Output = Collection
The type of the output returned by the service.
async fn serve(
&self,
_: CreateCollection,
) -> Result<Collection, Box<dyn Error + Send + Sync>>
async fn serve( &self, _: CreateCollection, ) -> Result<Collection, Box<dyn Error + Send + Sync>>
Serve an output or an error for the given input
fn boxed(self) -> BoxService<Input, Self::Output, Self::Error>
fn boxed(self) -> BoxService<Input, Self::Output, Self::Error>
Box this service to allow for dynamic dispatch.
impl Service<CreateCollection> for FileStore
impl Service<CreateCollection> for FileStore
type Output = Collection
type Output = Collection
The type of the output returned by the service.
async fn serve(
&self,
input: CreateCollection,
) -> Result<Collection, Box<dyn Error + Send + Sync>>
async fn serve( &self, input: CreateCollection, ) -> Result<Collection, Box<dyn Error + Send + Sync>>
Serve an output or an error for the given input
fn boxed(self) -> BoxService<Input, Self::Output, Self::Error>
fn boxed(self) -> BoxService<Input, Self::Output, Self::Error>
Box this service to allow for dynamic dispatch.
impl<S> Service<CreateCollection> for EncryptStore<S>
impl<S> Service<CreateCollection> for EncryptStore<S>
type Output = Collection
type Output = Collection
The type of the output returned by the service.
async fn serve(
&self,
input: CreateCollection,
) -> Result<Collection, Box<dyn Error + Send + Sync>>
async fn serve( &self, input: CreateCollection, ) -> Result<Collection, Box<dyn Error + Send + Sync>>
Serve an output or an error for the given input
fn boxed(self) -> BoxService<Input, Self::Output, Self::Error>
fn boxed(self) -> BoxService<Input, Self::Output, Self::Error>
Box this service to allow for dynamic dispatch.