Struct Section
pub struct Section {
pub title: ArcStr,
pub body: SectionBody,
}Available on crate feature
inspect only.Expand description
One detail block of an Entry, rendered as a titled group.
Fields
title: ArcStrGroup title, e.g. request headers.
body: SectionBodyGroup content.
Implementations
impl Section
impl Section
pub const UNAVAILABLE: &'static str = "—"
pub const UNAVAILABLE: &'static str = "—"
Placeholder for a value the capture did not record.
pub fn fields(title: impl Into<ArcStr>, fields: Vec<Field>) -> Section
pub fn fields(title: impl Into<ArcStr>, fields: Vec<Field>) -> Section
Create a section listing named values.
pub fn text(title: impl Into<ArcStr>, text: impl Into<ArcStr>) -> Section
pub fn text(title: impl Into<ArcStr>, text: impl Into<ArcStr>) -> Section
Create a section holding a (possibly truncated) text preview.
Create a section that states why its content is missing.