Struct PeekRouter
pub struct PeekRouter<P, T, F = RejectService> { /* private fields */ }std only.Expand description
A generic Service router driven by a fail-fast PeekVerdict predicate.
Peeking uses a grow-on-demand heap buffer and replays all read bytes. Any
outcome other than PeekVerdict::Match dispatches to the fallback.
Implementations
impl<P, T> PeekRouter<P, T>
impl<P, T> PeekRouter<P, T>
pub fn new(predicate: P, acceptor: T) -> PeekRouter<P, T>
pub fn new(predicate: P, acceptor: T) -> PeekRouter<P, T>
Create a router that rejects non-matching input by default.
pub fn with_fallback<F>(self, fallback: F) -> PeekRouter<P, T, F>
pub fn with_fallback<F>(self, fallback: F) -> PeekRouter<P, T, F>
Attach a fallback Service.
impl<P, T, F> PeekRouter<P, T, F>
impl<P, T, F> PeekRouter<P, T, F>
pub fn maybe_with_peek_timeout(
self,
peek_timeout: Option<Duration>,
) -> PeekRouter<P, T, F>
pub fn maybe_with_peek_timeout( self, peek_timeout: Option<Duration>, ) -> PeekRouter<P, T, F>
Set the maximum time spent peeking into the input.
pub fn maybe_set_peek_timeout(
&mut self,
peek_timeout: Option<Duration>,
) -> &mut PeekRouter<P, T, F>
pub fn maybe_set_peek_timeout( &mut self, peek_timeout: Option<Duration>, ) -> &mut PeekRouter<P, T, F>
Set the maximum time spent peeking into the input.
pub fn with_peek_timeout(self, peek_timeout: Duration) -> PeekRouter<P, T, F>
pub fn with_peek_timeout(self, peek_timeout: Duration) -> PeekRouter<P, T, F>
Set the maximum time spent peeking into the input.
pub fn set_peek_timeout(
&mut self,
peek_timeout: Duration,
) -> &mut PeekRouter<P, T, F>
pub fn set_peek_timeout( &mut self, peek_timeout: Duration, ) -> &mut PeekRouter<P, T, F>
Set the maximum time spent peeking into the input.
pub fn without_peek_timeout(self) -> PeekRouter<P, T, F>
pub fn without_peek_timeout(self) -> PeekRouter<P, T, F>
Set the maximum time spent peeking into the input.
pub fn unset_peek_timeout(&mut self) -> &mut PeekRouter<P, T, F>
pub fn unset_peek_timeout(&mut self) -> &mut PeekRouter<P, T, F>
Set the maximum time spent peeking into the input.
pub fn with_max_peek_size(
self,
max_peek_size: NonZero<usize>,
) -> PeekRouter<P, T, F>
pub fn with_max_peek_size( self, max_peek_size: NonZero<usize>, ) -> PeekRouter<P, T, F>
Set the byte limit for peeking; this does not impose a time limit.
pub fn set_max_peek_size(
&mut self,
max_peek_size: NonZero<usize>,
) -> &mut PeekRouter<P, T, F>
pub fn set_max_peek_size( &mut self, max_peek_size: NonZero<usize>, ) -> &mut PeekRouter<P, T, F>
Set the byte limit for peeking; this does not impose a time limit.
pub fn with_peek_read_chunk_size(
self,
peek_read_chunk_size: NonZero<usize>,
) -> PeekRouter<P, T, F>
pub fn with_peek_read_chunk_size( self, peek_read_chunk_size: NonZero<usize>, ) -> PeekRouter<P, T, F>
Set the maximum number of bytes requested per read.
pub fn set_peek_read_chunk_size(
&mut self,
peek_read_chunk_size: NonZero<usize>,
) -> &mut PeekRouter<P, T, F>
pub fn set_peek_read_chunk_size( &mut self, peek_read_chunk_size: NonZero<usize>, ) -> &mut PeekRouter<P, T, F>
Set the maximum number of bytes requested per read.
impl<T> PeekRouter<(), T>
impl<T> PeekRouter<(), T>
pub fn from_prefix(
prefix: &'static [u8],
acceptor: T,
) -> PeekRouter<impl Clone + Fn(&[u8]), T>
pub fn from_prefix( prefix: &'static [u8], acceptor: T, ) -> PeekRouter<impl Clone + Fn(&[u8]), T>
Create a router matching a fixed prefix.
Peeking is limited to the prefix length unless overridden.
Panics
Panics when prefix is empty.