BridgeIo

Struct BridgeIo 

pub struct BridgeIo<Io1, Io2>(pub Io1, pub Io2);
A bidirectional bridge between two Io objects.

Often this is for Client-Server communication, but in a P2P like topology it can also be equal nodes.

ExtensionsRef and ExtensionsMut is implemented in function of Io1 as it is assumed that in flows where BridgeIo is used that we keep moving from “left” (Io1) to “right” (Io2) until we start to actually relay bytes, handshakes or any kind of data.

If you ever use Io2’s extensions you can do so explicitly.

Tuple Fields

0: Io11: Io2