Struct CancelIo
pub struct CancelIo(pub CancellationToken);Expand description
Extension type that can be injected into an I/O stream to cancel it gracefully.
By itself it doesn’t do anything. It can however be used by your own middleware.
rama-core comes with GracefulIoService to make use of it for any Io,
and rama-net makes use of it for a connector service.
Tuple Fields
0: CancellationTokenTrait Implementations