Struct PrefixedIo
pub struct PrefixedIo<P, S> { /* private fields */ }Expand description
a stream which has some data prefixed to be read first prior to any other reading.
The source of that prefix data is often the result of data which was “peeked” from the inner I/O, although that is not required.
It’s similar to ChainReader, except that writing is also
supported and happening directly in function of the inner stream.
Implementations
impl<P, S> PrefixedIo<P, S>
impl<P, S> PrefixedIo<P, S>
pub fn new(prefix: P, inner: S) -> PrefixedIo<P, S> ⓘ
pub fn new(prefix: P, inner: S) -> PrefixedIo<P, S> ⓘ
Create a new PrefixedIo for the given prefix
[AsyncRead] and inner Io which implements ExtensionsMut.