TimeoutReader

Struct TimeoutReader 

pub struct TimeoutReader<R> { /* private fields */ }
An AsyncReader which applies a timeout to read operations.

Implementations



impl<R> TimeoutReader<R>
where R: AsyncRead,

pub fn new(reader: R) -> TimeoutReader<R>

Returns a new TimeoutReader wrapping the specified reader.

There is initially no timeout.

pub fn timeout(&self) -> Option<Duration>

Returns the current read timeout.

pub fn maybe_with_timeout(self, timeout: Option<Duration>) -> TimeoutReader<R>

Sets the read timeout.

This can only be used before the reader is pinned; use set_timeout_pinned otherwise.

pub fn maybe_set_timeout( &mut self, timeout: Option<Duration>, ) -> &mut TimeoutReader<R>

Sets the read timeout.

This can only be used before the reader is pinned; use set_timeout_pinned otherwise.

pub fn with_timeout(self, timeout: Duration) -> TimeoutReader<R>

Sets the read timeout.

This can only be used before the reader is pinned; use set_timeout_pinned otherwise.

pub fn set_timeout(&mut self, timeout: Duration) -> &mut TimeoutReader<R>

Sets the read timeout.

This can only be used before the reader is pinned; use set_timeout_pinned otherwise.

pub fn without_timeout(self) -> TimeoutReader<R>

Sets the read timeout.

This can only be used before the reader is pinned; use set_timeout_pinned otherwise.

pub fn unset_timeout(&mut self) -> &mut TimeoutReader<R>

Sets the read timeout.

This can only be used before the reader is pinned; use set_timeout_pinned otherwise.

pub fn set_timeout_pinned( self: Pin<&mut TimeoutReader<R>>, timeout: Option<Duration>, )

Sets the read timeout.

This will reset any pending timeout. Use set_timeout instead if the reader is not yet pinned.

pub fn get_ref(&self) -> &R

Returns a shared reference to the inner reader.

pub fn get_mut(&mut self) -> &mut R

Returns a mutable reference to the inner reader.

pub fn get_pin_mut(self: Pin<&mut TimeoutReader<R>>) -> Pin<&mut R>

Returns a pinned mutable reference to the inner reader.

pub fn into_inner(self) -> R

Consumes the TimeoutReader, returning the inner reader.