Struct TimeoutWriter
pub struct TimeoutWriter<W> { /* private fields */ }Expand description
An AsyncWriteer which applies a timeout to write operations.
Implementations
impl<W> TimeoutWriter<W>where
W: AsyncWrite,
impl<W> TimeoutWriter<W>where
W: AsyncWrite,
pub fn new(writer: W) -> TimeoutWriter<W>
pub fn new(writer: W) -> TimeoutWriter<W>
Returns a new TimeoutWriter wrapping the specified writer.
There is initially no timeout.
pub fn maybe_with_timeout(self, timeout: Option<Duration>) -> TimeoutWriter<W>
pub fn maybe_with_timeout(self, timeout: Option<Duration>) -> TimeoutWriter<W>
Sets the write timeout.
This can only be used before the writer is pinned;
use set_timeout_pinned
otherwise.
pub fn maybe_set_timeout(
&mut self,
timeout: Option<Duration>,
) -> &mut TimeoutWriter<W>
pub fn maybe_set_timeout( &mut self, timeout: Option<Duration>, ) -> &mut TimeoutWriter<W>
Sets the write timeout.
This can only be used before the writer is pinned;
use set_timeout_pinned
otherwise.
pub fn with_timeout(self, timeout: Duration) -> TimeoutWriter<W>
pub fn with_timeout(self, timeout: Duration) -> TimeoutWriter<W>
Sets the write timeout.
This can only be used before the writer is pinned;
use set_timeout_pinned
otherwise.
pub fn set_timeout(&mut self, timeout: Duration) -> &mut TimeoutWriter<W>
pub fn set_timeout(&mut self, timeout: Duration) -> &mut TimeoutWriter<W>
Sets the write timeout.
This can only be used before the writer is pinned;
use set_timeout_pinned
otherwise.
pub fn without_timeout(self) -> TimeoutWriter<W>
pub fn without_timeout(self) -> TimeoutWriter<W>
Sets the write timeout.
This can only be used before the writer is pinned;
use set_timeout_pinned
otherwise.
pub fn unset_timeout(&mut self) -> &mut TimeoutWriter<W>
pub fn unset_timeout(&mut self) -> &mut TimeoutWriter<W>
Sets the write timeout.
This can only be used before the writer is pinned;
use set_timeout_pinned
otherwise.
pub fn set_timeout_pinned(
self: Pin<&mut TimeoutWriter<W>>,
timeout: Option<Duration>,
)
pub fn set_timeout_pinned( self: Pin<&mut TimeoutWriter<W>>, timeout: Option<Duration>, )
Sets the write timeout.
This will reset any pending timeout. Use set_timeout
instead if the writer is not yet pinned.
pub fn get_pin_mut(self: Pin<&mut TimeoutWriter<W>>) -> Pin<&mut W>
pub fn get_pin_mut(self: Pin<&mut TimeoutWriter<W>>) -> Pin<&mut W>
Returns a pinned mutable reference to the inner writer.
pub fn into_inner(self) -> W
pub fn into_inner(self) -> W
Consumes the TimeoutWriter, returning the inner writer.