Enum JsErrorKind
#[non_exhaustive]pub enum JsErrorKind {
Parse,
Throw,
LimitExceeded,
Conversion,
NotFound,
Setup,
Timeout,
}Available on crate features
js and std only.Expand description
The kind of a JsError.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Parse
script could not be parsed
Throw
script threw an error (or a host function returned one)
LimitExceeded
a configured runtime limit was exceeded
Conversion
a value could not be converted across the js boundary
NotFound
a global (function) with the given name does not exist
Setup
runtime could not be set up or is no longer available
Timeout
a job did not complete within the configured timeout