Struct JsHostObjectBuilder
pub struct JsHostObjectBuilder<T> { /* private fields */ }Available on crate features
js and std only.Expand description
Builder for a JsHostObject.
Implementations
impl<T> JsHostObjectBuilder<T>where
T: Send + 'static,
impl<T> JsHostObjectBuilder<T>where
T: Send + 'static,
pub fn method<A, F>(
self,
name: impl Into<JsStr>,
method: F,
) -> JsHostObjectBuilder<T>where
F: JsHostFn<T, A>,
pub fn method<A, F>(
self,
name: impl Into<JsStr>,
method: F,
) -> JsHostObjectBuilder<T>where
F: JsHostFn<T, A>,
Add a read-only method.
pub fn method_mut<A, F>(
self,
name: impl Into<JsStr>,
method: F,
) -> JsHostObjectBuilder<T>where
F: JsHostFnMut<T, A>,
pub fn method_mut<A, F>(
self,
name: impl Into<JsStr>,
method: F,
) -> JsHostObjectBuilder<T>where
F: JsHostFnMut<T, A>,
Add a method which may mutate the Rust value.
pub fn getter<M, F>(
self,
name: impl Into<JsStr>,
getter: F,
) -> JsHostObjectBuilder<T>where
F: JsHostGetter<T, M>,
pub fn getter<M, F>(
self,
name: impl Into<JsStr>,
getter: F,
) -> JsHostObjectBuilder<T>where
F: JsHostGetter<T, M>,
Add a read-only property getter.
pub fn setter<A, M, F>(
self,
name: impl Into<JsStr>,
setter: F,
) -> JsHostObjectBuilder<T>where
F: JsHostSetter<T, A, M>,
pub fn setter<A, M, F>(
self,
name: impl Into<JsStr>,
setter: F,
) -> JsHostObjectBuilder<T>where
F: JsHostSetter<T, A, M>,
Add a property setter which may mutate the Rust value.
pub fn build(self) -> (JsHostObject<T>, JsHostHandle<T>)
pub fn build(self) -> (JsHostObject<T>, JsHostHandle<T>)
Finish the definition and return both the JavaScript capability and the handle used to recover the Rust value.