Struct JsNamespace
pub struct JsNamespace { /* private fields */ }Available on crate features
js and std only.Expand description
A global host object: a named bag of host functions and values,
exposed to scripts as a single global object via
JsRuntimeBuilder::with_global.
Implementations
impl JsNamespace
impl JsNamespace
pub fn with_fn<A, F>(self, name: impl Into<JsStr>, f: F) -> JsNamespacewhere
F: JsFn<A>,
pub fn with_fn<A, F>(self, name: impl Into<JsStr>, f: F) -> JsNamespacewhere
F: JsFn<A>,
Add a host function as a property of this namespace.
pub fn set_fn<A, F>(&mut self, name: impl Into<JsStr>, f: F) -> &mut JsNamespacewhere
F: JsFn<A>,
pub fn set_fn<A, F>(&mut self, name: impl Into<JsStr>, f: F) -> &mut JsNamespacewhere
F: JsFn<A>,
Add a host function as a property of this namespace.
pub fn with_value(
self,
name: impl Into<JsStr>,
value: impl Into<JsValue>,
) -> JsNamespace
pub fn with_value( self, name: impl Into<JsStr>, value: impl Into<JsValue>, ) -> JsNamespace
Add a value as a property of this namespace.