Struct BoxServiceMatcher
pub struct BoxServiceMatcher<Input, SelectedService, Error, ModifiedInput> { /* private fields */ }Expand description
A boxed ServiceMatcher.
This gives dynamic dispatch without constraining the selected value.
Implementations
impl<Input, SelectedService, Error, ModifiedInput> BoxServiceMatcher<Input, SelectedService, Error, ModifiedInput>
impl<Input, SelectedService, Error, ModifiedInput> BoxServiceMatcher<Input, SelectedService, Error, ModifiedInput>
pub fn new<T>(
matcher: T,
) -> BoxServiceMatcher<Input, SelectedService, Error, ModifiedInput>where
T: ServiceMatcher<Input, Service = SelectedService, Error = Error, ModifiedInput = ModifiedInput>,
pub fn new<T>(
matcher: T,
) -> BoxServiceMatcher<Input, SelectedService, Error, ModifiedInput>where
T: ServiceMatcher<Input, Service = SelectedService, Error = Error, ModifiedInput = ModifiedInput>,
Create a boxed matcher from a concrete matcher implementation.