Struct ExtensionMatcher
pub struct ExtensionMatcher<P, T> { /* private fields */ }Expand description
A matcher which allows you to match based on an extension,
either by comparing with an extension (ExtensionMatcher::with_const),
or using a custom predicate (ExtensionMatcher::with_fn).
Implementations
impl<F, T> ExtensionMatcher<PredicateFn<F, T>, T>
impl<F, T> ExtensionMatcher<PredicateFn<F, T>, T>
pub fn with_fn(predicate: F) -> ExtensionMatcher<PredicateFn<F, T>, T>
pub fn with_fn(predicate: F) -> ExtensionMatcher<PredicateFn<F, T>, T>
Create a new ExtensionMatcher with a predicate F,
that will be called using the found T (if one is present),
to let it decide whether or not the extension value is a match or not.
impl<T> ExtensionMatcher<PredicateConst<T>, T>
impl<T> ExtensionMatcher<PredicateConst<T>, T>
pub fn with_const(value: T) -> ExtensionMatcher<PredicateConst<T>, T>
pub fn with_const(value: T) -> ExtensionMatcher<PredicateConst<T>, T>
Create a new ExtensionMatcher with a const value T,
that will be Eq-checked to find a match.