is_private_ip

Function is_private_ip 

pub fn is_private_ip(addr: impl Into<IpAddr>) -> bool
Available on crate feature net only.
Returns true when the address belongs to a range that should be treated as private instead of a normal public-Internet destination.