Struct IpScopes
pub struct IpScopes(/* private fields */);net only.Expand description
Special-use scope an IP address belongs to.
ip_scope returns exactly one bit per address (the most specific
category, or IpScopes::GLOBAL for an ordinary public address). The
bits are meant to be combined into masks — see IpScopes::LOCAL and
IpScopes::NON_GLOBAL — so a caller can ask “is this in any of these
scopes?” with IpScopes::intersects.
Implementations
impl IpScopes
impl IpScopes
pub const PRIVATE: IpScopes
pub const PRIVATE: IpScopes
RFC 1918 private (10/8, 172.16/12, 192.168/16) and IPv6
unique-local (fc00::/7).
pub const LINK_LOCAL: IpScopes
pub const LINK_LOCAL: IpScopes
Link-local: 169.254.0.0/16, fe80::/10.
pub const UNSPECIFIED: IpScopes
pub const UNSPECIFIED: IpScopes
Unspecified / “this network”: 0.0.0.0/8, ::.
pub const DOCUMENTATION: IpScopes
pub const DOCUMENTATION: IpScopes
Documentation ranges (e.g. 192.0.2.0/24, 2001:db8::/32).
pub const BENCHMARKING: IpScopes
pub const BENCHMARKING: IpScopes
Benchmarking ranges (198.18.0.0/15, 2001:2::/48).
impl IpScopes
impl IpScopes
pub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u16) -> Option<IpScopes>
pub const fn from_bits(bits: u16) -> Option<IpScopes>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u16) -> IpScopes
pub const fn from_bits_truncate(bits: u16) -> IpScopes
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u16) -> IpScopes
pub const fn from_bits_retain(bits: u16) -> IpScopes
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<IpScopes>
pub fn from_name(name: &str) -> Option<IpScopes>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: IpScopes) -> bool
pub const fn intersects(&self, other: IpScopes) -> bool
Whether any set bits in other are also set in self.
pub const fn contains(&self, other: IpScopes) -> bool
pub const fn contains(&self, other: IpScopes) -> bool
Whether all set bits in other are also set in self.
pub fn remove(&mut self, other: IpScopes)
pub fn remove(&mut self, other: IpScopes)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: IpScopes)
pub fn toggle(&mut self, other: IpScopes)
The bitwise exclusive-or (^) of the bits in self and other.
pub fn set(&mut self, other: IpScopes, value: bool)
pub fn set(&mut self, other: IpScopes, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: IpScopes) -> IpScopes
pub const fn intersection(self, other: IpScopes) -> IpScopes
The bitwise and (&) of the bits in self and other.
pub const fn union(self, other: IpScopes) -> IpScopes
pub const fn union(self, other: IpScopes) -> IpScopes
The bitwise or (|) of the bits in self and other.
pub const fn difference(self, other: IpScopes) -> IpScopes
pub const fn difference(self, other: IpScopes) -> IpScopes
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(self, other: IpScopes) -> IpScopes
pub const fn symmetric_difference(self, other: IpScopes) -> IpScopes
The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> IpScopes
pub const fn complement(self) -> IpScopes
The bitwise negation (!) of the bits in self, truncating the result.
impl IpScopes
impl IpScopes
pub const fn iter(&self) -> Iter<IpScopes> ⓘ
pub const fn iter(&self) -> Iter<IpScopes> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<IpScopes> ⓘ
pub const fn iter_names(&self) -> IterNames<IpScopes> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
impl IpScopes
impl IpScopes
pub const NON_GLOBAL: IpScopes
pub const NON_GLOBAL: IpScopes
Every scope except IpScopes::GLOBAL — i.e. exactly the set that
is_private_ip treats as non-public.