Enum EitherConn6
pub enum EitherConn6<A, B, C, D, E, F> {
A(A),
B(B),
C(C),
D(D),
E(E),
F(F),
}net only.Expand description
A type to allow you to use multiple types as a single type.
and will delegate the functionality to the type that is wrapped in the Either type.
To keep it easy all wrapped types are expected to work with the same inputs and outputs.
You can use [crate::combinators::impl_either] to
implement the Either type for the available number of type parameters
on your own Trait implementations.
Variants
A(A)
one of the Either variants
B(B)
one of the Either variants
C(C)
one of the Either variants
D(D)
one of the Either variants
E(E)
one of the Either variants
F(F)
one of the Either variants
Implementations
impl<A, B, C, D, E, F> EitherConn6<A, B, C, D, E, F>
impl<A, B, C, D, E, F> EitherConn6<A, B, C, D, E, F>
pub fn as_pin_mut(
self: Pin<&mut EitherConn6<A, B, C, D, E, F>>,
) -> EitherConn6<Pin<&mut A>, Pin<&mut B>, Pin<&mut C>, Pin<&mut D>, Pin<&mut E>, Pin<&mut F>> ⓘ
pub fn as_pin_mut( self: Pin<&mut EitherConn6<A, B, C, D, E, F>>, ) -> EitherConn6<Pin<&mut A>, Pin<&mut B>, Pin<&mut C>, Pin<&mut D>, Pin<&mut E>, Pin<&mut F>> ⓘ
Convert Pin<&mut Either<A, B>> to Either<Pin<&mut A>, Pin<&mut B>>,
pinned projections of the inner variants.
This is the pin-projection used to implement pinned traits (e.g.
Future/AsyncRead) for Either; it is public so downstream
crates can implement their own pinned traits over Either too.