Enum ProxyRoute
pub enum ProxyRoute {
Direct,
Proxy(ProxyAddress),
}Available on crate feature
net only.Expand description
A single route through which a client connection can be established.
Variants
Direct
Connect to the requested authority without using a proxy.
Proxy(ProxyAddress)
Connect to the requested authority through the given proxy.
Implementations
impl ProxyRoute
impl ProxyRoute
pub const fn proxy_address(&self) -> Option<&ProxyAddress>
pub const fn proxy_address(&self) -> Option<&ProxyAddress>
Return the proxy address when this is a proxied route.
pub fn into_proxy_address(self) -> Option<ProxyAddress>
pub fn into_proxy_address(self) -> Option<ProxyAddress>
Consume this route and return its proxy address when proxied.