Enum SystemProxyInvalidBypassRulePolicy
#[non_exhaustive]pub enum SystemProxyInvalidBypassRulePolicy {
Ignore,
Reject,
}Available on crate feature
net only.Expand description
How system proxy discovery handles bypass rules Rama cannot parse.
This policy applies independently of whether a platform uses ordinary or reversed bypass-list semantics. Rejecting invalid rules prevents a partial snapshot from making routing decisions with a different rule set than the operating system supplied.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Ignore
Ignore an invalid rule and retain the rest of the system snapshot.
Reject
Reject the complete system snapshot when any bypass rule is invalid.