Struct BasicHttpConId
pub struct BasicHttpConId {
pub protocol: Protocol,
pub authority: HostWithOptPort,
pub proxy_address: Option<ProxyAddress>,
pub connector_target: Option<ConnectorTarget>,
}Available on crate features
net and http only.Expand description
Connection Identifier which will match inputs that have the exact same protocol, authority, proxy address and connector target
Fields
protocol: Protocolproxy_address: Option<ProxyAddress>connector_target: Option<ConnectorTarget>Trait Implementations
impl Clone for BasicHttpConId
impl Clone for BasicHttpConId
fn clone(&self) -> BasicHttpConId
fn clone(&self) -> BasicHttpConId
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl ConnID for BasicHttpConId
impl ConnID for BasicHttpConId
fn attributes(&self) -> impl Iterator<Item = KeyValue>
fn attributes(&self) -> impl Iterator<Item = KeyValue>
Available on crate feature
opentelemetry only.Returns a list of attributes to add to metrics generated by the
connection pool.
impl Debug for BasicHttpConId
impl Debug for BasicHttpConId
impl PartialEq for BasicHttpConId
impl PartialEq for BasicHttpConId
impl Eq for BasicHttpConId
impl StructuralPartialEq for BasicHttpConId