Struct MultiplexPool
pub struct MultiplexPool<C, ID> { /* private fields */ }net only.Expand description
Connection pool that multiplexes concurrent users over shared connections.
Implementations
impl<C, ID> MultiplexPool<C, ID>
impl<C, ID> MultiplexPool<C, ID>
pub fn try_new(
max_concurrent_streams: usize,
max_total: usize,
) -> Result<MultiplexPool<C, ID>, Box<dyn Error + Sync + Send>>
pub fn try_new( max_concurrent_streams: usize, max_total: usize, ) -> Result<MultiplexPool<C, ID>, Box<dyn Error + Sync + Send>>
Create a new MultiplexPool.
max_concurrent_streams: upper bound on the concurrent users a single connection serves. The actual per-connection concurrency is the minimum of this and the connection’sMaxConcurrencyextension (usize::MAXif unset), so useusize::MAXto defer entirely to what each connection advertises.max_total: max number of connections (across all ids).
pub fn maybe_with_idle_timeout(
self,
timeout: Option<Duration>,
) -> MultiplexPool<C, ID>
pub fn maybe_with_idle_timeout( self, timeout: Option<Duration>, ) -> MultiplexPool<C, ID>
Drop connections that have been idle (no active streams) for longer than the given timeout. Only checked when a connection is requested.
pub fn maybe_set_idle_timeout(
&mut self,
timeout: Option<Duration>,
) -> &mut MultiplexPool<C, ID>
pub fn maybe_set_idle_timeout( &mut self, timeout: Option<Duration>, ) -> &mut MultiplexPool<C, ID>
Drop connections that have been idle (no active streams) for longer than the given timeout. Only checked when a connection is requested.
pub fn with_idle_timeout(self, timeout: Duration) -> MultiplexPool<C, ID>
pub fn with_idle_timeout(self, timeout: Duration) -> MultiplexPool<C, ID>
Drop connections that have been idle (no active streams) for longer than the given timeout. Only checked when a connection is requested.
pub fn set_idle_timeout(
&mut self,
timeout: Duration,
) -> &mut MultiplexPool<C, ID>
pub fn set_idle_timeout( &mut self, timeout: Duration, ) -> &mut MultiplexPool<C, ID>
Drop connections that have been idle (no active streams) for longer than the given timeout. Only checked when a connection is requested.
pub fn without_idle_timeout(self) -> MultiplexPool<C, ID>
pub fn without_idle_timeout(self) -> MultiplexPool<C, ID>
Drop connections that have been idle (no active streams) for longer than the given timeout. Only checked when a connection is requested.
pub fn unset_idle_timeout(&mut self) -> &mut MultiplexPool<C, ID>
pub fn unset_idle_timeout(&mut self) -> &mut MultiplexPool<C, ID>
Drop connections that have been idle (no active streams) for longer than the given timeout. Only checked when a connection is requested.
pub fn with_selection(self, selection: MuxSelection) -> MultiplexPool<C, ID>
pub fn with_selection(self, selection: MuxSelection) -> MultiplexPool<C, ID>
Set the MuxSelection strategy used to pick among same-id connections.
pub fn set_selection(
&mut self,
selection: MuxSelection,
) -> &mut MultiplexPool<C, ID>
pub fn set_selection( &mut self, selection: MuxSelection, ) -> &mut MultiplexPool<C, ID>
Set the MuxSelection strategy used to pick among same-id connections.
pub fn maybe_with_metrics( self, metrics: Option<Arc<PoolMetrics>>, ) -> MultiplexPool<C, ID>
pub fn maybe_set_metrics( &mut self, metrics: Option<Arc<PoolMetrics>>, ) -> &mut MultiplexPool<C, ID>
pub fn with_metrics(self, metrics: Arc<PoolMetrics>) -> MultiplexPool<C, ID>
pub fn set_metrics( &mut self, metrics: Arc<PoolMetrics>, ) -> &mut MultiplexPool<C, ID>
pub fn without_metrics(self) -> MultiplexPool<C, ID>
pub fn unset_metrics(&mut self) -> &mut MultiplexPool<C, ID>