Struct BasicConnIdentifier
#[non_exhaustive]pub struct BasicConnIdentifier;Available on crate feature
net only.Expand description
Basic connection-pool identifier derived from connection input.
Inputs share a pool identity only when their application protocol, logical authority, selected proxy and physical connector target all match.
Implementations
impl BasicConnIdentifier
impl BasicConnIdentifier
pub const fn new() -> BasicConnIdentifier
pub const fn new() -> BasicConnIdentifier
Create a basic connection-pool identifier.