Struct ConnectRequest
#[non_exhaustive]pub struct ConnectRequest {
pub authority: HostWithPort,
pub extensions: Extensions,
pub application_protocol: Option<Protocol>,
pub transport_protocol: Option<TransportProtocol>,
}net only.Expand description
A protocol-independent request to establish a client connection.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.extensions: Extensionsapplication_protocol: Option<Protocol>transport_protocol: Option<TransportProtocol>Implementations
impl ConnectRequest
impl ConnectRequest
pub fn new(authority: HostWithPort) -> ConnectRequest
pub fn new(authority: HostWithPort) -> ConnectRequest
Create a new ConnectRequest with default Extensions.
pub const fn new_with_extensions(
authority: HostWithPort,
extensions: Extensions,
) -> ConnectRequest
pub const fn new_with_extensions( authority: HostWithPort, extensions: Extensions, ) -> ConnectRequest
Create a new ConnectRequest with given Extensions.
pub fn maybe_with_application_protocol(
self,
protocol: Option<Protocol>,
) -> ConnectRequest
pub fn maybe_with_application_protocol( self, protocol: Option<Protocol>, ) -> ConnectRequest
Define the application Protocol to this ConnectRequest
requested for this connection.
By default the flow context will define the used application protocol.
pub fn maybe_set_application_protocol(
&mut self,
protocol: Option<Protocol>,
) -> &mut ConnectRequest
pub fn maybe_set_application_protocol( &mut self, protocol: Option<Protocol>, ) -> &mut ConnectRequest
Define the application Protocol to this ConnectRequest
requested for this connection.
By default the flow context will define the used application protocol.
pub fn with_application_protocol(self, protocol: Protocol) -> ConnectRequest
pub fn with_application_protocol(self, protocol: Protocol) -> ConnectRequest
Define the application Protocol to this ConnectRequest
requested for this connection.
By default the flow context will define the used application protocol.
pub fn set_application_protocol(
&mut self,
protocol: Protocol,
) -> &mut ConnectRequest
pub fn set_application_protocol( &mut self, protocol: Protocol, ) -> &mut ConnectRequest
Define the application Protocol to this ConnectRequest
requested for this connection.
By default the flow context will define the used application protocol.
pub fn without_application_protocol(self) -> ConnectRequest
pub fn without_application_protocol(self) -> ConnectRequest
Define the application Protocol to this ConnectRequest
requested for this connection.
By default the flow context will define the used application protocol.
pub fn unset_application_protocol(&mut self) -> &mut ConnectRequest
pub fn unset_application_protocol(&mut self) -> &mut ConnectRequest
Define the application Protocol to this ConnectRequest
requested for this connection.
By default the flow context will define the used application protocol.
pub fn maybe_with_transport_protocol(
self,
protocol: Option<TransportProtocol>,
) -> ConnectRequest
pub fn maybe_with_transport_protocol( self, protocol: Option<TransportProtocol>, ) -> ConnectRequest
Define the TransportProtocol to this ConnectRequest
requested for this connection.
By default it will defined by the flow receiver itself.
pub fn maybe_set_transport_protocol(
&mut self,
protocol: Option<TransportProtocol>,
) -> &mut ConnectRequest
pub fn maybe_set_transport_protocol( &mut self, protocol: Option<TransportProtocol>, ) -> &mut ConnectRequest
Define the TransportProtocol to this ConnectRequest
requested for this connection.
By default it will defined by the flow receiver itself.
pub fn with_transport_protocol(
self,
protocol: TransportProtocol,
) -> ConnectRequest
pub fn with_transport_protocol( self, protocol: TransportProtocol, ) -> ConnectRequest
Define the TransportProtocol to this ConnectRequest
requested for this connection.
By default it will defined by the flow receiver itself.
pub fn set_transport_protocol(
&mut self,
protocol: TransportProtocol,
) -> &mut ConnectRequest
pub fn set_transport_protocol( &mut self, protocol: TransportProtocol, ) -> &mut ConnectRequest
Define the TransportProtocol to this ConnectRequest
requested for this connection.
By default it will defined by the flow receiver itself.
pub fn without_transport_protocol(self) -> ConnectRequest
pub fn without_transport_protocol(self) -> ConnectRequest
Define the TransportProtocol to this ConnectRequest
requested for this connection.
By default it will defined by the flow receiver itself.
pub fn unset_transport_protocol(&mut self) -> &mut ConnectRequest
pub fn unset_transport_protocol(&mut self) -> &mut ConnectRequest
Define the TransportProtocol to this ConnectRequest
requested for this connection.
By default it will defined by the flow receiver itself.