Struct ProxyRoutesConnectorLayer
#[non_exhaustive]pub struct ProxyRoutesConnectorLayer { /* private fields */ }Available on crate feature
net only.Expand description
Layer that tries ordered proxy routes while establishing a connection.
Implementations
impl ProxyRoutesConnectorLayer
impl ProxyRoutesConnectorLayer
pub const fn new() -> ProxyRoutesConnectorLayer
pub const fn new() -> ProxyRoutesConnectorLayer
Create a layer that reads routes from input extensions.
pub const fn with_timeout(self, timeout: Duration) -> ProxyRoutesConnectorLayer
pub const fn with_timeout(self, timeout: Duration) -> ProxyRoutesConnectorLayer
Limit the complete ordered-route operation to timeout while retaining
any route failures completed before the budget expires.
pub fn set_timeout(
&mut self,
timeout: Duration,
) -> &mut ProxyRoutesConnectorLayer
pub fn set_timeout( &mut self, timeout: Duration, ) -> &mut ProxyRoutesConnectorLayer
Limit the complete ordered-route operation to timeout while retaining
any route failures completed before the budget expires.