Struct Request
#[non_exhaustive]pub struct Request {
pub authority: HostWithPort,
pub extensions: Extensions,
pub application_protocol: Option<Protocol>,
pub transport_protocol: Option<TransportProtocol>,
}net only.Expand description
A request to establish a Transport (L4) Connection.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.extensions: Extensionsapplication_protocol: Option<Protocol>transport_protocol: Option<TransportProtocol>Implementations
impl Request
impl Request
pub fn new(authority: HostWithPort) -> Request
pub fn new(authority: HostWithPort) -> Request
Create a new transport (L4) Request with default Extensions.
pub const fn new_with_extensions(
authority: HostWithPort,
extensions: Extensions,
) -> Request
pub const fn new_with_extensions( authority: HostWithPort, extensions: Extensions, ) -> Request
Create a new transport (L4) Request with given Extensions.
pub fn maybe_with_application_protocol(
self,
protocol: Option<Protocol>,
) -> Request
pub fn maybe_with_application_protocol( self, protocol: Option<Protocol>, ) -> Request
pub fn maybe_set_application_protocol(
&mut self,
protocol: Option<Protocol>,
) -> &mut Request
pub fn maybe_set_application_protocol( &mut self, protocol: Option<Protocol>, ) -> &mut Request
pub fn with_application_protocol(self, protocol: Protocol) -> Request
pub fn with_application_protocol(self, protocol: Protocol) -> Request
pub fn set_application_protocol(&mut self, protocol: Protocol) -> &mut Request
pub fn set_application_protocol(&mut self, protocol: Protocol) -> &mut Request
pub fn without_application_protocol(self) -> Request
pub fn without_application_protocol(self) -> Request
pub fn unset_application_protocol(&mut self) -> &mut Request
pub fn unset_application_protocol(&mut self) -> &mut Request
pub fn maybe_with_transport_protocol(
self,
protocol: Option<TransportProtocol>,
) -> Request
pub fn maybe_with_transport_protocol( self, protocol: Option<TransportProtocol>, ) -> Request
Define the TransportProtocol to this Request
requested for this connection.
By default it will defined by the flow receiver itself.
pub fn maybe_set_transport_protocol(
&mut self,
protocol: Option<TransportProtocol>,
) -> &mut Request
pub fn maybe_set_transport_protocol( &mut self, protocol: Option<TransportProtocol>, ) -> &mut Request
Define the TransportProtocol to this Request
requested for this connection.
By default it will defined by the flow receiver itself.
pub fn with_transport_protocol(self, protocol: TransportProtocol) -> Request
pub fn with_transport_protocol(self, protocol: TransportProtocol) -> Request
Define the TransportProtocol to this Request
requested for this connection.
By default it will defined by the flow receiver itself.
pub fn set_transport_protocol(
&mut self,
protocol: TransportProtocol,
) -> &mut Request
pub fn set_transport_protocol( &mut self, protocol: TransportProtocol, ) -> &mut Request
Define the TransportProtocol to this Request
requested for this connection.
By default it will defined by the flow receiver itself.
pub fn without_transport_protocol(self) -> Request
pub fn without_transport_protocol(self) -> Request
Define the TransportProtocol to this Request
requested for this connection.
By default it will defined by the flow receiver itself.
pub fn unset_transport_protocol(&mut self) -> &mut Request
pub fn unset_transport_protocol(&mut self) -> &mut Request
Define the TransportProtocol to this Request
requested for this connection.
By default it will defined by the flow receiver itself.