pub struct ForwardedElement { /* private fields */ }net only.Expand description
A single entry in the Forwarded chain.
Implementations
Sourceimpl ForwardedElement
impl ForwardedElement
Sourcepub fn merge(&mut self, other: ForwardedElement) -> &mut ForwardedElement
pub fn merge(&mut self, other: ForwardedElement) -> &mut ForwardedElement
Merge the properties of another ForwardedElement into this one.
Return the host if one is defined.
Sourcepub fn forwarded_host(
authority: impl Into<ForwardedAuthority>,
) -> ForwardedElement
pub fn forwarded_host( authority: impl Into<ForwardedAuthority>, ) -> ForwardedElement
Create a new ForwardedElement with the “host” parameter set
using the given Host, Authority or SocketAddr.
Sourcepub fn set_forwarded_host(
&mut self,
authority: impl Into<ForwardedAuthority>,
) -> &mut ForwardedElement
pub fn set_forwarded_host( &mut self, authority: impl Into<ForwardedAuthority>, ) -> &mut ForwardedElement
Sets the “host” parameter in this ForwardedElement using
the given Host, Authority or SocketAddr.
Sourcepub fn ref_forwarded_host(&self) -> Option<&ForwardedAuthority>
pub fn ref_forwarded_host(&self) -> Option<&ForwardedAuthority>
Get a reference to the “host” parameter if it is set.
Sourcepub fn forwarded_for(node_id: impl Into<NodeId>) -> ForwardedElement
pub fn forwarded_for(node_id: impl Into<NodeId>) -> ForwardedElement
Create a new ForwardedElement with the “for” parameter
set to the given valid node identifier. Examples are
an Ip Address or Domain, with or without a port.
Sourcepub fn set_forwarded_for(
&mut self,
node_id: impl Into<NodeId>,
) -> &mut ForwardedElement
pub fn set_forwarded_for( &mut self, node_id: impl Into<NodeId>, ) -> &mut ForwardedElement
Sets the “for” parameter for this ForwardedElement using the given valid node identifier.
Examples are an Ip Address or Domain, with or without a port.
Sourcepub fn ref_forwarded_for(&self) -> Option<&NodeId>
pub fn ref_forwarded_for(&self) -> Option<&NodeId>
Get a reference to the “for” parameter if it is set.
Sourcepub fn forwarded_by(node_id: impl Into<NodeId>) -> ForwardedElement
pub fn forwarded_by(node_id: impl Into<NodeId>) -> ForwardedElement
Create a new ForwardedElement with the “by” parameter
set to the given valid node identifier. Examples are
an Ip Address or Domain, with or without a port.
Sourcepub fn set_forwarded_by(
&mut self,
node_id: impl Into<NodeId>,
) -> &mut ForwardedElement
pub fn set_forwarded_by( &mut self, node_id: impl Into<NodeId>, ) -> &mut ForwardedElement
Sets the “by” parameter for this ForwardedElement using the given valid node identifier.
Examples are an Ip Address or Domain, with or without a port.
Sourcepub fn ref_forwarded_by(&self) -> Option<&NodeId>
pub fn ref_forwarded_by(&self) -> Option<&NodeId>
Get a reference to the “by” parameter if it is set.
Sourcepub fn forwarded_proto(protocol: ForwardedProtocol) -> ForwardedElement
pub fn forwarded_proto(protocol: ForwardedProtocol) -> ForwardedElement
Create a new ForwardedElement with the “proto” parameter
set to the given valid/recognised ForwardedProtocol
Sourcepub fn set_forwarded_proto(
&mut self,
protocol: ForwardedProtocol,
) -> &mut ForwardedElement
pub fn set_forwarded_proto( &mut self, protocol: ForwardedProtocol, ) -> &mut ForwardedElement
Set the “proto” parameter to the given valid/recognised ForwardedProtocol.
Sourcepub fn ref_forwarded_proto(&self) -> Option<ForwardedProtocol>
pub fn ref_forwarded_proto(&self) -> Option<ForwardedProtocol>
Get a reference to the “proto” parameter if it is set.
Sourcepub fn forwarded_version(version: ForwardedVersion) -> ForwardedElement
pub fn forwarded_version(version: ForwardedVersion) -> ForwardedElement
Create a new ForwardedElement with the “version” parameter
set to the given valid/recognised ForwardedVersion.
Sourcepub fn set_forwarded_version(
&mut self,
version: ForwardedVersion,
) -> &mut ForwardedElement
pub fn set_forwarded_version( &mut self, version: ForwardedVersion, ) -> &mut ForwardedElement
Set the “version” parameter to the given valid/recognised ForwardedVersion.
Sourcepub fn ref_forwarded_version(&self) -> Option<ForwardedVersion>
pub fn ref_forwarded_version(&self) -> Option<ForwardedVersion>
Get a copy of the “version” parameter, if it is set.