Struct HttpRequestVersion
pub struct HttpRequestVersion(pub Version);Available on crate feature
net only.Expand description
HTTP version carried by the request that initiated a connection attempt.
This is descriptive input context, not an egress requirement. Connectors
must not use it to constrain protocol negotiation as they would a
TargetHttpVersion.
Tuple Fields
0: VersionTrait Implementations
impl Clone for HttpRequestVersion
impl Clone for HttpRequestVersion
fn clone(&self) -> HttpRequestVersion
fn clone(&self) -> HttpRequestVersion
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for HttpRequestVersion
impl Debug for HttpRequestVersion
impl Debug for HttpRequestVersion
impl Default for HttpRequestVersion
impl Default for HttpRequestVersion
fn default() -> HttpRequestVersion
fn default() -> HttpRequestVersion
Returns the “default value” for a type. Read more
impl Eq for HttpRequestVersion
impl Extension for HttpRequestVersion
impl HttpExtension for HttpRequestVersion
impl PartialEq for HttpRequestVersion
impl PartialEq for HttpRequestVersion
impl StructuralPartialEq for HttpRequestVersion