Struct ProxyTargetFromRequestContextLayer
#[non_exhaustive]pub struct ProxyTargetFromRequestContextLayer;Expand description
A layer to inject ProxyTarget in an input, based on an input from which a RequestContext can be derived.
Note that the concept of RequestContext is soon to be removed, which also means this layer (service) will be moved and refactored, and make use of the newer concept instead. More TBA soon.
Implementations
impl ProxyTargetFromRequestContextLayer
impl ProxyTargetFromRequestContextLayer
pub fn new() -> ProxyTargetFromRequestContextLayer
pub fn new() -> ProxyTargetFromRequestContextLayer
Create a new ProxyTargetFromRequestContextLayer.