Trait TryIntoPattern
pub trait TryIntoPattern: TryIntoPatternPriv { }Available on crate feature
net only.Expand description
Private trait used by this module to easily create patterns from owned or static byte-like objects.
pub trait TryIntoPattern: TryIntoPatternPriv { }net only.Private trait used by this module to easily create patterns from owned or static byte-like objects.