Trait HttpVersionInputExt
pub trait HttpVersionInputExt {
// Required method
fn http_version(&self) -> Option<Version>;
}Available on crate features
http and net only.Expand description
Read the contextual HTTP Version of a service input.
For an HTTP request this may resolve the original client version from
forwarded context, so it is not necessarily the egress version a connector
should establish. Connector code should use TargetHttpVersionInputExt.
It is None for non-HTTP inputs (e.g. a raw transport target).
Required Methods
fn http_version(&self) -> Option<Version>
fn http_version(&self) -> Option<Version>
The HTTP version, or None for non-HTTP inputs.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".