Struct IdleGuard
pub struct IdleGuard { /* private fields */ }net only.Expand description
A resettable idle deadline.
Designed to be used as one arm of a tokio::select!: poll IdleGuard::tick
in the select; when another arm fires (i.e. progress was observed) call
IdleGuard::reset before re-entering the select to extend the idle window.
If the inner [Sleep] elapses before reset is called,
the idle window has lapsed.
IdleGuard is intended for cases where the watched activity does not itself
produce values that can be selected on (e.g. byte progress observed inside
another future). For values that can be selected on, prefer racing the
activity directly.
Implementations
impl IdleGuard
impl IdleGuard
pub fn new(timeout: Duration) -> IdleGuard
pub fn new(timeout: Duration) -> IdleGuard
Create a new IdleGuard that fires after timeout of inactivity.
pub fn reset(&mut self)
pub fn reset(&mut self)
Reset the idle deadline to now + timeout. Call this whenever progress
has been observed, before re-entering the select that polls
IdleGuard::tick.
pub fn tick(&mut self) -> &mut Pin<Box<Sleep>>
pub fn tick(&mut self) -> &mut Pin<Box<Sleep>>
Poll-able future that completes when the idle window has elapsed.
Borrow-and-poll inside tokio::select!. Once it completes, the guard
is considered tripped — call IdleGuard::reset before re-arming if
you want to keep waiting.