Struct RecvFlags
pub struct RecvFlags(/* private fields */);net and neither Horizon nor Redox OS nor WASI only.Expand description
Flags for incoming messages.
Flags provide additional information about incoming messages.
Implementations
impl RecvFlags
Unix-only API.
impl RecvFlags
Unix-only API.
pub const fn is_end_of_record(self) -> bool
Available on neither ESP-IDF nor Horizon.
pub const fn is_end_of_record(self) -> bool
Check if the message terminates a record.
Not all socket types support the notion of records. For socket types
that do support it (such as SEQPACKET), a record is terminated by
sending a message with the end-of-record flag set.
On Unix this corresponds to the MSG_EOR flag.
pub const fn is_out_of_band(self) -> bool
pub const fn is_out_of_band(self) -> bool
Check if the message contains out-of-band data.
This is useful for protocols where you receive out-of-band data mixed in with the normal data stream.
On Unix this corresponds to the MSG_OOB flag.
pub const fn is_confirm(self) -> bool
Available on crate feature all and (Android or Linux) only.
pub const fn is_confirm(self) -> bool
all and (Android or Linux) only.Check if the confirm flag is set.
This is used by SocketCAN to indicate a frame was sent via the socket it is received on. This flag can be interpreted as a ‘transmission confirmation’.
On Unix this corresponds to the MSG_CONFIRM flag.
pub const fn is_dontroute(self) -> bool
Available on crate feature all and (Android or Cygwin or Linux) only.
pub const fn is_dontroute(self) -> bool
all and (Android or Cygwin or Linux) only.Check if the don’t route flag is set.
This is used by SocketCAN to indicate a frame was created on the local host.
On Unix this corresponds to the MSG_DONTROUTE flag.
impl RecvFlags
impl RecvFlags
pub const fn is_truncated(self) -> bool
Available on non-ESP-IDF only.
pub const fn is_truncated(self) -> bool
Check if the message contains a truncated datagram.
This flag is only used for datagram-based sockets, not for stream sockets.
On Unix this corresponds to the MSG_TRUNC flag.
On Windows this corresponds to the WSAEMSGSIZE error code.