Struct InterfaceAddress
pub struct InterfaceAddress { /* private fields */ }Available on crate feature
net only.Expand description
Implementations
impl InterfaceAddress
impl InterfaceAddress
pub fn prefix_len(&self) -> Option<u8>
pub fn prefix_len(&self) -> Option<u8>
Prefix length of the network the address sits in, when the platform reported a (contiguous, non-zero) netmask or on-link prefix.
pub fn scope_id(&self) -> Option<u32>
pub fn scope_id(&self) -> Option<u32>
Zone (scope id) of a scoped IPv6 address (e.g. link-local), when the platform reported one.
Not to be confused with the special-use classification of
IpScopes; this is the RFC 4007 zone index, as also found in
std::net::SocketAddrV6::scope_id.
pub fn ip_net(&self) -> Option<IpNet>
pub fn ip_net(&self) -> Option<IpNet>
Address and prefix as an (un-truncated) IpNet.
Use IpNet::trunc on the result to get the network address itself.