Struct InterfaceFlags
pub struct InterfaceFlags(/* private fields */);net only.Expand description
Status and capability flags of a local network Interface.
Mapped from IFF_* on unix platforms and from the adapter’s
operational status and type on windows; per-flag notes below call out
where the platforms differ.
String format
InterfaceFlags round-trips (Display/FromStr/serde) through a
comma-separated list of kebab-case flag names, e.g. "up,running".
Parsing is allocation-free and lenient: ASCII case-insensitive, _
equals -, and | is also accepted as separator. An empty string
parses as the empty set.
Implementations
impl InterfaceFlags
impl InterfaceFlags
pub const UP: InterfaceFlags
pub const UP: InterfaceFlags
Interface is administratively up.
On windows this is set together with InterfaceFlags::RUNNING
when the adapter’s operational status is up; the two states are
not reported separately there.
pub const RUNNING: InterfaceFlags
pub const RUNNING: InterfaceFlags
Interface is operationally running (e.g. carrier present).
pub const LOOPBACK: InterfaceFlags
pub const LOOPBACK: InterfaceFlags
Loopback interface.
pub const POINT_TO_POINT: InterfaceFlags
pub const POINT_TO_POINT: InterfaceFlags
Point-to-point link (tunnels, PPP).
pub const BROADCAST: InterfaceFlags
pub const BROADCAST: InterfaceFlags
Broadcast-capable link. Never set on windows.
pub const MULTICAST: InterfaceFlags
pub const MULTICAST: InterfaceFlags
Multicast-capable link.
impl InterfaceFlags
impl InterfaceFlags
pub const fn empty() -> InterfaceFlags
pub const fn empty() -> InterfaceFlags
Get a flags value with all bits unset.
pub const fn all() -> InterfaceFlags
pub const fn all() -> InterfaceFlags
Get a flags value with all known bits set.
pub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u8) -> Option<InterfaceFlags>
pub const fn from_bits(bits: u8) -> Option<InterfaceFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u8) -> InterfaceFlags
pub const fn from_bits_truncate(bits: u8) -> InterfaceFlags
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u8) -> InterfaceFlags
pub const fn from_bits_retain(bits: u8) -> InterfaceFlags
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<InterfaceFlags>
pub fn from_name(name: &str) -> Option<InterfaceFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: InterfaceFlags) -> bool
pub const fn intersects(&self, other: InterfaceFlags) -> bool
Whether any set bits in other are also set in self.
pub const fn contains(&self, other: InterfaceFlags) -> bool
pub const fn contains(&self, other: InterfaceFlags) -> bool
Whether all set bits in other are also set in self.
pub fn insert(&mut self, other: InterfaceFlags)
pub fn insert(&mut self, other: InterfaceFlags)
The bitwise or (|) of the bits in self and other.
pub fn remove(&mut self, other: InterfaceFlags)
pub fn remove(&mut self, other: InterfaceFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: InterfaceFlags)
pub fn toggle(&mut self, other: InterfaceFlags)
The bitwise exclusive-or (^) of the bits in self and other.
pub fn set(&mut self, other: InterfaceFlags, value: bool)
pub fn set(&mut self, other: InterfaceFlags, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: InterfaceFlags) -> InterfaceFlags
pub const fn intersection(self, other: InterfaceFlags) -> InterfaceFlags
The bitwise and (&) of the bits in self and other.
pub const fn union(self, other: InterfaceFlags) -> InterfaceFlags
pub const fn union(self, other: InterfaceFlags) -> InterfaceFlags
The bitwise or (|) of the bits in self and other.
pub const fn difference(self, other: InterfaceFlags) -> InterfaceFlags
pub const fn difference(self, other: InterfaceFlags) -> InterfaceFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(self, other: InterfaceFlags) -> InterfaceFlags
pub const fn symmetric_difference(self, other: InterfaceFlags) -> InterfaceFlags
The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> InterfaceFlags
pub const fn complement(self) -> InterfaceFlags
The bitwise negation (!) of the bits in self, truncating the result.
impl InterfaceFlags
impl InterfaceFlags
pub const fn iter(&self) -> Iter<InterfaceFlags> ⓘ
pub const fn iter(&self) -> Iter<InterfaceFlags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<InterfaceFlags> ⓘ
pub const fn iter_names(&self) -> IterNames<InterfaceFlags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.