Struct BytesRWTracker
pub struct BytesRWTracker<S> { /* private fields */ }Expand description
A wrapper around a AsyncRead and/or AsyncWrite that tracks the number
of bytes read and/or written.
Use BytesRWTracker::handle to get a BytesRWTrackerHandle in order
to get the number of bytes read and/or written even though the BytesRWTracker
is consumed by a protocol consumer.
Implementations
impl<S> BytesRWTracker<S>where
S: ExtensionsMut,
impl<S> BytesRWTracker<S>where
S: ExtensionsMut,
pub fn new(stream: S) -> BytesRWTracker<S>
pub fn new(stream: S) -> BytesRWTracker<S>
Create a new BytesRWTracker that wraps the
given AsyncRead and/or AsyncWrite.
impl<S> BytesRWTracker<S>
impl<S> BytesRWTracker<S>
pub fn handle(&self) -> BytesRWTrackerHandle
pub fn handle(&self) -> BytesRWTrackerHandle
Get a BytesRWTrackerHandle that can be used to get the number of bytes
read and/or written even though the tracker is consumed by a protocol
consumer in a later stage.
pub fn into_inner(self) -> S
pub fn into_inner(self) -> S
Get the inner AsyncRead and/or AsyncWrite stream.
Dropping the tracking info and capabilities for this stream.
Any previously obtained BytesRWTrackerHandle will no longer
be updated but will still report the number of bytes read and/or
written up to the point where this method was called.