Struct TcpStreamOptionsLayer
pub struct TcpStreamOptionsLayer { /* private fields */ }Available on crate feature
net only.Expand description
Apply connected TcpStreamOptions before delegating a TCP stream.
This layer is suitable for accepted and connected streams. It deliberately exposes only settings that can be applied at this point in the lifecycle.
Implementations
impl TcpStreamOptionsLayer
impl TcpStreamOptionsLayer
pub fn new(options: impl Into<TcpStreamOptions>) -> TcpStreamOptionsLayer
pub fn new(options: impl Into<TcpStreamOptions>) -> TcpStreamOptionsLayer
Create a layer backed by the supplied socket options.