Struct ThrottleBudget
pub struct ThrottleBudget { /* private fields */ }net only.Expand description
The StreamGate that throttles one direction of a single IO.
A ThrottledIo holds one per direction of a byte stream, and
ThrottleGates opens one per stream direction of a multiplexed
connection.
Must be polled within a tokio runtime context.
Implementations
impl ThrottleBudget
impl ThrottleBudget
pub fn new(mode: ThrottleMode) -> ThrottleBudget
pub fn new(mode: ThrottleMode) -> ThrottleBudget
Create a ThrottleBudget spending from mode, with the default grant quantum.
pub fn maybe_with_quantum(self, quantum: Option<u64>) -> ThrottleBudget
pub fn maybe_with_quantum(self, quantum: Option<u64>) -> ThrottleBudget
Override the grant quantum in bytes: the budget reserved per IO operation (clamped to the burst capacity).
Defaults to a tenth of a period worth of bytes, at most 16 KiB.
pub fn maybe_set_quantum(&mut self, quantum: Option<u64>) -> &mut ThrottleBudget
pub fn maybe_set_quantum(&mut self, quantum: Option<u64>) -> &mut ThrottleBudget
Override the grant quantum in bytes: the budget reserved per IO operation (clamped to the burst capacity).
Defaults to a tenth of a period worth of bytes, at most 16 KiB.
pub fn with_quantum(self, quantum: u64) -> ThrottleBudget
pub fn with_quantum(self, quantum: u64) -> ThrottleBudget
Override the grant quantum in bytes: the budget reserved per IO operation (clamped to the burst capacity).
Defaults to a tenth of a period worth of bytes, at most 16 KiB.
pub fn set_quantum(&mut self, quantum: u64) -> &mut ThrottleBudget
pub fn set_quantum(&mut self, quantum: u64) -> &mut ThrottleBudget
Override the grant quantum in bytes: the budget reserved per IO operation (clamped to the burst capacity).
Defaults to a tenth of a period worth of bytes, at most 16 KiB.
pub fn without_quantum(self) -> ThrottleBudget
pub fn without_quantum(self) -> ThrottleBudget
Override the grant quantum in bytes: the budget reserved per IO operation (clamped to the burst capacity).
Defaults to a tenth of a period worth of bytes, at most 16 KiB.
pub fn unset_quantum(&mut self) -> &mut ThrottleBudget
pub fn unset_quantum(&mut self) -> &mut ThrottleBudget
Override the grant quantum in bytes: the budget reserved per IO operation (clamped to the burst capacity).
Defaults to a tenth of a period worth of bytes, at most 16 KiB.