Struct ThrottleConfig
pub struct ThrottleConfig { /* private fields */ }net only.Expand description
How ThrottleLayer and OutgoingThrottleLayer throttle a
connection: a ThrottleMode per direction and the grant quantum.
Implementations
impl ThrottleConfig
impl ThrottleConfig
pub fn new(
read: Option<ThrottleMode>,
write: Option<ThrottleMode>,
) -> ThrottleConfig
pub fn new( read: Option<ThrottleMode>, write: Option<ThrottleMode>, ) -> ThrottleConfig
Create a ThrottleConfig with per-direction modes.
pub fn maybe_with_quantum(self, quantum: Option<u64>) -> ThrottleConfig
pub fn maybe_with_quantum(self, quantum: Option<u64>) -> ThrottleConfig
Override the grant quantum in bytes: the budget reserved per IO operation (clamped to the burst capacity; defaults to a tenth of a period worth of bytes, at most 16 KiB).
pub fn maybe_set_quantum(&mut self, quantum: Option<u64>) -> &mut ThrottleConfig
pub fn maybe_set_quantum(&mut self, quantum: Option<u64>) -> &mut ThrottleConfig
Override the grant quantum in bytes: the budget reserved per IO operation (clamped to the burst capacity; defaults to a tenth of a period worth of bytes, at most 16 KiB).
pub fn with_quantum(self, quantum: u64) -> ThrottleConfig
pub fn with_quantum(self, quantum: u64) -> ThrottleConfig
Override the grant quantum in bytes: the budget reserved per IO operation (clamped to the burst capacity; defaults to a tenth of a period worth of bytes, at most 16 KiB).
pub fn set_quantum(&mut self, quantum: u64) -> &mut ThrottleConfig
pub fn set_quantum(&mut self, quantum: u64) -> &mut ThrottleConfig
Override the grant quantum in bytes: the budget reserved per IO operation (clamped to the burst capacity; defaults to a tenth of a period worth of bytes, at most 16 KiB).
pub fn without_quantum(self) -> ThrottleConfig
pub fn without_quantum(self) -> ThrottleConfig
Override the grant quantum in bytes: the budget reserved per IO operation (clamped to the burst capacity; defaults to a tenth of a period worth of bytes, at most 16 KiB).
pub fn unset_quantum(&mut self) -> &mut ThrottleConfig
pub fn unset_quantum(&mut self) -> &mut ThrottleConfig
Override the grant quantum in bytes: the budget reserved per IO operation (clamped to the burst capacity; defaults to a tenth of a period worth of bytes, at most 16 KiB).
pub fn read(&self) -> Option<&ThrottleMode>
pub fn read(&self) -> Option<&ThrottleMode>
How the read (ingress) direction is throttled, if at all.
pub fn write(&self) -> Option<&ThrottleMode>
pub fn write(&self) -> Option<&ThrottleMode>
How the write (egress) direction is throttled, if at all.