Struct ThrottleGates
pub struct ThrottleGates { /* private fields */ }Available on crate feature
net only.Expand description
The StreamGates of one throttled multiplexed connection, such as a QUIC one.
All its streams spend from one budget per direction, as the reads or writes of a
ThrottledIo do: ThrottleMode::PerConn caps this connection,
ThrottleMode::Shared every connection spending from the same limiter.
Implementations
impl ThrottleGates
impl ThrottleGates
pub fn new(config: &ThrottleConfig) -> ThrottleGates
pub fn new(config: &ThrottleConfig) -> ThrottleGates
The gates of one connection, throttled as config sets out.