Struct IpNetMatcher
pub struct IpNetMatcher { /* private fields */ }Available on crate feature
net only.Expand description
Matcher based on whether or not the IpNet contains the SocketAddr of the peer.
Implementations
impl IpNetMatcher
impl IpNetMatcher
pub fn new(net: impl IntoIpNet) -> IpNetMatcher
pub fn new(net: impl IntoIpNet) -> IpNetMatcher
create a new IP network matcher to match on an IP Network.
This matcher will not match in case socket address could not be found,
if you want to match in case socket address could not be found,
use the IpNetMatcher::optional constructor..
pub fn optional(net: impl IntoIpNet) -> IpNetMatcher
pub fn optional(net: impl IntoIpNet) -> IpNetMatcher
create a new IP network matcher to match on an IP network
This matcher will match in case socket address could not be found.
Use the IpNetMatcher::new constructor if you want do not want
to match in case socket address could not be found.