Function parse_client_hello
pub fn parse_client_hello(
i: &[u8],
) -> Result<ClientHello, Box<dyn Error + Send + Sync>>Available on crate feature
net only.Expand description
Parse a ClientHello from the raw “wire” bytes.
This function is not infallible, it can return an error if the input is not a valid TLS ClientHello message or if there is unexpected trailing data.