Struct ClientHello

pub struct ClientHello { /* private fields */ }
Available on crate feature net only.
When a client first connects to a server, it is required to send the ClientHello as its first message.

The ClientHello contains random data, cipher suites, legacy content from <= TLS.12 and extensions.

For Rama however we only focus on the parts which a user might want to inspect and/or set.

Implementations

Source

impl ClientHello

pub fn new( protocol_version: ProtocolVersion, cipher_suites: Vec<CipherSuite>, compression_algorithms: Vec<CompressionAlgorithm>, extensions: Vec<ClientHelloExtension>, ) -> ClientHello

Available on (crate features rustls or boring) and crate feature boring only.
pub fn protocol_version(&self) -> ProtocolVersion

Available on (crate features rustls or boring) and crate feature boring only.

Return all ProtocolVersions defined in this ClientHello.

pub fn cipher_suites(&self) -> &[CipherSuite]

Available on (crate features rustls or boring) and crate feature boring only.

Return all CipherSuites defined in this ClientHello.

pub fn compression_algorithms(&self) -> &[CompressionAlgorithm]

Available on (crate features rustls or boring) and crate feature boring only.

Return all CompressionAlgorithms defined in this ClientHello.

pub fn extensions(&self) -> &[ClientHelloExtension]

Available on (crate features rustls or boring) and crate feature boring only.

Return all ClientHelloExtensions defined in this ClientHello.

pub fn ext_server_name(&self) -> Option<&Host>

Available on (crate features rustls or boring) and crate feature boring only.

Return the server name (SNI) if it is set in the ClientHelloExtension defined in this ClientHello.

See ClientHelloExtension::ServerName for more information about the server name.

pub fn ext_supported_groups(&self) -> Option<&[SupportedGroup]>

Available on (crate features rustls or boring) and crate feature boring only.

Return the elliptic curves supported by this client if it is set in the ClientHelloExtension defined in this ClientHello.

See ClientHelloExtension::SupportedGroups for more information about these curves.

pub fn ext_ec_point_formats(&self) -> Option<&[ECPointFormat]>

Available on (crate features rustls or boring) and crate feature boring only.

Return the EC point formats supported by this client if it is set in the ClientHelloExtension defined in this ClientHello.

See ClientHelloExtension::ECPointFormats for more information about this.

pub fn ext_signature_algorithms(&self) -> Option<&[SignatureScheme]>

Available on (crate features rustls or boring) and crate feature boring only.

Return the signature algorithms supported by this client if it is set in the ClientHelloExtension defined in this ClientHello.

See ClientHelloExtension::SignatureAlgorithms for more information about these algorithms

pub fn ext_alpn(&self) -> Option<&[ApplicationProtocol]>

Available on (crate features rustls or boring) and crate feature boring only.

Return the application layer protocols supported for negotiation by this client if it is set in the ClientHelloExtension defined in this ClientHello.

See ClientHelloExtension::ApplicationLayerProtocolNegotiation for more information about these protocols (ALPN).

pub fn supported_versions(&self) -> Option<&[ProtocolVersion]>

Available on (crate features rustls or boring) and crate feature boring only.

Return the TLS versions supported by this client if it is set in the ClientHelloExtension defined in this ClientHello.

See ClientHelloExtension::SupportedVersions for more information about these versions