Struct PeekTlsClientHelloService
pub struct PeekTlsClientHelloService<S, F = RejectService<(), NoTlsRejectError>> { /* private fields */ }Expand description
A peek Service which returns the ClientHello to the inner
service for tls-detected traffic, and otherwise make use of the Reject service.
The difference with SniRouter is that the entire
ClientHello is parsed and returned instead of just the SNI. Use the router
in case all you care about is the SNI, given it is more efficient.
By default non-tls traffic is rejected using RejectService.
Use PeekTlsClientHelloService::with_fallback to configure the fallback service.
Use the standalone peek_client_hello_from_input function if you prefer
this is as a standalone function instead.
Implementations
impl<S> PeekTlsClientHelloService<S>
impl<S> PeekTlsClientHelloService<S>
pub fn new(service: S) -> PeekTlsClientHelloService<S>
pub fn new(service: S) -> PeekTlsClientHelloService<S>
Create a new PeekTlsClientHelloService.
pub fn with_fallback<F>(self, fallback: F) -> PeekTlsClientHelloService<S, F>
pub fn with_fallback<F>(self, fallback: F) -> PeekTlsClientHelloService<S, F>
Attach a fallback Service to this PeekTlsClientHelloService.
Used in case the traffic is not Tls traffic (defined by the first bytes).
impl<S, F> PeekTlsClientHelloService<S, F>
impl<S, F> PeekTlsClientHelloService<S, F>
pub fn maybe_with_peek_timeout(
self,
peek_timeout: Option<Duration>,
) -> PeekTlsClientHelloService<S, F>
pub fn maybe_with_peek_timeout( self, peek_timeout: Option<Duration>, ) -> PeekTlsClientHelloService<S, F>
Set the peek window to timeout on
pub fn maybe_set_peek_timeout(
&mut self,
peek_timeout: Option<Duration>,
) -> &mut PeekTlsClientHelloService<S, F>
pub fn maybe_set_peek_timeout( &mut self, peek_timeout: Option<Duration>, ) -> &mut PeekTlsClientHelloService<S, F>
Set the peek window to timeout on
pub fn with_peek_timeout(
self,
peek_timeout: Duration,
) -> PeekTlsClientHelloService<S, F>
pub fn with_peek_timeout( self, peek_timeout: Duration, ) -> PeekTlsClientHelloService<S, F>
Set the peek window to timeout on
pub fn set_peek_timeout(
&mut self,
peek_timeout: Duration,
) -> &mut PeekTlsClientHelloService<S, F>
pub fn set_peek_timeout( &mut self, peek_timeout: Duration, ) -> &mut PeekTlsClientHelloService<S, F>
Set the peek window to timeout on
pub fn without_peek_timeout(self) -> PeekTlsClientHelloService<S, F>
pub fn without_peek_timeout(self) -> PeekTlsClientHelloService<S, F>
Set the peek window to timeout on
pub fn unset_peek_timeout(&mut self) -> &mut PeekTlsClientHelloService<S, F>
pub fn unset_peek_timeout(&mut self) -> &mut PeekTlsClientHelloService<S, F>
Set the peek window to timeout on