Struct ServerAuthData
pub struct ServerAuthData {
pub private_key: DataEncoding,
pub cert_chain: DataEncoding,
pub ocsp: Option<Vec<u8>>,
}Available on crate feature
net only.Expand description
Raw private key and certificate data to facilitate server authentication.
Fields
private_key: DataEncodingprivate key used by server
cert_chain: DataEncodingcertificate chain as a companion to the private key
ocsp: Option<Vec<u8>>ocsp is a DER-encoded OCSP response