Struct PathRouteCaptures
pub struct PathRouteCaptures { /* private fields */ }Available on crate feature
net only.Expand description
Decoded captures inserted by PathRouter’s Service implementation.
Implementations
impl PathRouteCaptures
impl PathRouteCaptures
pub fn get(&self, name: &str) -> Option<&str>
pub fn get(&self, name: &str) -> Option<&str>
The decoded value captured under name, or None if absent.
pub fn get_non_empty(&self, name: &str) -> Option<&str>
pub fn get_non_empty(&self, name: &str) -> Option<&str>
The decoded value captured under name, or None if absent or empty.