Struct Basic
pub struct Basic { /* private fields */ }net only.Expand description
Basic credentials.
Implementations
impl Basic
impl Basic
pub const fn new(username: NonEmptyStr, password: NonEmptyStr) -> Basic
pub const fn new(username: NonEmptyStr, password: NonEmptyStr) -> Basic
Creates a new Basic credential.
pub fn clone_with_new_username(&self, username: NonEmptyStr) -> Basic
pub fn clone_with_new_password(&self, password: NonEmptyStr) -> Basic
pub const fn new_insecure(username: NonEmptyStr) -> Basic
pub const fn new_insecure(username: NonEmptyStr) -> Basic
Creates a new Basic credential.
pub fn with_username(self, username: NonEmptyStr) -> Basic
pub fn with_username(self, username: NonEmptyStr) -> Basic
Set or overwrite the username with the given value.
pub fn set_username(&mut self, username: NonEmptyStr) -> &mut Basic
pub fn set_username(&mut self, username: NonEmptyStr) -> &mut Basic
Set or overwrite the username with the given value.
pub fn password(&self) -> Option<&str>
pub fn password(&self) -> Option<&str>
View the decoded password.
If Some(str) is returned it is guaranteed to be non-empty.
pub fn with_password(self, password: NonEmptyStr) -> Basic
pub fn with_password(self, password: NonEmptyStr) -> Basic
Set or overwrite the password with the given value.
pub fn set_password(&mut self, password: NonEmptyStr) -> &mut Basic
pub fn set_password(&mut self, password: NonEmptyStr) -> &mut Basic
Set or overwrite the password with the given value.
Turn itself into a StaticAuthorizer, so it can be used to authorize.
Just a shortcut, QoL.