Enum Crc32cStatus
pub enum Crc32cStatus {
Absent,
Valid,
Invalid,
MalformedBeforeCrc,
}Available on crate feature
haproxy only.Expand description
Result of Header::verify_crc32c.
See the method docs for what each variant means.
Variants
Absent
No PP2_TYPE_CRC32C TLV is present in this header.
Valid
A CRC32C TLV is present and matches the recomputed value.
Invalid
A CRC32C TLV is present but its value does not match the recomputed value, or its value length is not 4 bytes.
MalformedBeforeCrc
A CRC32C TLV may or may not be present — the TLV stream became unparseable before we could decide. Callers should treat this as “couldn’t verify”, not “verification failed”.