pub enum ParseError {
Incomplete(usize),
Prefix,
Version(u8),
Command(u8),
AddressFamily(u8),
Protocol(u8),
Partial(usize, usize),
InvalidAddresses(usize, usize),
InvalidTLV(u8, u16),
Leftovers(usize),
}proxy or haproxy) and crate feature haproxy only.Expand description
An error in parsing a binary PROXY protocol header.
Variants
Incomplete(usize)
Expected header to the protocol prefix plus 4 bytes after the prefix.
Prefix
Expected header to start with a prefix of ‘\r\n\r\n\0\r\nQUIT\n’.
Version(u8)
Expected version to be equal to 2.
Command(u8)
Invalid command. Command must be one of: Local, Proxy.
AddressFamily(u8)
Invalid Address Family. Address Family must be one of: Unspecified, IPv4, IPv6, Unix.
Protocol(u8)
Invalid protocol. Protocol must be one of: Unspecified, Stream, or Datagram.
Partial(usize, usize)
Header does not contain the advertised length of the address information and TLVs.
InvalidAddresses(usize, usize)
Header length of {0} bytes cannot store the {1} bytes required for the address family.
InvalidTLV(u8, u16)
Header is not long enough to contain TLV {0} with length {1}.
Leftovers(usize)
Header contains leftover {0} bytes not accounted for by the address family or TLVs.