Struct HaProxyLayer
#[non_exhaustive]pub struct HaProxyLayer { /* private fields */ }haproxy only.Expand description
Layer to decode the HaProxy Protocol
Implementations
impl HaProxyLayer
impl HaProxyLayer
pub const fn new() -> HaProxyLayer
pub const fn new() -> HaProxyLayer
Create a new HaProxyLayer.
pub fn with_peek(self, value: bool) -> HaProxyLayer
pub fn with_peek(self, value: bool) -> HaProxyLayer
Instruct HaProxyLayer to peek prior to comitting to the HaProxy protocol.
Doing so makes it possible to support traffic with or without the use of that data. This can be useful to run services locally (not behind a loadbalancer) as well as in the the cloud (production, behind a loadbalancer).
pub fn set_peek(&mut self, value: bool) -> &mut HaProxyLayer
pub fn set_peek(&mut self, value: bool) -> &mut HaProxyLayer
Instruct HaProxyLayer to peek prior to comitting to the HaProxy protocol.
Doing so makes it possible to support traffic with or without the use of that data. This can be useful to run services locally (not behind a loadbalancer) as well as in the the cloud (production, behind a loadbalancer).
pub fn with_strictness(self, value: HaProxyStrictness) -> HaProxyLayer
pub fn with_strictness(self, value: HaProxyStrictness) -> HaProxyLayer
Override the strictness configuration applied to incoming PROXY headers.
pub fn set_strictness(&mut self, value: HaProxyStrictness) -> &mut HaProxyLayer
pub fn set_strictness(&mut self, value: HaProxyStrictness) -> &mut HaProxyLayer
Override the strictness configuration applied to incoming PROXY headers.