Enum AddressType
pub enum AddressType {
IpV4,
DomainName,
IpV6,
Unknown(u8),
}socks5 only.Expand description
Type of the address following it.
Only used during encoding and decoding, but no use for the in-memory representation.
Variants
IpV4
The address is a version-4 IP address, with a length of 4 octets.
DomainName
The address is a length-prefixed (max 255 byte) domain name.
The address field contains a fully-qualified domain name (FQDN). The first octet of the address field contains the number of octets of name that follow, there is no terminating NUL octet.
IpV6
The address is a version-6 IP address, with a length of 16 octets.
Unknown(u8)
Retains an unrecognized numeric value.
Implementations
impl AddressType
impl AddressType
pub fn variant_name(&self) -> Cow<'static, str>
pub fn variant_name(&self) -> Cow<'static, str>
Return this value’s variant name, or its decimal number when the value is unknown.
Known values borrow their 'static mnemonic, and
Self::Unknown values render their numeric value. Unlike
Display and Debug the result is a bare, stable label,
suitable for log fields, metrics, and telemetry.