Enum Command
pub enum Command {
Connect,
Bind,
UdpAssociate,
Unknown(u8),
}socks5 only.Expand description
Request Command.
Reference: https://datatracker.ietf.org/doc/html/rfc1928#section-4
Variants
Connect
Request the server to establish a connection on behalf of the client with the destination address.
Reference: RFC 1928
Bind
Used in protocols which require the client to accept connections from the server.
FTP is a well-known example, which uses the primary client-to-server connection for commands and status reports, but may use a server-to-client connection for transferring data on demand (e.g. LS, GET, PUT).
Reference: RFC 1928
UdpAssociate
Used to establish an association within the UDP relay process to handle UDP datagrams.
Reference: RFC 1928
Unknown(u8)
Retains an unrecognized numeric value.