Enum Socks5MitmHandshakeOutcome
pub enum Socks5MitmHandshakeOutcome {
UnsupportedFlow,
ContinueInspection,
}Available on crate feature
socks5 only.Expand description
Outcome of Socks5MitmRelay::handshake.
Variants
UnsupportedFlow
Flow is not supported, skip traffic inspection and resort to proxying bytes…
ContinueInspection
Socks5 handshake complete, continue to inspect.
In case there were credentials negotiated in the flow,
they will also have been inserted in the input flow via
DpiProxyCredential in its extensions.