Struct Socks5MitmRelayService
pub struct Socks5MitmRelayService<I, F = IoForwardService> { /* private fields */ }socks5 only.Expand description
A service that can be used by MITM services such as transparent proxies, in order to relay a socks5 proxy connection between a client and server, as part of a deep protocol inspection protocol (DPI) flow.
Implementations
impl<I> Socks5MitmRelayService<I>
impl<I> Socks5MitmRelayService<I>
pub fn new(exec: Executor, dpi_svc: I) -> Socks5MitmRelayService<I>
pub fn new(exec: Executor, dpi_svc: I) -> Socks5MitmRelayService<I>
Create a new Socks5MitmRelayService using the given inspector
service to continue the DPI of (socks5) handshaked traffic with a
Socks5MitmHandshakeOutcome::ContinueInspection outcome.
The fallback service used for
Socks5MitmHandshakeOutcome::UnsupportedFlow outcomes is an
IoForwardService graceful with respect to the given Executor;
override it via Self::with_fallback.
pub fn with_fallback<F>(self, fallback_svc: F) -> Socks5MitmRelayService<I, F>
pub fn with_fallback<F>(self, fallback_svc: F) -> Socks5MitmRelayService<I, F>
Attach a fallback Service to this Socks5MitmRelayService.
Used in case the handshaked resulted in a
Socks5MitmHandshakeOutcome::UnsupportedFlow outcome,
e.g. because the method or command was not compatible with DPI (or desired).