Struct Binder
pub struct Binder<A, S> { /* private fields */ }socks5 only.Expand description
Only “useful” public Socks5Binder implementation,
which actually is able to accept bind requests and process them.
The Default implementation opens a new socket for accepting 1
incoming connection. Once received it will pipe the original request (source)
stream together with the received inbound stream from the secondary callee.
You can customise the Binder fully by creating it using Binder::new
or overwrite any of the default components using either or both of Binder::with_acceptor
and Binder::with_service.
Implementations
impl<A, S> Binder<A, S>
impl<A, S> Binder<A, S>
pub fn new(acceptor: A, service: S) -> Binder<A, S>
pub fn new(acceptor: A, service: S) -> Binder<A, S>
Create a new Binder.
In case you only wish to overwrite one of these components
you can also use a Default Binder and overwrite the specific component
using Binder::with_acceptor or Binder::with_service.
impl<A, S> Binder<A, S>
impl<A, S> Binder<A, S>
pub fn with_acceptor<T>(self, acceptor: T) -> Binder<T, S>
pub fn with_acceptor<T>(self, acceptor: T) -> Binder<T, S>
pub fn with_service<T>(self, service: T) -> Binder<A, T>
pub fn with_service<T>(self, service: T) -> Binder<A, T>
pub fn with_bind_address(self, addr: impl Into<SocketAddress>) -> Binder<A, S>
pub fn with_bind_address(self, addr: impl Into<SocketAddress>) -> Binder<A, S>
Define the SocketAddress to bind to.
By default it will use the client’s requested bind address, which is in many cases not what you want.
pub fn set_bind_address(
&mut self,
addr: impl Into<SocketAddress>,
) -> &mut Binder<A, S>
pub fn set_bind_address( &mut self, addr: impl Into<SocketAddress>, ) -> &mut Binder<A, S>
Define the SocketAddress to bind to.
By default it will use the client’s requested bind address, which is in many cases not what you want.
pub fn with_default_bind_address(self) -> Binder<A, S>
pub fn with_default_bind_address(self) -> Binder<A, S>
Define the default SocketAddress to bind to (0.0.0.0:0).
By default it will use the client’s requested bind address, which is in many cases not what you want.
pub fn set_default_bind_address(&mut self) -> &mut Binder<A, S>
pub fn set_default_bind_address(&mut self) -> &mut Binder<A, S>
Define the default SocketAddress to bind to (0.0.0.0:0).
By default it will use the client’s requested bind address, which is in many cases not what you want.
pub fn maybe_with_accept_timeout(
self,
timeout: Option<Duration>,
) -> Binder<A, S>
pub fn maybe_with_accept_timeout( self, timeout: Option<Duration>, ) -> Binder<A, S>
Define the accept timeout for this socks5 bind server.
pub fn maybe_set_accept_timeout(
&mut self,
timeout: Option<Duration>,
) -> &mut Binder<A, S>
pub fn maybe_set_accept_timeout( &mut self, timeout: Option<Duration>, ) -> &mut Binder<A, S>
Define the accept timeout for this socks5 bind server.
pub fn with_accept_timeout(self, timeout: Duration) -> Binder<A, S>
pub fn with_accept_timeout(self, timeout: Duration) -> Binder<A, S>
Define the accept timeout for this socks5 bind server.
pub fn set_accept_timeout(&mut self, timeout: Duration) -> &mut Binder<A, S>
pub fn set_accept_timeout(&mut self, timeout: Duration) -> &mut Binder<A, S>
Define the accept timeout for this socks5 bind server.
pub fn without_accept_timeout(self) -> Binder<A, S>
pub fn without_accept_timeout(self) -> Binder<A, S>
Define the accept timeout for this socks5 bind server.
pub fn unset_accept_timeout(&mut self) -> &mut Binder<A, S>
pub fn unset_accept_timeout(&mut self) -> &mut Binder<A, S>
Define the accept timeout for this socks5 bind server.
impl Binder<Timeout<DefaultAcceptorFactory, LayerErrorStatic<Elapsed>>, IoForwardService>
impl Binder<Timeout<DefaultAcceptorFactory, LayerErrorStatic<Elapsed>>, IoForwardService>
pub fn default_with_exec(
exec: Executor,
) -> Binder<Timeout<DefaultAcceptorFactory, LayerErrorStatic<Elapsed>>, IoForwardService>
pub fn default_with_exec( exec: Executor, ) -> Binder<Timeout<DefaultAcceptorFactory, LayerErrorStatic<Elapsed>>, IoForwardService>
Create a DefaultBinder whose forward bridge observes graceful
shutdown via the given Executor.