Struct LazyConnector
pub struct LazyConnector<S> { /* private fields */ }socks5 only.Expand description
Lazy Socks5Connector implementation,
which accepts a connection but delegates all the work
on the egress side to the inner (stream) service.
This connector is useful for proxy routers that need application bytes before
they can select an egress target. A regular MITM proxy should instead use
Connector and inspect its pre-established BridgeIo.
Default Connectors
Please use Connector for the more common SOCKS5 proxy use case. It
establishes the destination connection before returning a successful reply,
ready for piping between the incoming and established streams.
Implementations
impl<S> LazyConnector<S>
impl<S> LazyConnector<S>
pub fn new(service: S) -> LazyConnector<S>
pub fn new(service: S) -> LazyConnector<S>
Create a new LazyConnector.
The default LazyConnector forwards the stream as-is to the
received proxy target.
impl LazyConnector<IoToProxyBridgeIo<IoForwardService>>
impl LazyConnector<IoToProxyBridgeIo<IoForwardService>>
pub fn default_with_exec(
exec: Executor,
) -> LazyConnector<IoToProxyBridgeIo<IoForwardService>>
pub fn default_with_exec( exec: Executor, ) -> LazyConnector<IoToProxyBridgeIo<IoForwardService>>
Create a LazyConnector whose forward bridge observes graceful
shutdown via the given Executor.