Struct Socks5PeekRouter
pub struct Socks5PeekRouter<T, F = RejectService<(), NoSocks5RejectError>> { /* private fields */ }socks5 only.Expand description
A Service router that can be used to support
socks5 traffic as well as non-socks5 traffic.
By default non-socks5 traffic is rejected using RejectService.
Use Socks5PeekRouter::with_fallback to configure the fallback service.
A definitive non-SOCKS5 prefix invokes that fallback under either timeout
policy; an inconclusive timeout is fail-open by default and can be made
fail-closed with Socks5PeekRouter::with_peek_timeout_policy.
This kind of router can be useful in case you want to have a proxy which supports for example both HTTP proxy requests as well socks5 proxy requests.
Implementations
impl<T> Socks5PeekRouter<T>
impl<T> Socks5PeekRouter<T>
pub fn new(socks5_acceptor: T) -> Socks5PeekRouter<T>
pub fn new(socks5_acceptor: T) -> Socks5PeekRouter<T>
Create a new Socks5PeekRouter.
pub fn with_fallback<F>(self, fallback: F) -> Socks5PeekRouter<T, F>
pub fn with_fallback<F>(self, fallback: F) -> Socks5PeekRouter<T, F>
Attach a fallback Service tp this Socks5PeekRouter.
impl<T, F> Socks5PeekRouter<T, F>
impl<T, F> Socks5PeekRouter<T, F>
pub fn maybe_with_peek_timeout(
self,
peek_timeout: Option<Duration>,
) -> Socks5PeekRouter<T, F>
pub fn maybe_with_peek_timeout( self, peek_timeout: Option<Duration>, ) -> Socks5PeekRouter<T, F>
Set the maximum time spent peeking for a SOCKS5 greeting.
A timeout is inconclusive. Use
Socks5PeekRouter::with_peek_timeout_policy to choose whether it
invokes the fallback or rejects the connection.
pub fn maybe_set_peek_timeout(
&mut self,
peek_timeout: Option<Duration>,
) -> &mut Socks5PeekRouter<T, F>
pub fn maybe_set_peek_timeout( &mut self, peek_timeout: Option<Duration>, ) -> &mut Socks5PeekRouter<T, F>
Set the maximum time spent peeking for a SOCKS5 greeting.
A timeout is inconclusive. Use
Socks5PeekRouter::with_peek_timeout_policy to choose whether it
invokes the fallback or rejects the connection.
pub fn with_peek_timeout(self, peek_timeout: Duration) -> Socks5PeekRouter<T, F>
pub fn with_peek_timeout(self, peek_timeout: Duration) -> Socks5PeekRouter<T, F>
Set the maximum time spent peeking for a SOCKS5 greeting.
A timeout is inconclusive. Use
Socks5PeekRouter::with_peek_timeout_policy to choose whether it
invokes the fallback or rejects the connection.
pub fn set_peek_timeout(
&mut self,
peek_timeout: Duration,
) -> &mut Socks5PeekRouter<T, F>
pub fn set_peek_timeout( &mut self, peek_timeout: Duration, ) -> &mut Socks5PeekRouter<T, F>
Set the maximum time spent peeking for a SOCKS5 greeting.
A timeout is inconclusive. Use
Socks5PeekRouter::with_peek_timeout_policy to choose whether it
invokes the fallback or rejects the connection.
pub fn without_peek_timeout(self) -> Socks5PeekRouter<T, F>
pub fn without_peek_timeout(self) -> Socks5PeekRouter<T, F>
Set the maximum time spent peeking for a SOCKS5 greeting.
A timeout is inconclusive. Use
Socks5PeekRouter::with_peek_timeout_policy to choose whether it
invokes the fallback or rejects the connection.
pub fn unset_peek_timeout(&mut self) -> &mut Socks5PeekRouter<T, F>
pub fn unset_peek_timeout(&mut self) -> &mut Socks5PeekRouter<T, F>
Set the maximum time spent peeking for a SOCKS5 greeting.
A timeout is inconclusive. Use
Socks5PeekRouter::with_peek_timeout_policy to choose whether it
invokes the fallback or rejects the connection.
pub fn with_peek_timeout_policy(
self,
peek_timeout_policy: PeekTimeoutPolicy,
) -> Socks5PeekRouter<T, F>
pub fn with_peek_timeout_policy( self, peek_timeout_policy: PeekTimeoutPolicy, ) -> Socks5PeekRouter<T, F>
Set how an inconclusive peek timeout is handled.
Defaults to PeekTimeoutPolicy::FailOpen. A definitive non-SOCKS5
prefix invokes the fallback under either policy.
pub fn set_peek_timeout_policy(
&mut self,
peek_timeout_policy: PeekTimeoutPolicy,
) -> &mut Socks5PeekRouter<T, F>
pub fn set_peek_timeout_policy( &mut self, peek_timeout_policy: PeekTimeoutPolicy, ) -> &mut Socks5PeekRouter<T, F>
Set how an inconclusive peek timeout is handled.
Defaults to PeekTimeoutPolicy::FailOpen. A definitive non-SOCKS5
prefix invokes the fallback under either policy.