Enum UnspecifiedClientUdpAddressPolicy
#[non_exhaustive]pub enum UnspecifiedClientUdpAddressPolicy {
PinToTcpPeerIp,
PinToFirstPacket,
AnySource,
}Available on crate feature
socks5 only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
PinToTcpPeerIp
Accept the first UDP packet only when it matches the TCP peer IP, if known, then pin to that packet’s full UDP source address.
The IP match is canonicalized, so a v4-mapped IPv6 TCP peer matches the
equivalent plain IPv4 UDP source. When the TCP peer IP is unknown (no
SocketInfo in the extensions) this degrades to Self::PinToFirstPacket.
PinToFirstPacket
Accept the first UDP packet from any source, then pin to that packet’s full UDP source address.
AnySource
Accept UDP packets from any source. Replies are sent to the most recent accepted source address.