Struct AsyncUdpInspector
pub struct AsyncUdpInspector<S>(/* private fields */);Available on crate feature
socks5 only.Expand description
Wrapper used for Async udp inspectors.
Only exposed so you are able to define the type, it is not intended to be created directly by a rama user.