Socks5ProxyConnectorLayer

Struct Socks5ProxyConnectorLayer 

pub struct Socks5ProxyConnectorLayer { /* private fields */ }
Available on crate feature socks5 only.
A Layer which wraps the given service with a Socks5ProxyConnector.

See Socks5ProxyConnector for more information.

Implementations



impl Socks5ProxyConnectorLayer

pub fn optional() -> Socks5ProxyConnectorLayer

Create a new Socks5ProxyConnectorLayer which creates a Socks5ProxyConnector which will only connect via a socks5 proxy when a proxied ProxyRoute is available in the input Extensions.

pub fn required() -> Socks5ProxyConnectorLayer

Create a new Socks5ProxyConnectorLayer which creates a Socks5ProxyConnector which will always connect via a SOCKS5 proxy, but fail when a proxied ProxyRoute is not available in the input Extensions.



impl Socks5ProxyConnectorLayer

pub fn with_default_dns_resolver(self) -> Socks5ProxyConnectorLayer

Available on crate feature dns only.

Attach the default DnsAddressResolver to this Socks5ProxyConnectorLayer.

It will try to be used (best-effort) to resolve domain addresses as IP addresses if the socks5 protocol is used, but not for the socks5h protocol.

In case of an error with resolving the domain address the connector will anyway use the domain instead of the ip.

pub fn set_default_dns_resolver(&mut self) -> &mut Socks5ProxyConnectorLayer

Available on crate feature dns only.

Attach the default DnsAddressResolver to this Socks5ProxyConnectorLayer.

It will try to be used (best-effort) to resolve domain addresses as IP addresses if the socks5 protocol is used, but not for the socks5h protocol.

In case of an error with resolving the domain address the connector will anyway use the domain instead of the ip.

pub fn with_dns_address_resolver( self, resolver: impl DnsAddressResolver, ) -> Socks5ProxyConnectorLayer

Available on crate feature dns only.

Attach a DnsAddressResolver to this Socks5ProxyConnectorLayer.

It will try to be used (best-effort) to resolve domain addresses as IP addresses if the socks5 protocol is used, but not for the socks5h protocol.

In case of an error with resolving the domain address the connector will anyway use the domain instead of the ip.

pub fn set_dns_address_resolver( &mut self, resolver: impl DnsAddressResolver, ) -> &mut Socks5ProxyConnectorLayer

Available on crate feature dns only.

Attach a DnsAddressResolver to this Socks5ProxyConnectorLayer.

It will try to be used (best-effort) to resolve domain addresses as IP addresses if the socks5 protocol is used, but not for the socks5h protocol.

In case of an error with resolving the domain address the connector will anyway use the domain instead of the ip.