ProxyFilter

Struct ProxyFilter 

pub struct ProxyFilter {
    pub id: Option<NonEmptyStr>,
    pub pool_id: Option<Vec<StringFilter>>,
    pub continent: Option<Vec<StringFilter>>,
    pub country: Option<Vec<StringFilter>>,
    pub state: Option<Vec<StringFilter>>,
    pub city: Option<Vec<StringFilter>>,
    pub datacenter: Option<bool>,
    pub residential: Option<bool>,
    pub mobile: Option<bool>,
    pub carrier: Option<Vec<StringFilter>>,
    pub asn: Option<Vec<Asn>>,
}
Available on crate feature proxy only.
Filter to select a specific kind of proxy.

If the id is specified the other fields are used as a validator to see if the only possible matching proxy matches these fields.

If the id is not specified, the other fields select matching proxy candidates. The database defines their preference order; MemoryProxyDB randomizes its complete matching set.

Filters can be combined to make combinations with special meaning. E.g. datacenter:true, residential:true is essentially an ISP proxy.

Usage

  • Use HeaderConfigLayer (rama-http) to have this proxy filter be given by the http request headers, which will add the extracted and parsed ProxyFilter to the input Extensions.
  • Or extract yourself from the username/token validated in the ProxyAuthLayer (rama-http) to add it manually to the input Extensions.

Fields

id: Option<NonEmptyStr>

The ID of the proxy to select.

pool_id: Option<Vec<StringFilter>>

The ID of the pool from which to select the proxy.

continent: Option<Vec<StringFilter>>

The continent of the proxy.

country: Option<Vec<StringFilter>>

The country of the proxy.

state: Option<Vec<StringFilter>>

The state of the proxy.

city: Option<Vec<StringFilter>>

The city of the proxy.

datacenter: Option<bool>

Set explicitly to true to select a datacenter proxy.

residential: Option<bool>

Set explicitly to true to select a residential proxy.

mobile: Option<bool>

Set explicitly to true to select a mobile proxy.

carrier: Option<Vec<StringFilter>>

The mobile carrier desired.

asn: Option<Vec<Asn>>

Autonomous System Number (ASN).