Enum ConnectionError
pub enum ConnectionError {
VersionMismatch,
TransportError(Error),
ConnectionClosed(ConnectionClose),
ApplicationClosed(ApplicationClose),
Reset,
TimedOut,
LocallyClosed,
CidsExhausted,
}quic and std only.Expand description
Reasons why a connection might be lost
Variants
VersionMismatch
The peer doesn’t implement any supported version
TransportError(Error)
The peer violated the QUIC specification as understood by this implementation
ConnectionClosed(ConnectionClose)
The peer’s QUIC stack aborted the connection automatically
ApplicationClosed(ApplicationClose)
The peer closed the connection
Reset
The peer is unable to continue processing this connection, usually due to having restarted
TimedOut
The handshake deadline or negotiated idle timeout elapsed.
The local handshake deadline also applies when idle timeout is disabled.
After connecting, a long enough idle period can time out even if the peer is
still reachable. See TransportConfig::set_max_idle_timeout and
TransportConfig::set_keep_alive_interval.
LocallyClosed
The local application closed the connection
CidsExhausted
The connection could not be created because not enough of the CID space is available
Try using longer connection IDs.