Enum RetryRefused
#[non_exhaustive]pub enum RetryRefused {
AlreadyRetried,
NoServerConfig,
TokenSealing,
LifetimeUnrepresentable,
}Available on crate features
quic and std only.Expand description
Why a Retry was not sent
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AlreadyRetried
The attempt already bears a token from a previous Retry
NoServerConfig
The endpoint has no server configuration
TokenSealing
The token key’s provider failed to seal the retry token
LifetimeUnrepresentable
The configured retry token lifetime cannot be represented on the clock that would bound the return route, so no Retry is issued and the attempt is kept