Enum PaddingPlacement
#[non_exhaustive]pub enum PaddingPlacement {
Frames,
DatagramTail,
}Available on crate feature
quic only.Expand description
Where the bytes that bring an Initial datagram up to size go.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Frames
PADDING frames inside the last packet.
DatagramTail
Zero bytes after the last packet, which receivers ignore (RFC 9000 12.2).