Struct ParameterId
pub struct ParameterId(pub u64);Available on crate feature
quic only.Expand description
The identifier of a transport parameter (RFC 9000 18.2 and the QUIC transport parameter registry), including ones this crate does not otherwise know.
Tuple Fields
0: u64Implementations
impl ParameterId
impl ParameterId
pub const ORIGINAL_DESTINATION_CONNECTION_ID: ParameterId
pub const MAX_IDLE_TIMEOUT: ParameterId
pub const STATELESS_RESET_TOKEN: ParameterId
pub const MAX_UDP_PAYLOAD_SIZE: ParameterId
pub const INITIAL_MAX_DATA: ParameterId
pub const INITIAL_MAX_STREAM_DATA_BIDI_LOCAL: ParameterId
pub const INITIAL_MAX_STREAM_DATA_BIDI_REMOTE: ParameterId
pub const INITIAL_MAX_STREAM_DATA_UNI: ParameterId
pub const INITIAL_MAX_STREAMS_BIDI: ParameterId
pub const INITIAL_MAX_STREAMS_UNI: ParameterId
pub const ACK_DELAY_EXPONENT: ParameterId
pub const MAX_ACK_DELAY: ParameterId
pub const DISABLE_ACTIVE_MIGRATION: ParameterId
pub const PREFERRED_ADDRESS: ParameterId
pub const ACTIVE_CONNECTION_ID_LIMIT: ParameterId
pub const INITIAL_SOURCE_CONNECTION_ID: ParameterId
pub const RETRY_SOURCE_CONNECTION_ID: ParameterId
pub const VERSION_INFORMATION: ParameterId
pub const VERSION_INFORMATION: ParameterId
RFC 9368.
pub const MAX_DATAGRAM_FRAME_SIZE: ParameterId
pub const MAX_DATAGRAM_FRAME_SIZE: ParameterId
RFC 9221.
pub const GREASE_QUIC_BIT: ParameterId
pub const GREASE_QUIC_BIT: ParameterId
RFC 9287.
pub const MIN_ACK_DELAY: ParameterId
pub const MIN_ACK_DELAY: ParameterId
draft-ietf-quic-ack-frequency-07.
pub const GREASE: ParameterId
pub const GREASE: ParameterId
Not a parameter: where the greased parameter goes in a fixed order.
pub const fn is_reserved(self) -> bool
pub const fn is_reserved(self) -> bool
Whether this identifier is one reserved for greasing (RFC 9000 18.1): 31 * N + 27.