Struct ArrayRangeSet
pub struct ArrayRangeSet(/* private fields */);Available on crate feature
quic only.Expand description
A set of u64 values optimized for long runs and random insert/delete/contains
ArrayRangeSet uses an array representation, where each array entry represents
a range.
The array-based RangeSet provides 2 benefits:
- There exists an inline representation, which avoids the need of heap allocating ACK ranges for SentFrames for small ranges.
- Iterating over ranges should usually be faster since there is only a single cache-friendly contiguous range.
ArrayRangeSet is especially useful for tracking ACK ranges where the amount
of ranges is usually very low (since ACK numbers are in consecutive fashion
unless reordering or packet loss occur).
Implementations
impl ArrayRangeSet
impl ArrayRangeSet
pub fn new() -> ArrayRangeSet
pub fn iter(&self) -> impl DoubleEndedIterator
pub fn elts(&self) -> impl Iterator<Item = u64>
pub fn len(&self) -> usize
pub fn insert_one(&mut self, x: u64) -> bool
pub fn insert(&mut self, x: Range<u64>) -> bool
pub fn remove(&mut self, x: Range<u64>) -> bool
pub fn is_empty(&self) -> bool
pub fn pop_min(&mut self) -> Option<Range<u64>>
pub fn max(&self) -> Option<u64>