ReservedTransportParameter

Struct ReservedTransportParameter 

pub struct ReservedTransportParameter { /* private fields */ }
Available on crate feature quic only.
A reserved transport parameter.

It has an identifier of the form 31 * N + 27 for the integer value of N. Such identifiers are reserved to exercise the requirement that unknown transport parameters be ignored. The reserved transport parameter has no semantics and can carry arbitrary values. It may be included in transport parameters sent to the peer, and should be ignored when received.

See spec: https://www.rfc-editor.org/rfc/rfc9000.html#section-18.1

Implementations



impl ReservedTransportParameter

pub fn random( rng: &mut impl Rng, value_len: Option<usize>, ) -> ReservedTransportParameter

Generates a transport parameter with a random payload and a reserved ID. The payload is value_len bytes when given, else a random length up to a small fixed maximum.

pub fn fixed( id: u64, value: &[u8], ) -> Result<ReservedTransportParameter, VarIntBoundsExceeded>

A reserved parameter with this identifier and value on every connection.