TransportParameters

Struct TransportParameters 

pub struct TransportParameters {
Show 24 fields pub max_idle_timeout: VarInt, pub max_udp_payload_size: VarInt, pub initial_max_data: VarInt, pub initial_max_stream_data_bidi_local: VarInt, pub initial_max_stream_data_bidi_remote: VarInt, pub initial_max_stream_data_uni: VarInt, pub initial_max_streams_bidi: VarInt, pub initial_max_streams_uni: VarInt, pub ack_delay_exponent: VarInt, pub max_ack_delay: VarInt, pub active_connection_id_limit: VarInt, pub disable_active_migration: bool, pub max_datagram_frame_size: Option<VarInt>, pub initial_src_cid: Option<ConnectionId>, pub grease_quic_bit: bool, pub min_ack_delay: Option<VarInt>, pub version_information: Option<VersionInformation>, pub original_dst_cid: Option<ConnectionId>, pub retry_src_cid: Option<ConnectionId>, pub stateless_reset_token: Option<ResetToken>, pub preferred_address: Option<PreferredAddress>, pub grease_transport_parameter: Option<ReservedTransportParameter>, pub extra: Vec<(u64, Vec<u8>)>, pub write_plan: Option<Vec<WriteSlot>>,
}
Available on crate feature quic only.
Transport parameters used to negotiate connection-level preferences between peers

Fields

max_idle_timeout: VarInt

Milliseconds, disabled if zero

max_udp_payload_size: VarInt

Limits the size of UDP payloads that the endpoint is willing to receive

initial_max_data: VarInt

Initial value for the maximum amount of data that can be sent on the connection

initial_max_stream_data_bidi_local: VarInt

Initial flow control limit for locally-initiated bidirectional streams

initial_max_stream_data_bidi_remote: VarInt

Initial flow control limit for peer-initiated bidirectional streams

initial_max_stream_data_uni: VarInt

Initial flow control limit for unidirectional streams

initial_max_streams_bidi: VarInt

Initial maximum number of bidirectional streams the peer may initiate

initial_max_streams_uni: VarInt

Initial maximum number of unidirectional streams the peer may initiate

ack_delay_exponent: VarInt

Exponent used to decode the ACK Delay field in the ACK frame

max_ack_delay: VarInt

Maximum amount of time in milliseconds by which the endpoint will delay sending acknowledgments

active_connection_id_limit: VarInt

Maximum number of connection IDs from the peer that an endpoint is willing to store

disable_active_migration: bool

Does the endpoint support active connection migration

max_datagram_frame_size: Option<VarInt>

Maximum size for datagram frames

initial_src_cid: Option<ConnectionId>

The value that the endpoint included in the Source Connection ID field of the first Initial packet it sends for the connection

grease_quic_bit: bool

The endpoint is willing to receive QUIC packets containing any value for the fixed bit

min_ack_delay: Option<VarInt>

Minimum amount of time in microseconds by which the endpoint is able to delay sending acknowledgments

If a value is provided, it implies that the endpoint supports QUIC Acknowledgement Frequency

version_information: Option<VersionInformation>

The version the endpoint chose and the versions it can work with (RFC 9368 3)

original_dst_cid: Option<ConnectionId>

The value of the Destination Connection ID field from the first Initial packet sent by the client

retry_src_cid: Option<ConnectionId>

The value that the server included in the Source Connection ID field of a Retry packet

stateless_reset_token: Option<ResetToken>

Token used by the client to verify a stateless reset from the server

preferred_address: Option<PreferredAddress>

The server’s preferred address for communication after handshake completion

grease_transport_parameter: Option<ReservedTransportParameter>

The randomly generated reserved transport parameter to sustain future extensibility of transport parameter extensions. When present, it is included during serialization but ignored during deserialization.

extra: Vec<(u64, Vec<u8>)>

Parameters this crate does not interpret, written as given (a profile’s extras).

write_plan: Option<Vec<WriteSlot>>

The order in which transport parameters are serialized, one slot per parameter.

Set only for outgoing TransportParameters; None for received ones.

Implementations



impl TransportParameters

pub fn default() -> TransportParameters

Standard defaults, used if the peer does not supply a given parameter.



impl TransportParameters

pub fn plan(&self, order: &ParameterOrder, rng: &mut impl Rng) -> Vec<WriteSlot>

The order to write in: the profile’s, with what it does not name after it.

pub fn validate_resumption_from( &self, cached: &TransportParameters, ) -> Result<(), Error>

Check that these parameters are legal when resuming from certain cached parameters



impl TransportParameters

pub fn write<W>(&self, w: &mut W)
where W: BufMut,

Encode TransportParameters into buffer

pub fn read<R>(side: Side, r: &mut R) -> Result<TransportParameters, Error>
where R: Buf,

Decode the peer’s transport parameters. side is the local endpoint’s role.