Enum VersionPolicyError
#[non_exhaustive]pub enum VersionPolicyError {
MissingOriginal,
Empty,
Unknown(Version),
Reserved(Version),
Incompatible(Version, Version),
SwitchUnsupported,
}Available on crate feature
quic only.Expand description
Why a version policy is not usable.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MissingOriginal
A list must contain the version the first flight uses.
Empty
A list must not be empty.
Unknown(Version)
This crate does not implement the version.
Reserved(Version)
Reserved 0x?a?a?a?a versions are greased into lists, never listed as usable.
Incompatible(Version, Version)
Versions that are not compatible with each other cannot be offered for compatible negotiation (RFC 9368 2.2).
SwitchUnsupported
The TLS provider cannot change version during the handshake, so it can only offer the version it starts with.