Enum NegotiationEventView
pub enum NegotiationEventView<'a> {
VersionInformation(VersionInformationView<'a>),
AlpnInformation {
chosen_alpn: AlpnIdentifierView<'a>,
},
ParametersSet(ParametersSet),
ParametersRestored(RestoredParameters),
KeyUpdated(KeyChange),
KeyDiscarded(KeyChange),
}Available on crate features
quic and std only.Expand description
Version, ALPN, transport parameter, and traffic-key observations.
Variants
VersionInformation(VersionInformationView<'a>)
Versions advertised by either endpoint and the selected version.
AlpnInformation
The application protocol negotiated during the handshake.
Fields

chosen_alpn: AlpnIdentifierView<'a>Selected ALPN protocol identifier.
ParametersSet(ParametersSet)
Local or remote transport parameters became available.
ParametersRestored(RestoredParameters)
Remembered transport parameters were restored for session resumption.
KeyUpdated(KeyChange)
Packet-protection keys became available or advanced to a new generation.
KeyDiscarded(KeyChange)
Packet-protection keys were discarded.
Implementations
impl NegotiationEventView<'_>
impl NegotiationEventView<'_>
pub fn into_owned(self) -> NegotiationEventView<'static>
pub fn into_owned(self) -> NegotiationEventView<'static>
Retain this event, copying borrowed storage and moving existing owned storage.
pub fn owned_heap_size(&self) -> usize
pub fn owned_heap_size(&self) -> usize
Conservative heap bytes needed when retaining this value, including existing spare capacity.