Enum LifecycleEventView
pub enum LifecycleEventView<'a> {
Started {
local: TupleEndpointInfo,
remote: TupleEndpointInfo,
},
StateUpdated {
old: Option<ConnectionState>,
new: ConnectionState,
},
Closed(ConnectionClosedView<'a>),
}Available on crate features
quic and std only.Expand description
Connection start, state transition, and closure observations.
Variants
Started
A connection began on the reported endpoints.
Fields

local: TupleEndpointInfoLocal endpoint address and initial connection ID.

remote: TupleEndpointInfoRemote endpoint address and initial connection ID.
StateUpdated
The connection entered a new lifecycle state.
Fields

old: Option<ConnectionState>Previous lifecycle state, when known.

new: ConnectionStateNewly entered lifecycle state.
Closed(ConnectionClosedView<'a>)
Connection closure and its diagnostic details.
Implementations
impl LifecycleEventView<'_>
impl LifecycleEventView<'_>
pub fn into_owned(self) -> LifecycleEventView<'static>
pub fn into_owned(self) -> LifecycleEventView<'static>
Retain this event, copying borrowed storage and moving existing owned storage.
pub fn owned_heap_size(&self) -> usize
pub fn owned_heap_size(&self) -> usize
Conservative heap bytes needed when retaining this value, including existing spare capacity.