Enum VersionListView
pub enum VersionListView<'a> {
Host(Cow<'a, [u32]>),
Network(Cow<'a, [[u8; 4]]>),
}Available on crate features
quic and std only.Expand description
A version list in its existing host or wire representation, without conversion at capture.
Variants
Host(Cow<'a, [u32]>)
Version identifiers stored as host-order integers.
Network(Cow<'a, [[u8; 4]]>)
Version identifiers stored as network-order four-byte values.
Implementations
impl VersionListView<'_>
impl VersionListView<'_>
pub fn into_owned(self) -> VersionListView<'static>
pub fn into_owned(self) -> VersionListView<'static>
Retain this list, copying borrowed storage and moving existing owned storage.
pub fn owned_heap_size(&self) -> usize
pub fn owned_heap_size(&self) -> usize
Conservative heap bytes needed when retaining this value, including existing spare capacity.