Struct RestoredParameters
pub struct RestoredParameters {
pub disable_active_migration: bool,
pub max_idle_timeout: u64,
pub max_udp_payload_size: u64,
pub active_connection_id_limit: u64,
pub initial_max_data: u64,
pub initial_max_stream_data_bidi_local: u64,
pub initial_max_stream_data_bidi_remote: u64,
pub initial_max_stream_data_uni: u64,
pub initial_max_streams_bidi: u64,
pub initial_max_streams_uni: u64,
pub max_datagram_frame_size: Option<u64>,
pub grease_quic_bit: bool,
}quic and std only.Expand description
Remembered transport parameters restored by the implementation. Local and remote stream directions are relative to the endpoint advertising these parameters.
Fields
disable_active_migration: boolWhether the advertising endpoint prohibits peer-initiated active migration.
max_idle_timeout: u64Advertised maximum idle timeout, in milliseconds; zero disables this timeout.
max_udp_payload_size: u64Largest UDP payload the advertising endpoint accepts, in bytes.
active_connection_id_limit: u64Maximum peer-issued connection IDs the advertising endpoint retains.
initial_max_data: u64Initial connection-wide receive credit, in bytes.
initial_max_stream_data_bidi_local: u64Initial receive credit for locally initiated bidirectional streams, in bytes.
initial_max_stream_data_bidi_remote: u64Initial receive credit for remotely initiated bidirectional streams, in bytes.
initial_max_stream_data_uni: u64Initial receive credit per remotely initiated unidirectional stream, in bytes.
initial_max_streams_bidi: u64Initial number of bidirectional streams the peer may open.
initial_max_streams_uni: u64Initial number of unidirectional streams the peer may open.
max_datagram_frame_size: Option<u64>Largest accepted DATAGRAM frame, including its header, in bytes.
grease_quic_bit: boolWhether the endpoint accepts a cleared QUIC fixed bit.