NegotiationEvent

Type Alias NegotiationEvent 

pub type NegotiationEvent = NegotiationEventView<'static>;
Available on crate features quic and std only.
Negotiation event with owned or static backing storage.

Aliased Type

pub enum NegotiationEvent {
    VersionInformation(VersionInformationView<'static>),
    AlpnInformation {
        chosen_alpn: AlpnIdentifierView<'static>,
    },
    ParametersSet(ParametersSet),
    ParametersRestored(RestoredParameters),
    KeyUpdated(KeyChange),
    KeyDiscarded(KeyChange),
}

Variants



VersionInformation(VersionInformationView<'static>)

Versions advertised by either endpoint and the selected version.



AlpnInformation

The application protocol negotiated during the handshake.

Fields

chosen_alpn: AlpnIdentifierView<'static>

Selected ALPN protocol identifier.



ParametersSet(ParametersSet)

Local or remote transport parameters became available.



ParametersRestored(RestoredParameters)

Remembered transport parameters were restored for session resumption.



KeyUpdated(KeyChange)

Packet-protection keys became available or advanced to a new generation.



KeyDiscarded(KeyChange)

Packet-protection keys were discarded.