VersionInformation

Type Alias VersionInformation 

pub type VersionInformation = VersionInformationView<'static>;
Available on crate features quic and std only.
Version information with owned or static backing storage.

Aliased Type

pub struct VersionInformation {
    pub server_versions: Option<VersionListView<'static>>,
    pub client_versions: Option<VersionListView<'static>>,
    pub chosen_version: Option<Version>,
}

Fields

server_versions: Option<VersionListView<'static>>

Versions advertised or supported by the server, when known.

client_versions: Option<VersionListView<'static>>

Versions advertised or supported by the client, when known.

chosen_version: Option<Version>

Selected QUIC version, when known.