EventFields

Type Alias EventFields 

pub type EventFields = EventFieldsView<'static>;
Available on crate features quic and std only.
Event fields whose backing storage is owned or static.

Aliased Type

pub struct EventFields {
    pub tuple: Option<TupleId>,
    pub event: EventView<'static>,
}

Fields

tuple: Option<TupleId>

Explicit network tuple, omitted for the initial handshake tuple.

event: EventView<'static>

Event name and schema-specific data.