read_from

Function read_from 

pub fn read_from(
    reader: impl Read,
    limits: ReadLimits,
) -> Result<QlogFile, Box<dyn Error + Sync + Send>>
Available on crate features quic and std only.
Read a qlog file from a stream, collecting its events.

A whole capture is held in memory. Use read_streaming to consume events as they are decoded, which is what a viewer of a large file wants.