Struct TraceInfo
pub struct TraceInfo {
pub title: Option<ArcStr>,
pub description: Option<ArcStr>,
pub start_time: Instant,
}Available on crate features
quic and std only.Expand description
Metadata shared by the events in a recorder’s output.
Fields
title: Option<ArcStr>Short label for the output trace. Static labels can use arcstr!.
description: Option<ArcStr>Optional context for the trace, shared across metadata clones.
start_time: InstantMonotonic epoch used to express event timestamps as elapsed milliseconds.