Struct ApplicationClose
pub struct ApplicationClose { /* private fields */ }Available on crate features
quic and std only.Expand description
Reason given by an application for closing the connection
Implementations
impl ApplicationClose
impl ApplicationClose
pub fn error_code(&self) -> VarInt
pub fn error_code(&self) -> VarInt
The code the application gave, which means whatever the two applications agreed.