Struct ConnectionStats
#[non_exhaustive]pub struct ConnectionStats {
pub udp_tx: UdpStats,
pub udp_rx: UdpStats,
pub frame_tx: FrameStats,
pub frame_rx: FrameStats,
pub path: PathStats,
pub key_updates: u64,
}Available on crate features
quic and std only.Expand description
Connection statistics
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.udp_tx: UdpStatsStatistics about UDP datagrams transmitted on a connection
udp_rx: UdpStatsStatistics about UDP datagrams received on a connection
frame_tx: FrameStatsHow many frames of each kind this connection has sent.
frame_rx: FrameStatsHow many frames of each kind it has received.
path: PathStatsStatistics related to the current transmission path
key_updates: u64How many times this connection’s traffic keys were updated (RFC 9001 6), whether the update was asked for locally, forced by the usage limit, or started by the peer.