Incoming

Struct Incoming 

pub struct Incoming(/* private fields */);
Available on crate features quic and std only.
An incoming connection for which the server has not yet begun its part of the handshake

Implementations



impl Incoming

pub fn accept(self) -> Result<Connecting, ConnectionError>

Attempt to accept this incoming connection (an error may still occur)

pub fn accept_with( self, server_config: Arc<ServerConfig>, ) -> Result<Connecting, ConnectionError>

Accept this incoming connection using a custom configuration

See accept() for more details.

pub fn refuse(self)

Reject this incoming connection attempt

pub fn retry(self) -> Result<(), RetryError>

Respond with a retry packet, requiring the client to retry with address validation

Errors if may_retry() is false.

pub fn ignore(self)

Ignore this incoming connection attempt, not sending any packet in response

pub fn local_ip(&self) -> Option<IpAddr>

The local IP address which was used when the peer established the connection

pub fn remote_address(&self) -> SocketAddr

The peer’s UDP address

pub fn remote_address_validated(&self) -> bool

Whether the socket address that is initiating this connection has been validated

This means that the sender of the initial packet has proved that they can receive traffic sent to self.remote_address().

Before expiry, if self.remote_address_validated() is false, self.may_retry() is true. The inverse is not guaranteed.

pub fn is_expired(&self) -> bool

Whether this pending attempt has expired or was retired by endpoint shutdown.

pub fn may_retry(&self) -> bool

Whether it is legal to respond with a retry packet

Before expiry, if self.remote_address_validated() is false, self.may_retry() is true. The inverse is not guaranteed.

pub fn orig_dst_cid(&self) -> ConnectionId

The original destination CID when initiating the connection