RandomConnectionIdGenerator

Struct RandomConnectionIdGenerator 

pub struct RandomConnectionIdGenerator { /* private fields */ }
Available on crate features quic and std only.
Generates purely random connection IDs of a specified length

Random CIDs can be smaller than those produced by HashedConnectionIdGenerator, but cannot be usefully validated.

Implementations



impl RandomConnectionIdGenerator

pub fn new(cid_len: usize) -> Result<RandomConnectionIdGenerator, ConfigError>

A generator of identifiers cid_len bytes long, at most MAX_CID_SIZE.

Fails for a longer length, which QUIC has no room for (RFC 9000 17.2).

pub fn of_max_size() -> RandomConnectionIdGenerator

A generator of identifiers of the longest size QUIC carries.

pub fn maybe_with_lifetime( self, lifetime: Option<Duration>, ) -> RandomConnectionIdGenerator

How long the identifiers this generator creates are used before they are retired.

None, the default, retires them only when the peer or the protocol asks.

pub fn maybe_set_lifetime( &mut self, lifetime: Option<Duration>, ) -> &mut RandomConnectionIdGenerator

How long the identifiers this generator creates are used before they are retired.

None, the default, retires them only when the peer or the protocol asks.

pub fn with_lifetime(self, lifetime: Duration) -> RandomConnectionIdGenerator

How long the identifiers this generator creates are used before they are retired.

None, the default, retires them only when the peer or the protocol asks.

pub fn set_lifetime( &mut self, lifetime: Duration, ) -> &mut RandomConnectionIdGenerator

How long the identifiers this generator creates are used before they are retired.

None, the default, retires them only when the peer or the protocol asks.

pub fn without_lifetime(self) -> RandomConnectionIdGenerator

How long the identifiers this generator creates are used before they are retired.

None, the default, retires them only when the peer or the protocol asks.

pub fn unset_lifetime(&mut self) -> &mut RandomConnectionIdGenerator

How long the identifiers this generator creates are used before they are retired.

None, the default, retires them only when the peer or the protocol asks.