Struct StreamAbortHandle
pub struct StreamAbortHandle { /* private fields */ }Available on crate features
quic and std only.Expand description
Cloneable cancellation handle independent of the stream’s I/O owner. It resets sending and, for bidirectional streams, stops receiving. Dropping the handle has no effect on the stream.
Implementations
impl StreamAbortHandle
impl StreamAbortHandle