Enum AlpnPolicy
pub enum AlpnPolicy {
Require,
OutOfBandAgreement,
}Available on crate feature
quic and crate feature rustls and crate feature std and (crate features aws-lc or ring) only.Expand description
How the application protocol is agreed for a connection.
Variants
Require
Require a nonempty ALPN offer and a negotiated protocol on both peers.
OutOfBandAgreement
The application has explicitly agreed the protocol through another mechanism.