Enum HandshakeEvent
pub enum HandshakeEvent {
Data(SpaceId, Vec<u8>),
Keys(SpaceId, Keys),
ReadKeys(SpaceId, DirectionalKeys),
}Available on crate features
quic and std only.Expand description
Ordered TLS output and packet-key installation events.
Variants
Data(SpaceId, Vec<u8>)
Handshake bytes to send at this encryption level before subsequent events.
Keys(SpaceId, Keys)
Install write keys and any already available read keys for this level.
ReadKeys(SpaceId, DirectionalKeys)
Install read keys that became available after the write keys.