Struct NoInitialCipherSuite
pub struct NoInitialCipherSuite { /* private fields */ }Available on crate feature
quic and crate feature rustls and crate feature std and (crate features aws-lc or ring) only.Expand description
The initial cipher suite (AES-128-GCM-SHA256) is not available
A configuration built with its own initial cipher suite must use
TLS13_AES_128_GCM_SHA256. When the cipher suite is derived from a config’s
CryptoProvider, that provider must reference a cipher suite with the same ID.