Struct RustlsTlsProvider
pub struct RustlsTlsProvider { /* private fields */ }Available on crate feature
quic and crate feature rustls and crate feature std and (crate features aws-lc or ring) only.Expand description
Rustls QUIC configuration factory with an explicitly supplied cryptographic provider.
The adapter still requires the ring or aws-lc feature for its packet crypto.
Supplying a provider here does not install or use Rustls’s process-wide default.
Implementations
impl RustlsTlsProvider
impl RustlsTlsProvider
pub fn new(crypto: Arc<CryptoProvider>) -> RustlsTlsProvider