Struct TlsOptions
pub struct TlsOptions { /* private fields */ }Available on crate feature
quic and crate feature rustls and crate feature std and (crate features aws-lc or ring) only.Implementations
impl TlsOptions
impl TlsOptions
pub fn with_alpn(self, policy: AlpnPolicy) -> TlsOptions
pub fn with_alpn(self, policy: AlpnPolicy) -> TlsOptions
How the application protocol is agreed for connections built with this configuration.
pub fn set_alpn(&mut self, policy: AlpnPolicy) -> &mut TlsOptions
pub fn set_alpn(&mut self, policy: AlpnPolicy) -> &mut TlsOptions
How the application protocol is agreed for connections built with this configuration.
pub fn with_early_data(self, allowed: bool) -> TlsOptions
pub fn with_early_data(self, allowed: bool) -> TlsOptions
Allow early application data, which a peer may replay. Off unless asked for.
pub fn set_early_data(&mut self, allowed: bool) -> &mut TlsOptions
pub fn set_early_data(&mut self, allowed: bool) -> &mut TlsOptions
Allow early application data, which a peer may replay. Off unless asked for.