Enum RuntimeFlavor
#[non_exhaustive]pub enum RuntimeFlavor {
CurrentThread,
MultiThread {
worker_threads: usize,
},
}Available on crate feature
std only.Expand description
The Tokio scheduler used by a Runtime.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
CurrentThread
A single-thread scheduler, driven continuously by the runtime owner thread.
MultiThread
A multi-thread scheduler with the requested number of worker threads.