Struct Sender
pub struct Sender { /* private fields */ }Available on crate feature
std only.Expand description
Sender of the simplex channel.
Cancellation safety
The Sender is cancel safe. If it is used as the event in a
tokio::select! statement and some other branch
completes first, it is guaranteed that no bytes were sent on this
channel.
Shutdown