Struct ParseConfig
pub struct ParseConfig { /* private fields */ }Expand description
Configuration for the NDJSON-parser which controls the behavior in various situations.
By default, the parser will skip empty lines (EmptyLineHandling::IgnoreEmpty) and accept
lines of unbounded size. The unbounded line size is safe only for trusted input — when
parsing data from an untrusted peer (e.g. a remote proxy backend), set
ParseConfig::with_max_line_bytes to bound memory usage. Oversized lines are reported as a
parse error and the engine resyncs to the next newline so subsequent lines can still be
decoded.
You can construct a config by first calling ParseConfig::default and then using the
builder-style associated functions to configure it. See the example below.
Implementations
impl ParseConfig
impl ParseConfig
pub fn with_empty_line_handling(
self,
empty_line_handling: EmptyLineHandling,
) -> ParseConfig
pub fn with_empty_line_handling( self, empty_line_handling: EmptyLineHandling, ) -> ParseConfig
Creates a new config from this config which has a different handling for lines that contain no JSON values. See EmptyLineHandling for more details.
Returns
A new config with all the same values as this one, except the empty-line-handling.
pub fn set_empty_line_handling(
&mut self,
empty_line_handling: EmptyLineHandling,
) -> &mut ParseConfig
pub fn set_empty_line_handling( &mut self, empty_line_handling: EmptyLineHandling, ) -> &mut ParseConfig
Creates a new config from this config which has a different handling for lines that contain no JSON values. See EmptyLineHandling for more details.
Returns
A new config with all the same values as this one, except the empty-line-handling.
pub fn with_parse_rest(self, parse_rest: bool) -> ParseConfig
pub fn with_parse_rest(self, parse_rest: bool) -> ParseConfig
Creates a new config from this config which has the given configuration on whether to parse
or ignore the rest, i.e. the part after the last newline character. If parse_rest is set
to false, the rest will always be ignored, while true causes it to only be ignored if it
is empty or considered empty by the handling configured in
ParseConfig::with_empty_line_handling, which by default is only truly empty. Otherwise,
the rest is parsed like an ordinary JSON record. By default, this is set to true.
Returns
A new config with all the same values as this one, except the parse-rest-flag.
pub fn set_parse_rest(&mut self, parse_rest: bool) -> &mut ParseConfig
pub fn set_parse_rest(&mut self, parse_rest: bool) -> &mut ParseConfig
Creates a new config from this config which has the given configuration on whether to parse
or ignore the rest, i.e. the part after the last newline character. If parse_rest is set
to false, the rest will always be ignored, while true causes it to only be ignored if it
is empty or considered empty by the handling configured in
ParseConfig::with_empty_line_handling, which by default is only truly empty. Otherwise,
the rest is parsed like an ordinary JSON record. By default, this is set to true.
Returns
A new config with all the same values as this one, except the parse-rest-flag.
pub fn maybe_with_max_line_bytes(
self,
max_line_bytes: Option<NonZero<usize>>,
) -> ParseConfig
pub fn maybe_with_max_line_bytes( self, max_line_bytes: Option<NonZero<usize>>, ) -> ParseConfig
Caps the size of a single NDJSON line. When the accumulated bytes for a single line
(i.e. between two \n characters) exceed this limit, the engine emits a parse error
and resynchronises to the next newline; subsequent lines can still be decoded.
None (the default) means no limit — appropriate only for trusted input sources.
Set this for any NDJSON stream sourced from an untrusted peer to avoid unbounded
memory growth from a peer that never sends a \n.
Returns
A new config with all the same values as this one, except the max-line-bytes.
pub fn maybe_set_max_line_bytes(
&mut self,
max_line_bytes: Option<NonZero<usize>>,
) -> &mut ParseConfig
pub fn maybe_set_max_line_bytes( &mut self, max_line_bytes: Option<NonZero<usize>>, ) -> &mut ParseConfig
Caps the size of a single NDJSON line. When the accumulated bytes for a single line
(i.e. between two \n characters) exceed this limit, the engine emits a parse error
and resynchronises to the next newline; subsequent lines can still be decoded.
None (the default) means no limit — appropriate only for trusted input sources.
Set this for any NDJSON stream sourced from an untrusted peer to avoid unbounded
memory growth from a peer that never sends a \n.
Returns
A new config with all the same values as this one, except the max-line-bytes.
pub fn with_max_line_bytes(self, max_line_bytes: NonZero<usize>) -> ParseConfig
pub fn with_max_line_bytes(self, max_line_bytes: NonZero<usize>) -> ParseConfig
Caps the size of a single NDJSON line. When the accumulated bytes for a single line
(i.e. between two \n characters) exceed this limit, the engine emits a parse error
and resynchronises to the next newline; subsequent lines can still be decoded.
None (the default) means no limit — appropriate only for trusted input sources.
Set this for any NDJSON stream sourced from an untrusted peer to avoid unbounded
memory growth from a peer that never sends a \n.
Returns
A new config with all the same values as this one, except the max-line-bytes.
pub fn set_max_line_bytes(
&mut self,
max_line_bytes: NonZero<usize>,
) -> &mut ParseConfig
pub fn set_max_line_bytes( &mut self, max_line_bytes: NonZero<usize>, ) -> &mut ParseConfig
Caps the size of a single NDJSON line. When the accumulated bytes for a single line
(i.e. between two \n characters) exceed this limit, the engine emits a parse error
and resynchronises to the next newline; subsequent lines can still be decoded.
None (the default) means no limit — appropriate only for trusted input sources.
Set this for any NDJSON stream sourced from an untrusted peer to avoid unbounded
memory growth from a peer that never sends a \n.
Returns
A new config with all the same values as this one, except the max-line-bytes.
pub fn without_max_line_bytes(self) -> ParseConfig
pub fn without_max_line_bytes(self) -> ParseConfig
Caps the size of a single NDJSON line. When the accumulated bytes for a single line
(i.e. between two \n characters) exceed this limit, the engine emits a parse error
and resynchronises to the next newline; subsequent lines can still be decoded.
None (the default) means no limit — appropriate only for trusted input sources.
Set this for any NDJSON stream sourced from an untrusted peer to avoid unbounded
memory growth from a peer that never sends a \n.
Returns
A new config with all the same values as this one, except the max-line-bytes.
pub fn unset_max_line_bytes(&mut self) -> &mut ParseConfig
pub fn unset_max_line_bytes(&mut self) -> &mut ParseConfig
Caps the size of a single NDJSON line. When the accumulated bytes for a single line
(i.e. between two \n characters) exceed this limit, the engine emits a parse error
and resynchronises to the next newline; subsequent lines can still be decoded.
None (the default) means no limit — appropriate only for trusted input sources.
Set this for any NDJSON stream sourced from an untrusted peer to avoid unbounded
memory growth from a peer that never sends a \n.
Returns
A new config with all the same values as this one, except the max-line-bytes.