Struct StreamForwardService
pub struct StreamForwardService { /* private fields */ }Expand description
A Service which takes a StreamBridge and pumps frames between
the two endpoints bidirectionally.
The service optionally observes a ShutdownGuard (for graceful
termination) and an idle timeout that closes the bridge when no frame
has been forwarded in either direction within the configured window.
Returns a BridgeCloseReason describing why the bridge ended.
Implementations
impl StreamForwardService
impl StreamForwardService
pub fn new() -> StreamForwardService
pub fn new() -> StreamForwardService
Create a new StreamForwardService with no idle timeout and no
shutdown guard. Equivalent to StreamForwardService::default.
pub fn maybe_with_idle_timeout(
self,
timeout: Option<Duration>,
) -> StreamForwardService
pub fn maybe_with_idle_timeout( self, timeout: Option<Duration>, ) -> StreamForwardService
Idle timeout. When set, the bridge closes with reason
BridgeCloseReason::IdleTimeout if no frame has been
forwarded in either direction within timeout.
None (the default) disables idle detection.
pub fn maybe_set_idle_timeout(
&mut self,
timeout: Option<Duration>,
) -> &mut StreamForwardService
pub fn maybe_set_idle_timeout( &mut self, timeout: Option<Duration>, ) -> &mut StreamForwardService
Idle timeout. When set, the bridge closes with reason
BridgeCloseReason::IdleTimeout if no frame has been
forwarded in either direction within timeout.
None (the default) disables idle detection.
pub fn with_idle_timeout(self, timeout: Duration) -> StreamForwardService
pub fn with_idle_timeout(self, timeout: Duration) -> StreamForwardService
Idle timeout. When set, the bridge closes with reason
BridgeCloseReason::IdleTimeout if no frame has been
forwarded in either direction within timeout.
None (the default) disables idle detection.
pub fn set_idle_timeout(
&mut self,
timeout: Duration,
) -> &mut StreamForwardService
pub fn set_idle_timeout( &mut self, timeout: Duration, ) -> &mut StreamForwardService
Idle timeout. When set, the bridge closes with reason
BridgeCloseReason::IdleTimeout if no frame has been
forwarded in either direction within timeout.
None (the default) disables idle detection.
pub fn without_idle_timeout(self) -> StreamForwardService
pub fn without_idle_timeout(self) -> StreamForwardService
Idle timeout. When set, the bridge closes with reason
BridgeCloseReason::IdleTimeout if no frame has been
forwarded in either direction within timeout.
None (the default) disables idle detection.
pub fn unset_idle_timeout(&mut self) -> &mut StreamForwardService
pub fn unset_idle_timeout(&mut self) -> &mut StreamForwardService
Idle timeout. When set, the bridge closes with reason
BridgeCloseReason::IdleTimeout if no frame has been
forwarded in either direction within timeout.
None (the default) disables idle detection.
pub fn maybe_with_shutdown_guard(
self,
guard: Option<ShutdownGuard>,
) -> StreamForwardService
pub fn maybe_with_shutdown_guard( self, guard: Option<ShutdownGuard>, ) -> StreamForwardService
ShutdownGuard used to observe graceful-shutdown signals.
When the guard fires, the bridge closes with reason
BridgeCloseReason::Shutdown.
None (the default) means no shutdown observation.
pub fn maybe_set_shutdown_guard(
&mut self,
guard: Option<ShutdownGuard>,
) -> &mut StreamForwardService
pub fn maybe_set_shutdown_guard( &mut self, guard: Option<ShutdownGuard>, ) -> &mut StreamForwardService
ShutdownGuard used to observe graceful-shutdown signals.
When the guard fires, the bridge closes with reason
BridgeCloseReason::Shutdown.
None (the default) means no shutdown observation.
pub fn with_shutdown_guard(self, guard: ShutdownGuard) -> StreamForwardService
pub fn with_shutdown_guard(self, guard: ShutdownGuard) -> StreamForwardService
ShutdownGuard used to observe graceful-shutdown signals.
When the guard fires, the bridge closes with reason
BridgeCloseReason::Shutdown.
None (the default) means no shutdown observation.
pub fn set_shutdown_guard(
&mut self,
guard: ShutdownGuard,
) -> &mut StreamForwardService
pub fn set_shutdown_guard( &mut self, guard: ShutdownGuard, ) -> &mut StreamForwardService
ShutdownGuard used to observe graceful-shutdown signals.
When the guard fires, the bridge closes with reason
BridgeCloseReason::Shutdown.
None (the default) means no shutdown observation.
pub fn without_shutdown_guard(self) -> StreamForwardService
pub fn without_shutdown_guard(self) -> StreamForwardService
ShutdownGuard used to observe graceful-shutdown signals.
When the guard fires, the bridge closes with reason
BridgeCloseReason::Shutdown.
None (the default) means no shutdown observation.
pub fn unset_shutdown_guard(&mut self) -> &mut StreamForwardService
pub fn unset_shutdown_guard(&mut self) -> &mut StreamForwardService
ShutdownGuard used to observe graceful-shutdown signals.
When the guard fires, the bridge closes with reason
BridgeCloseReason::Shutdown.
None (the default) means no shutdown observation.