Stream

Trait Stream 

pub trait Stream {
    type Item;

    // Required method
    fn poll_next(
        self: Pin<&mut Self>,
        cx: &mut Context<'_>,
    ) -> Poll<Option<Self::Item>>;

    // Provided method
    fn size_hint(&self) -> (usize, Option<usize>) { ... }
}
Available on crate feature std only.
A stream of values produced asynchronously.

If Future<Output = T> is an asynchronous version of T, then Stream<Item = T> is an asynchronous version of Iterator<Item = T>. A stream represents a sequence of value-producing events that occur asynchronously to the caller.

The trait is modeled after Future, but allows poll_next to be called even after a value has been produced, yielding None once the stream has been fully exhausted.

Required Associated Types

type Item

Values yielded by the stream.

Required Methods

fn poll_next( self: Pin<&mut Self>, cx: &mut Context<'_>, ) -> Poll<Option<Self::Item>>

Attempt to pull out the next value of this stream, registering the current task for wakeup if the value is not yet available, and returning None if the stream is exhausted.

Return value

There are several possible return values, each indicating a distinct stream state:

  • Poll::Pending means that this stream’s next value is not ready yet. Implementations will ensure that the current task will be notified when the next value may be ready.

  • Poll::Ready(Some(val)) means that the stream has successfully produced a value, val, and may produce further values on subsequent poll_next calls.

  • Poll::Ready(None) means that the stream has terminated, and poll_next should not be invoked again.

Panics

Once a stream has finished (returned Ready(None) from poll_next), calling its poll_next method again may panic, block forever, or cause other kinds of problems; the Stream trait places no requirements on the effects of such a call. However, as the poll_next method is not marked unsafe, Rust’s usual rules apply: calls must never cause undefined behavior (memory corruption, incorrect use of unsafe functions, or the like), regardless of the stream’s state.

If this is difficult to guard against then the fuse adapter can be used to ensure that poll_next always returns Ready(None) in subsequent calls.

Provided Methods

fn size_hint(&self) -> (usize, Option<usize>)

Returns the bounds on the remaining length of the stream.

Specifically, size_hint() returns a tuple where the first element is the lower bound, and the second element is the upper bound.

The second half of the tuple that is returned is an Option<usize>. A None here means that either there is no known upper bound, or the upper bound is larger than usize.

Implementation notes

It is not enforced that a stream implementation yields the declared number of elements. A buggy stream may yield less than the lower bound or more than the upper bound of elements.

size_hint() is primarily intended to be used for optimizations such as reserving space for the elements of the stream, but must not be trusted to e.g., omit bounds checks in unsafe code. An incorrect implementation of size_hint() should not lead to memory safety violations.

That said, the implementation should provide a correct estimation, because otherwise it would be a violation of the trait’s protocol.

The default implementation returns (0, None) which is correct for any stream.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types



impl Stream for Field<'_>



type Item = Result<Bytes, Error>



fn poll_next( self: Pin<&mut Field<'_>>, cx: &mut Context<'_>, ) -> Poll<Option<<Field<'_> as Stream>::Item>>



impl Stream for PollSemaphore



type Item = OwnedSemaphorePermit



fn poll_next( self: Pin<&mut PollSemaphore>, cx: &mut Context<'_>, ) -> Poll<Option<OwnedSemaphorePermit>>



impl<'a, S, T> Stream for Cloned<S>
where T: 'a + Clone, S: Stream<Item = &'a T>,



type Item = T



fn poll_next( self: Pin<&mut Cloned<S>>, cx: &mut Context<'_>, ) -> Poll<Option<<Cloned<S> as Stream>::Item>>



impl<'a, S, T> Stream for Copied<S>
where T: 'a + Copy, S: Stream<Item = &'a T>,



type Item = T



fn poll_next( self: Pin<&mut Copied<S>>, cx: &mut Context<'_>, ) -> Poll<Option<<Copied<S> as Stream>::Item>>



impl<'a, T> Stream for RecvStream<'a, T>



type Item = T



fn poll_next( self: Pin<&mut RecvStream<'a, T>>, cx: &mut Context<'_>, ) -> Poll<Option<<RecvStream<'a, T> as Stream>::Item>>



impl<A, B> Stream for Zip<A, B>
where A: Stream, B: Stream,



type Item = (<A as Stream>::Item, <B as Stream>::Item)



fn poll_next( self: Pin<&mut Zip<A, B>>, cx: &mut Context<'_>, ) -> Poll<Option<<Zip<A, B> as Stream>::Item>>



impl<B, S, P> Stream for MapWhile<S, P>
where S: Stream, P: FnMut(<S as Stream>::Item) -> Option<B>,



type Item = B



fn poll_next( self: Pin<&mut MapWhile<S, P>>, cx: &mut Context<'_>, ) -> Poll<Option<<MapWhile<S, P> as Stream>::Item>>



impl<F> Stream for FutureGroup<F>
where F: Future,



type Item = <F as Future>::Output



fn poll_next( self: Pin<&mut FutureGroup<F>>, cx: &mut Context<'_>, ) -> Poll<Option<<FutureGroup<F> as Stream>::Item>>



impl<F> Stream for Keyed<F>
where F: Future,



type Item = (Key, <F as Future>::Output)



fn poll_next( self: Pin<&mut Keyed<F>>, cx: &mut Context<'_>, ) -> Poll<Option<<Keyed<F> as Stream>::Item>>



impl<F> Stream for OnceFuture<F>
where F: Future,



type Item = <F as Future>::Output



fn poll_next( self: Pin<&mut OnceFuture<F>>, cx: &mut Context<'_>, ) -> Poll<Option<<OnceFuture<F> as Stream>::Item>>



impl<I> Stream for Iter<I>
where I: Iterator,



type Item = <I as Iterator>::Item



fn poll_next( self: Pin<&mut Iter<I>>, _cx: &mut Context<'_>, ) -> Poll<Option<<Iter<I> as Stream>::Item>>



fn size_hint(&self) -> (usize, Option<usize>)



impl<L, R> Stream for Either<L, R>
where L: Stream, R: Stream<Item = <L as Stream>::Item>,



type Item = <L as Stream>::Item



fn poll_next( self: Pin<&mut Either<L, R>>, cx: &mut Context<'_>, ) -> Poll<Option<<Either<L, R> as Stream>::Item>>



impl<P> Stream for Pin<P>
where P: DerefMut + Unpin, <P as Deref>::Target: Stream,



type Item = <<P as Deref>::Target as Stream>::Item



fn poll_next( self: Pin<&mut Pin<P>>, cx: &mut Context<'_>, ) -> Poll<Option<<Pin<P> as Stream>::Item>>



fn size_hint(&self) -> (usize, Option<usize>)



impl<R> Stream for Bytes<R>
where R: AsyncRead + Unpin,



type Item = Result<u8, Error>



fn poll_next( self: Pin<&mut Bytes<R>>, cx: &mut Context<'_>, ) -> Poll<Option<<Bytes<R> as Stream>::Item>>



impl<R> Stream for Lines<R>
where R: AsyncBufRead,



type Item = Result<String, Error>



fn poll_next( self: Pin<&mut Lines<R>>, cx: &mut Context<'_>, ) -> Poll<Option<<Lines<R> as Stream>::Item>>



impl<R> Stream for Split<R>
where R: AsyncBufRead,



type Item = Result<Vec<u8>, Error>



fn poll_next( self: Pin<&mut Split<R>>, cx: &mut Context<'_>, ) -> Poll<Option<<Split<R> as Stream>::Item>>



impl<S, D> Stream for WaitUntil<S, D>
where S: Stream, D: Future,



type Item = <S as Stream>::Item



fn poll_next( self: Pin<&mut WaitUntil<S, D>>, cx: &mut Context<'_>, ) -> Poll<Option<<WaitUntil<S, D> as Stream>::Item>>



impl<S, F, Fut> Stream for Then<S, F, Fut>
where S: Stream, F: FnMut(<S as Stream>::Item) -> Fut, Fut: Future,



type Item = <Fut as Future>::Output



fn poll_next( self: Pin<&mut Then<S, F, Fut>>, cx: &mut Context<'_>, ) -> Poll<Option<<Then<S, F, Fut> as Stream>::Item>>



fn size_hint(&self) -> (usize, Option<usize>)



impl<S, F, T> Stream for FilterMap<S, F>
where S: Stream, F: FnMut(<S as Stream>::Item) -> Option<T>,



type Item = T



fn poll_next( self: Pin<&mut FilterMap<S, F>>, cx: &mut Context<'_>, ) -> Poll<Option<<FilterMap<S, F> as Stream>::Item>>



impl<S, F, T> Stream for Map<S, F>
where S: Stream, F: FnMut(<S as Stream>::Item) -> T,



type Item = T



fn poll_next( self: Pin<&mut Map<S, F>>, cx: &mut Context<'_>, ) -> Poll<Option<<Map<S, F> as Stream>::Item>>



fn size_hint(&self) -> (usize, Option<usize>)



impl<S, F> Stream for Inspect<S, F>
where S: Stream, F: FnMut(&<S as Stream>::Item),



type Item = <S as Stream>::Item



fn poll_next( self: Pin<&mut Inspect<S, F>>, cx: &mut Context<'_>, ) -> Poll<Option<<Inspect<S, F> as Stream>::Item>>



impl<S, P> Stream for Filter<S, P>
where S: Stream, P: FnMut(&<S as Stream>::Item) -> bool,



type Item = <S as Stream>::Item



fn poll_next( self: Pin<&mut Filter<S, P>>, cx: &mut Context<'_>, ) -> Poll<Option<<Filter<S, P> as Stream>::Item>>



fn size_hint(&self) -> (usize, Option<usize>)



impl<S, P> Stream for SkipWhile<S, P>
where S: Stream, P: FnMut(&<S as Stream>::Item) -> bool,



type Item = <S as Stream>::Item



fn poll_next( self: Pin<&mut SkipWhile<S, P>>, cx: &mut Context<'_>, ) -> Poll<Option<<SkipWhile<S, P> as Stream>::Item>>



impl<S, P> Stream for TakeWhile<S, P>
where S: Stream, P: FnMut(&<S as Stream>::Item) -> bool,



type Item = <S as Stream>::Item



fn poll_next( self: Pin<&mut TakeWhile<S, P>>, cx: &mut Context<'_>, ) -> Poll<Option<<TakeWhile<S, P> as Stream>::Item>>



impl<S, St, F, B> Stream for Scan<S, St, F>
where S: Stream, F: FnMut(&mut St, <S as Stream>::Item) -> Option<B>,



type Item = B



fn poll_next( self: Pin<&mut Scan<S, St, F>>, cx: &mut Context<'_>, ) -> Poll<Option<B>>



impl<S, U, F> Stream for FlatMap<S, U, F>
where S: Stream, U: Stream, F: FnMut(<S as Stream>::Item) -> U,



type Item = <U as Stream>::Item



fn poll_next( self: Pin<&mut FlatMap<S, U, F>>, cx: &mut Context<'_>, ) -> Poll<Option<<FlatMap<S, U, F> as Stream>::Item>>



impl<S, U> Stream for Chain<S, U>
where S: Stream, U: Stream<Item = <S as Stream>::Item>,



type Item = <S as Stream>::Item



fn poll_next( self: Pin<&mut Chain<S, U>>, cx: &mut Context<'_>, ) -> Poll<Option<<Chain<S, U> as Stream>::Item>>



impl<S, U> Stream for Flatten<S>
where S: Stream<Item = U>, U: Stream,



type Item = <U as Stream>::Item



fn poll_next( self: Pin<&mut Flatten<S>>, cx: &mut Context<'_>, ) -> Poll<Option<<Flatten<S> as Stream>::Item>>



impl<S, const N: usize> Stream for Chain<S, N>
where S: Stream,



type Item = <S as Stream>::Item



fn poll_next( self: Pin<&mut Chain<S, N>>, cx: &mut Context<'_>, ) -> Poll<Option<<Chain<S, N> as Stream>::Item>>



impl<S, const N: usize> Stream for Merge<S, N>
where S: Stream,



type Item = <S as Stream>::Item



fn poll_next( self: Pin<&mut Merge<S, N>>, cx: &mut Context<'_>, ) -> Poll<Option<<Merge<S, N> as Stream>::Item>>



impl<S, const N: usize> Stream for Zip<S, N>
where S: Stream,



type Item = [<S as Stream>::Item; N]



fn poll_next( self: Pin<&mut Zip<S, N>>, cx: &mut Context<'_>, ) -> Poll<Option<<Zip<S, N> as Stream>::Item>>



impl<S> Stream for &mut S
where S: Stream + Unpin + ?Sized,



type Item = <S as Stream>::Item



fn poll_next( self: Pin<&mut &mut S>, cx: &mut Context<'_>, ) -> Poll<Option<<&mut S as Stream>::Item>>



fn size_hint(&self) -> (usize, Option<usize>)



impl<S> Stream for AssertUnwindSafe<S>
where S: Stream,



type Item = <S as Stream>::Item



fn poll_next( self: Pin<&mut AssertUnwindSafe<S>>, cx: &mut Context<'_>, ) -> Poll<Option<<S as Stream>::Item>>



fn size_hint(&self) -> (usize, Option<usize>)



impl<S> Stream for Chain<S>
where S: Stream,



type Item = <S as Stream>::Item



fn poll_next( self: Pin<&mut Chain<S>>, cx: &mut Context<'_>, ) -> Poll<Option<<Chain<S> as Stream>::Item>>



impl<S> Stream for Cycle<S>
where S: Stream + Clone,



type Item = <S as Stream>::Item



fn poll_next( self: Pin<&mut Cycle<S>>, cx: &mut Context<'_>, ) -> Poll<Option<<Cycle<S> as Stream>::Item>>



impl<S> Stream for Drain<'_, S>
where S: Stream + Unpin + ?Sized,



type Item = <S as Stream>::Item



fn poll_next( self: Pin<&mut Drain<'_, S>>, cx: &mut Context<'_>, ) -> Poll<Option<<Drain<'_, S> as Stream>::Item>>



fn size_hint(&self) -> (usize, Option<usize>)



impl<S> Stream for Enumerate<S>
where S: Stream,



type Item = (usize, <S as Stream>::Item)



fn poll_next( self: Pin<&mut Enumerate<S>>, cx: &mut Context<'_>, ) -> Poll<Option<<Enumerate<S> as Stream>::Item>>



impl<S> Stream for Fuse<S>
where S: Stream,



type Item = <S as Stream>::Item



fn poll_next( self: Pin<&mut Fuse<S>>, cx: &mut Context<'_>, ) -> Poll<Option<<S as Stream>::Item>>



impl<S> Stream for Keyed<S>
where S: Stream,



type Item = (Key, <S as Stream>::Item)



fn poll_next( self: Pin<&mut Keyed<S>>, cx: &mut Context<'_>, ) -> Poll<Option<<Keyed<S> as Stream>::Item>>



impl<S> Stream for Merge<S>
where S: Stream,



type Item = <S as Stream>::Item



fn poll_next( self: Pin<&mut Merge<S>>, cx: &mut Context<'_>, ) -> Poll<Option<<Merge<S> as Stream>::Item>>



impl<S> Stream for Skip<S>
where S: Stream,



type Item = <S as Stream>::Item



fn poll_next( self: Pin<&mut Skip<S>>, cx: &mut Context<'_>, ) -> Poll<Option<<Skip<S> as Stream>::Item>>



impl<S> Stream for StepBy<S>
where S: Stream,



type Item = <S as Stream>::Item



fn poll_next( self: Pin<&mut StepBy<S>>, cx: &mut Context<'_>, ) -> Poll<Option<<StepBy<S> as Stream>::Item>>



impl<S> Stream for StreamGroup<S>
where S: Stream,



type Item = <S as Stream>::Item



fn poll_next( self: Pin<&mut StreamGroup<S>>, cx: &mut Context<'_>, ) -> Poll<Option<<StreamGroup<S> as Stream>::Item>>



impl<S> Stream for Take<S>
where S: Stream,



type Item = <S as Stream>::Item



fn poll_next( self: Pin<&mut Take<S>>, cx: &mut Context<'_>, ) -> Poll<Option<<S as Stream>::Item>>



impl<S> Stream for Zip<S>
where S: Stream,



type Item = Vec<<S as Stream>::Item>



fn poll_next( self: Pin<&mut Zip<S>>, cx: &mut Context<'_>, ) -> Poll<Option<<Zip<S> as Stream>::Item>>



impl<St, Fut> Stream for StopAfterFuture<St, Fut>
where St: Stream, Fut: Future,



type Item = <St as Stream>::Item



fn poll_next( self: Pin<&mut StopAfterFuture<St, Fut>>, cx: &mut Context<'_>, ) -> Poll<Option<<St as Stream>::Item>>



fn size_hint(&self) -> (usize, Option<usize>)



impl<T, E, F, Fut, Item> Stream for TryUnfold<T, F, Fut>
where F: FnMut(T) -> Fut, Fut: Future<Output = Result<Option<(Item, T)>, E>>,



type Item = Result<Item, E>



fn poll_next( self: Pin<&mut TryUnfold<T, F, Fut>>, cx: &mut Context<'_>, ) -> Poll<Option<<TryUnfold<T, F, Fut> as Stream>::Item>>



impl<T, F, Fut, Item> Stream for Unfold<T, F, Fut>
where F: FnMut(T) -> Fut, Fut: Future<Output = Option<(Item, T)>>,



type Item = Item



fn poll_next( self: Pin<&mut Unfold<T, F, Fut>>, cx: &mut Context<'_>, ) -> Poll<Option<<Unfold<T, F, Fut> as Stream>::Item>>



impl<T, F> Stream for PollFn<F>
where F: FnMut(&mut Context<'_>) -> Poll<Option<T>>,



type Item = T



fn poll_next(self: Pin<&mut PollFn<F>>, cx: &mut Context<'_>) -> Poll<Option<T>>



impl<T, F> Stream for RepeatWith<F>
where F: FnMut() -> T,



type Item = T



fn poll_next( self: Pin<&mut RepeatWith<F>>, _: &mut Context<'_>, ) -> Poll<Option<<RepeatWith<F> as Stream>::Item>>



fn size_hint(&self) -> (usize, Option<usize>)



impl<T, S1, S2> Stream for Or<S1, S2>
where S1: Stream<Item = T>, S2: Stream<Item = T>,



type Item = T



fn poll_next( self: Pin<&mut Or<S1, S2>>, cx: &mut Context<'_>, ) -> Poll<Option<<Or<S1, S2> as Stream>::Item>>



impl<T, S1, S2> Stream for Race<S1, S2>
where S1: Stream<Item = T>, S2: Stream<Item = T>,

Available on crate feature race only.


type Item = T



fn poll_next( self: Pin<&mut Race<S1, S2>>, cx: &mut Context<'_>, ) -> Poll<Option<<Race<S1, S2> as Stream>::Item>>



impl<T> Stream for Empty<T>



type Item = T



fn poll_next( self: Pin<&mut Empty<T>>, _: &mut Context<'_>, ) -> Poll<Option<<Empty<T> as Stream>::Item>>



fn size_hint(&self) -> (usize, Option<usize>)



impl<T> Stream for Once<T>



type Item = T



fn poll_next(self: Pin<&mut Once<T>>, _: &mut Context<'_>) -> Poll<Option<T>>



fn size_hint(&self) -> (usize, Option<usize>)



impl<T> Stream for Pending<T>



type Item = T



fn poll_next(self: Pin<&mut Pending<T>>, _: &mut Context<'_>) -> Poll<Option<T>>



fn size_hint(&self) -> (usize, Option<usize>)



impl<T> Stream for Repeat<T>
where T: Clone,



type Item = T



fn poll_next( self: Pin<&mut Repeat<T>>, _: &mut Context<'_>, ) -> Poll<Option<<Repeat<T> as Stream>::Item>>



fn size_hint(&self) -> (usize, Option<usize>)

Implementors



impl Stream for AtomFeedStream



impl Stream for rama::http::BodyDataStream



type Item = Result<Bytes, Box<dyn Error + Sync + Send>>



impl Stream for DnsResponseReceiver



impl Stream for DnsResponseStream



impl Stream for FeedStream

FeedStream is itself a Stream of FeedItems: each inner stream yields its strongly-typed item, and the dispatch here wraps it in the umbrella enum so a caller can iterate format-agnostically.



impl Stream for FeedStreamWriter



type Item = Result<Bytes, Box<dyn Error + Sync + Send>>



impl Stream for rama::http::service::web::extract::body::multipart::Field<'_>



impl Stream for IntervalStream



type Item = Instant



impl Stream for PushPromises



impl Stream for ReadDirStream



type Item = Result<DirEntry, Error>



impl Stream for rama::http::core::h2::RecvStream



impl Stream for Rss2FeedStream



impl Stream for SignalStream



type Item = ()



impl Stream for TcpListenerStream



impl Stream for UnixListenerStream



impl Stream for rama::http::grpc::service::health::server::WatchStream



impl<A, B> Stream for rama::futures::prelude::future::Either<A, B>
where A: Stream, B: Stream<Item = <A as Stream>::Item>,



type Item = <A as Stream>::Item



impl<A, F> Stream for rama::futures::prelude::stream::RepeatWith<F>
where F: FnMut() -> A,



type Item = A



impl<B, St, S, Fut, F> Stream for rama::futures::prelude::stream::Scan<St, S, Fut, F>
where St: Stream, F: FnMut(&mut S, <St as Stream>::Item) -> Fut, Fut: Future<Output = Option<B>>,



type Item = B



impl<B> Stream for rama::http::body::util::BodyDataStream<B>
where B: Body,



type Item = Result<<B as Body>::Data, <B as Body>::Error>



impl<B> Stream for BodyStream<B>
where B: Body,



type Item = Result<Frame<<B as Body>::Data>, <B as Body>::Error>



impl<B> Stream for GrpcWebCall<B>
where B: Body, <B as Body>::Error: Display,



impl<C, S> Stream for UdpFramedRelay<C, S>
where C: Decoder, <C as Decoder>::Error: Into<Box<dyn Error + Sync + Send>>, S: Io + Unpin,



type Item = Result<(<C as Decoder>::Item, SocketAddress), Box<dyn Error + Sync + Send>>



impl<C, T> Stream for UdpFramed<C, T>
where T: Borrow<UdpSocket>, C: Decoder,



type Item = Result<(<C as Decoder>::Item, SocketAddr), <C as Decoder>::Error>



impl<C, T> Stream for UnixDatagramFramed<C, T>
where T: Borrow<UnixDatagram>, C: Decoder,



impl<C> Stream for ConnectedUdpFramed<C>
where C: Decoder + Unpin,



type Item = Result<<C as Decoder>::Item, <C as Decoder>::Error>



impl<F> Stream for FlattenStream<F>
where Flatten<F, <F as Future>::Output>: Stream, F: Future,



type Item = <Flatten<F, <F as Future>::Output> as Stream>::Item



impl<F> Stream for rama::futures::prelude::future::IntoStream<F>
where Once<F>: Stream,



type Item = <Once<F> as Stream>::Item



impl<Fut, Si> Stream for FlattenSink<Fut, Si>
where TryFlatten<Fut, Si>: Stream,



type Item = <TryFlatten<Fut, Si> as Stream>::Item



impl<Fut> Stream for FuturesOrdered<Fut>
where Fut: Future,



type Item = <Fut as Future>::Output



impl<Fut> Stream for FuturesUnordered<Fut>
where Fut: Future,



type Item = <Fut as Future>::Output



impl<Fut> Stream for rama::futures::prelude::stream::Once<Fut>
where Fut: Future,



type Item = <Fut as Future>::Output



impl<Fut> Stream for TryFlattenStream<Fut>
where TryFlatten<Fut, <Fut as TryFuture>::Ok>: Stream, Fut: TryFuture,



type Item = <TryFlatten<Fut, <Fut as TryFuture>::Ok> as Stream>::Item



impl<I> Stream for rama::futures::prelude::stream::Iter<I>
where I: Iterator,



type Item = <I as Iterator>::Item



impl<I> Stream for rama::stream::Iter<I>
where I: Iterator,



type Item = <I as Iterator>::Item



impl<K, V> Stream for StreamMap<K, V>
where K: Clone + Unpin, V: Stream + Unpin,



type Item = (K, <V as Stream>::Item)



impl<P> Stream for DnsExchangeSend<P>
where P: Unpin,



impl<P> Stream for UdpClientStream<P>



impl<P> Stream for UdpStream<P>
where P: RuntimeProvider,



impl<R> Stream for ClientStreamXfr<R>
where R: Stream<Item = Result<DnsResponse, NetError>> + Send + Unpin + 'static,



impl<R> Stream for ClientStreamingResponse<R>
where R: Stream<Item = Result<DnsResponse, ProtoError>> + Send + Unpin + 'static,



impl<R> Stream for rama::futures::io::Lines<R>
where R: AsyncBufRead,



impl<R> Stream for LinesStream<R>
where R: AsyncBufRead,



impl<R> Stream for ReaderStream<R>
where R: AsyncRead,



impl<R> Stream for rama::stream::wrappers::SplitStream<R>
where R: AsyncBufRead,



impl<S, B, E, T> Stream for EventStream<S, T>
where S: Stream<Item = Result<B, E>>, E: Into<Box<dyn Error + Sync + Send>>, B: AsRef<[u8]>, T: EventDataRead,



type Item = Result<Event<T>, Box<dyn Error + Sync + Send>>



impl<S, C> Stream for PacedSink<S, C>
where S: Stream,



type Item = <S as Stream>::Item



impl<S, E, T> Stream for KeepAliveStream<S, T>
where S: Stream<Item = Result<Event<T>, E>>, E: Into<Box<dyn Error + Sync + Send>>, T: EventDataWrite + Clone,



type Item = Result<Event<T>, E>



impl<S, E> Stream for AtomStreamWriter<S>
where S: Stream<Item = Result<AtomEntry, E>>, E: Into<Box<dyn Error + Sync + Send>>,



type Item = Result<Bytes, Box<dyn Error + Sync + Send>>



impl<S, E> Stream for BytesFreeze<S>
where S: Stream<Item = Result<BytesMut, E>> + Unpin,



type Item = Result<Bytes, E>



impl<S, E> Stream for Rss2StreamWriter<S>
where S: Stream<Item = Result<Rss2Item, E>>, E: Into<Box<dyn Error + Sync + Send>>,



type Item = Result<Bytes, Box<dyn Error + Sync + Send>>



impl<S, F> Stream for GracefulStream<S, F>
where S: Stream, F: Future,



type Item = <S as Stream>::Item



impl<S, F> Stream for SinkMapErr<S, F>
where S: Stream,



type Item = <S as Stream>::Item



impl<S, Item, E> Stream for SinkErrInto<S, Item, E>
where S: Sink<Item> + Stream, <S as Sink<Item>>::Error: Into<E>,



type Item = <S as Stream>::Item



impl<S, Item, U, Fut, F> Stream for With<S, Item, U, Fut, F>
where S: Stream + Sink<Item>, F: FnMut(U) -> Fut, Fut: Future,



type Item = <S as Stream>::Item



impl<S, Item, U, St, F> Stream for WithFlatMap<S, Item, U, St, F>
where S: Stream + Sink<Item>, F: FnMut(U) -> St, St: Stream<Item = Result<Item, <S as Sink<Item>>::Error>>,



type Item = <S as Stream>::Item



impl<S, Item> Stream for Buffer<S, Item>
where S: Sink<Item> + Stream,



type Item = <S as Stream>::Item



impl<S, T, E> Stream for JsonWriteStream<S>
where S: Stream<Item = Result<T, E>>, T: Serialize, E: Into<Box<dyn Error + Sync + Send>>,



type Item = Result<Bytes, Box<dyn Error + Sync + Send>>



impl<S> Stream for Box<S>
where S: Stream + Unpin + ?Sized,



type Item = <S as Stream>::Item



impl<S> Stream for ChunksTimeout<S>
where S: Stream,



type Item = Vec<<S as Stream>::Item>



impl<S> Stream for CopyToBytes<S>
where S: Stream,



type Item = <S as Stream>::Item



impl<S> Stream for DnsMultiplexer<S>
where S: DnsClientStream,



impl<S> Stream for rama::futures::prelude::stream::Fuse<S>
where S: Stream,



type Item = <S as Stream>::Item



impl<S> Stream for rama::futures::prelude::stream::Peekable<S>
where S: Stream,



type Item = <S as Stream>::Item



impl<S> Stream for SinkWriter<S>
where S: Stream,



type Item = <S as Stream>::Item



impl<S> Stream for rama::futures::prelude::stream::SplitStream<S>
where S: Stream,



type Item = <S as Stream>::Item



impl<S> Stream for StreamBody<S>
where S: Stream,



type Item = <S as Stream>::Item



impl<S> Stream for StreamNotifyClose<S>
where S: Stream,



type Item = Option<<S as Stream>::Item>



impl<S> Stream for TcpClientStream<S>
where S: DnsTcpStream,



impl<S> Stream for TcpStream<S>
where S: DnsTcpStream,



impl<S> Stream for Timeout<S>
where S: Stream,



type Item = Result<<S as Stream>::Item, Elapsed>



impl<S> Stream for TimeoutRepeating<S>
where S: Stream,



type Item = Result<<S as Stream>::Item, Elapsed>



impl<St1, St2, Clos, State> Stream for SelectWithStrategy<St1, St2, Clos, State>
where St1: Stream, St2: Stream<Item = <St1 as Stream>::Item>, Clos: FnMut(&mut State) -> PollNext,



type Item = <St1 as Stream>::Item



impl<St1, St2> Stream for rama::futures::prelude::stream::Chain<St1, St2>
where St1: Stream, St2: Stream<Item = <St1 as Stream>::Item>,



type Item = <St1 as Stream>::Item



impl<St1, St2> Stream for Select<St1, St2>
where St1: Stream, St2: Stream<Item = <St1 as Stream>::Item>,



type Item = <St1 as Stream>::Item



impl<St1, St2> Stream for rama::futures::prelude::stream::Zip<St1, St2>
where St1: Stream, St2: Stream,



type Item = (<St1 as Stream>::Item, <St2 as Stream>::Item)



impl<St, E> Stream for ErrInto<St, E>
where MapErr<St, IntoFn<E>>: Stream,



type Item = <MapErr<St, IntoFn<E>> as Stream>::Item



impl<St, F, Fut> Stream for rama::stream::adapters::Then<St, Fut, F>
where St: Stream, Fut: Future, F: FnMut(<St as Stream>::Item) -> Fut,



type Item = <Fut as Future>::Output



impl<St, F, T> Stream for rama::stream::adapters::FilterMap<St, F>
where St: Stream, F: FnMut(<St as Stream>::Item) -> Option<T>,



type Item = T



impl<St, F, T> Stream for rama::stream::adapters::Map<St, F>
where St: Stream, F: FnMut(<St as Stream>::Item) -> T,



type Item = T



impl<St, F, T> Stream for rama::stream::adapters::MapWhile<St, F>
where St: Stream, F: FnMut(<St as Stream>::Item) -> Option<T>,



type Item = T



impl<St, F> Stream for rama::stream::adapters::Filter<St, F>
where St: Stream, F: FnMut(&<St as Stream>::Item) -> bool,



type Item = <St as Stream>::Item



impl<St, F> Stream for rama::futures::prelude::stream::Inspect<St, F>
where Map<St, InspectFn<F>>: Stream,



type Item = <Map<St, InspectFn<F>> as Stream>::Item



impl<St, F> Stream for InspectErr<St, F>
where Inspect<IntoStream<St>, InspectErrFn<F>>: Stream,



type Item = <Inspect<IntoStream<St>, InspectErrFn<F>> as Stream>::Item



impl<St, F> Stream for InspectOk<St, F>
where Inspect<IntoStream<St>, InspectOkFn<F>>: Stream,



type Item = <Inspect<IntoStream<St>, InspectOkFn<F>> as Stream>::Item



impl<St, F> Stream for rama::futures::prelude::stream::Map<St, F>
where St: Stream, F: FnMut1<<St as Stream>::Item>,



type Item = <F as FnOnce1<<St as Stream>::Item>>::Output



impl<St, F> Stream for MapErr<St, F>
where Map<IntoStream<St>, MapErrFn<F>>: Stream,



type Item = <Map<IntoStream<St>, MapErrFn<F>> as Stream>::Item



impl<St, F> Stream for MapOk<St, F>
where Map<IntoStream<St>, MapOkFn<F>>: Stream,



type Item = <Map<IntoStream<St>, MapOkFn<F>> as Stream>::Item



impl<St, F> Stream for rama::stream::adapters::SkipWhile<St, F>
where St: Stream, F: FnMut(&<St as Stream>::Item) -> bool,



type Item = <St as Stream>::Item



impl<St, F> Stream for rama::stream::adapters::TakeWhile<St, F>
where St: Stream, F: FnMut(&<St as Stream>::Item) -> bool,



type Item = <St as Stream>::Item



impl<St, Fut, F, T> Stream for rama::futures::prelude::stream::FilterMap<St, Fut, F>
where St: Stream, F: FnMut1<<St as Stream>::Item, Output = Fut>, Fut: Future<Output = Option<T>>,



type Item = T



impl<St, Fut, F, T> Stream for TryFilterMap<St, Fut, F>
where St: TryStream, Fut: TryFuture<Ok = Option<T>, Error = <St as TryStream>::Error>, F: FnMut(<St as TryStream>::Ok) -> Fut,



type Item = Result<T, <St as TryStream>::Error>



impl<St, Fut, F> Stream for AndThen<St, Fut, F>
where St: TryStream, F: FnMut(<St as TryStream>::Ok) -> Fut, Fut: TryFuture<Error = <St as TryStream>::Error>,



type Item = Result<<Fut as TryFuture>::Ok, <St as TryStream>::Error>



impl<St, Fut, F> Stream for rama::futures::prelude::stream::Filter<St, Fut, F>
where St: Stream, F: for<'a> FnMut1<&'a <St as Stream>::Item, Output = Fut>, Fut: Future<Output = bool>,



type Item = <St as Stream>::Item



impl<St, Fut, F> Stream for OrElse<St, Fut, F>
where St: TryStream, F: FnMut(<St as TryStream>::Error) -> Fut, Fut: TryFuture<Ok = <St as TryStream>::Ok>,



type Item = Result<<St as TryStream>::Ok, <Fut as TryFuture>::Error>



impl<St, Fut, F> Stream for rama::futures::prelude::stream::SkipWhile<St, Fut, F>
where St: Stream, F: FnMut(&<St as Stream>::Item) -> Fut, Fut: Future<Output = bool>,



type Item = <St as Stream>::Item



impl<St, Fut, F> Stream for rama::futures::prelude::stream::TakeWhile<St, Fut, F>
where St: Stream, F: FnMut(&<St as Stream>::Item) -> Fut, Fut: Future<Output = bool>,



type Item = <St as Stream>::Item



impl<St, Fut, F> Stream for rama::futures::prelude::stream::Then<St, Fut, F>
where St: Stream, F: FnMut(<St as Stream>::Item) -> Fut, Fut: Future,



type Item = <Fut as Future>::Output



impl<St, Fut, F> Stream for TryFilter<St, Fut, F>
where St: TryStream, Fut: Future<Output = bool>, F: FnMut(&<St as TryStream>::Ok) -> Fut,



type Item = Result<<St as TryStream>::Ok, <St as TryStream>::Error>



impl<St, Fut, F> Stream for TrySkipWhile<St, Fut, F>
where St: TryStream, F: FnMut(&<St as TryStream>::Ok) -> Fut, Fut: TryFuture<Ok = bool, Error = <St as TryStream>::Error>,



type Item = Result<<St as TryStream>::Ok, <St as TryStream>::Error>



impl<St, Fut, F> Stream for TryTakeWhile<St, Fut, F>
where St: TryStream, F: FnMut(&<St as TryStream>::Ok) -> Fut, Fut: TryFuture<Ok = bool, Error = <St as TryStream>::Error>,



type Item = Result<<St as TryStream>::Ok, <St as TryStream>::Error>



impl<St, Fut> Stream for TakeUntil<St, Fut>
where St: Stream, Fut: Future,



type Item = <St as Stream>::Item



impl<St, U, F> Stream for rama::futures::prelude::stream::FlatMap<St, U, F>
where Flatten<Map<St, F>, U>: Stream,



type Item = <Flatten<Map<St, F>, U> as Stream>::Item



impl<St, U, F> Stream for FlatMapUnordered<St, U, F>
where FlattenUnorderedWithFlowController<Map<St, F>, ()>: Stream, St: Stream, U: Stream + Unpin, F: FnMut(<St as Stream>::Item) -> U,



type Item = <FlattenUnorderedWithFlowController<Map<St, F>, ()> as Stream>::Item



impl<St> Stream for Abortable<St>
where St: Stream,



type Item = <St as Stream>::Item



impl<St> Stream for BufferUnordered<St>
where St: Stream, <St as Stream>::Item: Future,



type Item = <<St as Stream>::Item as Future>::Output



impl<St> Stream for Buffered<St>
where St: Stream, <St as Stream>::Item: Future,



type Item = <<St as Stream>::Item as Future>::Output



impl<St> Stream for CatchUnwind<St>
where St: Stream + UnwindSafe,



type Item = Result<<St as Stream>::Item, Box<dyn Any + Send>>



impl<St> Stream for Chunks<St>
where St: Stream,



type Item = Vec<<St as Stream>::Item>



impl<St> Stream for rama::futures::prelude::stream::Cycle<St>
where St: Clone + Stream,



type Item = <St as Stream>::Item



impl<St> Stream for rama::futures::prelude::stream::Enumerate<St>
where St: Stream,



type Item = (usize, <St as Stream>::Item)



impl<St> Stream for rama::futures::prelude::stream::Flatten<St>
where Flatten<St, <St as Stream>::Item>: Stream, St: Stream,



type Item = <Flatten<St, <St as Stream>::Item> as Stream>::Item



impl<St> Stream for rama::futures::prelude::stream::IntoStream<St>
where St: TryStream,



type Item = Result<<St as TryStream>::Ok, <St as TryStream>::Error>



impl<St> Stream for ReadyChunks<St>
where St: Stream,



type Item = Vec<<St as Stream>::Item>



impl<St> Stream for SelectAll<St>
where St: Stream + Unpin,



type Item = <St as Stream>::Item



impl<St> Stream for rama::futures::prelude::stream::Skip<St>
where St: Stream,



type Item = <St as Stream>::Item



impl<St> Stream for rama::stream::adapters::Skip<St>
where St: Stream,



type Item = <St as Stream>::Item



impl<St> Stream for rama::futures::prelude::stream::Take<St>
where St: Stream,



type Item = <St as Stream>::Item



impl<St> Stream for rama::stream::adapters::Take<St>
where St: Stream,



type Item = <St as Stream>::Item



impl<St> Stream for TryBufferUnordered<St>
where St: TryStream, <St as TryStream>::Ok: TryFuture<Error = <St as TryStream>::Error>,



type Item = Result<<<St as TryStream>::Ok as TryFuture>::Ok, <St as TryStream>::Error>



impl<St> Stream for TryBuffered<St>
where St: TryStream, <St as TryStream>::Ok: TryFuture<Error = <St as TryStream>::Error>,



type Item = Result<<<St as TryStream>::Ok as TryFuture>::Ok, <St as TryStream>::Error>



impl<St> Stream for TryChunks<St>
where St: TryStream,



type Item = Result<Vec<<St as TryStream>::Ok>, TryChunksError<<St as TryStream>::Ok, <St as TryStream>::Error>>



impl<St> Stream for TryFlatten<St>
where St: TryStream, <St as TryStream>::Ok: TryStream, <<St as TryStream>::Ok as TryStream>::Error: From<<St as TryStream>::Error>,



type Item = Result<<<St as TryStream>::Ok as TryStream>::Ok, <<St as TryStream>::Ok as TryStream>::Error>



impl<St> Stream for TryFlattenUnordered<St>
where FlattenUnorderedWithFlowController<NestedTryStreamIntoEitherTryStream<St>, PropagateBaseStreamError<St>>: Stream, St: TryStream, <St as TryStream>::Ok: TryStream + Unpin, <<St as TryStream>::Ok as TryStream>::Error: From<<St as TryStream>::Error>,



type Item = <FlattenUnorderedWithFlowController<NestedTryStreamIntoEitherTryStream<St>, PropagateBaseStreamError<St>> as Stream>::Item



impl<St> Stream for TryReadyChunks<St>
where St: TryStream,



type Item = Result<Vec<<St as TryStream>::Ok>, TryReadyChunksError<<St as TryStream>::Ok, <St as TryStream>::Error>>



impl<T, B> Stream for Connection<T, B>
where T: AsyncRead + AsyncWrite + Unpin + ExtensionsRef, B: Buf,



impl<T, D> Stream for FramedRead<T, D>
where T: AsyncRead, D: Decoder,



type Item = Result<<D as Decoder>::Item, <D as Decoder>::Error>



impl<T, D> Stream for FramedWrite<T, D>
where T: Stream,



type Item = <T as Stream>::Item



impl<T, F, Fut, Item> Stream for rama::futures::prelude::stream::TryUnfold<T, F, Fut>
where F: FnMut(T) -> Fut, Fut: TryFuture<Ok = Option<(Item, T)>>,



type Item = Result<Item, <Fut as TryFuture>::Error>



impl<T, F, Fut, Item> Stream for rama::futures::prelude::stream::Unfold<T, F, Fut>
where F: FnMut(T) -> Fut, Fut: Future<Output = Option<(Item, T)>>,



type Item = Item



impl<T, F> Stream for rama::futures::prelude::stream::PollFn<F>
where F: FnMut(&mut Context<'_>) -> Poll<Option<T>>,



type Item = T



impl<T, F> Stream for rama::futures::prelude::future::PollImmediate<F>
where F: Future<Output = T>,

A Stream implementation that can be polled repeatedly until the future is done. The stream will never return Poll::Pending so polling it in a tight loop is worse than using a blocking synchronous function.

use core::pin::pin;

use futures::task::Poll;
use futures::{StreamExt, future};
use future::FusedFuture;

let f = async { 1_u32 };
let f = pin!(f);
let mut r = future::poll_immediate(f);
assert_eq!(r.next().await, Some(Poll::Ready(1)));

let f = async {futures::pending!(); 42_u8};
let f = pin!(f);
let mut p = future::poll_immediate(f);
assert_eq!(p.next().await, Some(Poll::Pending));
assert!(!p.is_terminated());
assert_eq!(p.next().await, Some(Poll::Ready(42)));
assert!(p.is_terminated());
assert_eq!(p.next().await, None);


type Item = Poll<T>



impl<T, S, B, E> Stream for JsonReadStream<T, S>
where T: for<'deserialize> Deserialize<'deserialize>, E: Into<Box<dyn Error + Sync + Send>>, S: Stream<Item = Result<B, E>>, B: AsRef<[u8]>,



type Item = Result<T, Box<dyn Error + Sync + Send>>



impl<T, S> Stream for rama::futures::prelude::stream::PollImmediate<S>
where S: Stream<Item = T>,



type Item = Poll<T>



impl<T, U> Stream for rama::stream::adapters::Chain<T, U>
where T: Stream, U: Stream<Item = <T as Stream>::Item>,



type Item = <T as Stream>::Item



impl<T, U> Stream for Framed<T, U>
where T: AsyncRead, U: Decoder,



type Item = Result<<U as Decoder>::Item, <U as Decoder>::Error>



impl<T, U> Stream for rama::stream::adapters::Merge<T, U>
where T: Stream, U: Stream<Item = <T as Stream>::Item>,



type Item = <T as Stream>::Item



impl<T> Stream for AsyncWebSocket<T>
where T: Io + Unpin,



impl<T> Stream for BroadcastStream<T>
where T: 'static + Clone + Send,



impl<T> Stream for DelayStream<T>
where T: Stream,



type Item = <T as Stream>::Item



impl<T> Stream for rama::futures::prelude::stream::Empty<T>



type Item = T



impl<T> Stream for rama::stream::Empty<T>



type Item = T



impl<T> Stream for rama::stream::adapters::Fuse<T>
where T: Stream,



type Item = <T as Stream>::Item



impl<T> Stream for JoinSetStream<T>
where T: 'static,



type Item = Result<T, JoinError>



impl<T> Stream for rama::stream::Once<T>



type Item = T



impl<T> Stream for rama::stream::adapters::Peekable<T>
where T: Stream,



type Item = <T as Stream>::Item



impl<T> Stream for rama::futures::prelude::stream::Pending<T>



type Item = T



impl<T> Stream for rama::stream::Pending<T>



type Item = T



impl<T> Stream for Receiver<T>



type Item = T



impl<T> Stream for ReceiverStream<T>



type Item = T



impl<T> Stream for rama::futures::prelude::stream::Repeat<T>
where T: Clone,



type Item = T



impl<T> Stream for Streaming<T>



type Item = Result<T, Status>



impl<T> Stream for UnboundedReceiver<T>



type Item = T



impl<T> Stream for UnboundedReceiverStream<T>



type Item = T



impl<T> Stream for rama::stream::wrappers::WatchStream<T>
where T: Clone + 'static + Send + Sync,



type Item = T



impl<T> Stream for WithContext<T>
where T: Stream,



type Item = <T as Stream>::Item