Struct TcpConnector
pub struct TcpConnector<StreamConnector = ()> { /* private fields */ }std and tcp only.Expand description
A connector which can be used to establish a TCP connection to a server.
Implementations
impl TcpConnector
impl TcpConnector
pub fn new() -> TcpConnector
pub fn new() -> TcpConnector
Create a new TcpConnector, which is used to establish a connection to a server.
You can use middleware around the TcpConnector
or add connection pools, retry logic and more.
impl<StreamConnector> TcpConnector<StreamConnector>
impl<StreamConnector> TcpConnector<StreamConnector>
pub fn with_max_in_flight_connect_attempts(
self,
n: usize,
) -> TcpConnector<StreamConnector>
pub fn with_max_in_flight_connect_attempts( self, n: usize, ) -> TcpConnector<StreamConnector>
Set the maximum number of resolved candidate connection attempts
raced concurrently (default 3, clamped to a minimum of 1).
Only takes effect when a ConnectorTargetStream is present on the
input (i.e. a domain target was resolved by an upstream DNS
connector), a single IP target is dialed directly.
pub fn set_max_in_flight_connect_attempts(
&mut self,
n: usize,
) -> &mut TcpConnector<StreamConnector>
pub fn set_max_in_flight_connect_attempts( &mut self, n: usize, ) -> &mut TcpConnector<StreamConnector>
Set the maximum number of resolved candidate connection attempts
raced concurrently (default 3, clamped to a minimum of 1).
Only takes effect when a ConnectorTargetStream is present on the
input (i.e. a domain target was resolved by an upstream DNS
connector), a single IP target is dialed directly.
impl TcpConnector
impl TcpConnector
pub fn with_connector<StreamConnector>(
self,
connector: StreamConnector,
) -> TcpConnector<StreamConnector>
pub fn with_connector<StreamConnector>( self, connector: StreamConnector, ) -> TcpConnector<StreamConnector>
Consume self to attach the given Connector (a TcpStreamConnector),
used to establish the actual TcpStream.