Struct Request
#[non_exhaustive]pub struct Request {
pub authority: HostWithPort,
pub protocol: Option<Protocol>,
pub http_version: Option<Version>,
pub extensions: Extensions,
}tcp only.Expand description
A request to establish a Tcp Connection.
This can be used in case you operate on a layer below an application layer such as Http.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.protocol: Option<Protocol>http_version: Option<Version>extensions: ExtensionsImplementations
impl Request
impl Request
pub fn new(authority: HostWithPort) -> Request
pub fn new(authority: HostWithPort) -> Request
Create a new Tcp Request with default Extensions.
pub const fn new_with_extensions(
authority: HostWithPort,
extensions: Extensions,
) -> Request
pub const fn new_with_extensions( authority: HostWithPort, extensions: Extensions, ) -> Request
Create a new Tcp Request with given Extensions.
pub fn maybe_with_protocol(self, protocol: Option<Protocol>) -> Request
pub fn maybe_with_protocol(self, protocol: Option<Protocol>) -> Request
Define the application protocol to this Request
on which the established connection will operate.
pub fn maybe_set_protocol(&mut self, protocol: Option<Protocol>) -> &mut Request
pub fn maybe_set_protocol(&mut self, protocol: Option<Protocol>) -> &mut Request
Define the application protocol to this Request
on which the established connection will operate.
pub fn with_protocol(self, protocol: Protocol) -> Request
pub fn with_protocol(self, protocol: Protocol) -> Request
Define the application protocol to this Request
on which the established connection will operate.
pub fn set_protocol(&mut self, protocol: Protocol) -> &mut Request
pub fn set_protocol(&mut self, protocol: Protocol) -> &mut Request
Define the application protocol to this Request
on which the established connection will operate.
pub fn without_protocol(self) -> Request
pub fn without_protocol(self) -> Request
Define the application protocol to this Request
on which the established connection will operate.
pub fn unset_protocol(&mut self) -> &mut Request
pub fn unset_protocol(&mut self) -> &mut Request
Define the application protocol to this Request
on which the established connection will operate.
pub fn maybe_with_http_version(self, version: Option<Version>) -> Request
pub fn maybe_with_http_version(self, version: Option<Version>) -> Request
Define the http version as a hint to the application layer.
pub fn maybe_set_http_version(
&mut self,
version: Option<Version>,
) -> &mut Request
pub fn maybe_set_http_version( &mut self, version: Option<Version>, ) -> &mut Request
Define the http version as a hint to the application layer.
pub fn with_http_version(self, version: Version) -> Request
pub fn with_http_version(self, version: Version) -> Request
Define the http version as a hint to the application layer.
pub fn set_http_version(&mut self, version: Version) -> &mut Request
pub fn set_http_version(&mut self, version: Version) -> &mut Request
Define the http version as a hint to the application layer.
pub fn without_http_version(self) -> Request
pub fn without_http_version(self) -> Request
Define the http version as a hint to the application layer.
pub fn unset_http_version(&mut self) -> &mut Request
pub fn unset_http_version(&mut self) -> &mut Request
Define the http version as a hint to the application layer.