Struct PostedRecvBlocked
pub struct PostedRecvBlocked {
pub timestamp_ns: u64,
pub error_raw_os: i64,
}Available on crate features
dial9 and std and tcp only.Expand description
The system ran out of buffers for a receive; reads of that stream pass through until one can be posted again.
Fields
timestamp_ns: u64error_raw_os: i64Raw OS error code of the failed receive.