Enum ThreadStopReason
#[non_exhaustive]pub enum ThreadStopReason {
Idle,
OverMaximum,
}Available on crate features
std and tcp only.Expand description
Why a completion thread stopped.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Idle
It had nothing to do for the idle timeout.
OverMaximum
The configured maximum was lowered below the running threads.
Implementations
impl ThreadStopReason
impl ThreadStopReason
pub const fn dial9_code(self) -> u8
pub const fn dial9_code(self) -> u8
Stable code used in the trace.