Struct PostedRecvConfig
pub struct PostedRecvConfig { /* private fields */ }std and tcp only.Expand description
Configuration of a PostedRecv.
Only used on Windows; other platforms accept and ignore it.
Implementations
impl PostedRecvConfig
impl PostedRecvConfig
pub const fn new() -> PostedRecvConfig
pub const fn new() -> PostedRecvConfig
Create the default configuration: two receives of 16 KiB each, and up to 64 KiB of received bytes waiting for the reader.
pub fn with_slots(self, slots: usize) -> PostedRecvConfig
pub fn with_slots(self, slots: usize) -> PostedRecvConfig
Number of receives kept posted on the socket (at least 1).
Together with slot_size this sets which
replies are surely kept before a reset: as many receives as the
parts they arrive in fill, see the
module docs.
pub fn set_slots(&mut self, slots: usize) -> &mut PostedRecvConfig
pub fn set_slots(&mut self, slots: usize) -> &mut PostedRecvConfig
Number of receives kept posted on the socket (at least 1).
Together with slot_size this sets which
replies are surely kept before a reset: as many receives as the
parts they arrive in fill, see the
module docs.
pub fn with_slot_size(self, size: usize) -> PostedRecvConfig
pub fn with_slot_size(self, size: usize) -> PostedRecvConfig
Buffer size of each posted receive, in bytes (at least 1).
pub fn set_slot_size(&mut self, size: usize) -> &mut PostedRecvConfig
pub fn set_slot_size(&mut self, size: usize) -> &mut PostedRecvConfig
Buffer size of each posted receive, in bytes (at least 1).
pub fn with_max_buffered(self, bytes: usize) -> PostedRecvConfig
pub fn with_max_buffered(self, bytes: usize) -> PostedRecvConfig
How far, in bytes, the reader may fall behind while receives stay posted.
Received bytes are queued until they are read; once more than this is queued no new receive is posted until the reader catches up.
pub fn set_max_buffered(&mut self, bytes: usize) -> &mut PostedRecvConfig
pub fn set_max_buffered(&mut self, bytes: usize) -> &mut PostedRecvConfig
How far, in bytes, the reader may fall behind while receives stay posted.
Received bytes are queued until they are read; once more than this is queued no new receive is posted until the reader catches up.
pub const fn max_buffered(&self) -> usize
pub const fn max_buffered(&self) -> usize
How far, in bytes, the reader may fall behind while receives stay posted.