Struct IoToProxyBridgeIo
pub struct IoToProxyBridgeIo<S, C = TcpConnector> { /* private fields */ }Implementations
impl<S> IoToProxyBridgeIo<S>
impl<S> IoToProxyBridgeIo<S>
pub fn new(
inner: S,
exec: Executor,
target: HostWithPort,
) -> IoToProxyBridgeIo<S>
pub fn new( inner: S, exec: Executor, target: HostWithPort, ) -> IoToProxyBridgeIo<S>
Creates a new IoToProxyBridgeIo service,
which will use the provided target info to connect to.
Use Self::extension_proxy_target if you wish to have it be done
using the ProxyTarget extension instead, failing the input flow
in case that extension not exist.
pub fn extension_proxy_target(exec: Executor, inner: S) -> IoToProxyBridgeIo<S>
pub fn extension_proxy_target(exec: Executor, inner: S) -> IoToProxyBridgeIo<S>
Creates a new IoToProxyBridgeIo service,
which expects while serving that ProxyTarget
is available in the input’s extension, and fail otherwise.
Use Self::new if you wish to use a hardcoded target instead,
pub fn into_inner(self) -> S
pub fn into_inner(self) -> S
Consumes self, returning the underlying service.
impl<S> IoToProxyBridgeIo<S>
impl<S> IoToProxyBridgeIo<S>
pub fn with_connector<C>(self, connector: C) -> IoToProxyBridgeIo<S, C>
pub fn with_connector<C>(self, connector: C) -> IoToProxyBridgeIo<S, C>
Set a custom “connector” for service, overwriting the default tcp forwarder which simply establishes a TCP connection.
This can be useful for any custom middleware, but also to enrich with rama-provided services for tls connections, HAproxy client endoding or even an entirely custom tcp connector service.