Struct IoToProxyBridgeIoLayer
pub struct IoToProxyBridgeIoLayer<C = TcpConnector> { /* private fields */ }Expand description
A Layer that produces IoToProxyBridgeIo services.
Implementations
impl IoToProxyBridgeIoLayer
impl IoToProxyBridgeIoLayer
pub fn new(
exec: Executor,
target: impl Into<HostWithPort>,
) -> IoToProxyBridgeIoLayer
pub fn new( exec: Executor, target: impl Into<HostWithPort>, ) -> IoToProxyBridgeIoLayer
Creates a new IoToProxyBridgeIoLayer,
which will use by the IoToProxyBridgeIo Service the provided target info to connect to.
Use Self::extension_proxy_target if you wish to have it be done
using the ProxyTarget extension instead, failing the input flow
in case that extension not exist.
pub fn extension_proxy_target(exec: Executor) -> IoToProxyBridgeIoLayer
pub fn extension_proxy_target(exec: Executor) -> IoToProxyBridgeIoLayer
Creates a new IoToProxyBridgeIoLayer,
which will create the IoToProxyBridgeIo Service
that with this constructor will expect while serving that ProxyTarget
is available in the input’s extension, and fail otherwise.
Use Self::new if you wish to use a hardcoded target instead,
impl IoToProxyBridgeIoLayer
impl IoToProxyBridgeIoLayer
pub fn with_connector<C>(self, connector: C) -> IoToProxyBridgeIoLayer<C>
pub fn with_connector<C>(self, connector: C) -> IoToProxyBridgeIoLayer<C>
Set a custom “connector” for layer’s service, overwriting the default tcp forwarder which simply establishes a TCP connection.
This can be useful for any custom middleware, but also to enrich with rama-provided services for tls connections, HAproxy client endoding or even an entirely custom tcp connector service.
impl<C> IoToProxyBridgeIoLayer<C>
impl<C> IoToProxyBridgeIoLayer<C>
pub fn new_with_connector(
target: impl Into<HostWithPort>,
connector: C,
) -> IoToProxyBridgeIoLayer<C>
pub fn new_with_connector( target: impl Into<HostWithPort>, connector: C, ) -> IoToProxyBridgeIoLayer<C>
Same as Self::new but using a custom connector.
pub fn extension_proxy_target_with_connector(
connector: C,
) -> IoToProxyBridgeIoLayer<C>
pub fn extension_proxy_target_with_connector( connector: C, ) -> IoToProxyBridgeIoLayer<C>
Same as Self::extension_proxy_target but using a custom connector.