Struct BackgroundTaskConfig
pub struct BackgroundTaskConfig { /* private fields */ }Available on crate feature
dial9 only.Expand description
Configuration for the in-process worker pipeline.
The pipeline is composed of a sequence of SegmentProcessors supplied
via processors. When none are provided the worker runs no processing.
Implementations
impl BackgroundTaskConfig
impl BackgroundTaskConfig
pub fn builder() -> BackgroundTaskConfigBuilder
pub fn builder() -> BackgroundTaskConfigBuilder
Create an instance of BackgroundTaskConfig using the builder syntax
impl BackgroundTaskConfig
impl BackgroundTaskConfig
pub fn poll_interval(&self) -> Duration
pub fn poll_interval(&self) -> Duration
How often the worker checks for sealed segments.
pub fn trace_stem(&self) -> &str
pub fn trace_stem(&self) -> &str
File stem used for segment matching (e.g. “trace” for “trace.0.bin”).