Struct WriteBackProcessor
pub struct WriteBackProcessor { /* private fields */ }Available on crate features
dial9 and pipeline only.Expand description
Writes the current payload bytes back to disk. If a
write_back_extension metadata key is present, the bytes are written to
{original}{extension} and the original segment file is removed.
When dir is set, the file is written to that directory instead of
alongside the original.
Implementations
impl WriteBackProcessor
impl WriteBackProcessor
pub fn to_dir(dir: PathBuf) -> WriteBackProcessor
pub fn to_dir(dir: PathBuf) -> WriteBackProcessor
Write to dir instead of alongside the original segment.