Enum FieldType
#[non_exhaustive]#[repr(u8)]pub enum FieldType {
Show 30 variants
I64 = 1,
F64 = 2,
Bool = 3,
String = 4,
Bytes = 5,
PooledStackFrames = 6,
PooledString = 7,
StackFrames = 8,
Varint = 9,
StringMap = 10,
U8 = 11,
U16 = 12,
U32 = 13,
DynamicList = 14,
DynamicMap = 15,
OptionalI64 = 129,
OptionalF64 = 130,
OptionalBool = 131,
OptionalString = 132,
OptionalBytes = 133,
OptionalPooledStackFrames = 134,
OptionalPooledString = 135,
OptionalStackFrames = 136,
OptionalVarint = 137,
OptionalStringMap = 138,
OptionalU8 = 139,
OptionalU16 = 140,
OptionalU32 = 141,
OptionalDynamicList = 142,
OptionalDynamicMap = 143,
}Available on crate feature
dial9 only.Expand description
Wire type tags for field types.
The high bit (0x80) is reserved as an “optional” modifier. When set, the
field is preceded by a 1-byte presence prefix on the wire: 0x00 means
absent (decoded as FieldValueRef::None), 0x01 means present (followed
by the inner type’s normal encoding). The inner type tag is tag & 0x7F.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
I64 = 1
F64 = 2
Bool = 3
String = 4
Bytes = 5
PooledStackFrames = 6
PooledString = 7
StackFrames = 8
Varint = 9
StringMap = 10
U8 = 11
U16 = 12
U32 = 13
DynamicList = 14
DynamicMap = 15
OptionalI64 = 129
OptionalF64 = 130
OptionalBool = 131
OptionalString = 132
OptionalBytes = 133
OptionalPooledStackFrames = 134
OptionalPooledString = 135
OptionalStackFrames = 136
OptionalVarint = 137
OptionalStringMap = 138
OptionalU8 = 139
OptionalU16 = 140
OptionalU32 = 141
OptionalDynamicList = 142
OptionalDynamicMap = 143
Implementations
impl FieldType
impl FieldType
pub const OPTIONAL_BIT: u8 = 0x80
pub const OPTIONAL_BIT: u8 = 0x80
The high bit used to mark a field type as optional on the wire.
pub fn from_tag(tag: u8) -> Option<FieldType>
pub fn is_optional(self) -> bool
pub fn is_optional(self) -> bool
Returns true if this is an optional field type.