Struct TokioHooks
#[non_exhaustive]pub struct TokioHooks { /* private fields */ }dial9 only.Expand description
User-provided callbacks to run alongside dial9’s internal Tokio runtime hooks.
All callbacks are composed with dial9’s internal hooks: dial9 always runs first, then the user callbacks fire in registration order. This applies to all 8 hooks.
Registering the same hook multiple times (either within one closure or
across multiple with_tokio_hooks calls) stacks the callbacks — all
registered callbacks will fire.
Example
use dial9_tokio_telemetry::telemetry::{TokioHooks, TracedRuntime, NullWriter};
let mut builder = tokio::runtime::Builder::new_multi_thread();
builder.worker_threads(4).enable_all();
let (runtime, guard) = TracedRuntime::builder()
.with_tokio_hooks(|h| {
h.on_thread_start(|| println!("started"));
h.on_thread_stop(|| println!("stopping"));
})
.build_and_start_with_writer(builder, NullWriter)
.unwrap();Implementations
impl TokioHooks
impl TokioHooks
pub fn on_thread_start(
&mut self,
f: impl Fn() + Send + Sync + 'static,
) -> &mut TokioHooks
pub fn on_thread_start( &mut self, f: impl Fn() + Send + Sync + 'static, ) -> &mut TokioHooks
Register a callback to run when a runtime worker thread starts.
Multiple callbacks can be registered; they fire in registration order.
pub fn on_thread_stop(
&mut self,
f: impl Fn() + Send + Sync + 'static,
) -> &mut TokioHooks
pub fn on_thread_stop( &mut self, f: impl Fn() + Send + Sync + 'static, ) -> &mut TokioHooks
Register a callback to run when a runtime worker thread stops.
Multiple callbacks can be registered; they fire in registration order.
pub fn on_thread_park(
&mut self,
f: impl Fn() + Send + Sync + 'static,
) -> &mut TokioHooks
pub fn on_thread_park( &mut self, f: impl Fn() + Send + Sync + 'static, ) -> &mut TokioHooks
Register a callback to run when a runtime worker thread parks.
Multiple callbacks can be registered; they fire in registration order.
pub fn on_thread_unpark(
&mut self,
f: impl Fn() + Send + Sync + 'static,
) -> &mut TokioHooks
pub fn on_thread_unpark( &mut self, f: impl Fn() + Send + Sync + 'static, ) -> &mut TokioHooks
Register a callback to run when a runtime worker thread unparks.
Multiple callbacks can be registered; they fire in registration order.
pub fn on_task_spawn(
&mut self,
f: impl Fn(&TaskMeta<'_>) + Send + Sync + 'static,
) -> &mut TokioHooks
pub fn on_task_spawn( &mut self, f: impl Fn(&TaskMeta<'_>) + Send + Sync + 'static, ) -> &mut TokioHooks
Register a callback to run when a task is spawned.
Multiple callbacks can be registered; they fire in registration order.
pub fn on_task_terminate(
&mut self,
f: impl Fn(&TaskMeta<'_>) + Send + Sync + 'static,
) -> &mut TokioHooks
pub fn on_task_terminate( &mut self, f: impl Fn(&TaskMeta<'_>) + Send + Sync + 'static, ) -> &mut TokioHooks
Register a callback to run when a task terminates.
Multiple callbacks can be registered; they fire in registration order.
pub fn on_before_task_poll(
&mut self,
f: impl Fn(&TaskMeta<'_>) + Send + Sync + 'static,
) -> &mut TokioHooks
pub fn on_before_task_poll( &mut self, f: impl Fn(&TaskMeta<'_>) + Send + Sync + 'static, ) -> &mut TokioHooks
Register a callback to run before a task is polled.
Multiple callbacks can be registered; they fire in registration order.
pub fn on_after_task_poll(
&mut self,
f: impl Fn(&TaskMeta<'_>) + Send + Sync + 'static,
) -> &mut TokioHooks
pub fn on_after_task_poll( &mut self, f: impl Fn(&TaskMeta<'_>) + Send + Sync + 'static, ) -> &mut TokioHooks
Register a callback to run after a task is polled.
Multiple callbacks can be registered; they fire in registration order.