Struct Schema
pub struct Schema { /* private fields */ }Available on crate feature
dial9 only.Expand description
A schema handle returned by Encoder::register_schema or created via
Schema::new.
Carries the full schema definition (name + fields) so it can auto-register
itself with any encoder on first use. This means a Schema created on one
encoder can be passed to a different encoder and it will just work.
Schema is cheap to clone (internally Arc-backed).
Implementations
impl Schema
impl Schema
pub fn new(name: &str, fields: Vec<FieldDef>) -> Schema
pub fn new(name: &str, fields: Vec<FieldDef>) -> Schema
Create a schema handle without an encoder.
The schema will be lazily registered the first time it is passed to
Encoder::write_event.
pub fn from_entry(entry: SchemaEntry) -> Schema
pub fn from_entry(entry: SchemaEntry) -> Schema
Create a schema handle from a complete SchemaEntry.