Struct SchemaEntry
#[non_exhaustive]pub struct SchemaEntry { /* private fields */ }Available on crate feature
dial9 only.Expand description
Describes the layout of an event type. Does not carry a wire type ID — the ID is assigned by the encoder and tracked externally by the registry.
Implementations
impl SchemaEntry
impl SchemaEntry
pub fn new(
name: impl Into<String>,
has_timestamp: bool,
fields: impl IntoIterator<Item = FieldDef>,
) -> SchemaEntry
pub fn new( name: impl Into<String>, has_timestamp: bool, fields: impl IntoIterator<Item = FieldDef>, ) -> SchemaEntry
Construct a new schema entry.
pub fn with_annotations(
name: impl Into<String>,
has_timestamp: bool,
fields: impl IntoIterator<Item = FieldDef>,
annotations: impl IntoIterator<Item = FieldAnnotation>,
) -> SchemaEntry
pub fn with_annotations( name: impl Into<String>, has_timestamp: bool, fields: impl IntoIterator<Item = FieldDef>, annotations: impl IntoIterator<Item = FieldAnnotation>, ) -> SchemaEntry
Construct a schema entry with annotations.
pub fn has_timestamp(&self) -> bool
pub fn has_timestamp(&self) -> bool
Whether events of this type carry a packed timestamp in the event header.
pub fn annotations(&self) -> &[FieldAnnotation]
pub fn annotations(&self) -> &[FieldAnnotation]
Per-field annotations.