Struct EventEncoder
pub struct EventEncoder<'a, W = Vec<u8>>where
W: Write,{ /* private fields */ }Available on crate feature
dial9 only.Expand description
Short-lived encoder for writing the fields of a single event.
Created by crate::encoder::Encoder::write and passed to
crate::TraceEvent::encode_fields, analogous to fmt::Formatter.
Implementations
impl<'a, W> EventEncoder<'a, W>where
W: Write,
impl<'a, W> EventEncoder<'a, W>where
W: Write,
pub fn write_u8(&mut self, v: u8) -> Result<(), Error>
pub fn write_u16(&mut self, v: u16) -> Result<(), Error>
pub fn write_u32(&mut self, v: u32) -> Result<(), Error>
pub fn write_u64(&mut self, v: u64) -> Result<(), Error>
pub fn write_i64(&mut self, v: i64) -> Result<(), Error>
pub fn write_f64(&mut self, v: f64) -> Result<(), Error>
pub fn write_bool(&mut self, v: bool) -> Result<(), Error>
pub fn write_string(&mut self, v: &str) -> Result<(), Error>
pub fn write_bytes(&mut self, v: &[u8]) -> Result<(), Error>
pub fn write_interned(&mut self, v: InternedString) -> Result<(), Error>
pub fn write_interned_stack_frames( &mut self, v: InternedStackFrames, ) -> Result<(), Error>
pub fn write_stack_frames(&mut self, v: &StackFrames) -> Result<(), Error>
pub fn write_string_map(&mut self, v: &[(String, String)]) -> Result<(), Error>
pub fn write_field_value(
&mut self,
value: &FieldValue,
field_type: FieldType,
) -> Result<(), Error>
pub fn write_field_value( &mut self, value: &FieldValue, field_type: FieldType, ) -> Result<(), Error>
Write a FieldValue with its associated FieldType.
For optional field types, writes the presence prefix byte (0x00 for
None, 0x01 + inner encoding for present values).