Struct SpanBuilder
pub struct SpanBuilder {
pub span_kind: Option<SpanKind>,
pub name: Cow<'static, str>,
pub start_time: Option<SystemTime>,
pub attributes: Option<Vec<KeyValue>>,
pub events: Option<Vec<Event>>,
pub links: Option<Vec<Link>>,
}Available on crate features
opentelemetry and trace only.Expand description
SpanBuilder allows span attributes to be configured before the span
has started.
use opentelemetry::{
global,
trace::{TracerProvider, SpanBuilder, SpanKind, Tracer},
};
let tracer = global::tracer("example-tracer");
// The builder can be used to create a span directly with the tracer
let _span = tracer.build(SpanBuilder {
name: "example-span-name".into(),
span_kind: Some(SpanKind::Server),
..Default::default()
});
// Or used with builder pattern
let _span = tracer
.span_builder("example-span-name")
.with_kind(SpanKind::Server)
.start(&tracer);Fields
span_kind: Option<SpanKind>Span kind
name: Cow<'static, str>Span name
start_time: Option<SystemTime>Span start time
attributes: Option<Vec<KeyValue>>Span attributes that are provided at the span creation time. More attributes can be added afterwards. Providing duplicate keys will result in multiple attributes with the same key, as there is no de-duplication performed.
events: Option<Vec<Event>>Span events
links: Option<Vec<Link>>Span Links
Implementations
impl SpanBuilder
SpanBuilder methods
impl SpanBuilder
SpanBuilder methods
pub fn from_name<T>(name: T) -> SpanBuilder
pub fn from_name<T>(name: T) -> SpanBuilder
Create a new span builder from a span name
pub fn with_kind(self, span_kind: SpanKind) -> SpanBuilder
pub fn with_kind(self, span_kind: SpanKind) -> SpanBuilder
Assign span kind
pub fn with_start_time<T>(self, start_time: T) -> SpanBuilderwhere
T: Into<SystemTime>,
pub fn with_start_time<T>(self, start_time: T) -> SpanBuilderwhere
T: Into<SystemTime>,
Assign span start time
pub fn with_attributes<I>(self, attributes: I) -> SpanBuilderwhere
I: IntoIterator<Item = KeyValue>,
pub fn with_attributes<I>(self, attributes: I) -> SpanBuilderwhere
I: IntoIterator<Item = KeyValue>,
Assign span attributes from an iterable. Providing duplicate keys will result in multiple attributes with the same key, as there is no de-duplication performed.
pub fn with_events(self, events: Vec<Event>) -> SpanBuilder
pub fn with_events(self, events: Vec<Event>) -> SpanBuilder
Assign events
pub fn with_links(self, links: Vec<Link>) -> SpanBuilder
pub fn with_links(self, links: Vec<Link>) -> SpanBuilder
Assign links