pub struct NonBlocking { /* private fields */ }std only.Expand description
A non-blocking writer.
While the line between “blocking” and “non-blocking” IO is fuzzy, writing to a file is typically
considered to be a blocking operation. For an application whose Subscriber writes spans and events
as they are emitted, an application might find the latency profile to be unacceptable.
NonBlocking moves the writing out of an application’s data path by sending spans and events
to a dedicated logging thread.
This struct implements [MakeWriter] from the tracing-subscriber
crate. Therefore, it can be used with the tracing_subscriber::fmt module
or with any other subscriber/layer implementation that uses the MakeWriter trait.
Implementations
impl NonBlocking
impl NonBlocking
pub fn new<T>(writer: T) -> (NonBlocking, WorkerGuard)
pub fn new<T>(writer: T) -> (NonBlocking, WorkerGuard)
Returns a new NonBlocking writer wrapping the provided writer.
The returned NonBlocking writer will have the default configuration values.
Other configurations can be specified using the builder interface.
pub fn error_counter(&self) -> ErrorCounter
pub fn error_counter(&self) -> ErrorCounter
Returns a counter for the number of times logs where dropped. This will always return zero if
NonBlocking is not lossy.