NonBlockingBuilder

Struct NonBlockingBuilder 

pub struct NonBlockingBuilder { /* private fields */ }
Available on crate feature std only.
A builder for NonBlocking.

Implementations



impl NonBlockingBuilder

pub fn buffered_lines_limit( self, buffered_lines_limit: usize, ) -> NonBlockingBuilder

Sets the number of lines to buffer before dropping logs or exerting backpressure on senders

pub fn lossy(self, is_lossy: bool) -> NonBlockingBuilder

Sets whether NonBlocking should be lossy or not.

If set to true, logs will be dropped when the buffered limit is reached. If false, backpressure will be exerted on senders, blocking them until the buffer has capacity again.

By default, the built NonBlocking will be lossy.

pub fn thread_name(self, name: &str) -> NonBlockingBuilder

Override the worker thread’s name.

The default worker thread name is “tracing-appender”.

pub fn finish<T>(self, writer: T) -> (NonBlocking, WorkerGuard)
where T: Write + Send + 'static,

Completes the builder, returning the configured NonBlocking.