Struct WorkerGuard
pub struct WorkerGuard { /* private fields */ }std only.Expand description
A guard that flushes spans/events associated to a NonBlocking on a drop
Writing to a NonBlocking writer will not immediately write a span or event to the underlying
output. Instead, the span or event will be written by a dedicated logging thread at some later point.
To increase throughput, the non-blocking writer will flush to the underlying output on
a periodic basis rather than every time a span or event is written. This means that if the program
terminates abruptly (such as through an uncaught panic or a std::process::exit), some spans
or events may not be written.
Since spans/events and events recorded near a crash are often necessary for diagnosing the failure,
WorkerGuard provides a mechanism to ensure that all buffered logs are flushed to their output.
WorkerGuard should be assigned in the main function or whatever the entrypoint of the program is.
This will ensure that the guard will be dropped during an unwinding or when main exits
successfully.
Examples
fn main () {
let (non_blocking, _guard) = tracing_appender::non_blocking(std::io::stdout());
let subscriber = tracing_subscriber::fmt().with_writer(non_blocking);
tracing::subscriber::with_default(subscriber.finish(), || {
// Emit some tracing events within context of the non_blocking `_guard` and tracing subscriber
tracing::event!(tracing::Level::INFO, "Hello");
});
// Exiting the context of `main` will drop the `_guard` and any remaining logs should get flushed
}Trait Implementations
impl Debug for WorkerGuard
impl Debug for WorkerGuard