Struct EmulateTlsProfileLayer
#[non_exhaustive]pub struct EmulateTlsProfileLayer { /* private fields */ }Available on crate feature
boring only.Implementations
impl EmulateTlsProfileLayer
impl EmulateTlsProfileLayer
pub fn new() -> EmulateTlsProfileLayer
pub fn maybe_with_config_overwrites(
self,
config: Option<TlsClientConfig>,
) -> EmulateTlsProfileLayer
pub fn maybe_with_config_overwrites( self, config: Option<TlsClientConfig>, ) -> EmulateTlsProfileLayer
Set config pieces that are always layered on top of the emulated profile (they override the profile).
pub fn maybe_set_config_overwrites(
&mut self,
config: Option<TlsClientConfig>,
) -> &mut EmulateTlsProfileLayer
pub fn maybe_set_config_overwrites( &mut self, config: Option<TlsClientConfig>, ) -> &mut EmulateTlsProfileLayer
Set config pieces that are always layered on top of the emulated profile (they override the profile).
pub fn with_config_overwrites(
self,
config: TlsClientConfig,
) -> EmulateTlsProfileLayer
pub fn with_config_overwrites( self, config: TlsClientConfig, ) -> EmulateTlsProfileLayer
Set config pieces that are always layered on top of the emulated profile (they override the profile).
pub fn set_config_overwrites(
&mut self,
config: TlsClientConfig,
) -> &mut EmulateTlsProfileLayer
pub fn set_config_overwrites( &mut self, config: TlsClientConfig, ) -> &mut EmulateTlsProfileLayer
Set config pieces that are always layered on top of the emulated profile (they override the profile).
pub fn without_config_overwrites(self) -> EmulateTlsProfileLayer
pub fn without_config_overwrites(self) -> EmulateTlsProfileLayer
Set config pieces that are always layered on top of the emulated profile (they override the profile).
pub fn unset_config_overwrites(&mut self) -> &mut EmulateTlsProfileLayer
pub fn unset_config_overwrites(&mut self) -> &mut EmulateTlsProfileLayer
Set config pieces that are always layered on top of the emulated profile (they override the profile).