Struct TlsClientSessionCache
pub struct TlsClientSessionCache<K = TlsClientSessionKey, V = TlsClientSession> { /* private fields */ }Available on crate feature
boring only.Expand description
Bounded in-memory sessions: the newest few per key, evicting the least recently stored key once full.
The default TlsClientSessionStore, also usable for other entries.
Implementations
impl<K, V> TlsClientSessionCache<K, V>
impl<K, V> TlsClientSessionCache<K, V>
pub fn new(
max_keys: NonZero<usize>,
per_key: NonZero<usize>,
) -> TlsClientSessionCache<K, V>
pub fn new( max_keys: NonZero<usize>, per_key: NonZero<usize>, ) -> TlsClientSessionCache<K, V>
Keep at most per_key values for each of at most max_keys keys.
pub fn insert(&self, key: K, value: V)
pub fn insert(&self, key: K, value: V)
Store value as the newest one for key.
pub fn most_recent<'k>(
&self,
keys: impl IntoIterator<Item = &'k K>,
) -> Option<&'k K>where
K: 'k,
pub fn most_recent<'k>(
&self,
keys: impl IntoIterator<Item = &'k K>,
) -> Option<&'k K>where
K: 'k,
Which of keys holds values and was stored to most recently.