Struct AeadKey
pub struct AeadKey(/* private fields */);Available on crate feature
boring only.Expand description
A prepared AEAD key. Nonces must never repeat for encryption with one key.
Implementations
impl AeadKey
impl AeadKey
pub fn new(algorithm: Algorithm, key: &[u8]) -> Result<AeadKey, ErrorStack>
pub fn seal_in_place(
&self,
nonce: &[u8; 12],
aad: &[u8],
buffer: &mut [u8],
) -> Result<(), ErrorStack>
pub fn seal_in_place( &self, nonce: &[u8; 12], aad: &[u8], buffer: &mut [u8], ) -> Result<(), ErrorStack>
Encrypt in place. The last 16 bytes of buffer are reserved for the tag.
pub fn open_in_place<'a>(
&self,
nonce: &[u8; 12],
aad: &[u8],
buffer: &'a mut [u8],
) -> Result<&'a mut [u8], ErrorStack>
pub fn open_in_place<'a>( &self, nonce: &[u8; 12], aad: &[u8], buffer: &'a mut [u8], ) -> Result<&'a mut [u8], ErrorStack>
Authenticate and decrypt in place, returning the plaintext prefix.