Function hash
pub fn hash(t: MessageDigest, data: &[u8]) -> Result<DigestBytes, ErrorStack>Available on crate feature
boring only.Expand description
Computes the hash of the data with the non-XOF hasher t.
pub fn hash(t: MessageDigest, data: &[u8]) -> Result<DigestBytes, ErrorStack>boring only.Computes the hash of the data with the non-XOF hasher t.