Struct SslCredential
pub struct SslCredential(/* private fields */);Available on crate feature
boring only.Expand description
A credential.
Implementations
impl SslCredential
impl SslCredential
pub fn builder() -> Result<SslCredentialBuilder, ErrorStack>
pub fn builder() -> Result<SslCredentialBuilder, ErrorStack>
Creates an X.509 credential builder. Configure a chain and private key (or private key method) before adding the built credential to a context or SSL.
This corresponds to SSL_CREDENTIAL_new_x509.
pub fn new_ex_index<T>() -> Result<Index<SslCredential, T>, ErrorStack>
pub fn new_ex_index<T>() -> Result<Index<SslCredential, T>, ErrorStack>
Returns a new extra data index.
Each invocation of this function is guaranteed to return a distinct index. These can be used to store data in the context that can be retrieved later by callbacks, for example.
This corresponds to SSL_C_get_ex_new_index.
Methods from Deref<Target = SslCredentialRef>
pub fn is_complete(&self) -> bool
pub fn is_complete(&self) -> bool
Whether the credential has the certificate and key material it requires. This does not validate the chain against a trust store.
This corresponds to SSL_CREDENTIAL_is_complete.
pub fn ex_data<T>(&self, index: Index<SslCredential, T>) -> Option<&T>
pub fn ex_data<T>(&self, index: Index<SslCredential, T>) -> Option<&T>
Returns a reference to the extra data at the specified index.
This corresponds to SSL_CREDENTIAL_get_ex_data.