Stackable

Trait Stackable 

pub trait Stackable: ForeignType {
    type StackType;
}
Available on crate feature boring only.
Trait implemented by types which can be placed in a stack.

It should not be implemented for any type outside of this crate.

Required Associated Types

type StackType

The C stack type for this element.

Generally called stack_st_{ELEMENT_TYPE}, normally hidden by the STACK_OF(ELEMENT_TYPE) macro in the OpenSSL API.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors



impl Stackable for Asn1Object



type StackType = stack_st_ASN1_OBJECT



impl Stackable for GeneralName



type StackType = stack_st_GENERAL_NAME



impl Stackable for OpensslString



type StackType = stack_st_OPENSSL_STRING



impl Stackable for SrtpProtectionProfile



type StackType = stack_st_SRTP_PROTECTION_PROFILE



impl Stackable for SslCipher



type StackType = stack_st_SSL_CIPHER



impl Stackable for X509



type StackType = stack_st_X509



impl Stackable for X509Extension



type StackType = stack_st_X509_EXTENSION



impl Stackable for X509Name



type StackType = stack_st_X509_NAME



impl Stackable for X509Object



type StackType = stack_st_X509_OBJECT