Function built_on
pub fn built_on() -> &'static strAvailable on crate feature
boring only.Expand description
The date of the build process in the form “built on: …” if available or “built on: date not available” otherwise.
pub fn built_on() -> &'static strboring only.The date of the build process in the form “built on: …” if available or “built on: date not available” otherwise.