Function dir
pub fn dir() -> &'static strAvailable on crate feature
boring only.Expand description
The “OPENSSLDIR” setting of the library build in the form “OPENSSLDIR: “…”“ if available or “OPENSSLDIR: N/A” otherwise.
pub fn dir() -> &'static strboring only.The “OPENSSLDIR” setting of the library build in the form “OPENSSLDIR: “…”“ if available or “OPENSSLDIR: N/A” otherwise.