Function version
pub fn version() -> &'static strAvailable on crate feature
boring only.Expand description
The text variant of the version number and the release date. For example, “OpenSSL 0.9.5a 1 Apr 2000”.
pub fn version() -> &'static strboring only.The text variant of the version number and the release date. For example, “OpenSSL 0.9.5a 1 Apr 2000”.