Struct MaybeAlpnSelected
pub struct MaybeAlpnSelected(/* private fields */);Available on crate features
boring and dial9 only.Trait Implementations
impl Clone for MaybeAlpnSelected
impl Clone for MaybeAlpnSelected
fn clone(&self) -> MaybeAlpnSelected
fn clone(&self) -> MaybeAlpnSelected
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for MaybeAlpnSelected
impl Debug for MaybeAlpnSelected
impl TraceField for MaybeAlpnSelected
impl TraceField for MaybeAlpnSelected
fn field_type() -> FieldType
fn encode<W>(&self, enc: &mut EventEncoder<'_, W>) -> Result<(), Error>where
W: Write,
fn encode<W>(&self, enc: &mut EventEncoder<'_, W>) -> Result<(), Error>where
W: Write,
Encode this field’s value into the event encoder.
fn decode_ref<'a>(
val: &FieldValueRef<'a>,
) -> Option<<MaybeAlpnSelected as TraceField>::Ref<'a>>
fn decode_ref<'a>( val: &FieldValueRef<'a>, ) -> Option<<MaybeAlpnSelected as TraceField>::Ref<'a>>
Extract this field’s value from a zero-copy FieldValueRef.
fn is_optional() -> bool
fn is_optional() -> bool
Whether this field is optional on the wire (high-bit modifier).
fn decode_missing<'a>() -> Option<Self::Ref<'a>>
fn decode_missing<'a>() -> Option<Self::Ref<'a>>
Called when the field is absent from the wire data (not in the schema).
Returns
None for required fields (decode failure) and Some(None) for
optional fields.Auto Trait Implementations
impl Freeze for MaybeAlpnSelected
impl RefUnwindSafe for MaybeAlpnSelected
impl Send for MaybeAlpnSelected
impl Sync for MaybeAlpnSelected
impl Unpin for MaybeAlpnSelected
impl UnsafeUnpin for MaybeAlpnSelected
impl UnwindSafe for MaybeAlpnSelected