Struct MaybeServerName
pub struct MaybeServerName(/* private fields */);Available on crate features
boring and dial9 only.Trait Implementations
impl Clone for MaybeServerName
impl Clone for MaybeServerName
fn clone(&self) -> MaybeServerName
fn clone(&self) -> MaybeServerName
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for MaybeServerName
impl Debug for MaybeServerName
impl TraceField for MaybeServerName
impl TraceField for MaybeServerName
fn field_type() -> FieldType
fn encode<W>(&self, enc: &mut EventEncoder<'_, W>) -> Result<(), Error>where
W: Write,
fn encode<W>(&self, enc: &mut EventEncoder<'_, W>) -> Result<(), Error>where
W: Write,
Encode this field’s value into the event encoder.
fn decode_ref<'a>(
val: &FieldValueRef<'a>,
) -> Option<<MaybeServerName as TraceField>::Ref<'a>>
fn decode_ref<'a>( val: &FieldValueRef<'a>, ) -> Option<<MaybeServerName as TraceField>::Ref<'a>>
Extract this field’s value from a zero-copy FieldValueRef.
fn is_optional() -> bool
fn is_optional() -> bool
Whether this field is optional on the wire (high-bit modifier).
fn decode_missing<'a>() -> Option<Self::Ref<'a>>
fn decode_missing<'a>() -> Option<Self::Ref<'a>>
Called when the field is absent from the wire data (not in the schema).
Returns
None for required fields (decode failure) and Some(None) for
optional fields.Auto Trait Implementations
impl Freeze for MaybeServerName
impl RefUnwindSafe for MaybeServerName
impl Send for MaybeServerName
impl Sync for MaybeServerName
impl Unpin for MaybeServerName
impl UnsafeUnpin for MaybeServerName
impl UnwindSafe for MaybeServerName