Struct InMemoryBoringMitmCertIssuer
pub struct InMemoryBoringMitmCertIssuer { /* private fields */ }boring only.Expand description
A BoringMitmCertIssuer which mirrors the original reference
using its internal (in-memory) CA crt/key pair to sign.
Implementations
impl InMemoryBoringMitmCertIssuer
impl InMemoryBoringMitmCertIssuer
pub fn new(ca_crt: X509, ca_key: PKey<Private>) -> InMemoryBoringMitmCertIssuer
pub fn new(ca_crt: X509, ca_key: PKey<Private>) -> InMemoryBoringMitmCertIssuer
Create a new InMemoryBoringMitmCertIssuer.
pub fn try_new_self_signed(
data: &SelfSignedData,
) -> Result<InMemoryBoringMitmCertIssuer, Box<dyn Error + Send + Sync>>
pub fn try_new_self_signed( data: &SelfSignedData, ) -> Result<InMemoryBoringMitmCertIssuer, Box<dyn Error + Send + Sync>>
Create a new InMemoryBoringMitmCertIssuer with self-signed CA using the given data.
pub fn maybe_with_revocation(
self,
revocation: Option<Arc<dyn BoringMitmRevocation>>,
) -> InMemoryBoringMitmCertIssuer
pub fn maybe_with_revocation( self, revocation: Option<Arc<dyn BoringMitmRevocation>>, ) -> InMemoryBoringMitmCertIssuer
Attach a BoringMitmRevocation responder. Its CA must be the same
one this issuer signs with, so the stamped pointers resolve. Issued
leaves then carry the responder’s revocation extensions.
pub fn maybe_set_revocation(
&mut self,
revocation: Option<Arc<dyn BoringMitmRevocation>>,
) -> &mut InMemoryBoringMitmCertIssuer
pub fn maybe_set_revocation( &mut self, revocation: Option<Arc<dyn BoringMitmRevocation>>, ) -> &mut InMemoryBoringMitmCertIssuer
Attach a BoringMitmRevocation responder. Its CA must be the same
one this issuer signs with, so the stamped pointers resolve. Issued
leaves then carry the responder’s revocation extensions.
pub fn with_revocation(
self,
revocation: Arc<dyn BoringMitmRevocation>,
) -> InMemoryBoringMitmCertIssuer
pub fn with_revocation( self, revocation: Arc<dyn BoringMitmRevocation>, ) -> InMemoryBoringMitmCertIssuer
Attach a BoringMitmRevocation responder. Its CA must be the same
one this issuer signs with, so the stamped pointers resolve. Issued
leaves then carry the responder’s revocation extensions.
pub fn set_revocation(
&mut self,
revocation: Arc<dyn BoringMitmRevocation>,
) -> &mut InMemoryBoringMitmCertIssuer
pub fn set_revocation( &mut self, revocation: Arc<dyn BoringMitmRevocation>, ) -> &mut InMemoryBoringMitmCertIssuer
Attach a BoringMitmRevocation responder. Its CA must be the same
one this issuer signs with, so the stamped pointers resolve. Issued
leaves then carry the responder’s revocation extensions.
pub fn without_revocation(self) -> InMemoryBoringMitmCertIssuer
pub fn without_revocation(self) -> InMemoryBoringMitmCertIssuer
Attach a BoringMitmRevocation responder. Its CA must be the same
one this issuer signs with, so the stamped pointers resolve. Issued
leaves then carry the responder’s revocation extensions.
pub fn unset_revocation(&mut self) -> &mut InMemoryBoringMitmCertIssuer
pub fn unset_revocation(&mut self) -> &mut InMemoryBoringMitmCertIssuer
Attach a BoringMitmRevocation responder. Its CA must be the same
one this issuer signs with, so the stamped pointers resolve. Issued
leaves then carry the responder’s revocation extensions.