Struct TlsClientConfig
pub struct TlsClientConfig(/* private fields */);boring only.Expand description
A backend agnostic builder for the common TLS configs.
It holds a set of fine grained config extensions (e.g. TlsAlpn, TlsServerVerify)
and exposes typed setters for the settings both TLS backends support.
Backend crates add setters for their backend-specific pieces via extension
traits (RustlsClientConfigExt or BoringServerConfigExt).
Implementations
impl TlsClientConfig
impl TlsClientConfig
pub fn new() -> TlsClientConfig
pub fn new() -> TlsClientConfig
Create an empty config.
pub fn default_http() -> TlsClientConfig
pub fn default_http() -> TlsClientConfig
Create a default TlsClientConfig that enables:
- ALPN: H2, http1.1
- Keylogger:
KeyLogIntent::Environment
pub fn write_to(&self, extensions: &Extensions)
pub fn write_to(&self, extensions: &Extensions)
Transfer this config’s pieces onto extensions (appending, so they
override existing entries of the same type — newest-wins). Use this to
transfer the tls config to e.g. request extensions
pub fn with_alpn(
self,
protocols: SmallVec<[ApplicationProtocol; 2]>,
) -> TlsClientConfig
pub fn with_alpn( self, protocols: SmallVec<[ApplicationProtocol; 2]>, ) -> TlsClientConfig
Set the ALPN protocols to offer.
pub fn set_alpn(
&mut self,
protocols: SmallVec<[ApplicationProtocol; 2]>,
) -> &mut TlsClientConfig
pub fn set_alpn( &mut self, protocols: SmallVec<[ApplicationProtocol; 2]>, ) -> &mut TlsClientConfig
Set the ALPN protocols to offer.
pub fn with_alpn_http_auto(self) -> TlsClientConfig
pub fn with_alpn_http_auto(self) -> TlsClientConfig
Offer HTTP/2 and HTTP/1.1 via ALPN.
pub fn set_alpn_http_auto(&mut self) -> &mut TlsClientConfig
pub fn set_alpn_http_auto(&mut self) -> &mut TlsClientConfig
Offer HTTP/2 and HTTP/1.1 via ALPN.
pub fn with_alpn_http_1(self) -> TlsClientConfig
pub fn with_alpn_http_1(self) -> TlsClientConfig
Offer HTTP/1.1 only via ALPN.
pub fn set_alpn_http_1(&mut self) -> &mut TlsClientConfig
pub fn set_alpn_http_1(&mut self) -> &mut TlsClientConfig
Offer HTTP/1.1 only via ALPN.
pub fn with_alpn_http_2(self) -> TlsClientConfig
pub fn with_alpn_http_2(self) -> TlsClientConfig
Offer HTTP/2 only via ALPN.
pub fn set_alpn_http_2(&mut self) -> &mut TlsClientConfig
pub fn set_alpn_http_2(&mut self) -> &mut TlsClientConfig
Offer HTTP/2 only via ALPN.
pub fn with_server_name(self, server_name: Host) -> TlsClientConfig
pub fn with_server_name(self, server_name: Host) -> TlsClientConfig
Set the client SNI (server name) to send.
Overrides the SNI the connector would otherwise derive: the transport
authority host, or for a tunnel connector, the TlsTunnel sni
pub fn set_server_name(&mut self, server_name: Host) -> &mut TlsClientConfig
pub fn set_server_name(&mut self, server_name: Host) -> &mut TlsClientConfig
Set the client SNI (server name) to send.
Overrides the SNI the connector would otherwise derive: the transport
authority host, or for a tunnel connector, the TlsTunnel sni
pub fn with_server_verify(self, mode: ServerVerifyMode) -> TlsClientConfig
pub fn with_server_verify(self, mode: ServerVerifyMode) -> TlsClientConfig
Set how the server certificate is verified.
pub fn set_server_verify(
&mut self,
mode: ServerVerifyMode,
) -> &mut TlsClientConfig
pub fn set_server_verify( &mut self, mode: ServerVerifyMode, ) -> &mut TlsClientConfig
Set how the server certificate is verified.
pub fn with_supported_versions(
self,
versions: Vec<ProtocolVersion>,
) -> TlsClientConfig
pub fn with_supported_versions( self, versions: Vec<ProtocolVersion>, ) -> TlsClientConfig
Set the supported protocol versions.
pub fn set_supported_versions(
&mut self,
versions: Vec<ProtocolVersion>,
) -> &mut TlsClientConfig
pub fn set_supported_versions( &mut self, versions: Vec<ProtocolVersion>, ) -> &mut TlsClientConfig
Set the supported protocol versions.
pub fn with_keylog(self, intent: KeyLogIntent) -> TlsClientConfig
pub fn with_keylog(self, intent: KeyLogIntent) -> TlsClientConfig
Set the keylog intent.
pub fn set_keylog(&mut self, intent: KeyLogIntent) -> &mut TlsClientConfig
pub fn set_keylog(&mut self, intent: KeyLogIntent) -> &mut TlsClientConfig
Set the keylog intent.
pub fn with_client_auth(self, client_auth: ClientAuth) -> TlsClientConfig
pub fn with_client_auth(self, client_auth: ClientAuth) -> TlsClientConfig
Set the client certificate authentication material (mTLS).
pub fn set_client_auth(
&mut self,
client_auth: ClientAuth,
) -> &mut TlsClientConfig
pub fn set_client_auth( &mut self, client_auth: ClientAuth, ) -> &mut TlsClientConfig
Set the client certificate authentication material (mTLS).
pub fn with_store_server_cert_chain(self, store: bool) -> TlsClientConfig
pub fn with_store_server_cert_chain(self, store: bool) -> TlsClientConfig
Set whether the peer certificate chain is captured.
pub fn set_store_server_cert_chain(
&mut self,
store: bool,
) -> &mut TlsClientConfig
pub fn set_store_server_cert_chain( &mut self, store: bool, ) -> &mut TlsClientConfig
Set whether the peer certificate chain is captured.
pub fn as_extensions(&self) -> &Extensions