TlsClientConfig

Struct TlsClientConfig 

pub struct TlsClientConfig(/* private fields */);
Available on crate feature tls only.
A backend agnostic builder for the common TLS configs.

It holds a set of fine grained config extensions (e.g. TlsAlpn, TlsServerVerify) and exposes typed setters for the settings both TLS backends support. Backend crates add setters for their backend-specific pieces via extension traits (RustlsClientConfigExt or BoringServerConfigExt).

Implementations



impl TlsClientConfig

pub fn new() -> TlsClientConfig

Available on crate feature boring only.

Create an empty config.

pub fn default_http() -> TlsClientConfig

Available on crate feature boring only.

Create a default TlsClientConfig that enables:

pub fn write_to(&self, extensions: &Extensions)

Available on crate feature boring only.

Transfer this config’s pieces onto extensions (appending, so they override existing entries of the same type — newest-wins). Use this to transfer the tls config to e.g. request extensions

pub fn with_alpn( self, protocols: SmallVec<[ApplicationProtocol; 2]>, ) -> TlsClientConfig

Available on crate feature boring only.

Set the ALPN protocols to offer.

pub fn set_alpn( &mut self, protocols: SmallVec<[ApplicationProtocol; 2]>, ) -> &mut TlsClientConfig

Available on crate feature boring only.

Set the ALPN protocols to offer.

pub fn with_alpn_http_auto(self) -> TlsClientConfig

Available on crate feature boring only.

Offer HTTP/2 and HTTP/1.1 via ALPN.

pub fn set_alpn_http_auto(&mut self) -> &mut TlsClientConfig

Available on crate feature boring only.

Offer HTTP/2 and HTTP/1.1 via ALPN.

pub fn with_alpn_http_1(self) -> TlsClientConfig

Available on crate feature boring only.

Offer HTTP/1.1 only via ALPN.

pub fn set_alpn_http_1(&mut self) -> &mut TlsClientConfig

Available on crate feature boring only.

Offer HTTP/1.1 only via ALPN.

pub fn with_alpn_http_2(self) -> TlsClientConfig

Available on crate feature boring only.

Offer HTTP/2 only via ALPN.

pub fn set_alpn_http_2(&mut self) -> &mut TlsClientConfig

Available on crate feature boring only.

Offer HTTP/2 only via ALPN.

pub fn with_server_name(self, server_name: Host) -> TlsClientConfig

Available on crate feature boring only.

Set the server identity used for certificate verification.

A DNS identity is also sent as SNI. An IP identity is matched against an iPAddress subject alternative name and is not sent as SNI. Overrides the identity the connector would otherwise derive from the transport authority host or [TlsTunnel::server_identity].

pub fn set_server_name(&mut self, server_name: Host) -> &mut TlsClientConfig

Available on crate feature boring only.

Set the server identity used for certificate verification.

A DNS identity is also sent as SNI. An IP identity is matched against an iPAddress subject alternative name and is not sent as SNI. Overrides the identity the connector would otherwise derive from the transport authority host or [TlsTunnel::server_identity].

pub fn with_server_verify(self, mode: ServerVerifyMode) -> TlsClientConfig

Available on crate feature boring only.

Set how the server certificate is verified.

pub fn set_server_verify( &mut self, mode: ServerVerifyMode, ) -> &mut TlsClientConfig

Available on crate feature boring only.

Set how the server certificate is verified.

pub fn with_server_cert_pins(self, pins: TlsServerCertPins) -> TlsClientConfig

Available on crate feature boring only.

Require the server leaf certificate to match an applicable pin set.

With ServerVerifyMode::Auto, normal certificate verification must also succeed. With ServerVerifyMode::Disable, applicable pins are the only certificate check.

pub fn set_server_cert_pins( &mut self, pins: TlsServerCertPins, ) -> &mut TlsClientConfig

Available on crate feature boring only.

Require the server leaf certificate to match an applicable pin set.

With ServerVerifyMode::Auto, normal certificate verification must also succeed. With ServerVerifyMode::Disable, applicable pins are the only certificate check.

pub fn try_with_server_trust_anchors( self, certificates: impl IntoIterator<Item = CertificateDer<'static>>, ) -> Result<TlsClientConfig, Box<dyn Error + Send + Sync>>

Available on crate feature boring only.

Replace the default server trust anchors with certificates.

The certificates are used only with ServerVerifyMode::Auto, and a backend-specific verifier or store takes precedence.

pub fn try_set_server_trust_anchors( &mut self, certificates: impl IntoIterator<Item = CertificateDer<'static>>, ) -> Result<&mut TlsClientConfig, Box<dyn Error + Send + Sync>>

Available on crate feature boring only.

Replace the default server trust anchors with certificates.

The certificates are used only with ServerVerifyMode::Auto, and a backend-specific verifier or store takes precedence.

pub fn with_server_trust(self, trust: TlsServerTrust) -> TlsClientConfig

Available on crate feature boring only.

Set the complete server trust policy.

pub fn set_server_trust( &mut self, trust: TlsServerTrust, ) -> &mut TlsClientConfig

Available on crate feature boring only.

Set the complete server trust policy.

pub fn try_with_extra_server_trust_anchors( self, certificates: impl IntoIterator<Item = CertificateDer<'static>>, ) -> Result<TlsClientConfig, Box<dyn Error + Send + Sync>>

Available on crate feature boring only.

Add certificates to the configured server trust roots.

Without another trust setting, the certificates extend the default native roots. This composes with Self::with_webpki_roots.

pub fn try_set_extra_server_trust_anchors( &mut self, certificates: impl IntoIterator<Item = CertificateDer<'static>>, ) -> Result<&mut TlsClientConfig, Box<dyn Error + Send + Sync>>

Available on crate feature boring only.

Add certificates to the configured server trust roots.

Without another trust setting, the certificates extend the default native roots. This composes with Self::with_webpki_roots.

pub fn with_webpki_roots(self) -> TlsClientConfig

Available on crate feature boring only.

Use Rama’s bundled Mozilla (CCADB) roots instead of native roots.

Existing additional trust anchors are retained.

pub fn set_webpki_roots(&mut self) -> &mut TlsClientConfig

Available on crate feature boring only.

Use Rama’s bundled Mozilla (CCADB) roots instead of native roots.

Existing additional trust anchors are retained.

pub fn with_supported_versions( self, versions: Vec<ProtocolVersion>, ) -> TlsClientConfig

Available on crate feature boring only.

Set the supported protocol versions.

pub fn set_supported_versions( &mut self, versions: Vec<ProtocolVersion>, ) -> &mut TlsClientConfig

Available on crate feature boring only.

Set the supported protocol versions.

pub fn with_keylog(self, intent: KeyLogIntent) -> TlsClientConfig

Available on crate feature boring only.

Set the keylog intent.

pub fn set_keylog(&mut self, intent: KeyLogIntent) -> &mut TlsClientConfig

Available on crate feature boring only.

Set the keylog intent.

pub fn with_client_auth(self, client_auth: ClientAuth) -> TlsClientConfig

Available on crate feature boring only.

Set the client certificate authentication material (mTLS).

pub fn set_client_auth( &mut self, client_auth: ClientAuth, ) -> &mut TlsClientConfig

Available on crate feature boring only.

Set the client certificate authentication material (mTLS).

pub fn with_store_server_cert_chain(self, store: bool) -> TlsClientConfig

Available on crate feature boring only.

Set whether the peer certificate chain is captured.

pub fn set_store_server_cert_chain( &mut self, store: bool, ) -> &mut TlsClientConfig

Available on crate feature boring only.

Set whether the peer certificate chain is captured.

pub fn as_extensions(&self) -> &Extensions

Available on crate feature boring only.