Struct TlsServerCertPinSet
pub struct TlsServerCertPinSet { /* private fields */ }Available on crate feature
tls only.Expand description
One alternative group of server leaf pins, optionally scoped to server names.
Implementations
impl TlsServerCertPinSet
impl TlsServerCertPinSet
pub fn new(pin: impl Into<TlsServerCertPin>) -> TlsServerCertPinSet
Available on crate feature boring only.
pub fn new(pin: impl Into<TlsServerCertPin>) -> TlsServerCertPinSet
boring only.Create a global pin set containing a single pin.
pub fn try_new(
pins: impl IntoIterator- >,
) -> Result<TlsServerCertPinSet, Box<dyn Error + Send + Sync>>
Available on crate feature boring only.
pub fn try_new(
pins: impl IntoIterator- >,
) -> Result<TlsServerCertPinSet, Box<dyn Error + Send + Sync>>
boring only.Create a global, non-empty pin set of alternative pins.
pub fn with_pin(self, pin: impl Into<TlsServerCertPin>) -> TlsServerCertPinSet
Available on crate feature boring only.
pub fn with_pin(self, pin: impl Into<TlsServerCertPin>) -> TlsServerCertPinSet
boring only.Add an alternative pin to this set.
pub fn set_pin(
&mut self,
pin: impl Into<TlsServerCertPin>,
) -> &mut TlsServerCertPinSet
Available on crate feature boring only.
pub fn set_pin( &mut self, pin: impl Into<TlsServerCertPin>, ) -> &mut TlsServerCertPinSet
boring only.Add an alternative pin to this set.
pub fn with_server_name(
self,
server_name: impl Into<Host>,
) -> TlsServerCertPinSet
Available on crate feature boring only.
pub fn with_server_name( self, server_name: impl Into<Host>, ) -> TlsServerCertPinSet
boring only.Scope this set to server_name, added as an alternative to any
previously set server names. Without any the set applies globally.
pub fn set_server_name(
&mut self,
server_name: impl Into<Host>,
) -> &mut TlsServerCertPinSet
Available on crate feature boring only.
pub fn set_server_name( &mut self, server_name: impl Into<Host>, ) -> &mut TlsServerCertPinSet
boring only.Scope this set to server_name, added as an alternative to any
previously set server names. Without any the set applies globally.