Struct TlsServerCertPins
pub struct TlsServerCertPins(/* private fields */);Available on crate feature
tls only.Expand description
Server leaf certificate pin sets accepted by a TLS client.
Pins within a set and applicable sets are alternatives. A set without server names applies globally; otherwise it is considered only when the effective TLS server name matches. Names are configured explicitly rather than inferred from certificate contents.
Implementations
impl TlsServerCertPins
impl TlsServerCertPins
pub fn new(set: impl Into<TlsServerCertPinSet>) -> TlsServerCertPins
Available on crate feature boring only.
pub fn new(set: impl Into<TlsServerCertPinSet>) -> TlsServerCertPins
boring only.Create pins holding a single pin set.
A single pin or certificate converts into a global single-pin set.
pub fn with_pin_set(
self,
set: impl Into<TlsServerCertPinSet>,
) -> TlsServerCertPins
Available on crate feature boring only.
pub fn with_pin_set( self, set: impl Into<TlsServerCertPinSet>, ) -> TlsServerCertPins
boring only.Add an alternative pin set.
pub fn set_pin_set(
&mut self,
set: impl Into<TlsServerCertPinSet>,
) -> &mut TlsServerCertPins
Available on crate feature boring only.
pub fn set_pin_set( &mut self, set: impl Into<TlsServerCertPinSet>, ) -> &mut TlsServerCertPins
boring only.Add an alternative pin set.