Struct TlsServerTrust
pub struct TlsServerTrust { /* private fields */ }Available on crate feature
tls only.Expand description
Server trust policy used with ServerVerifyMode::Auto.
A backend-specific verifier or store takes precedence. The policy is ignored when server verification is disabled.
Implementations
impl TlsServerTrust
impl TlsServerTrust
pub const fn default_roots() -> TlsServerTrust
Available on crate feature boring only.
pub const fn default_roots() -> TlsServerTrust
boring only.Use native roots, or explicitly configured environment roots. Bundled WebPKI roots are the fallback only without an environment override.
pub const fn webpki_roots() -> TlsServerTrust
Available on crate feature boring only.
pub const fn webpki_roots() -> TlsServerTrust
boring only.Use Rama’s bundled Mozilla (CCADB) roots.
pub const fn custom(anchors: TlsServerTrustAnchors) -> TlsServerTrust
Available on crate feature boring only.
pub const fn custom(anchors: TlsServerTrustAnchors) -> TlsServerTrust
boring only.Use only anchors as trust roots.
pub fn roots(&self) -> &ServerTrustRoots
Available on crate feature boring only.
pub fn roots(&self) -> &ServerTrustRoots
boring only.Return the configured base roots.
pub fn additional_anchors(&self) -> Option<&TlsServerTrustAnchors>
Available on crate feature boring only.
pub fn additional_anchors(&self) -> Option<&TlsServerTrustAnchors>
boring only.Return trust anchors added to the base roots.
pub fn with_roots(self, roots: ServerTrustRoots) -> TlsServerTrust
Available on crate feature boring only.
pub fn with_roots(self, roots: ServerTrustRoots) -> TlsServerTrust
boring only.Set the base trust roots while retaining additional anchors.
pub fn set_roots(&mut self, roots: ServerTrustRoots) -> &mut TlsServerTrust
Available on crate feature boring only.
pub fn set_roots(&mut self, roots: ServerTrustRoots) -> &mut TlsServerTrust
boring only.Set the base trust roots while retaining additional anchors.
pub fn try_with_additional_anchors(
self,
certificates: impl IntoIterator<Item = CertificateDer<'static>>,
) -> Result<TlsServerTrust, Box<dyn Error + Sync + Send>>
Available on crate feature boring only.
pub fn try_with_additional_anchors( self, certificates: impl IntoIterator<Item = CertificateDer<'static>>, ) -> Result<TlsServerTrust, Box<dyn Error + Sync + Send>>
boring only.Add certificates to the base trust roots.
pub fn try_set_additional_anchors(
&mut self,
certificates: impl IntoIterator<Item = CertificateDer<'static>>,
) -> Result<&mut TlsServerTrust, Box<dyn Error + Sync + Send>>
Available on crate feature boring only.
pub fn try_set_additional_anchors( &mut self, certificates: impl IntoIterator<Item = CertificateDer<'static>>, ) -> Result<&mut TlsServerTrust, Box<dyn Error + Sync + Send>>
boring only.Add certificates to the base trust roots.