Struct RustlsTlsConnectorConfig
pub struct RustlsTlsConnectorConfig<'a> {
pub alpn: Option<&'a TlsAlpn>,
pub versions: Option<&'a TlsSupportedVersions>,
pub verify: Option<&'a TlsServerVerify>,
pub keylog: Option<&'a TlsKeyLog>,
pub server_name: Option<&'a TlsServerName>,
pub store_chain: Option<&'a TlsStoreServerCertChain>,
pub client_auth: Option<&'a TlsClientAuth>,
pub server_cert_pins: Option<&'a TlsServerCertPins>,
pub server_trust_anchors: Option<&'a TlsServerTrustAnchors>,
pub verifier: Option<&'a RustlsServerCertVerifier>,
pub modify: Option<&'a ModifyRustlsClientConfig>,
}Available on crate feature
rustls only.Expand description
Gather all the TLS extensions supported by rustls
Fields
alpn: Option<&'a TlsAlpn>versions: Option<&'a TlsSupportedVersions>verify: Option<&'a TlsServerVerify>keylog: Option<&'a TlsKeyLog>server_name: Option<&'a TlsServerName>store_chain: Option<&'a TlsStoreServerCertChain>client_auth: Option<&'a TlsClientAuth>server_cert_pins: Option<&'a TlsServerCertPins>server_trust_anchors: Option<&'a TlsServerTrustAnchors>verifier: Option<&'a RustlsServerCertVerifier>modify: Option<&'a ModifyRustlsClientConfig>Implementations
impl<'a> RustlsTlsConnectorConfig<'a>
impl<'a> RustlsTlsConnectorConfig<'a>
pub fn from_extensions(ext: &'a Extensions) -> RustlsTlsConnectorConfig<'a>
pub fn from_extensions(ext: &'a Extensions) -> RustlsTlsConnectorConfig<'a>
Gather these extension pieces from ext in a single pass.
Generated by #[derive(FromExtensions)]. Each field uses the
same lookup as Extensions::get_ref (newest-wins, walks wrappers
and the parent chain), but the store is traversed only once, even
for nested group fields, whose candidates are folded into
the same pass. A field shaped Option<(&'a T, usize)> (or
Option<(Arc<T>, usize)>) also captures the entry’s traversal rank,
0 is the newest value seen, growing for older ones, so ranks
order fields by recency.