Struct PlainMessage
pub struct PlainMessage {
pub typ: ContentType,
pub version: ProtocolVersion,
pub payload: Payload<'static>,
}Available on crate feature
rustls only.Expand description
A decrypted TLS frame
This type owns all memory for its interior parts. It can be decrypted from an OpaqueMessage or encrypted into an OpaqueMessage, and it is also used for joining and fragmenting.
Fields
typ: ContentTypeversion: ProtocolVersionpayload: Payload<'static>Implementations
impl PlainMessage
impl PlainMessage
pub fn into_unencrypted_opaque(self) -> OutboundOpaqueMessage
pub fn borrow_inbound(&self) -> InboundPlainMessage<'_>
pub fn borrow_outbound(&self) -> OutboundPlainMessage<'_>