Struct HpkeSuite
pub struct HpkeSuite {
pub kem: HpkeKem,
pub sym: HpkeSymmetricCipherSuite,
}Available on crate feature
rustls only.Expand description
An HPKE suite, specifying a key encapsulation mechanism and a symmetric cipher suite.
Fields
kem: HpkeKemThe choice of HPKE key encapsulation mechanism.
sym: HpkeSymmetricCipherSuiteThe choice of HPKE symmetric cipher suite.
This combines a choice of authenticated encryption with additional data (AEAD) algorithm and a key derivation function (KDF).