Struct WantsServerCert
pub struct WantsServerCert { /* private fields */ }Available on crate feature
rustls only.Expand description
A config builder state where the caller must supply how to provide a server certificate to the connecting peer.
For more information, see the ConfigBuilder documentation.