Stream

Struct Stream 

pub struct Stream<'a, C, T>
where C: 'a + ?Sized, T: 'a + Read + Write + ?Sized,
{ pub conn: &'a mut C, pub sock: &'a mut T, }
This type implements io::Read and io::Write, encapsulating a Connection C and an underlying transport T, such as a socket.

Relies on ConnectionCommon::complete_io() to perform the necessary I/O.

This allows you to use a rustls Connection like a normal stream.

Fields

conn: &'a mut C

Our TLS connection

sock: &'a mut T

The underlying transport, like a socket

Implementations



impl<'a, C, T, S> Stream<'a, C, T>
where C: 'a + DerefMut<Target = ConnectionCommon<S>> + Deref, T: 'a + Read + Write, S: SideData,

pub fn new(conn: &'a mut C, sock: &'a mut T) -> Stream<'a, C, T>

Make a new Stream using the Connection conn and socket-like object sock. This does not fail and does no IO.