Struct TlsConnectorWithAlpn
pub struct TlsConnectorWithAlpn<'c> { /* private fields */ }Available on crate feature
rustls only.Implementations
impl TlsConnectorWithAlpn<'_>
impl TlsConnectorWithAlpn<'_>
pub fn connect<IO>(self, domain: ServerName<'static>, stream: IO) -> Connect<IO> ⓘwhere
IO: AsyncRead + AsyncWrite + Unpin,
pub fn connect<IO>(self, domain: ServerName<'static>, stream: IO) -> Connect<IO> ⓘwhere
IO: AsyncRead + AsyncWrite + Unpin,
Returns a future that performs a TLS handshake with domain using the stream.
You likely want to wrap this in a timeout (for example with tokio::time::timeout)
to bound the handshake time.
pub fn connect_with<IO, F>(
self,
domain: ServerName<'static>,
stream: IO,
f: F,
) -> Connect<IO> ⓘ
pub fn connect_with<IO, F>( self, domain: ServerName<'static>, stream: IO, f: F, ) -> Connect<IO> ⓘ
Similar to Self::connect(), but calls f before performing the handshake.
As with Self::connect() you likely want to wrap this in a timeout to
bound the handshake time.
The f handler is given a mutable reference to a ClientConnection that can
be used for tasks like writing early data.