Struct ExtractedSecrets
pub struct ExtractedSecrets {
pub tx: (u64, ConnectionTrafficSecrets),
pub rx: (u64, ConnectionTrafficSecrets),
}Expand description
Secrets for transmitting/receiving data over a TLS session.
After performing a handshake with rustls, these secrets can be extracted to configure kTLS for a socket, and have the kernel take over encryption and/or decryption.
Fields
tx: (u64, ConnectionTrafficSecrets)sequence number and secrets for the “tx” (transmit) direction
rx: (u64, ConnectionTrafficSecrets)sequence number and secrets for the “rx” (receive) direction