Reader

Struct Reader 

pub struct Reader<'a> { /* private fields */ }
A structure that implements std::io::Read for reading plaintext.

Implementations



impl<'a> Reader<'a>

pub fn into_first_chunk(self) -> Result<&'a [u8], Error>

Obtain a chunk of plaintext data received from the peer over this TLS connection.

This method consumes self so that it can return a slice whose lifetime is bounded by the ConnectionCommon that created this Reader.