Trait Permutation
pub trait Permutation<I, O, E> {
// Required method
fn permutation(&mut self, input: I) -> Result<(I, O), Err<E>>;
}Available on crate feature
rustls only.Expand description
Helper trait for the permutation() combinator.
This trait is implemented for tuples of up to 21 elements
Required Methods
fn permutation(&mut self, input: I) -> Result<(I, O), Err<E>>
fn permutation(&mut self, input: I) -> Result<(I, O), Err<E>>
Tries to apply all parsers in the tuple in various orders until all of them succeed
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".