Choice

Trait Choice 

pub trait Choice {
    // Required method
    fn can_decode(tag: Tag) -> bool;
}
Available on crate feature rustls only.

Required Methods

fn can_decode(tag: Tag) -> bool

Is the provided Tag decodable as a variant of this CHOICE?

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors



impl<T> Choice for T
where T: Tagged,

This blanket impl allows any Tagged type to function as a Choice with a single alternative.