Macro oid
macro_rules! oid {
($($args:tt)*) => { ... };
}Available on crate feature
rustls only.Expand description
Procedural macro to get encoded oids, see the oid module.
macro_rules! oid {
($($args:tt)*) => { ... };
}rustls only.Procedural macro to get encoded oids, see the oid module.