Macro align32
macro_rules! align32 {
($x:expr) => { ... };
}Available on crate feature
rustls only.Expand description
Align input value to the next multiple of 4 bytes
macro_rules! align32 {
($x:expr) => { ... };
}rustls only.Align input value to the next multiple of 4 bytes