Enum ECHClientHello
pub enum ECHClientHello {
Outer(ECHClientHelloOuter),
Inner,
}Available on crate feature
rustls only.Expand description
Client Hello contents send by ech
Variants
Outer(ECHClientHelloOuter)
Send when message is in the outer (unencrypted) part of client hello. It contains encryption data and the encrypted client hello.
Inner
The inner extension has an empty payload, which is included because TLS servers are not allowed to provide extensions in ServerHello which were not included in ClientHello. And when using encrypted client hello the server will discard the outer unencrypted one, and only look at the encrypted client hello. So we have to add this extension again there so the server knows ECH is supported by the client.