Struct PinnedServerCertVerifier
pub struct PinnedServerCertVerifier { /* private fields */ }Available on crate feature
rustls only.Expand description
Leaf certificate pinning layered in front of another verifier.
Implementations
impl PinnedServerCertVerifier
impl PinnedServerCertVerifier
pub fn new(
pins: TlsServerCertPins,
child: Arc<dyn ServerCertVerifier>,
) -> PinnedServerCertVerifier
pub fn new( pins: TlsServerCertPins, child: Arc<dyn ServerCertVerifier>, ) -> PinnedServerCertVerifier
Create a pin verifier that delegates matching certificates to child.