Struct SniRouter
pub struct SniRouter<S, F = RejectService<(), NoTlsRejectError>> { /* private fields */ }tls only.Expand description
A Service router that can be used to support
routing of tls traffic as well as non-tls traffic.
The difference with TlsPeekRouter is that the SniRouter
continues to parse after the initial couple of bytes,
in order to learn more about underlying traffic. This allowing
you to route based on the SNI from the client hello,
among other capabilities.
By default non-tls traffic is rejected using RejectService.
Use SniRouter::with_fallback to configure the fallback service.
A definitive non-TLS or malformed ClientHello prefix invokes that fallback
under either timeout policy; an inconclusive timeout is fail-open by default
and can be made fail-closed with SniRouter::with_peek_timeout_policy.
Implementations
impl<S, F> SniRouter<S, F>
impl<S, F> SniRouter<S, F>
pub fn maybe_with_peek_timeout(
self,
peek_timeout: Option<Duration>,
) -> SniRouter<S, F>
pub fn maybe_with_peek_timeout( self, peek_timeout: Option<Duration>, ) -> SniRouter<S, F>
Set an optional timeout on the ClientHello peek.
Defaults to None (no timeout). A valid-but-partial ClientHello from
an idle peer otherwise blocks until EOF; set a timeout for untrusted
ingress. Use SniRouter::with_peek_timeout_policy to choose whether
an inconclusive timeout invokes the fallback or rejects the connection.
pub fn maybe_set_peek_timeout(
&mut self,
peek_timeout: Option<Duration>,
) -> &mut SniRouter<S, F>
pub fn maybe_set_peek_timeout( &mut self, peek_timeout: Option<Duration>, ) -> &mut SniRouter<S, F>
Set an optional timeout on the ClientHello peek.
Defaults to None (no timeout). A valid-but-partial ClientHello from
an idle peer otherwise blocks until EOF; set a timeout for untrusted
ingress. Use SniRouter::with_peek_timeout_policy to choose whether
an inconclusive timeout invokes the fallback or rejects the connection.
pub fn with_peek_timeout(self, peek_timeout: Duration) -> SniRouter<S, F>
pub fn with_peek_timeout(self, peek_timeout: Duration) -> SniRouter<S, F>
Set an optional timeout on the ClientHello peek.
Defaults to None (no timeout). A valid-but-partial ClientHello from
an idle peer otherwise blocks until EOF; set a timeout for untrusted
ingress. Use SniRouter::with_peek_timeout_policy to choose whether
an inconclusive timeout invokes the fallback or rejects the connection.
pub fn set_peek_timeout(
&mut self,
peek_timeout: Duration,
) -> &mut SniRouter<S, F>
pub fn set_peek_timeout( &mut self, peek_timeout: Duration, ) -> &mut SniRouter<S, F>
Set an optional timeout on the ClientHello peek.
Defaults to None (no timeout). A valid-but-partial ClientHello from
an idle peer otherwise blocks until EOF; set a timeout for untrusted
ingress. Use SniRouter::with_peek_timeout_policy to choose whether
an inconclusive timeout invokes the fallback or rejects the connection.
pub fn without_peek_timeout(self) -> SniRouter<S, F>
pub fn without_peek_timeout(self) -> SniRouter<S, F>
Set an optional timeout on the ClientHello peek.
Defaults to None (no timeout). A valid-but-partial ClientHello from
an idle peer otherwise blocks until EOF; set a timeout for untrusted
ingress. Use SniRouter::with_peek_timeout_policy to choose whether
an inconclusive timeout invokes the fallback or rejects the connection.
pub fn unset_peek_timeout(&mut self) -> &mut SniRouter<S, F>
pub fn unset_peek_timeout(&mut self) -> &mut SniRouter<S, F>
Set an optional timeout on the ClientHello peek.
Defaults to None (no timeout). A valid-but-partial ClientHello from
an idle peer otherwise blocks until EOF; set a timeout for untrusted
ingress. Use SniRouter::with_peek_timeout_policy to choose whether
an inconclusive timeout invokes the fallback or rejects the connection.
pub fn with_peek_timeout_policy(
self,
peek_timeout_policy: PeekTimeoutPolicy,
) -> SniRouter<S, F>
pub fn with_peek_timeout_policy( self, peek_timeout_policy: PeekTimeoutPolicy, ) -> SniRouter<S, F>
Set how an inconclusive ClientHello peek timeout is handled.
Defaults to PeekTimeoutPolicy::FailOpen. A definitive non-TLS or
malformed ClientHello prefix invokes the fallback under either policy.
pub fn set_peek_timeout_policy(
&mut self,
peek_timeout_policy: PeekTimeoutPolicy,
) -> &mut SniRouter<S, F>
pub fn set_peek_timeout_policy( &mut self, peek_timeout_policy: PeekTimeoutPolicy, ) -> &mut SniRouter<S, F>
Set how an inconclusive ClientHello peek timeout is handled.
Defaults to PeekTimeoutPolicy::FailOpen. A definitive non-TLS or
malformed ClientHello prefix invokes the fallback under either policy.