pub struct Cursor<'a, K, V>where
K: 'a,
V: 'a,{ /* private fields */ }btree_cursors)protobuf and ttrpc only.Expand description
A cursor over a BTreeMap.
A Cursor is like an iterator, except that it can freely seek back-and-forth.
Cursors always point to a gap between two elements in the map, and can operate on the two immediately adjacent elements.
A Cursor is created with the BTreeMap::lower_bound and BTreeMap::upper_bound methods.
Implementations
Sourceimpl<'a, K, V> Cursor<'a, K, V>
impl<'a, K, V> Cursor<'a, K, V>
Sourcepub fn next(&mut self) -> Option<(&'a K, &'a V)>
🔬This is a nightly-only experimental API. (btree_cursors)Available on crate features grpc and http and std only.
pub fn next(&mut self) -> Option<(&'a K, &'a V)>
btree_cursors)grpc and http and std only.Advances the cursor to the next gap, returning the key and value of the element that it moved over.
If the cursor is already at the end of the map then None is returned
and the cursor is not moved.
Sourcepub fn prev(&mut self) -> Option<(&'a K, &'a V)>
🔬This is a nightly-only experimental API. (btree_cursors)Available on crate features grpc and http and std only.
pub fn prev(&mut self) -> Option<(&'a K, &'a V)>
btree_cursors)grpc and http and std only.Advances the cursor to the previous gap, returning the key and value of the element that it moved over.
If the cursor is already at the start of the map then None is returned
and the cursor is not moved.
Sourcepub fn peek_next(&self) -> Option<(&'a K, &'a V)>
🔬This is a nightly-only experimental API. (btree_cursors)Available on crate features grpc and http and std only.
pub fn peek_next(&self) -> Option<(&'a K, &'a V)>
btree_cursors)grpc and http and std only.Returns a reference to the key and value of the next element without moving the cursor.
If the cursor is at the end of the map then None is returned.
Sourcepub fn peek_prev(&self) -> Option<(&'a K, &'a V)>
🔬This is a nightly-only experimental API. (btree_cursors)Available on crate features grpc and http and std only.
pub fn peek_prev(&self) -> Option<(&'a K, &'a V)>
btree_cursors)grpc and http and std only.Returns a reference to the key and value of the previous element without moving the cursor.
If the cursor is at the start of the map then None is returned.