pub struct Version {
pub major: Option<i32>,
pub minor: Option<i32>,
pub patch: Option<i32>,
pub suffix: Option<String>,
}Available on crate features
protobuf and ttrpc only.Expand description
The version number of protocol compiler.
Fields
major: Option<i32>minor: Option<i32>patch: Option<i32>suffix: Option<String>A suffix for alpha, beta or rc release, e.g., “alpha-1”, “rc2”. It should be empty for mainline stable releases.
Implementations
Sourceimpl Version
impl Version
Sourcepub fn major(&self) -> i32
Available on crate features grpc and http and std only.
pub fn major(&self) -> i32
grpc and http and std only.Returns the value of major, or the default value if major is unset.
Sourcepub fn minor(&self) -> i32
Available on crate features grpc and http and std only.
pub fn minor(&self) -> i32
grpc and http and std only.Returns the value of minor, or the default value if minor is unset.