#[repr(i32)]pub enum Kind {
Show 19 variants
TypeUnknown = 0,
TypeDouble = 1,
TypeFloat = 2,
TypeInt64 = 3,
TypeUint64 = 4,
TypeInt32 = 5,
TypeFixed64 = 6,
TypeFixed32 = 7,
TypeBool = 8,
TypeString = 9,
TypeGroup = 10,
TypeMessage = 11,
TypeBytes = 12,
TypeUint32 = 13,
TypeEnum = 14,
TypeSfixed32 = 15,
TypeSfixed64 = 16,
TypeSint32 = 17,
TypeSint64 = 18,
}Available on crate features
protobuf and ttrpc only.Expand description
Basic field types.
Variants
TypeUnknown = 0
Field type unknown.
TypeDouble = 1
Field type double.
TypeFloat = 2
Field type float.
TypeInt64 = 3
Field type int64.
TypeUint64 = 4
Field type uint64.
TypeInt32 = 5
Field type int32.
TypeFixed64 = 6
Field type fixed64.
TypeFixed32 = 7
Field type fixed32.
TypeBool = 8
Field type bool.
TypeString = 9
Field type string.
TypeGroup = 10
Field type group. Proto2 syntax only, and deprecated.
TypeMessage = 11
Field type message.
TypeBytes = 12
Field type bytes.
TypeUint32 = 13
Field type uint32.
TypeEnum = 14
Field type enum.
TypeSfixed32 = 15
Field type sfixed32.
TypeSfixed64 = 16
Field type sfixed64.
TypeSint32 = 17
Field type sint32.
TypeSint64 = 18
Field type sint64.
Implementations
Sourceimpl Kind
impl Kind
Sourceimpl Kind
impl Kind
Sourcepub fn as_str_name(&self) -> &'static str
Available on crate features grpc and http and std only.
pub fn as_str_name(&self) -> &'static str
grpc and http and std only.String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Kind>
Available on crate features grpc and http and std only.
pub fn from_str_name(value: &str) -> Option<Kind>
grpc and http and std only.Creates an enum from field names used in the ProtoBuf definition.