#[repr(i32)]pub enum IdempotencyLevel {
IdempotencyUnknown = 0,
NoSideEffects = 1,
Idempotent = 2,
}Available on crate features
protobuf and ttrpc only.Expand description
Is this method side-effect-free (or safe in HTTP parlance), or idempotent, or neither? HTTP based RPC implementation may choose GET verb for safe methods, and PUT verb for idempotent methods instead of the default POST.
Variants
IdempotencyUnknown = 0
NoSideEffects = 1
implies idempotent
Idempotent = 2
idempotent, but may have side effects
Implementations
Sourceimpl IdempotencyLevel
impl IdempotencyLevel
Sourcepub const fn is_valid(value: i32) -> bool
Available on crate features grpc and http and std only.
pub const fn is_valid(value: i32) -> bool
grpc and http and std only.Returns true if value is a variant of IdempotencyLevel.
Sourcepub fn from_i32(value: i32) -> Option<IdempotencyLevel>
👎Deprecated: Use the TryFrom<i32> implementation instead
Available on crate features grpc and http and std only.
pub fn from_i32(value: i32) -> Option<IdempotencyLevel>
Use the TryFrom<i32> implementation instead
grpc and http and std only.Converts an i32 to a IdempotencyLevel, or None if value is not a valid variant.
Sourceimpl IdempotencyLevel
impl IdempotencyLevel
Sourcepub fn as_str_name(&self) -> &'static str
Available on crate features grpc and http and std only.
pub fn as_str_name(&self) -> &'static str
grpc and http and std only.String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<IdempotencyLevel>
Available on crate features grpc and http and std only.
pub fn from_str_name(value: &str) -> Option<IdempotencyLevel>
grpc and http and std only.Creates an enum from field names used in the ProtoBuf definition.