pub struct FieldDescriptorProto {
pub name: Option<String>,
pub number: Option<i32>,
pub label: Option<i32>,
pub type: Option<i32>,
pub type_name: Option<String>,
pub extendee: Option<String>,
pub default_value: Option<String>,
pub oneof_index: Option<i32>,
pub json_name: Option<String>,
pub options: Option<FieldOptions>,
pub proto3_optional: Option<bool>,
}protobuf and ttrpc only.Expand description
Describes a field within a message.
Fields
name: Option<String>number: Option<i32>label: Option<i32>type: Option<i32>If type_name is set, this need not be set. If both this and type_name are set, this must be one of TYPE_ENUM, TYPE_MESSAGE or TYPE_GROUP.
type_name: Option<String>For message and enum types, this is the name of the type. If the name starts with a ‘.’, it is fully-qualified. Otherwise, C++-like scoping rules are used to find the type (i.e. first the nested types within this message are searched, then within the parent, on up to the root namespace).
extendee: Option<String>For extensions, this is the name of the type being extended. It is resolved in the same manner as type_name.
default_value: Option<String>For numeric types, contains the original text representation of the value. For booleans, “true” or “false”. For strings, contains the default text contents (not escaped in any way). For bytes, contains the C escaped value. All bytes >= 128 are escaped. TODO(kenton): Base-64 encode?
oneof_index: Option<i32>If set, gives the index of a oneof in the containing type’s oneof_decl list. This field is a member of that oneof.
json_name: Option<String>JSON name of this field. The value is set by protocol compiler. If the user has set a “json_name” option on this field, that option’s value will be used. Otherwise, it’s deduced from the field’s name by converting it to camelCase.
options: Option<FieldOptions>proto3_optional: Option<bool>If true, this is a proto3 “optional”. When a proto3 field is optional, it tracks presence regardless of field type.
When proto3_optional is true, this field must be belong to a oneof to signal to old proto3 clients that presence is tracked for this field. This oneof is known as a “synthetic” oneof, and this field must be its sole member (each proto3 optional field gets its own synthetic oneof). Synthetic oneofs exist in the descriptor only, and do not generate any API. Synthetic oneofs must be ordered after all “real” oneofs.
For message fields, proto3_optional doesn’t create any semantic change, since non-repeated message fields always track presence. However it still indicates the semantic detail of whether the user wrote “optional” or not. This can be useful for round-tripping the .proto file. For consistency we give message fields a synthetic oneof also, even though it is not required to track presence. This is especially important because the parser can’t tell if a field is a message or an enum, so it must always create a synthetic oneof.
Proto2 optional fields do not set this flag, because they already indicate
optional with LABEL_OPTIONAL.
Implementations
Sourceimpl FieldDescriptorProto
impl FieldDescriptorProto
Sourcepub fn name(&self) -> &str
Available on crate features grpc and http and std only.
pub fn name(&self) -> &str
grpc and http and std only.Returns the value of name, or the default value if name is unset.
Sourcepub fn extendee(&self) -> &str
Available on crate features grpc and http and std only.
pub fn extendee(&self) -> &str
grpc and http and std only.Returns the value of extendee, or the default value if extendee is unset.
Sourcepub fn number(&self) -> i32
Available on crate features grpc and http and std only.
pub fn number(&self) -> i32
grpc and http and std only.Returns the value of number, or the default value if number is unset.
Sourcepub fn label(&self) -> Label
Available on crate features grpc and http and std only.
pub fn label(&self) -> Label
grpc and http and std only.Returns the enum value of label, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_label(&mut self, value: Label)
Available on crate features grpc and http and std only.
pub fn set_label(&mut self, value: Label)
grpc and http and std only.Sets label to the provided enum value.
Sourcepub fn type(&self) -> Type
Available on crate features grpc and http and std only.
pub fn type(&self) -> Type
grpc and http and std only.Returns the enum value of type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: Type)
Available on crate features grpc and http and std only.
pub fn set_type(&mut self, value: Type)
grpc and http and std only.Sets type to the provided enum value.
Sourcepub fn type_name(&self) -> &str
Available on crate features grpc and http and std only.
pub fn type_name(&self) -> &str
grpc and http and std only.Returns the value of type_name, or the default value if type_name is unset.
Sourcepub fn default_value(&self) -> &str
Available on crate features grpc and http and std only.
pub fn default_value(&self) -> &str
grpc and http and std only.Returns the value of default_value, or the default value if default_value is unset.
Sourcepub fn oneof_index(&self) -> i32
Available on crate features grpc and http and std only.
pub fn oneof_index(&self) -> i32
grpc and http and std only.Returns the value of oneof_index, or the default value if oneof_index is unset.
Sourcepub fn json_name(&self) -> &str
Available on crate features grpc and http and std only.
pub fn json_name(&self) -> &str
grpc and http and std only.Returns the value of json_name, or the default value if json_name is unset.
Sourcepub fn proto3_optional(&self) -> bool
Available on crate features grpc and http and std only.
pub fn proto3_optional(&self) -> bool
grpc and http and std only.Returns the value of proto3_optional, or the default value if proto3_optional is unset.