FileDescriptorProto

Struct FileDescriptorProto 

pub struct FileDescriptorProto {
    pub name: Option<String>,
    pub package: Option<String>,
    pub dependency: Vec<String>,
    pub public_dependency: Vec<i32>,
    pub weak_dependency: Vec<i32>,
    pub message_type: Vec<DescriptorProto>,
    pub enum_type: Vec<EnumDescriptorProto>,
    pub service: Vec<ServiceDescriptorProto>,
    pub extension: Vec<FieldDescriptorProto>,
    pub options: Option<FileOptions>,
    pub source_code_info: Option<SourceCodeInfo>,
    pub syntax: Option<String>,
}
Available on crate features protobuf and ttrpc only.
Describes a complete .proto file.

Fields

name: Option<String>

file name, relative to root of source tree

package: Option<String>

e.g. “foo”, “foo.bar”, etc.

dependency: Vec<String>

Names of files imported by this file.

public_dependency: Vec<i32>

Indexes of the public imported files in the dependency list above.

weak_dependency: Vec<i32>

Indexes of the weak imported files in the dependency list. For Google-internal migration only. Do not use.

message_type: Vec<DescriptorProto>

All top-level definitions in this file.

enum_type: Vec<EnumDescriptorProto>service: Vec<ServiceDescriptorProto>extension: Vec<FieldDescriptorProto>options: Option<FileOptions>source_code_info: Option<SourceCodeInfo>

This field contains optional information about the original source code. You may safely remove this entire field without harming runtime functionality of the descriptors – the information is needed only by development tools.

syntax: Option<String>

The syntax of the proto file. The supported values are “proto2” and “proto3”.

Implementations

Source

impl FileDescriptorProto

pub fn name(&self) -> &str

Available on crate features grpc and http and std only.

Returns the value of name, or the default value if name is unset.

pub fn package(&self) -> &str

Available on crate features grpc and http and std only.

Returns the value of package, or the default value if package is unset.

pub fn syntax(&self) -> &str

Available on crate features grpc and http and std only.

Returns the value of syntax, or the default value if syntax is unset.