pub struct MethodOptions {
pub deprecated: Option<bool>,
pub idempotency_level: Option<i32>,
pub uninterpreted_option: Vec<UninterpretedOption>,
}Available on crate features
protobuf and ttrpc only.Fields
deprecated: Option<bool>Is this method deprecated? Depending on the target platform, this can emit Deprecated annotations for the method, or it will be completely ignored; in the very least, this is a formalization for deprecating methods.
idempotency_level: Option<i32>uninterpreted_option: Vec<UninterpretedOption>The parser stores options it doesn’t recognize here. See above.
Implementations
Sourceimpl MethodOptions
impl MethodOptions
Sourcepub fn deprecated(&self) -> bool
Available on crate features grpc and http and std only.
pub fn deprecated(&self) -> bool
grpc and http and std only.Returns the value of deprecated, or the default value if deprecated is unset.
Sourcepub fn idempotency_level(&self) -> IdempotencyLevel
Available on crate features grpc and http and std only.
pub fn idempotency_level(&self) -> IdempotencyLevel
grpc and http and std only.Returns the enum value of idempotency_level, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_idempotency_level(&mut self, value: IdempotencyLevel)
Available on crate features grpc and http and std only.
pub fn set_idempotency_level(&mut self, value: IdempotencyLevel)
grpc and http and std only.Sets idempotency_level to the provided enum value.