pub enum Kind {
NullValue(i32),
NumberValue(f64),
StringValue(String),
BoolValue(bool),
StructValue(Struct),
ListValue(ListValue),
}Available on crate features
protobuf and ttrpc only.Expand description
The kind of value.
Variants
NullValue(i32)
Represents a null value.
NumberValue(f64)
Represents a double value.
StringValue(String)
Represents a string value.
BoolValue(bool)
Represents a boolean value.
StructValue(Struct)
Represents a structured value.
ListValue(ListValue)
Represents a repeated Value.
Implementations
Sourceimpl Kind
impl Kind
Sourcepub fn encode(&self, buf: &mut impl BufMut)
Available on crate features grpc and http and std only.
pub fn encode(&self, buf: &mut impl BufMut)
grpc and http and std only.Encodes the message to a buffer.
Sourcepub fn merge(
field: &mut Option<Kind>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
Available on crate features grpc and http and std only.
pub fn merge( field: &mut Option<Kind>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
grpc and http and std only.Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
Available on crate features grpc and http and std only.
pub fn encoded_len(&self) -> usize
grpc and http and std only.Returns the encoded length of the message without a length delimiter.