Struct ServerConnection
pub struct ServerConnection { /* private fields */ }ttrpc only.Implementations
impl ServerConnection
impl ServerConnection
pub fn new<C>(connection: C) -> ServerConnectionwhere
C: Io,
pub fn new_with<'a, C>(
connection: C,
services: impl IntoIterator<Item = &'a dyn Service>,
) -> ServerConnectionwhere
C: Io,
pub fn with_max_concurrent_streams(self, max: usize) -> ServerConnection
pub fn with_max_concurrent_streams(self, max: usize) -> ServerConnection
Set the maximum number of concurrently-executing request handlers on this connection.
Once reached, further requests are rejected with RESOURCE_EXHAUSTED until a handler
completes. Defaults to DEFAULT_MAX_CONCURRENT_STREAMS.
pub fn set_max_concurrent_streams(
&mut self,
max: usize,
) -> &mut ServerConnection
pub fn set_max_concurrent_streams( &mut self, max: usize, ) -> &mut ServerConnection
Set the maximum number of concurrently-executing request handlers on this connection.
Once reached, further requests are rejected with RESOURCE_EXHAUSTED until a handler
completes. Defaults to DEFAULT_MAX_CONCURRENT_STREAMS.
pub fn with_close_connection_on_oversized_frame(
self,
enabled: bool,
) -> ServerConnection
pub fn with_close_connection_on_oversized_frame( self, enabled: bool, ) -> ServerConnection
Treat an oversized inbound frame as a fatal protocol error that closes this
connection, instead of the default Go-parity discard + per-stream
RESOURCE_EXHAUSTED. See TtrpcServer::with_close_connection_on_oversized_frame.
pub fn set_close_connection_on_oversized_frame(
&mut self,
enabled: bool,
) -> &mut ServerConnection
pub fn set_close_connection_on_oversized_frame( &mut self, enabled: bool, ) -> &mut ServerConnection
Treat an oversized inbound frame as a fatal protocol error that closes this
connection, instead of the default Go-parity discard + per-stream
RESOURCE_EXHAUSTED. See TtrpcServer::with_close_connection_on_oversized_frame.
pub fn register(&mut self, service: impl Service) -> &mut ServerConnection
pub async fn start(&mut self) -> Result<(), Error>