Enum TlsAgent
pub enum TlsAgent {
Rustls,
Boringssl,
Nss,
Preserve,
}Available on crate feature
ua only.Expand description
Tls implementation used by the UserAgent
Variants
Rustls
Rustls is used as a fallback for all user agents, that are not chromium based.
Boringssl
Boringssl is used for Chromium based user agents.
Nss
NSS is used for Firefox
Preserve
Preserve the incoming TlsAgent as much as possible.
For this Tls this means that emulators can try to preserve details of the incoming Tls connection such as the (Tls) Client Hello.
Implementations