try_load_embedded_profiles

Function try_load_embedded_profiles 

pub fn try_load_embedded_profiles() -> Result<impl Iterator<Item = UserAgentProfile>, Box<dyn Error + Send + Sync>>
Available on crate features embed-profiles and std and ua only.
Load the profiles embedded with the rama-ua crate.

Complementary captures are merged before incomplete profiles are skipped with a warning. Malformed data and bundles with no usable profiles remain errors. This function is only available if the embed-profiles feature is enabled.