Struct TlsProfile
pub struct TlsProfile {
pub client_hello: ClientHello,
pub ws_client_config_overwrites: Option<WsClientConfigOverwrites>,
}std and ua only.Expand description
Profile of the user-agent’s TLS (client) configuration.
It is used to emulate the TLS configuration of the user-agent: the captured
ClientHello is the fingerprint to reproduce.
Fields
client_hello: ClientHelloThe captured ClientHello (the TLS fingerprint to emulate).
ws_client_config_overwrites: Option<WsClientConfigOverwrites>Optional WebSocket-specific client config overwrites.
Implementations
impl TlsProfile
impl TlsProfile
pub fn compute_ja3(
&self,
negotiated_tls_version: Option<ProtocolVersion>,
) -> Result<Ja3, Ja3ComputeError>
pub fn compute_ja3( &self, negotiated_tls_version: Option<ProtocolVersion>, ) -> Result<Ja3, Ja3ComputeError>
Compute the Ja3 (hash) based on this TlsProfile.
This can be useful in case you want to compare profiles loaded into memory of your service with the profile of an incoming request.
As specified by https://github.com/salesforce/ja3`.
pub fn compute_ja4(
&self,
negotiated_tls_version: Option<ProtocolVersion>,
) -> Result<Ja4, Ja4ComputeError>
pub fn compute_ja4( &self, negotiated_tls_version: Option<ProtocolVersion>, ) -> Result<Ja4, Ja4ComputeError>
Compute the Ja4 (hash) on this TlsProfile.
This can be useful in case you want to compare profiles loaded into memory of your service with the profile of an incoming request.
As specified by https://blog.foxio.io/ja4%2B-network-fingerprinting and reference implementations found at https://github.com/FoxIO-LLC/ja4.
pub fn compute_peet(&self) -> Result<PeetPrint, PeetComputeError>
pub fn compute_peet(&self) -> Result<PeetPrint, PeetComputeError>
Compute the PeetPrint (hash) on this TlsProfile.
This can be useful in case you want to compare profiles loaded into memory of your service with the profile of an incoming request.
As specified by https://github.com/pagpeter/TrackMe?tab=readme-ov-file#custom-fingerpint-peetprint