pub struct UserAgentRuntimeProfile {
pub source_info: Option<UserAgentSourceInfo>,
pub js_info: Option<JsProfile>,
}Available on crate feature
ua only.Expand description
Runtime (meta) info about the UA profile.
This information is not taken into account for UA Emulation on the network layer, but that is none the less useful in the bigger picture.
Fields
source_info: Option<UserAgentSourceInfo>Source information injected by fingerprinting service.
js_info: Option<JsProfile>Javascript information for a user-agent which supports Javascript and Web APIs.