Enum ReceiveTimestamp
#[non_exhaustive]pub enum ReceiveTimestamp {
UnixEpoch(Duration),
Monotonic(Duration),
}Available on crate features
std and udp only.Expand description
Receive time together with the clock domain used by its producer.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnixEpoch(Duration)
Duration since the Unix epoch, normally supplied by a kernel real-time clock.
Monotonic(Duration)
Duration on an implementation-defined monotonic timeline.
Values are comparable only when they came from the same socket backend.