SendDatagram

Struct SendDatagram 

#[non_exhaustive]
pub struct SendDatagram<'a> { /* private fields */ }
Available on crate features std and udp only.
Borrowed description of one outgoing datagram or segmented datagram group.

This type contains UDP packet metadata only. It has no connection, packet number, retransmission, or upper-protocol semantics.

Implementations



impl<'a> SendDatagram<'a>

pub fn new( destination: impl Into<SocketAddress>, payload: &'a [u8], ) -> SendDatagram<'a>

Construct an ordinary unsegmented datagram.

pub const fn destination(&self) -> SocketAddress

Destination address.

pub const fn payload(&self) -> &'a [u8]

Datagram bytes, or concatenated segmented bytes.

pub const fn ecn(&self) -> Option<EcnCodepoint>

Selected ECN codepoint.

pub const fn source_ip(&self) -> Option<IpAddr>

Selected source IP.

pub const fn segment_size(&self) -> Option<NonZero<usize>>

Configured segment size.

pub fn maybe_with_ecn(self, ecn: Option<EcnCodepoint>) -> SendDatagram<'a>

Set the ECN codepoint, or clear it to retain the socket default.

pub fn maybe_set_ecn( &mut self, ecn: Option<EcnCodepoint>, ) -> &mut SendDatagram<'a>

Set the ECN codepoint, or clear it to retain the socket default.

pub fn with_ecn(self, ecn: EcnCodepoint) -> SendDatagram<'a>

Set the ECN codepoint, or clear it to retain the socket default.

pub fn set_ecn(&mut self, ecn: EcnCodepoint) -> &mut SendDatagram<'a>

Set the ECN codepoint, or clear it to retain the socket default.

pub fn without_ecn(self) -> SendDatagram<'a>

Set the ECN codepoint, or clear it to retain the socket default.

pub fn unset_ecn(&mut self) -> &mut SendDatagram<'a>

Set the ECN codepoint, or clear it to retain the socket default.

pub fn maybe_with_source_ip(self, source_ip: Option<IpAddr>) -> SendDatagram<'a>

Select the outgoing source IP.

pub fn maybe_set_source_ip( &mut self, source_ip: Option<IpAddr>, ) -> &mut SendDatagram<'a>

Select the outgoing source IP.

pub fn with_source_ip(self, source_ip: IpAddr) -> SendDatagram<'a>

Select the outgoing source IP.

pub fn set_source_ip(&mut self, source_ip: IpAddr) -> &mut SendDatagram<'a>

Select the outgoing source IP.

pub fn without_source_ip(self) -> SendDatagram<'a>

Select the outgoing source IP.

pub fn unset_source_ip(&mut self) -> &mut SendDatagram<'a>

Select the outgoing source IP.

pub fn maybe_with_segment_size( self, segment_size: Option<NonZero<usize>>, ) -> SendDatagram<'a>

Describe concatenated datagrams for a segmented send.

The size must be smaller than the payload length. Callers adapting descriptors from another API must omit a one-segment value equal to the payload length.

pub fn maybe_set_segment_size( &mut self, segment_size: Option<NonZero<usize>>, ) -> &mut SendDatagram<'a>

Describe concatenated datagrams for a segmented send.

The size must be smaller than the payload length. Callers adapting descriptors from another API must omit a one-segment value equal to the payload length.

pub fn with_segment_size(self, segment_size: NonZero<usize>) -> SendDatagram<'a>

Describe concatenated datagrams for a segmented send.

The size must be smaller than the payload length. Callers adapting descriptors from another API must omit a one-segment value equal to the payload length.

pub fn set_segment_size( &mut self, segment_size: NonZero<usize>, ) -> &mut SendDatagram<'a>

Describe concatenated datagrams for a segmented send.

The size must be smaller than the payload length. Callers adapting descriptors from another API must omit a one-segment value equal to the payload length.

pub fn without_segment_size(self) -> SendDatagram<'a>

Describe concatenated datagrams for a segmented send.

The size must be smaller than the payload length. Callers adapting descriptors from another API must omit a one-segment value equal to the payload length.

pub fn unset_segment_size(&mut self) -> &mut SendDatagram<'a>

Describe concatenated datagrams for a segmented send.

The size must be smaller than the payload length. Callers adapting descriptors from another API must omit a one-segment value equal to the payload length.

pub fn segment_count(self) -> usize

Number of UDP datagrams represented by this descriptor.