Enum CreatedFilePermissions
#[non_exhaustive]pub enum CreatedFilePermissions {
Default,
OwnerReadWrite,
}Available on crate feature
std only.Expand description
Permissions to apply when OpenOptions or OpenOptionsSync creates a
new file.
These permissions only affect newly-created files. Existing files keep their current permissions, matching the behavior of platform open options.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Default
Use platform defaults.
OwnerReadWrite
Create private files intended for secrets or sensitive diagnostics.
On Unix this creates files with mode 0o600 before the process umask is
applied. On other platforms the file inherits the platform default ACLs.