Macro include_dir
include_dir!() { /* proc-macro */ }Available on crate feature
std only.Expand description
Embed the contents of a directory in your crate.
include_dir!() { /* proc-macro */ }std only.Embed the contents of a directory in your crate.