pub struct RefundWait(/* private fields */);Expand description
A registered wait for the next RateLimiter::refund.
Registration happens when this value is created, before it is first polled, so callers can safely create it before checking the bucket.