trim_ascii_quotes_non_empty

Function trim_ascii_quotes_non_empty 

pub fn trim_ascii_quotes_non_empty(value: &str) -> Option<&str>
Trim surrounding whitespace and ASCII quote marks.

This accepts the presentation used by command-line configuration tools: either single or double quote marks may occur at either edge. Whitespace is trimmed again after the quote marks, and an empty result is returned as None. The returned string is always a slice of the input.