now_system_time

Function now_system_time 

pub fn now_system_time() -> SystemTime
Returns an approximate system time using approximate unix timestamp.

Optimized for high-frequency calls. The underlying wall clock skew is refreshed roughly once per hour.