Function now_unix
pub fn now_unix() -> i64Expand description
Returns an approximate unix timestamp in seconds.
Optimized for high-frequency calls. The underlying wall clock skew is refreshed roughly once per hour.
pub fn now_unix() -> i64Returns an approximate unix timestamp in seconds.
Optimized for high-frequency calls. The underlying wall clock skew is refreshed roughly once per hour.