Function now_unix_ms
pub fn now_unix_ms() -> i64Expand description
Returns an approximate unix timestamp in milliseconds.
Optimized for high-frequency calls. The underlying wall clock skew is refreshed roughly once per hour.
pub fn now_unix_ms() -> i64Returns an approximate unix timestamp in milliseconds.
Optimized for high-frequency calls. The underlying wall clock skew is refreshed roughly once per hour.