Function unix_timestamp_millis
pub fn unix_timestamp_millis() -> i64Available on crate feature
std only.Expand description
Returns the current unix timestamp in milliseconds by reading the system clock.
pub fn unix_timestamp_millis() -> i64std only.Returns the current unix timestamp in milliseconds by reading the system clock.