Function unix_timestamp_secs
pub fn unix_timestamp_secs() -> i64Available on crate feature
std only.Expand description
Returns the current unix timestamp in seconds by reading the system clock.
pub fn unix_timestamp_secs() -> i64std only.Returns the current unix timestamp in seconds by reading the system clock.