Struct PublicKeyComponents
pub struct PublicKeyComponents<B> {
pub n: B,
pub e: B,
}alloc and crypto and ring and std only.Expand description
RSA public key components.
B must implement AsRef<[u8]> like &[u8] or Vec<u8>.
Fields
n: BThe public modulus, encoded in big-endian bytes without leading zeros.
e: BThe public exponent, encoded in big-endian bytes without leading zeros.
Implementations
impl<B> PublicKeyComponents<B>
impl<B> PublicKeyComponents<B>
pub fn verify(
&self,
params: &RsaParameters,
message: &[u8],
signature: &[u8],
) -> Result<(), Unspecified>
pub fn verify( &self, params: &RsaParameters, message: &[u8], signature: &[u8], ) -> Result<(), Unspecified>
Verifies that signature is a valid signature of message using self
as the public key. params determine what algorithm parameters
(padding, digest algorithm, key length range, etc.) are used in the
verification.
When the public key is in DER-encoded PKCS#1 ASN.1 format, it is
recommended to use ring::signature::verify() with
ring::signature::RSA_PKCS1_*, because ring::signature::verify()
will handle the parsing in that case. Otherwise, this function can be used
to pass in the raw bytes for the public key components as
untrusted::Input arguments.