Ord

Trait Ord 

1.0.0 (const: unstable) · Source
pub trait Ord: Eq + PartialOrd {
    // Required method
    fn cmp(&self, other: &Self) -> Ordering;

    // Provided methods
    fn max(self, other: Self) -> Self
       where Self: Sized { ... }
    fn min(self, other: Self) -> Self
       where Self: Sized { ... }
    fn clamp(self, min: Self, max: Self) -> Self
       where Self: Sized { ... }
}
Available on crate features crypto and std only.
Trait for types that form a total order.

Implementations must be consistent with the PartialOrd implementation, and ensure max, min, and clamp are consistent with cmp:

  • partial_cmp(a, b) == Some(cmp(a, b)).
  • max(a, b) == max_by(a, b, cmp) (ensured by the default implementation).
  • min(a, b) == min_by(a, b, cmp) (ensured by the default implementation).
  • For a.clamp(min, max), see the method docs (ensured by the default implementation).

Violating these requirements is a logic error. The behavior resulting from a logic error is not specified, but users of the trait must ensure that such logic errors do not result in undefined behavior. This means that unsafe code must not rely on the correctness of these methods.

Corollaries

From the above and the requirements of PartialOrd, it follows that for all a, b and c:

  • exactly one of a < b, a == b or a > b is true; and
  • < is transitive: a < b and b < c implies a < c. The same must hold for both == and >.

Mathematically speaking, the < operator defines a strict weak order. In cases where == conforms to mathematical equality, it also defines a strict total order.

Derivable

This trait can be used with #[derive].

When derived on structs, it will produce a lexicographic ordering based on the top-to-bottom declaration order of the struct’s members.

When derived on enums, variants are ordered primarily by their discriminants. Secondarily, they are ordered by their fields. By default, the discriminant is smallest for variants at the top, and largest for variants at the bottom. Here’s an example:

#[derive(PartialEq, Eq, PartialOrd, Ord)]
enum E {
    Top,
    Bottom,
}

assert!(E::Top < E::Bottom);

However, manually setting the discriminants can override this default behavior:

#[derive(PartialEq, Eq, PartialOrd, Ord)]
enum E {
    Top = 2,
    Bottom = 1,
}

assert!(E::Bottom < E::Top);

Lexicographical comparison

Lexicographical comparison is an operation with the following properties:

  • Two sequences are compared element by element.
  • The first mismatching element defines which sequence is lexicographically less or greater than the other.
  • If one sequence is a prefix of another, the shorter sequence is lexicographically less than the other.
  • If two sequences have equivalent elements and are of the same length, then the sequences are lexicographically equal.
  • An empty sequence is lexicographically less than any non-empty sequence.
  • Two empty sequences are lexicographically equal.

How can I implement Ord?

Ord requires that the type also be PartialOrd, PartialEq, and Eq.

Because Ord implies a stronger ordering relationship than PartialOrd, and both Ord and PartialOrd must agree, you must choose how to implement Ord first. You can choose to derive it, or implement it manually. If you derive it, you should derive all four traits. If you implement it manually, you should manually implement all four traits, based on the implementation of Ord.

Here’s an example where you want to define the Character comparison by health and experience only, disregarding the field mana:

use std::cmp::Ordering;

struct Character {
    health: u32,
    experience: u32,
    mana: f32,
}

impl Ord for Character {
    fn cmp(&self, other: &Self) -> Ordering {
        self.experience
            .cmp(&other.experience)
            .then(self.health.cmp(&other.health))
    }
}

impl PartialOrd for Character {
    fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
        Some(self.cmp(other))
    }
}

impl PartialEq for Character {
    fn eq(&self, other: &Self) -> bool {
        self.health == other.health && self.experience == other.experience
    }
}

impl Eq for Character {}

If all you need is to slice::sort a type by a field value, it can be simpler to use slice::sort_by_key.

Examples of incorrect Ord implementations

use std::cmp::Ordering;

#[derive(Debug)]
struct Character {
    health: f32,
}

impl Ord for Character {
    fn cmp(&self, other: &Self) -> std::cmp::Ordering {
        if self.health < other.health {
            Ordering::Less
        } else if self.health > other.health {
            Ordering::Greater
        } else {
            Ordering::Equal
        }
    }
}

impl PartialOrd for Character {
    fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
        Some(self.cmp(other))
    }
}

impl PartialEq for Character {
    fn eq(&self, other: &Self) -> bool {
        self.health == other.health
    }
}

impl Eq for Character {}

let a = Character { health: 4.5 };
let b = Character { health: f32::NAN };

// Mistake: floating-point values do not form a total order and using the built-in comparison
// operands to implement `Ord` irregardless of that reality does not change it. Use
// `f32::total_cmp` if you need a total order for floating-point values.

// Reflexivity requirement of `Ord` is not given.
assert!(a == a);
assert!(b != b);

// Antisymmetry requirement of `Ord` is not given. Only one of a < c and c < a is allowed to be
// true, not both or neither.
assert_eq!((a < b) as u8 + (b < a) as u8, 0);
use std::cmp::Ordering;

#[derive(Debug)]
struct Character {
    health: u32,
    experience: u32,
}

impl PartialOrd for Character {
    fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
        Some(self.cmp(other))
    }
}

impl Ord for Character {
    fn cmp(&self, other: &Self) -> std::cmp::Ordering {
        if self.health < 50 {
            self.health.cmp(&other.health)
        } else {
            self.experience.cmp(&other.experience)
        }
    }
}

// For performance reasons implementing `PartialEq` this way is not the idiomatic way, but it
// ensures consistent behavior between `PartialEq`, `PartialOrd` and `Ord` in this example.
impl PartialEq for Character {
    fn eq(&self, other: &Self) -> bool {
        self.cmp(other) == Ordering::Equal
    }
}

impl Eq for Character {}

let a = Character {
    health: 3,
    experience: 5,
};
let b = Character {
    health: 10,
    experience: 77,
};
let c = Character {
    health: 143,
    experience: 2,
};

// Mistake: The implementation of `Ord` compares different fields depending on the value of
// `self.health`, the resulting order is not total.

// Transitivity requirement of `Ord` is not given. If a is smaller than b and b is smaller than
// c, by transitive property a must also be smaller than c.
assert!(a < b && b < c && c < a);

// Antisymmetry requirement of `Ord` is not given. Only one of a < c and c < a is allowed to be
// true, not both or neither.
assert_eq!((a < c) as u8 + (c < a) as u8, 2);

The documentation of PartialOrd contains further examples, for example it’s wrong for PartialOrd and PartialEq to disagree.

Required Methods

1.0.0 (const: unstable) · Source

fn cmp(&self, other: &Self) -> Ordering

This method returns an Ordering between self and other.

By convention, self.cmp(&other) returns the ordering matching the expression self <operator> other if true.

Examples
use std::cmp::Ordering;

assert_eq!(5.cmp(&10), Ordering::Less);
assert_eq!(10.cmp(&5), Ordering::Greater);
assert_eq!(5.cmp(&5), Ordering::Equal);

Provided Methods

1.21.0 (const: unstable) · Source

fn max(self, other: Self) -> Self
where Self: Sized,

Compares and returns the maximum of two values.

Returns the second argument if the comparison determines them to be equal.

Examples
assert_eq!(1.max(2), 2);
assert_eq!(2.max(2), 2);
use std::cmp::Ordering;

#[derive(Eq)]
struct Equal(&'static str);

impl PartialEq for Equal {
    fn eq(&self, other: &Self) -> bool { true }
}
impl PartialOrd for Equal {
    fn partial_cmp(&self, other: &Self) -> Option<Ordering> { Some(Ordering::Equal) }
}
impl Ord for Equal {
    fn cmp(&self, other: &Self) -> Ordering { Ordering::Equal }
}

assert_eq!(Equal("self").max(Equal("other")).0, "other");
1.21.0 (const: unstable) · Source

fn min(self, other: Self) -> Self
where Self: Sized,

Compares and returns the minimum of two values.

Returns the first argument if the comparison determines them to be equal.

Examples
assert_eq!(1.min(2), 1);
assert_eq!(2.min(2), 2);
use std::cmp::Ordering;

#[derive(Eq)]
struct Equal(&'static str);

impl PartialEq for Equal {
    fn eq(&self, other: &Self) -> bool { true }
}
impl PartialOrd for Equal {
    fn partial_cmp(&self, other: &Self) -> Option<Ordering> { Some(Ordering::Equal) }
}
impl Ord for Equal {
    fn cmp(&self, other: &Self) -> Ordering { Ordering::Equal }
}

assert_eq!(Equal("self").min(Equal("other")).0, "self");
1.50.0 (const: unstable) · Source

fn clamp(self, min: Self, max: Self) -> Self
where Self: Sized,

Restrict a value to a certain interval.

Returns max if self is greater than max, and min if self is less than min. Otherwise this returns self.

Panics

Panics if min > max.

Examples
assert_eq!((-3).clamp(-2, 1), -2);
assert_eq!(0.clamp(-2, 1), 0);
assert_eq!(2.clamp(-2, 1), 1);

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Ord for !

1.0.0 (const: unstable) · Source

impl Ord for ()



impl Ord for ASN1DateTime



impl Ord for ASN1Time



impl Ord for ASN1TimeZone

Source

impl Ord for ATerm



impl Ord for AccessControlMaxAge



impl Ord for AddressType



impl Ord for Age



impl Ord for AggregationTemporality

Source

impl Ord for Alignment



impl Ord for AnyDelimiterCodec



impl Ord for ArcStr

Source

impl Ord for AsciiChar



impl Ord for Asn



impl Ord for Attribute



impl Ord for Attributes

Source

impl Ord for B0

Source

impl Ord for B1



impl Ord for BERMode



impl Ord for BStr



impl Ord for BidiClass



impl Ord for BigEndian



impl Ord for BigEndian

Source

impl Ord for BigInt



impl Ord for BigNum



impl Ord for BigNumRef

Source

impl Ord for BigUint



impl Ord for Blocking

Source

impl Ord for Braced

Source

impl Ord for ByteStr

Source

impl Ord for ByteString



impl Ord for rama::bytes::Bytes



impl Ord for Bytes



impl Ord for BytesCodec



impl Ord for BytesMut

1.0.0 · Source

impl Ord for CStr

1.64.0 · Source

impl Ord for CString

Source

impl Ord for CType



impl Ord for CanonicalCombiningClass

Source

impl Ord for Cardinality



impl Ord for CertificateCompressionAlgorithm

Source

impl Ord for CharCase



impl Ord for CharULE



impl Ord for CipherSuite



impl Ord for ClassBytesRange



impl Ord for ClassUnicodeRange



impl Ord for ClientSubnet



impl Ord for ClientVerifyMode



impl Ord for Command

1.0.0 · Source

impl Ord for Components<'_>



impl Ord for CompressionAlgorithm

1.27.0 · Source

impl Ord for CpuidResult



impl Ord for DNSClass



impl Ord for DataEncoding



impl Ord for DataMarkerAttributes



impl Ord for DataMarkerId



impl Ord for DataMarkerIdHash



impl Ord for DataMarkerInfo



impl Ord for DataPointFlags



impl Ord for DataRequestMetadata



impl Ord for Date



impl Ord for Date



impl Ord for rama::http::headers::Date



impl Ord for Date



impl Ord for DateTime



impl Ord for Datetime



impl Ord for DeviceName

Source

impl Ord for petgraph::Direction



impl Ord for Direction



impl Ord for Directive



impl Ord for DnsResolveMode



impl Ord for rama::net::address::Domain



impl Ord for Domain<'_>



impl Ord for DomainRef<'_>



impl Ord for Dst

1.3.0 · Source

impl Ord for core::time::Duration



impl Ord for Duration



impl Ord for ECPointFormat



impl Ord for EastAsianWidth



impl Ord for EdnsCode



impl Ord for EdnsOption



impl Ord for rama::http::headers::encoding::Encoding



impl Ord for Encoding

Source

impl Ord for Equal



impl Ord for Errno

1.0.0 · Source

impl Ord for Error

1.0.0 · Source

impl Ord for ErrorKind



impl Ord for Event



impl Ord for EventKind



impl Ord for Expires



impl Ord for ExtensionId



impl Ord for ExtensionType

Source

impl Ord for Feature

Source

impl Ord for FieldId



impl Ord for Fields



impl Ord for FipsStatus



impl Ord for FixedBitSet



impl Ord for FmtSpan

Source

impl Ord for ForwardKind

Available on crate feature cli only.


impl Ord for ForwardedProtocol



impl Ord for ForwardedVersion



impl Ord for Fragment



impl Ord for GeneralCategory



impl Ord for GeneralCategoryOutOfBoundsError



impl Ord for GeneralCategoryULE



impl Ord for GeneralizedTime



impl Ord for rama::crypto::dep::x509_parser::prelude::asn1_rs::GeneralizedTime



impl Ord for GraphemeClusterBreak

Source

impl Ord for Greater



impl Ord for HangulSyllableType



impl Ord for HeaderByteLength



impl Ord for HeaderValue



impl Ord for HeaderValueString



impl Ord for rama::net::address::Host



impl Ord for HostRef<'_>



impl Ord for rama::http::headers::util::HttpDate



impl Ord for HttpDate

Source

impl Ord for Hyphenated



impl Ord for ISOWeekDate



impl Ord for Id

Source

impl Ord for IdempotencyLevel

Source

impl Ord for Ident



impl Ord for IfModifiedSince



impl Ord for IfUnmodifiedSince



impl Ord for Index8



impl Ord for Index16



impl Ord for Index32



impl Ord for IndicConjunctBreak



impl Ord for IndicSyllabicCategory

1.34.0 (const: unstable) · Source

impl Ord for Infallible



impl Ord for Info



impl Ord for InsertError

1.8.0 · Source

impl Ord for std::time::Instant



impl Ord for Instant



impl Ord for IntegerRadix



impl Ord for Interest

1.7.0 · Source

impl Ord for IpAddr

Source

impl Ord for IpAddrRange

Source

impl Ord for IpNet

Source

impl Ord for IpSubnets

1.0.0 (const: unstable) · Source

impl Ord for Ipv4Addr

Source

impl Ord for Ipv4AddrRange

Source

impl Ord for Ipv4Net

Source

impl Ord for Ipv4Subnets

1.0.0 (const: unstable) · Source

impl Ord for Ipv6Addr

Source

impl Ord for Ipv6AddrRange

Source

impl Ord for Ipv6MulticastScope

Source

impl Ord for Ipv6Net

Source

impl Ord for Ipv6Subnets



impl Ord for JoiningGroup



impl Ord for JoiningType

Source

impl Ord for JsType



impl Ord for rama::telemetry::opentelemetry::Key



impl Ord for Key



impl Ord for Key



impl Ord for Key



impl Ord for Key



impl Ord for KeyName



impl Ord for Keywords

Source

impl Ord for Kind



impl Ord for Label



impl Ord for rama::net::address::Label



impl Ord for rama::dns::client::hickory::resolver::net::proto::rr::Label

Source

impl Ord for rama::http::grpc::protobuf::prost::types::field_descriptor_proto::Label



impl Ord for Language



impl Ord for LastModified



impl Ord for LazyStateID

Source

impl Ord for Less



impl Ord for rama::telemetry::tracing::Level

Source

impl Ord for log::Level



impl Ord for rama::telemetry::tracing::level_filters::LevelFilter

Source

impl Ord for log::LevelFilter

Source

impl Ord for Lifetime



impl Ord for LineBreak



impl Ord for LinesCodec



impl Ord for Literal



impl Ord for LittleEndian



impl Ord for LittleEndian



impl Ord for Local

1.10.0 · Source

impl Ord for Location<'_>



impl Ord for LogRecordFlags



impl Ord for LowerName

Source

impl Ord for Mime

Source

impl Ord for Module



impl Ord for Month



impl Ord for NSIDPayload



impl Ord for rama::dns::client::hickory::resolver::net::proto::rr::Name



impl Ord for NegativeScale



impl Ord for NodeId



impl Ord for NonEmptyStr



impl Ord for NonMaxUsize

Source

impl Ord for NonNilUuid



impl Ord for NormalizedPathBuf



impl Ord for Null

Source

impl Ord for NullValue



impl Ord for NumericType



impl Ord for OPT



impl Ord for ObjectIdentifier



impl Ord for Offset



impl Ord for Offset



impl Ord for OffsetDateTime



impl Ord for OptPort

Source

impl Ord for OptimizeMode

1.0.0 (const: unstable) · Source

impl Ord for Ordering

1.0.0 · Source

impl Ord for OsStr

1.0.0 · Source

impl Ord for OsString



impl Ord for Other



impl Ord for PCBit

1.0.0 · Source

impl Ord for Path

1.0.0 · Source

impl Ord for PathBuf



impl Ord for PatternID



impl Ord for PatternID

1.33.0 · Source

impl Ord for PhantomPinned



impl Ord for Position



impl Ord for PositiveScale



impl Ord for PotentialCodePoint



impl Ord for PotentialUtf8



impl Ord for PotentialUtf16

1.0.0 · Source

impl Ord for PrefixComponent<'_>



impl Ord for PrimitiveDateTime



impl Ord for Private



impl Ord for Protocol



impl Ord for ProtocolStatus



impl Ord for rama::net::tls::ProtocolVersion



impl Ord for rama::proxy::socks5::proto::ProtocolVersion



impl Ord for ProxyID



impl Ord for PseudoHeader



impl Ord for Quality



impl Ord for Query



impl Ord for RData



impl Ord for RapidRng



impl Ord for Ready



impl Ord for ReasonPhrase



impl Ord for Record



impl Ord for rama::dns::client::hickory::resolver::net::proto::rr::RecordType



impl Ord for rama::gateway::fastcgi::proto::RecordType



impl Ord for Region



impl Ord for ReplyKind



impl Ord for Role



impl Ord for RrKey



impl Ord for ScalarKind



impl Ord for Script



impl Ord for Script



impl Ord for Seconds



impl Ord for SentenceBreak



impl Ord for Server



impl Ord for ServerVerifyMode



impl Ord for ServingStatus



impl Ord for SettingId



impl Ord for Severity



impl Ord for SeverityNumber



impl Ord for ShutdownState



impl Ord for SigId

Source

impl Ord for Sign



impl Ord for SignatureScheme



impl Ord for SignedDuration

Source

impl Ord for Simple



impl Ord for SmallIndex



impl Ord for SmolStr

1.0.0 · Source

impl Ord for SocketAddr

1.0.0 · Source

impl Ord for SocketAddrV4

1.0.0 · Source

impl Ord for SocketAddrV6



impl Ord for SocksMethod



impl Ord for Span



impl Ord for Span



impl Ord for SpanFlags



impl Ord for SpanKind



impl Ord for SslInfoCallbackAlert



impl Ord for SslInfoCallbackMode



impl Ord for SslInfoCallbackValue



impl Ord for SslMode



impl Ord for SslOptions



impl Ord for SslSessionCacheMode



impl Ord for SslVerifyMode



impl Ord for StateID



impl Ord for StateID



impl Ord for rama::http::StatusCode



impl Ord for rama::http::grpc::service::opentelemetry::proto::trace::v1::status::StatusCode



impl Ord for StreamId

1.0.0 · Source

impl Ord for String



impl Ord for SubdivisionId



impl Ord for SubdivisionSuffix



impl Ord for Substr



impl Ord for Subtag



impl Ord for Subtag



impl Ord for Suffix<'_>



impl Ord for SupportedGroup



impl Ord for SvcParamKey

Source

impl Ord for Syntax

1.8.0 · Source

impl Ord for std::time::SystemTime



impl Ord for SystemTime



impl Ord for Tag



impl Ord for TagClass



impl Ord for TaggedDerValue



impl Ord for Time



impl Ord for Time

Source

impl Ord for petgraph::visit::dfsvisit::Time



impl Ord for Time



impl Ord for Timespec



impl Ord for Timestamp



impl Ord for Token



impl Ord for Token



impl Ord for TokenKind

Source

impl Ord for TopologicalPosition



impl Ord for TransportProtocol



impl Ord for Type

Source

impl Ord for rama::http::grpc::protobuf::prost::types::field_descriptor_proto::Type



impl Ord for rama::proxy::haproxy::protocol::v2::Type

1.0.0 · Source

impl Ord for TypeId



impl Ord for UTCTime

Source

impl Ord for UTerm



impl Ord for UninterpretedHost



impl Ord for UninterpretedHostRef<'_>



impl Ord for Unit



impl Ord for Unit



impl Ord for UnixTime



impl Ord for Uri



impl Ord for UriTemplateStr



impl Ord for UriTemplateString

Source

impl Ord for Url

URLs compare like their serialization.

Source

impl Ord for Urn



impl Ord for UserAgent



impl Ord for UserInfo



impl Ord for UsernamePasswordSubnegotiationVersion



impl Ord for Utc



impl Ord for UtcDateTime



impl Ord for UtcOffset



impl Ord for UtcTime



impl Ord for Utf8Bytes



impl Ord for Utf8Range



impl Ord for Utf8Sequence

Source

impl Ord for Uuid



impl Ord for Value



impl Ord for Value



impl Ord for Variant



impl Ord for Variants



impl Ord for Version



impl Ord for VerticalOrientation



impl Ord for WordBreak



impl Ord for WorkerId



impl Ord for X509CheckFlags



impl Ord for X509VerifyFlags



impl Ord for XClacksOverhead

Source

impl Ord for Z0



impl Ord for ZipString



impl Ord for Zoned

1.0.0 (const: unstable) · Source

impl Ord for bool

1.0.0 (const: unstable) · Source

impl Ord for char

1.0.0 (const: unstable) · Source

impl Ord for i8

1.0.0 (const: unstable) · Source

impl Ord for i16

1.0.0 (const: unstable) · Source

impl Ord for i32

1.0.0 (const: unstable) · Source

impl Ord for i64

1.0.0 (const: unstable) · Source

impl Ord for i128

1.0.0 (const: unstable) · Source

impl Ord for isize

1.0.0 · Source

impl Ord for str

Implements ordering of strings.

Strings are ordered lexicographically by their byte values. This orders Unicode code points based on their positions in the code charts. This is not necessarily the same as “alphabetical” order, which varies by language and locale. Sorting strings according to culturally-accepted standards requires locale-specific data that is outside the scope of the str type.

1.0.0 (const: unstable) · Source

impl Ord for u8

1.0.0 (const: unstable) · Source

impl Ord for u16

1.0.0 (const: unstable) · Source

impl Ord for u32

1.0.0 (const: unstable) · Source

impl Ord for u64

1.0.0 (const: unstable) · Source

impl Ord for u128

1.0.0 (const: unstable) · Source

impl Ord for usize

Source

impl<'a, E, Ix> Ord for EdgeReference<'a, E, Ix>
where E: Ord, Ix: Ord + IndexType,



impl<'a, P, L, R> Ord for DifferenceItem<'a, P, L, R>
where P: Ord, L: Ord, R: Ord,



impl<'a, P, L, R> Ord for DifferenceItem<'a, P, L, R>
where P: Ord, L: Ord, R: Ord,



impl<'a, P, L, R> Ord for UnionItem<'a, P, L, R>
where P: Ord, L: Ord, R: Ord,



impl<'a, P, L, R> Ord for UnionItem<'a, P, L, R>
where P: Ord, L: Ord, R: Ord,



impl<'a, T, F> Ord for VarZeroVec<'a, T, F>
where T: VarULE + Ord + ?Sized, F: VarZeroVecFormat,



impl<'a, T> Ord for ZeroVec<'a, T>
where T: AsULE + Ord,



impl<'a, V> Ord for VarZeroCow<'a, V>
where V: VarULE + Ord + ?Sized,



impl<'a> Ord for AuthorityRef<'a>

1.0.0 · Source

impl<'a> Ord for Component<'a>



impl<'a> Ord for FragmentRef<'a>

Source

impl<'a> Ord for Metadata<'a>

Source

impl<'a> Ord for MetadataBuilder<'a>

Source

impl<'a> Ord for rama::http::mime::Name<'a>



impl<'a> Ord for NonBlocking<'a>



impl<'a> Ord for NormalizedPath<'a>



impl<'a> Ord for PathRef<'a>



impl<'a> Ord for PercentDecodedWhatwgBytes<'a>

Source

impl<'a> Ord for PhantomContravariantLifetime<'a>

Source

impl<'a> Ord for PhantomCovariantLifetime<'a>

Source

impl<'a> Ord for PhantomInvariantLifetime<'a>

1.0.0 · Source

impl<'a> Ord for Prefix<'a>



impl<'a> Ord for QueryRef<'a>



impl<'a> Ord for RawPath<'a>



impl<'a> Ord for UserInfoRef<'a>



impl<'a> Ord for ZipStr<'a>



impl<'d> Ord for TimeZoneName<'d>



impl<'k, 'v> Ord for Params<'k, 'v>



impl<'k> Ord for KeyMut<'k>



impl<'s, T> Ord for SliceVec<'s, T>
where T: Ord,



impl<A, B, C, D, E, F, Format> Ord for Tuple6VarULE<A, B, C, D, E, F, Format>
where A: Ord + VarULE + ?Sized, B: Ord + VarULE + ?Sized, C: Ord + VarULE + ?Sized, D: Ord + VarULE + ?Sized, E: Ord + VarULE + ?Sized, F: Ord + VarULE + ?Sized, Format: VarZeroVecFormat,



impl<A, B, C, D, E, F> Ord for Tuple6ULE<A, B, C, D, E, F>
where A: Ord + ULE, B: Ord + ULE, C: Ord + ULE, D: Ord + ULE, E: Ord + ULE, F: Ord + ULE,



impl<A, B, C, D, E, Format> Ord for Tuple5VarULE<A, B, C, D, E, Format>
where A: Ord + VarULE + ?Sized, B: Ord + VarULE + ?Sized, C: Ord + VarULE + ?Sized, D: Ord + VarULE + ?Sized, E: Ord + VarULE + ?Sized, Format: VarZeroVecFormat,



impl<A, B, C, D, E> Ord for Tuple5ULE<A, B, C, D, E>
where A: Ord + ULE, B: Ord + ULE, C: Ord + ULE, D: Ord + ULE, E: Ord + ULE,



impl<A, B, C, D, Format> Ord for Tuple4VarULE<A, B, C, D, Format>
where A: Ord + VarULE + ?Sized, B: Ord + VarULE + ?Sized, C: Ord + VarULE + ?Sized, D: Ord + VarULE + ?Sized, Format: VarZeroVecFormat,



impl<A, B, C, D> Ord for Tuple4ULE<A, B, C, D>
where A: Ord + ULE, B: Ord + ULE, C: Ord + ULE, D: Ord + ULE,



impl<A, B, C, Format> Ord for Tuple3VarULE<A, B, C, Format>
where A: Ord + VarULE + ?Sized, B: Ord + VarULE + ?Sized, C: Ord + VarULE + ?Sized, Format: VarZeroVecFormat,



impl<A, B, C> Ord for Tuple3ULE<A, B, C>
where A: Ord + ULE, B: Ord + ULE, C: Ord + ULE,



impl<A, B, Format> Ord for Tuple2VarULE<A, B, Format>
where A: Ord + VarULE + ?Sized, B: Ord + VarULE + ?Sized, Format: VarZeroVecFormat,



impl<A, B> Ord for Tuple2ULE<A, B>
where A: Ord + ULE, B: Ord + ULE,



impl<A, B> Ord for VarTuple<A, B>
where A: Ord, B: Ord,



impl<A, V> Ord for VarTupleULE<A, V>
where A: Ord + AsULE, V: Ord + VarULE + ?Sized, <A as AsULE>::ULE: Ord,

1.0.0 (const: unstable) · Source

impl<A> Ord for &A
where A: Ord + ?Sized,

1.0.0 (const: unstable) · Source

impl<A> Ord for &mut A
where A: Ord + ?Sized,



impl<A> Ord for ArrayVec<A>
where A: Array, <A as Array>::Item: Ord,



impl<A> Ord for SmallVec<A>
where A: Array, <A as Array>::Item: Ord,



impl<A> Ord for TinyVec<A>
where A: Array, <A as Array>::Item: Ord,

1.0.0 · Source

impl<B> Ord for Cow<'_, B>
where B: Ord + ToOwned + ?Sized,

Source

impl<Dyn> Ord for DynMetadata<Dyn>
where Dyn: ?Sized,

1.4.0 · Source

impl<F> Ord for F
where F: FnPtr,



impl<I> Ord for LocatingSlice<I>
where I: Ord,



impl<I> Ord for Partial<I>
where I: Ord,

Source

impl<Ix> Ord for petgraph::adj::EdgeIndex<Ix>
where Ix: Ord + IndexType,

Source

impl<Ix> Ord for petgraph::graph_impl::EdgeIndex<Ix>
where Ix: Ord,

Source

impl<Ix> Ord for NodeIndex<Ix>
where Ix: Ord,

1.0.0 · Source

impl<K, V, A> Ord for BTreeMap<K, V, A>
where K: Ord, V: Ord, A: Allocator + Clone,



impl<K, V, S> Ord for LiteMap<K, V, S>
where K: Ord + ?Sized, V: Ord + ?Sized, S: Ord,



impl<K, V> Ord for Slice<K, V>
where K: Ord, V: Ord,

Source

impl<L, R> Ord for Either<L, R>
where L: Ord, R: Ord,



impl<O> Ord for I16<O>
where O: ByteOrder,



impl<O> Ord for I32<O>
where O: ByteOrder,



impl<O> Ord for I64<O>
where O: ByteOrder,



impl<O> Ord for I128<O>
where O: ByteOrder,



impl<O> Ord for Isize<O>
where O: ByteOrder,



impl<O> Ord for U16<O>
where O: ByteOrder,



impl<O> Ord for U32<O>
where O: ByteOrder,



impl<O> Ord for U64<O>
where O: ByteOrder,



impl<O> Ord for U128<O>
where O: ByteOrder,



impl<O> Ord for Usize<O>
where O: ByteOrder,

1.41.0 · Source

impl<Ptr> Ord for Pin<Ptr>
where Ptr: Deref, <Ptr as Deref>::Target: Ord,



impl<R> Ord for ZipFilePath<R>
where R: Ord,

Source

impl<S> Ord for url::host::Host<S>
where S: Ord,



impl<S> Ord for RiAbsoluteStr<S>
where S: Spec,



impl<S> Ord for RiAbsoluteString<S>
where S: Spec,



impl<S> Ord for RiFragmentStr<S>
where S: Spec,



impl<S> Ord for RiFragmentString<S>
where S: Spec,



impl<S> Ord for RiQueryStr<S>
where S: Spec,



impl<S> Ord for RiQueryString<S>
where S: Spec,



impl<S> Ord for RiReferenceStr<S>
where S: Spec,



impl<S> Ord for RiReferenceString<S>
where S: Spec,



impl<S> Ord for RiRelativeStr<S>
where S: Spec,



impl<S> Ord for RiRelativeString<S>
where S: Spec,



impl<S> Ord for RiStr<S>
where S: Spec,



impl<S> Ord for RiString<S>
where S: Spec,



impl<Storage> Ord for __BindgenBitfieldUnit<Storage>
where Storage: Ord,



impl<Storage> Ord for __BindgenBitfieldUnit<Storage>
where Storage: Ord,



impl<Storage> Ord for __BindgenBitfieldUnit<Storage>
where Storage: Ord,

1.0.0 · Source

impl<T, A> Ord for Arc<T, A>
where T: Ord + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Ord for BTreeSet<T, A>
where T: Ord, A: Allocator + Clone,

1.0.0 · Source

impl<T, A> Ord for rama::utils::collections::smallvec::alloc::boxed::Box<T, A>
where T: Ord + ?Sized, A: Allocator,



impl<T, A> Ord for Box<T, A>
where T: Ord + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Ord for LinkedList<T, A>
where T: Ord, A: Allocator,

1.0.0 · Source

impl<T, A> Ord for Rc<T, A>
where T: Ord + ?Sized, A: Allocator,

Source

impl<T, A> Ord for UniqueArc<T, A>
where T: Ord + ?Sized, A: Allocator,

Source

impl<T, A> Ord for UniqueRc<T, A>
where T: Ord + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Ord for rama::http::grpc::protobuf::prost::alloc::vec::Vec<T, A>
where T: Ord, A: Allocator,

Implements ordering of vectors, lexicographically.



impl<T, A> Ord for Vec<T, A>
where T: Ord, A: Allocator,

Implements ordering of vectors, lexicographically.

1.0.0 · Source

impl<T, A> Ord for VecDeque<T, A>
where T: Ord, A: Allocator,



impl<T, B> Ord for Ref<B, T>
where B: ByteSlice, T: FromBytes + Ord + KnownLayout + Immutable + ?Sized,

1.0.0 (const: unstable) · Source

impl<T, E> Ord for Result<T, E>
where T: Ord, E: Ord,



impl<T, F> Ord for VarZeroSlice<T, F>
where T: VarULE + Ord + ?Sized, F: VarZeroVecFormat,



impl<T, FLAGS> Ord for ForceFlag<T, FLAGS>
where FLAGS: FlagConstructor, T: Ord,



impl<T, N> Ord for GenericArray<T, N>
where T: Ord, N: ArrayLength<T>,



impl<T, S> Ord for Checkpoint<T, S>
where T: Ord,

Source

impl<T, const N: usize> Ord for Simd<T, N>
where T: SimdElement + Ord,

Lexicographic order. For the SIMD elementwise minimum and maximum, use simd_min and simd_max instead.



impl<T, const N: usize> Ord for TagNonNull<T, N>



impl<T, const N: usize> Ord for TagPtr<T, N>

1.0.0 (const: unstable) · Source

impl<T, const N: usize> Ord for [T; N]
where T: Ord,

Implements comparison of arrays lexicographically.

Source

impl<T, const VARIANT: u32, const FIELD: u32> Ord for FieldRepresentingType<T, VARIANT, FIELD>
where T: ?Sized,

1.0.0 (const: unstable) · Source

impl<T> Ord for (T₁, T₂, …, Tₙ)
where T: Ord,

This trait is implemented for tuples up to twelve items long.

1.0.0 · Source

impl<T> Ord for *const T
where T: ?Sized,

Pointer comparison is by address, as produced by the [<*const T>::addr](pointer::addr) method.

1.0.0 · Source

impl<T> Ord for *mut T
where T: ?Sized,

Pointer comparison is by address, as produced by the <*mut T>::addr method.



impl<T> Ord for AllowStdIo<T>
where T: Ord,



impl<T> Ord for Ascii<T>
where T: AsRef<str>,



impl<T> Ord for BigEndian<T>
where T: Ord,

1.10.0 · Source

impl<T> Ord for Cell<T>
where T: Ord + Copy,



impl<T> Ord for Constant<T>
where T: Ord,



impl<T> Ord for LittleEndian<T>
where T: Ord,

1.20.0 · Source

impl<T> Ord for ManuallyDrop<T>
where T: Ord + ?Sized,



impl<T> Ord for NonEmptyVec<T>
where T: Ord,

1.25.0 · Source

impl<T> Ord for NonNull<T>
where T: ?Sized,

1.28.0 (const: unstable) · Source

impl<T> Ord for NonZero<T>

1.0.0 (const: unstable) · Source

impl<T> Ord for Option<T>
where T: Ord,

Source

impl<T> Ord for PhantomContravariant<T>
where T: ?Sized,

Source

impl<T> Ord for PhantomCovariant<T>
where T: ?Sized,

1.0.0 · Source

impl<T> Ord for PhantomData<T>
where T: ?Sized,

Source

impl<T> Ord for PhantomInvariant<T>
where T: ?Sized,

1.36.0 · Source

impl<T> Ord for Poll<T>
where T: Ord,

1.10.0 · Source

impl<T> Ord for RefCell<T>
where T: Ord + ?Sized,

1.19.0 (const: unstable) · Source

impl<T> Ord for Reverse<T>
where T: Ord,

1.74.0 · Source

impl<T> Ord for Saturating<T>
where T: Ord,



impl<T> Ord for Shared<'_, T>
where T: Pointable + ?Sized,



impl<T> Ord for Slice<T>
where T: Ord,

Source

impl<T> Ord for SyncView<T>
where T: Sync + Ord + ?Sized,



impl<T> Ord for TryWriteableInfallibleAsWriteable<T>
where T: Ord,



impl<T> Ord for Unalign<T>
where T: Unaligned + Ord,



impl<T> Ord for UniCase<T>
where T: AsRef<str>,

1.0.0 · Source

impl<T> Ord for Wrapping<T>
where T: Ord,



impl<T> Ord for WriteableAsTryWriteableInfallible<T>
where T: Ord,



impl<T> Ord for ZeroSlice<T>
where T: AsULE + Ord,

1.0.0 (const: unstable) · Source

impl<T> Ord for [T]
where T: Ord,

Implements comparison of slices lexicographically.



impl<TZ> Ord for ZipDateTime<TZ>
where TZ: Ord,

Source

impl<U, B> Ord for UInt<U, B>
where U: Ord, B: Ord,



impl<U, const N: usize> Ord for NichedOption<U, N>
where U: Ord,

Source

impl<U> Ord for NInt<U>
where U: Ord + Unsigned + NonZero,



impl<U> Ord for OptionVarULE<U>
where U: VarULE + Ord + ?Sized,

Source

impl<U> Ord for PInt<U>
where U: Ord + Unsigned + NonZero,

Source

impl<V, A> Ord for TArr<V, A>
where V: Ord, A: Ord,



impl<V, U> Ord for WithUnit<V, U>
where V: Ord,



impl<VE> Ord for MetadataValue<VE>
where VE: ValueEncoding,



impl<Y, C> Ord for Yoke<Y, C>
where Y: for<'a> Yokeable<'a>, <Y as Yokeable<'a>>::Output: for<'a> Ord,

Source

impl<Y, R> Ord for CoroutineState<Y, R>
where Y: Ord, R: Ord,



impl<const MIN: i8, const MAX: i8> Ord for OptionRangedI8<MIN, MAX>



impl<const MIN: i8, const MAX: i8> Ord for RangedI8<MIN, MAX>



impl<const MIN: i16, const MAX: i16> Ord for OptionRangedI16<MIN, MAX>



impl<const MIN: i16, const MAX: i16> Ord for RangedI16<MIN, MAX>



impl<const MIN: i32, const MAX: i32> Ord for OptionRangedI32<MIN, MAX>



impl<const MIN: i32, const MAX: i32> Ord for RangedI32<MIN, MAX>



impl<const MIN: i64, const MAX: i64> Ord for OptionRangedI64<MIN, MAX>



impl<const MIN: i64, const MAX: i64> Ord for RangedI64<MIN, MAX>



impl<const MIN: i128, const MAX: i128> Ord for OptionRangedI128<MIN, MAX>



impl<const MIN: i128, const MAX: i128> Ord for RangedI128<MIN, MAX>



impl<const MIN: isize, const MAX: isize> Ord for OptionRangedIsize<MIN, MAX>



impl<const MIN: isize, const MAX: isize> Ord for RangedIsize<MIN, MAX>



impl<const MIN: u8, const MAX: u8> Ord for OptionRangedU8<MIN, MAX>



impl<const MIN: u8, const MAX: u8> Ord for RangedU8<MIN, MAX>



impl<const MIN: u16, const MAX: u16> Ord for OptionRangedU16<MIN, MAX>



impl<const MIN: u16, const MAX: u16> Ord for RangedU16<MIN, MAX>



impl<const MIN: u32, const MAX: u32> Ord for OptionRangedU32<MIN, MAX>



impl<const MIN: u32, const MAX: u32> Ord for RangedU32<MIN, MAX>



impl<const MIN: u64, const MAX: u64> Ord for OptionRangedU64<MIN, MAX>



impl<const MIN: u64, const MAX: u64> Ord for RangedU64<MIN, MAX>



impl<const MIN: u128, const MAX: u128> Ord for OptionRangedU128<MIN, MAX>



impl<const MIN: u128, const MAX: u128> Ord for RangedU128<MIN, MAX>



impl<const MIN: usize, const MAX: usize> Ord for OptionRangedUsize<MIN, MAX>



impl<const MIN: usize, const MAX: usize> Ord for RangedUsize<MIN, MAX>



impl<const N: usize, T> Ord for NonEmptySmallVec<N, T>
where T: Ord,



impl<const N: usize> Ord for RawBytesULE<N>



impl<const N: usize> Ord for TinyAsciiStr<N>



impl<const N: usize> Ord for UnvalidatedTinyAsciiStr<N>



impl<const SIZE: usize> Ord for WriteBuffer<SIZE>