DerefMut

Trait DerefMut 

1.0.0 (const: unstable) · Source
pub trait DerefMut: Deref {
    // Required method
    fn deref_mut(&mut self) -> &mut Self::Target;
}
Available on crate features crypto and std only.
Used for mutable dereferencing operations, like in *v = 1;.

In addition to being used for explicit dereferencing operations with the (unary) * operator in mutable contexts, DerefMut is also used implicitly by the compiler in many circumstances. This mechanism is called “mutable deref coercion”. In immutable contexts, Deref is used.

Warning: Deref coercion is a powerful language feature which has far-reaching implications for every type that implements DerefMut. The compiler will silently insert calls to DerefMut::deref_mut. For this reason, one should be careful about implementing DerefMut and only do so when mutable deref coercion is desirable. See the Deref docs for advice on when this is typically desirable or undesirable.

Types that implement DerefMut or Deref are often called “smart pointers” and the mechanism of deref coercion has been specifically designed to facilitate the pointer-like behavior that name suggests. Often, the purpose of a “smart pointer” type is to change the ownership semantics of a contained value (for example, Rc or Cow) or the storage semantics of a contained value (for example, Box).

Mutable deref coercion

If T implements DerefMut<Target = U>, and v is a value of type T, then:

  • In mutable contexts, *v (where T is neither a reference nor a raw pointer) is equivalent to *DerefMut::deref_mut(&mut v).
  • Values of type &mut T are coerced to values of type &mut U
  • T implicitly implements all the (mutable) methods of the type U.

For more details, visit the chapter in The Rust Programming Language as well as the reference sections on the dereference operator, method resolution and type coercions.

Fallibility

This trait’s method should never unexpectedly fail. Deref coercion means the compiler will often insert calls to DerefMut::deref_mut implicitly. Failure during dereferencing can be extremely confusing when DerefMut is invoked implicitly. In the majority of uses it should be infallible, though it may be acceptable to panic if the type is misused through programmer error, for example.

However, infallibility is not enforced and therefore not guaranteed. As such, unsafe code should not rely on infallibility in general for soundness.

Examples

A struct with a single field which is modifiable by dereferencing the struct.

use std::ops::{Deref, DerefMut};

struct DerefMutExample<T> {
    value: T
}

impl<T> Deref for DerefMutExample<T> {
    type Target = T;

    fn deref(&self) -> &Self::Target {
        &self.value
    }
}

impl<T> DerefMut for DerefMutExample<T> {
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.value
    }
}

let mut x = DerefMutExample { value: 'a' };
*x = 'b';
assert_eq!('b', x.value);

Required Methods

1.0.0 (const: unstable) · Source

fn deref_mut(&mut self) -> &mut Self::Target

Mutably dereferences the value.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl DerefMut for And



impl DerefMut for Asn1BitString



impl DerefMut for Asn1GeneralizedTime



impl DerefMut for Asn1Integer



impl DerefMut for Asn1Object



impl DerefMut for Asn1String



impl DerefMut for Asn1Time

Source

impl DerefMut for At



impl DerefMut for Authority



impl DerefMut for BigNum



impl DerefMut for BigNumContext



impl DerefMut for Body



impl DerefMut for BorrowedPayload<'_>

Source

impl DerefMut for ByteStr

Source

impl DerefMut for ByteString



impl DerefMut for Bytes



impl DerefMut for BytesMut

Source

impl DerefMut for Caret



impl DerefMut for CipherCtx



impl DerefMut for rama::tls::rustls::dep::rustls::ClientConnection



impl DerefMut for rama::tls::rustls::dep::rustls::quic::ClientConnection



impl DerefMut for ClientWebSocket

Source

impl DerefMut for Colon

Source

impl DerefMut for Comma



impl DerefMut for Conf



impl DerefMut for ConnectConfiguration



impl DerefMut for rama::tls::rustls::dep::rustls::Connection



impl DerefMut for rama::tls::rustls::dep::rustls::quic::Connection



impl DerefMut for Digest



impl DerefMut for DigestBytes



impl DerefMut for DnsRequest



impl DerefMut for DnsResponse



impl DerefMut for DocumentMut

Source

impl DerefMut for Dollar

Source

impl DerefMut for Dot



impl DerefMut for EcGroup



impl DerefMut for EcPoint



impl DerefMut for EcdsaSig

Source

impl DerefMut for Eq



impl DerefMut for Forwarded



impl DerefMut for GeneralName

Source

impl DerefMut for Gt



impl DerefMut for HmacCtx



impl DerefMut for Host



impl DerefMut for HpkeKey



impl DerefMut for LowerName

Source

impl DerefMut for Lt

Source

impl DerefMut for Minus



impl DerefMut for ModalEncoder<'_, '_>

Source

impl DerefMut for Not



impl DerefMut for OctetStream



impl DerefMut for OpensslString

Source

impl DerefMut for Or

1.44.0 · Source

impl DerefMut for OsString

1.68.0 · Source

impl DerefMut for PathBuf

Source

impl DerefMut for Percent



impl DerefMut for Pkcs12

Source

impl DerefMut for Plus

Source

impl DerefMut for Pound

Source

impl DerefMut for Question

Source

impl DerefMut for Semi



impl DerefMut for rama::tls::rustls::dep::rustls::ServerConnection



impl DerefMut for rama::tls::rustls::dep::rustls::quic::ServerConnection



impl DerefMut for ServerWebSocket

Source

impl DerefMut for Slash



impl DerefMut for SrtpProtectionProfile



impl DerefMut for Ssl



impl DerefMut for SslAcceptorBuilder



impl DerefMut for SslConnectorBuilder



impl DerefMut for SslContext



impl DerefMut for SslCredential



impl DerefMut for SslEchKeys



impl DerefMut for SslSession

Source

impl DerefMut for Star

1.3.0 · Source

impl DerefMut for String



impl DerefMut for Text

Source

impl DerefMut for Tilde



impl DerefMut for UnbufferedClientConnection



impl DerefMut for UnbufferedServerConnection

Source

impl DerefMut for Underscore



impl DerefMut for X509



impl DerefMut for X509Algorithm



impl DerefMut for X509Extension



impl DerefMut for X509Name



impl DerefMut for X509NameEntry



impl DerefMut for X509Object



impl DerefMut for X509Req



impl DerefMut for X509Store



impl DerefMut for X509StoreBuilder



impl DerefMut for X509StoreContext



impl DerefMut for X509VerifyParam



impl<'a, R, T> DerefMut for MappedMutexGuard<'a, R, T>
where R: RawMutex + 'a, T: 'a + ?Sized,



impl<'a, R, T> DerefMut for MappedRwLockWriteGuard<'a, R, T>
where R: RawRwLock + 'a, T: 'a + ?Sized,



impl<'a, R, T> DerefMut for MutexGuard<'a, R, T>
where R: RawMutex + 'a, T: 'a + ?Sized,



impl<'a, R, T> DerefMut for RwLockWriteGuard<'a, R, T>
where R: RawRwLock + 'a, T: 'a + ?Sized,

Source

impl<'a, T, A> DerefMut for rama::http::grpc::protobuf::prost::alloc::vec::PeekMut<'a, T, A>
where A: Allocator,

Source

impl<'a, T, C> DerefMut for sharded_slab::pool::RefMut<'a, T, C>
where T: Clear + Default, C: Config,



impl<'a, T, F> DerefMut for PoolGuard<'a, T, F>
where T: Send, F: Fn() -> T,



impl<'a, T> DerefMut for AllocatedStackMemory<'a, T>



impl<'a, T> DerefMut for Locked<'a, T>



impl<'a, T> DerefMut for MappedMutexGuard<'a, T>
where T: ?Sized,



impl<'a, T> DerefMut for MutexGuard<'a, T>
where T: ?Sized,



impl<'a, T> DerefMut for SpinMutexGuard<'a, T>
where T: ?Sized,

1.36.0 · Source

impl<'a> DerefMut for IoSliceMut<'a>



impl<'a> DerefMut for MaybeUninitSlice<'a>



impl<'rwlock, T, R> DerefMut for RwLockWriteGuard<'rwlock, T, R>
where T: ?Sized,



impl<'s, T> DerefMut for SliceVec<'s, T>



impl<A> DerefMut for ArrayVec<A>
where A: Array,



impl<A> DerefMut for SmallVec<A>
where A: Array,



impl<A> DerefMut for TinyVec<A>
where A: Array,



impl<B, T> DerefMut for Ref<B, T>
where B: ByteSliceMut, T: FromBytes + IntoBytes + KnownLayout + Immutable + ?Sized,



impl<C, ID> DerefMut for LeasedConnection<C, ID>
where C: ExtensionsRef,



impl<C> DerefMut for Authorization<C>



impl<Data> DerefMut for rama::tls::rustls::dep::rustls::quic::ConnectionCommon<Data>



impl<E, Q> DerefMut for AppendOnDrop<E, Q>
where E: Entry, Q: EntrySink<E>,



impl<E, S> DerefMut for AppendAndCloseOnDrop<E, S>
where E: CloseEntry, S: EntrySink<RootEntry<<E as CloseValue>::Closed>>,



impl<E, const N: usize> DerefMut for WithGlobalDimensions<E, N>



impl<E> DerefMut for EnumMapEntry<E>



impl<K, V, S> DerefMut for AHashMap<K, V, S>

Source

impl<L, R> DerefMut for Either<L, R>
where L: DerefMut, R: DerefMut<Target = <L as Deref>::Target>,

1.33.0 (const: unstable) · Source

impl<Ptr> DerefMut for Pin<Ptr>
where Ptr: Deref, PinHelper<Ptr>: PinDerefMutHelper<Target = <Pin<Ptr> as Deref>::Target>,



impl<S> DerefMut for Ascii<S>



impl<S> DerefMut for BlockingStream<S>
where S: Stream + Unpin,



impl<S> DerefMut for State<S>



impl<S> DerefMut for UniCase<S>

1.0.0 · Source

impl<T, A> DerefMut for rama::utils::collections::smallvec::alloc::boxed::Box<T, A>
where A: Allocator, T: ?Sized,



impl<T, A> DerefMut for Box<T, A>
where A: Allocator, T: ?Sized,

1.12.0 · Source

impl<T, A> DerefMut for rama::utils::collections::smallvec::alloc::collections::binary_heap::PeekMut<'_, T, A>
where T: Ord, A: Allocator,

Source

impl<T, A> DerefMut for UniqueArc<T, A>
where A: Allocator, T: ?Sized,

Source

impl<T, A> DerefMut for UniqueRc<T, A>
where A: Allocator, T: ?Sized,

1.0.0 (const: unstable) · Source

impl<T, A> DerefMut for rama::http::grpc::protobuf::prost::alloc::vec::Vec<T, A>
where A: Allocator,



impl<T, A> DerefMut for Vec<T, A>
where A: Allocator,

Source

impl<T, C> DerefMut for OwnedRefMut<T, C>
where T: Clear + Default, C: Config,

Source

impl<T, F, S> DerefMut for ScopeGuard<T, F, S>
where F: FnOnce(T), S: Strategy,

Source

impl<T, F> DerefMut for DropGuard<T, F>
where F: FnOnce(T),



impl<T, F> DerefMut for Lazy<T, F>
where F: FnOnce() -> T,



impl<T, F> DerefMut for Lazy<T, F>
where F: FnOnce() -> T,

1.89.0 · Source

impl<T, F> DerefMut for LazyCell<T, F>
where F: FnOnce() -> T,

1.89.0 · Source

impl<T, F> DerefMut for LazyLock<T, F>
where F: FnOnce() -> T,



impl<T, FLAGS> DerefMut for ForceFlag<T, FLAGS>
where FLAGS: FlagConstructor,



impl<T, N> DerefMut for GenericArray<T, N>
where N: ArrayLength<T>,



impl<T, S> DerefMut for AHashSet<T, S>



impl<T, U> DerefMut for rama::futures::lock::MappedMutexGuard<'_, T, U>
where T: ?Sized, U: ?Sized,



impl<T, U> DerefMut for OwnedMappedMutexGuard<T, U>
where T: ?Sized, U: ?Sized,



impl<T, U> DerefMut for OwnedRwLockMappedWriteGuard<T, U>
where T: ?Sized, U: ?Sized,

1.0.0 · Source

impl<T> !DerefMut for &T
where T: ?Sized,

1.0.0 (const: unstable) · Source

impl<T> DerefMut for &mut T
where T: ?Sized,



impl<T> DerefMut for AppendHeaders<T>

1.9.0 (const: unstable) · Source

impl<T> DerefMut for AssertUnwindSafe<T>



impl<T> DerefMut for CachePadded<T>



impl<T> DerefMut for rama::tls::rustls::dep::rustls::ConnectionCommon<T>



impl<T> DerefMut for Css<T>



impl<T> DerefMut for Csv<T>



impl<T> DerefMut for Dh<T>



impl<T> DerefMut for Dsa<T>



impl<T> DerefMut for EcKey<T>



impl<T> DerefMut for Egress<T>



impl<T> DerefMut for Form<T>



impl<T> DerefMut for Html<T>



impl<T> DerefMut for Ingress<T>



impl<T> DerefMut for Json<T>



impl<T> DerefMut for JsonEventData<T>

1.20.0 (const: unstable) · Source

impl<T> DerefMut for ManuallyDrop<T>
where T: ?Sized,

Source

impl<T> DerefMut for std::sync::nonpoison::mutex::MappedMutexGuard<'_, T>
where T: ?Sized,

Source

impl<T> DerefMut for std::sync::poison::mutex::MappedMutexGuard<'_, T>
where T: ?Sized,

Source

impl<T> DerefMut for std::sync::nonpoison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: ?Sized,

Source

impl<T> DerefMut for std::sync::poison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: ?Sized,

Source

impl<T> DerefMut for std::sync::nonpoison::mutex::MutexGuard<'_, T>
where T: ?Sized,

1.0.0 · Source

impl<T> DerefMut for rama::tls::rustls::dep::rustls::lock::MutexGuard<'_, T>
where T: ?Sized,



impl<T> DerefMut for MutexGuard<'_, T>
where T: ?Sized,



impl<T> DerefMut for rama::futures::lock::MutexGuard<'_, T>
where T: ?Sized,



impl<T> DerefMut for MutexGuard<'_, T>
where T: ?Sized,



impl<T> DerefMut for MutexGuardArc<T>
where T: ?Sized,



impl<T> DerefMut for Owned<T>
where T: Pointable + ?Sized,



impl<T> DerefMut for OwnedMutexGuard<T>
where T: ?Sized,



impl<T> DerefMut for rama::futures::lock::OwnedMutexGuard<T>
where T: ?Sized,



impl<T> DerefMut for OwnedRwLockWriteGuard<T>
where T: ?Sized,



impl<T> DerefMut for PKey<T>



impl<T> DerefMut for Path<T>



impl<T> DerefMut for ReadOnly<T>
where T: Immutable + ?Sized,

1.0.0 (const: unstable) · Source

impl<T> DerefMut for core::cell::RefMut<'_, T>
where T: ?Sized,



impl<T> DerefMut for Rsa<T>



impl<T> DerefMut for RwLockMappedWriteGuard<'_, T>
where T: ?Sized,

Source

impl<T> DerefMut for std::sync::nonpoison::rwlock::RwLockWriteGuard<'_, T>
where T: ?Sized,

1.0.0 · Source

impl<T> DerefMut for std::sync::poison::rwlock::RwLockWriteGuard<'_, T>
where T: ?Sized,



impl<T> DerefMut for RwLockWriteGuard<'_, T>
where T: ?Sized,



impl<T> DerefMut for RwLockWriteGuard<'_, T>
where T: ?Sized,



impl<T> DerefMut for RwLockWriteGuardArc<T>
where T: ?Sized,



impl<T> DerefMut for Script<T>



impl<T> DerefMut for SequenceOf<T>



impl<T> DerefMut for SetOf<T>



impl<T> DerefMut for ShardedLockWriteGuard<'_, T>
where T: ?Sized,



impl<T> DerefMut for SlotGuard<T>
where T: CloseValue,



impl<T> DerefMut for Stack<T>
where T: Stackable,

Source

impl<T> DerefMut for ThinBox<T>
where T: ?Sized,



impl<T> DerefMut for Unalign<T>
where T: Unaligned,



impl<V, U> DerefMut for WithUnit<V, U>



impl<V, const N: usize> DerefMut for WithDimensions<V, N>



impl<Z> DerefMut for Zeroizing<Z>
where Z: Zeroize,