Struct TaggedParser
pub struct TaggedParser<'a, TagKind, T, E = Error> {
pub header: Header<'a>,
pub inner: T,
/* private fields */
}Available on crate feature
crypto only.Fields
header: Header<'a>inner: TImplementations
impl<'a, T, E> TaggedParser<'a, Explicit, T, E>
impl<'a, T, E> TaggedParser<'a, Explicit, T, E>
pub const fn new_explicit( class: Class, tag: u32, inner: T, ) -> TaggedParser<'a, Explicit, T, E>
pub fn from_ber_and_then<F>(
class: Class,
tag: u32,
bytes: &'a [u8],
op: F,
) -> Result<(&'a [u8], T), Err<E>>
pub fn from_ber_and_then<F>( class: Class, tag: u32, bytes: &'a [u8], op: F, ) -> Result<(&'a [u8], T), Err<E>>
Parse a BER tagged value and apply the provided parsing function to content
After parsing, the sequence object and header are discarded.
Note: this function is provided for Explicit, but there is not difference between
explicit or implicit tags. The op function is responsible of handling the content.
pub fn from_der_and_then<F>(
class: Class,
tag: u32,
bytes: &'a [u8],
op: F,
) -> Result<(&'a [u8], T), Err<E>>
pub fn from_der_and_then<F>( class: Class, tag: u32, bytes: &'a [u8], op: F, ) -> Result<(&'a [u8], T), Err<E>>
Parse a DER tagged value and apply the provided parsing function to content
After parsing, the sequence object and header are discarded.
Note: this function is provided for Explicit, but there is not difference between
explicit or implicit tags. The op function is responsible of handling the content.
impl<T, E> TaggedParser<'_, Implicit, T, E>
impl<T, E> TaggedParser<'_, Implicit, T, E>
pub const fn new_implicit( class: Class, constructed: bool, tag: u32, inner: T, ) -> TaggedParser<'_, Implicit, T, E>
impl<'a, TagKind, T, E> TaggedParser<'a, TagKind, T, E>
impl<'a, TagKind, T, E> TaggedParser<'a, TagKind, T, E>
impl<'a, TagKind, T, E> TaggedParser<'a, TagKind, T, E>
impl<'a, TagKind, T, E> TaggedParser<'a, TagKind, T, E>
impl<'a, TagKind, T, E> TaggedParser<'a, TagKind, T, E>
impl<'a, TagKind, T, E> TaggedParser<'a, TagKind, T, E>