Struct NameServerConfig
#[non_exhaustive]pub struct NameServerConfig {
pub ip: IpAddr,
pub trust_negative_responses: bool,
pub connections: Vec<ConnectionConfig>,
}Expand description
Configuration for the NameServer
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.ip: IpAddrThe address which the DNS NameServer is registered at.
trust_negative_responses: boolWhether to trust NXDOMAIN responses from upstream nameservers.
When this is true, and an empty NXDOMAIN response with an empty answers set is
received, the query will not be retried against other configured name servers.
(On a response with any other error response code, the query will still be retried regardless of this configuration setting.)
Defaults to true.
connections: Vec<ConnectionConfig>Connection protocols configured for this server.
Implementations
impl NameServerConfig
impl NameServerConfig
pub fn udp_and_tcp(ip: IpAddr) -> NameServerConfig
pub fn udp_and_tcp(ip: IpAddr) -> NameServerConfig
Constructs a nameserver configuration with a UDP and TCP connections
pub fn udp(ip: IpAddr) -> NameServerConfig
pub fn udp(ip: IpAddr) -> NameServerConfig
Constructs a nameserver configuration with a single UDP connection
pub fn tcp(ip: IpAddr) -> NameServerConfig
pub fn tcp(ip: IpAddr) -> NameServerConfig
Constructs a nameserver configuration with a single TCP connection
pub fn new(
ip: IpAddr,
trust_negative_responses: bool,
connections: Vec<ConnectionConfig>,
) -> NameServerConfig
pub fn new( ip: IpAddr, trust_negative_responses: bool, connections: Vec<ConnectionConfig>, ) -> NameServerConfig
Create a new NameServerConfig from its constituent parts.