AccessControlSet

Struct AccessControlSet 

pub struct AccessControlSet { /* private fields */ }
An IPv4/IPv6 access control set. This mainly hides the complexity of supporting v4 and v6 addresses concurrently in a given set. The AccessControlSet differs from a typical Access Control List in that there is no order. The access semantics are:

Present in allow listPresent in deny listResult
truefalseallowed
truetrueallowed
falsefalseallowed
falsetruedenied

Implementations



impl<'a> AccessControlSet

pub fn new(name: &'static str) -> AccessControlSet

Construct a new AccessControlSet with the given name. name is an arbitrary string used in log messages.

pub fn allow(&mut self, allow: impl Iterator<Item = &'a IpNet>)

Insert new subnets in the allow list. Existing subnets will not be removed.

pub fn deny(&mut self, deny: impl Iterator<Item = &'a IpNet>)

Insert new subnets in the deny list. Existing subnets will not be removed.

pub fn clear_allow(&mut self)

Clear all subnets from the allow list.

pub fn clear_deny(&mut self)

Clear all subnets from the deny list.

pub fn denied(&self, ip: IpAddr) -> bool

Check if the IP address ip should be denied. If the IP address is in the deny list and not in the allow list, this function will return true. All other combinations will return false (i.e., the allow list acts like an exception list.)