Struct AccessControlSetBuilder
pub struct AccessControlSetBuilder(/* private fields */);Expand description
A builder interface for constructing an AccessControlSet.
Implementations
impl<'a> AccessControlSetBuilder
impl<'a> AccessControlSetBuilder
pub fn new(name: &'static str) -> AccessControlSetBuilder
pub fn new(name: &'static str) -> AccessControlSetBuilder
Construct a builder for an access control set with the given name.
The name is used to contextualize logging when an IpAddr is denied.
pub fn allow(
self,
allow: impl Iterator<Item = &'a IpNet>,
) -> AccessControlSetBuilder
pub fn allow( self, allow: impl Iterator<Item = &'a IpNet>, ) -> AccessControlSetBuilder
Override the Self::deny() list for the provided IP networks, allowing access.
Existing networks allowed by prior Self::allow() calls are not removed.
See AccessControlSet for more information on the access semantics.
pub fn deny(
self,
deny: impl Iterator<Item = &'a IpNet>,
) -> AccessControlSetBuilder
pub fn deny( self, deny: impl Iterator<Item = &'a IpNet>, ) -> AccessControlSetBuilder
Deny clients from the provided IP networks, unless present in the Self::allow() list.
Existing networks denied by prior Self::deny() calls are not removed.
See AccessControlSet for more information on the access semantics.
pub fn clear_allow(self) -> AccessControlSetBuilder
pub fn clear_allow(self) -> AccessControlSetBuilder
Clear all IP networks previous allowed with Self::allow().
pub fn clear_deny(self) -> AccessControlSetBuilder
pub fn clear_deny(self) -> AccessControlSetBuilder
Clear all IP networks previously denied with Self::deny().
pub fn build(self) -> Result<AccessControlSet, ProtoError>
pub fn build(self) -> Result<AccessControlSet, ProtoError>
Consume the builder and produce an AccessControlSet.
Returns an error if Self::allow() was used to add deny list override networks
without using Self::deny() to specify one or more denied networks.