Struct SMIMEA
pub struct SMIMEA(/* private fields */);Expand description
Implementations
impl SMIMEA
impl SMIMEA
pub fn new(
cert_usage: CertUsage,
selector: Selector,
matching: Matching,
cert_data: Vec<u8>,
) -> SMIMEA
pub fn new( cert_usage: CertUsage, selector: Selector, matching: Matching, cert_data: Vec<u8>, ) -> SMIMEA
Construct a new SMIMEA
2. The SMIMEA Resource Record
The SMIMEA DNS resource record (RR) is used to associate an end
entity certificate or public key with the associated email address,
thus forming a "SMIMEA certificate association". The semantics of
how the SMIMEA resource record is interpreted are given later in this
document. Note that the information returned in the SMIMEA record
might be for the end entity certificate, or it might be for the trust
anchor or an intermediate certificate. This mechanism is similar to
the one given in [RFC7929] for OpenPGP.
The type value for the SMIMEA RRtype is defined in Section 8. The
SMIMEA resource record is class independent.Methods from Deref<Target = TLSA>
pub fn cert_usage(&self) -> CertUsage
pub fn cert_usage(&self) -> CertUsage
Specifies the provided association that will be used to match the certificate presented in the TLS handshake