Function message_tbs
pub fn message_tbs<M>(
message: &M,
pre_tsig: &TSIG,
key_name: &Name,
) -> Result<Vec<u8>, ProtoError>where
M: BinEncodable,Expand description
Return the to-be-signed data for authenticating the message with TSIG.
Arguments
message- the message to authenticate. Should not be modified after calling this function except to add the final TSIG recordpre_tsig- TSIG rrdata, possibly with missing MAC. Should not be modified in any other way after calling this function.key_name- the name of the TSIG key, should be the same as the name known by the remote peer.