Struct NoRecords
#[non_exhaustive]pub struct NoRecords {
pub query: Box<Query>,
pub soa: Option<Box<Record<SOA>>>,
pub ns: Option<Arc<[ForwardNSData]>>,
pub negative_ttl: Option<u32>,
pub response_code: ResponseCode,
pub authorities: Option<Arc<[Record]>>,
}Expand description
Response where no records were found
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.query: Box<Query>The query for which no records were found.
soa: Option<Box<Record<SOA>>>If an SOA is present, then this is an authoritative response or a referral to another nameserver, see the negative_type field.
ns: Option<Arc<[ForwardNSData]>>Nameservers may be present in addition to or in lieu of an SOA for a referral The tuple struct layout is vec[(Nameserver, [vec of glue records])]
negative_ttl: Option<u32>negative ttl, as determined from DnsResponse::negative_ttl this will only be present if the SOA was also present.
response_code: ResponseCodeResponseCode, if NXDOMAIN, the domain does not exist (and no other types).
If NoError, then the domain exists but there exist either other types at the same label, or subzones of that label.
Authority records from the query. These are important to preserve for DNSSEC validation.
Implementations