Enum Role
pub enum Role {
Responder,
Authorizer,
Filter,
Unknown(u16),
}Available on crate feature
fastcgi only.Expand description
Role of the FastCGI application in a request.
Sent in the BeginRequestBody to indicate how the application is expected to behave.
Reference: FastCGI spec 6
Variants
Responder
The application generates a response for every request.
This is the most common role and equivalent to a traditional CGI program.
Reference: FastCGI Specification 6.2
Authorizer
The application authorises or denies a request before the web server handles it.
Reference: FastCGI Specification 6.3
Filter
The application processes data associated with a file, and the web server provides both the file data and extra stream data.
Reference: FastCGI Specification 6.4
Unknown(u16)