Function try_cmd_string_for_request_parts_and_payload
pub fn try_cmd_string_for_request_parts_and_payload(
parts: &(impl HttpRequestParts + AuthorityInputExt + ProtocolInputExt),
payload: &Bytes,
) -> Result<String, CurlPayloadRequiresStdin>Available on crate features
http and std only.Expand description
Create a pure curl command string for the given request and inline payload.
This function refuses payloads that cannot be represented losslessly as a
command-line argument. Use prepare_cmd_for_request_parts_and_payload for
arbitrary bytes without a shell, or use
try_cmd_string_for_request_parts_and_payload_with_options to select a
platform-specific script target or external payload source.