pub struct Extensions { /* private fields */ }http only.Expand description
A type map of protocol extensions.
Extensions can be used by Request and Response to store
extra data derived from the underlying protocol.
Implementations
Sourceimpl Extensions
impl Extensions
Sourcepub const fn new() -> Extensions
pub const fn new() -> Extensions
Create an empty Extensions.
Sourcepub fn insert<T>(&mut self, val: T) -> Option<T>
pub fn insert<T>(&mut self, val: T) -> Option<T>
Insert a type into this Extensions.
If a extension of this type already existed, it will be returned.
Sourcepub fn maybe_insert<T>(&mut self, val: Option<T>) -> Option<T>
pub fn maybe_insert<T>(&mut self, val: Option<T>) -> Option<T>
Insert a type only into this Extensions, if the value is Some(T).
See Self::insert for more information.
Sourcepub fn extend(&mut self, other: Extensions)
pub fn extend(&mut self, other: Extensions)
Extend these extensions with another Extensions.
Sourcepub fn get<T>(&self) -> Option<&T>
pub fn get<T>(&self) -> Option<&T>
Get a shared reference to a type previously inserted on this Extensions.
Sourcepub fn get_mut<T>(&mut self) -> Option<&mut T>
pub fn get_mut<T>(&mut self) -> Option<&mut T>
Get an exclusive reference to a type previously inserted on this Extensions.
Sourcepub fn get_or_insert_with_ext<T>(
&mut self,
f: impl FnOnce(&Extensions) -> T,
) -> &mut T
pub fn get_or_insert_with_ext<T>( &mut self, f: impl FnOnce(&Extensions) -> T, ) -> &mut T
Inserts a value into the map computed from f into if it is None,
then returns an exclusive reference to the contained value.
Use the cheaper Self::get_or_insert_with in case you do not need access to
the extensions for the creation of T, as this function comes with
an extra cost.
Sourcepub fn get_or_insert_with<T>(&mut self, f: impl FnOnce() -> T) -> &mut T
pub fn get_or_insert_with<T>(&mut self, f: impl FnOnce() -> T) -> &mut T
Inserts a value into the map computed from f into if it is None,
then returns an exclusive reference to the contained value.
Sourcepub fn get_or_insert_from<T, U>(&mut self, src: U) -> &mut T
pub fn get_or_insert_from<T, U>(&mut self, src: U) -> &mut T
Inserts a value into the map computed by converting U into T if it is None
then returns an exclusive reference to the contained value.
Sourcepub fn get_or_insert<T>(&mut self, fallback: T) -> &mut T
pub fn get_or_insert<T>(&mut self, fallback: T) -> &mut T
Retrieves a value of type T from the context.
If the value does not exist, the given value is inserted and an exclusive reference to it is returned.
Sourcepub fn get_or_insert_default<T>(&mut self) -> &mut T
pub fn get_or_insert_default<T>(&mut self) -> &mut T
Get an extension or T’s Default.
see Extensions::get for more details.