#[repr(i32)]pub enum Cardinality {
Unknown = 0,
Optional = 1,
Required = 2,
Repeated = 3,
}Expand description
Whether a field is optional, required, or repeated.
Variants
Unknown = 0
For fields with unknown cardinality.
Optional = 1
For optional fields.
Required = 2
For required fields. Proto2 syntax only.
Repeated = 3
For repeated fields.
Implementations
Sourceimpl Cardinality
impl Cardinality
Sourceimpl Cardinality
impl Cardinality
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Cardinality>
pub fn from_str_name(value: &str) -> Option<Cardinality>
Creates an enum from field names used in the ProtoBuf definition.