Trait AuthoritySync
pub trait AuthoritySync<C, L>:
Send
+ Sync
+ 'static {
// Required method
fn authorized(&self, ext: &Extensions, credentials: &C) -> bool;
}Available on crate feature
http only.Expand description
A synchronous version of Authority, to be used for primitive implementations.
Required Methods
Returns true if the credentials are authorized, otherwise false.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".