Struct AcceptCh
pub struct AcceptCh(pub NonEmptySmallVec<16, ClientHint>);Available on crate feature
http only.Expand description
Accept-CH header, defined in RFC8942.
Sent by a server to advertise the set of ClientHints it would like
the user agent to send on subsequent requests to the same origin. Each
hint is advertised under every spelling it answers to (its preferred
Sec-CH- form plus any legacy bare alias); entries that do not map to a
known ClientHint are rejected on decode.
ABNF
Accept-CH = #client-hint-nameExample
use rama_utils::collections::non_empty_smallvec;
use rama_http_headers::{AcceptCh, ClientHint};
let accept_ch = AcceptCh(
non_empty_smallvec![ClientHint::Ua, ClientHint::Platform, ClientHint::Mobile; 16],
);Tuple Fields
0: NonEmptySmallVec<16, ClientHint>Implementations
impl AcceptCh
impl AcceptCh
pub fn new(hint: ClientHint) -> AcceptCh
pub fn new(hint: ClientHint) -> AcceptCh
Create a AcceptCh advertising a single ClientHint.