Macro bdo
bdo!() { /* proc-macro */ }Available on crate features
http and html only.Expand description
Overrides the current directionality of text, so that the text within is rendered in a different direction.
bdo!() { /* proc-macro */ }http and html only.Overrides the current directionality of text, so that the text within is rendered in a different direction.