Macro body
body!() { /* proc-macro */ }Available on crate features
http and html only.Expand description
Represents the content of an HTML document. There can be only one such element in a document.
body!() { /* proc-macro */ }http and html only.Represents the content of an HTML document. There can be only one such element in a document.