Macro br
br!() { /* proc-macro */ }Available on crate features
http and html only.Expand description
Produces a line break in text (carriage-return). It is useful for writing a poem or an address, where the division of lines is significant.