Macro code
code!() { /* proc-macro */ }Available on crate features
http and html only.Expand description
Displays its contents styled in a fashion intended to indicate that the text is a short fragment of computer code. By default, the content text is displayed using the user agent’s default monospace font.