Macro del
del!() { /* proc-macro */ }Available on crate features
http and html only.Expand description
Represents a range of text that has been deleted from a document. This can be used when rendering “track changes” or source code diff information, for example. The ins! element can be used for the opposite purpose: to indicate text that has been added to the document.