Macro fieldset
fieldset!() { /* proc-macro */ }Available on crate features
http and html only.Expand description
Used to group several controls as well as labels (label!) within a web form.
fieldset!() { /* proc-macro */ }http and html only.Used to group several controls as well as labels (label!) within a web form.