Macro kbd
kbd!() { /* proc-macro */ }Available on crate features
http and html only.Expand description
Represents a span of inline text denoting textual user input from a keyboard, voice input, or any other text entry device. By convention, the user agent defaults to rendering the contents of a kbd! element using its default monospace font, although this is not mandated by the HTML standard.