Macro label
label!() { /* proc-macro */ }Available on crate features
http and html only.Expand description
Represents a caption for an item in a user interface.
label!() { /* proc-macro */ }http and html only.Represents a caption for an item in a user interface.