Macro li
li!() { /* proc-macro */ }Available on crate features
http and html only.Expand description
Represents an item in a list. It must be contained in a parent element: an ordered list (ol!), an unordered list (ul!), or a menu (menu!). In menus and unordered lists, list items are usually displayed using bullet points. In ordered lists, they are usually displayed with an ascending counter on the left, such as a number or letter.