object

Macro object 

object!() { /* proc-macro */ }
Available on crate features http and html only.
Represents an external resource, which can be treated as an image, a nested browsing context, or a resource to be handled by a plugin.