Macro q
q!() { /* proc-macro */ }Available on crate features
http and html only.Expand description
Indicates that the enclosed text is a short inline quotation. Most modern browsers implement this by surrounding the text in quotation marks. This element is intended for short quotations that don’t require paragraph breaks; for long quotations use the blockquote! element.