Macro sub
sub!() { /* proc-macro */ }Available on crate features
http and html only.Expand description
Specifies inline text which should be displayed as subscript for solely typographical reasons. Subscripts are typically rendered with a lowered baseline using smaller text.