Macro sup
sup!() { /* proc-macro */ }Available on crate features
http and html only.Expand description
Specifies inline text which is to be displayed as superscript for solely typographical reasons. Superscripts are usually rendered with a raised baseline using smaller text.