Macro template
template!() { /* proc-macro */ }Available on crate features
http and html only.Expand description
A mechanism for holding HTML that is not to be rendered immediately when a page is loaded but may be instantiated subsequently during runtime using JavaScript.