Macro var
var!() { /* proc-macro */ }Available on crate features
http and html only.Expand description
Represents the name of a variable in a mathematical expression or a programming context. It’s typically presented using an italicized version of the current typeface, although that behavior is browser-dependent.