IntoHtml

Trait IntoHtml 

pub trait IntoHtml {
    // Required method
    fn into_html(self) -> impl IntoHtml;

    // Provided methods
    fn escape_and_write(self, buf: &mut String)
       where Self: Sized { ... }
    fn size_hint(&self) -> usize { ... }
    fn into_string(self) -> String
       where Self: Sized { ... }
}
Available on crate features http and html only.
A type that can be rendered as a fragment of HTML.

This is the central trait of the HTML templating support. Built-in scalars (e.g. &str, String, bool, integers, floats) all implement it; new types can implement it either by returning a composition of other IntoHtml values, or — for “leaf” types — by overriding IntoHtml::escape_and_write directly.

Examples

Compose nested HTML elements using macros:

use rama_http::html::*;

struct Article { title: String, content: String, author: String }

impl IntoHtml for Article {
    fn into_html(self) -> impl IntoHtml {
        article!(
            h1!(self.title),
            p!(class = "content", self.content),
            footer!("Written by ", self.author),
        )
    }
}

For leaf types, return self to terminate the rendering chain and override IntoHtml::escape_and_write:

use rama_http::html::{IntoHtml, escape_into};

struct TextNode(String);

impl IntoHtml for TextNode {
    fn into_html(self) -> impl IntoHtml { self }
    fn escape_and_write(self, buf: &mut String) { escape_into(buf, &self.0); }
    fn size_hint(&self) -> usize { self.0.len() }
}

Required Methods

fn into_html(self) -> impl IntoHtml

Convert this value into another IntoHtml value. Used for composition; leaf types should return self.

Provided Methods

fn escape_and_write(self, buf: &mut String)
where Self: Sized,

Append the rendered (escaped) HTML to buf.

fn size_hint(&self) -> usize

Best-effort estimate of the rendered byte length, used to pre-allocate the output buffer.

fn into_string(self) -> String
where Self: Sized,

Render to a freshly allocated String.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types



impl IntoHtml for &str



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



fn size_hint(&self) -> usize



impl IntoHtml for bool



fn into_html(self) -> impl IntoHtml



fn size_hint(&self) -> usize



impl IntoHtml for char



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



fn size_hint(&self) -> usize



impl IntoHtml for f32



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



impl IntoHtml for f64



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



impl IntoHtml for i8



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



impl IntoHtml for i16



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



impl IntoHtml for i32



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



impl IntoHtml for i64



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



impl IntoHtml for i128



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



impl IntoHtml for isize



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



impl IntoHtml for u8



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



impl IntoHtml for u16



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



impl IntoHtml for u32



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



impl IntoHtml for u64



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



impl IntoHtml for u128



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



impl IntoHtml for ()



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, _: &mut String)



impl IntoHtml for usize



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_> IntoHtml for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_)
where A: IntoHtml, B: IntoHtml, C: IntoHtml, D: IntoHtml, E: IntoHtml, F: IntoHtml, G: IntoHtml, H: IntoHtml, I: IntoHtml, J: IntoHtml, K: IntoHtml, L: IntoHtml, M: IntoHtml, N: IntoHtml, O: IntoHtml, P: IntoHtml, Q: IntoHtml, R: IntoHtml, S: IntoHtml, T: IntoHtml, U: IntoHtml, V: IntoHtml, W: IntoHtml, X: IntoHtml, Y: IntoHtml, Z: IntoHtml, A_: IntoHtml, B_: IntoHtml, C_: IntoHtml, D_: IntoHtml, E_: IntoHtml, F_: IntoHtml, G_: IntoHtml, H_: IntoHtml, I_: IntoHtml, J_: IntoHtml, K_: IntoHtml,



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



fn size_hint(&self) -> usize



impl<A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_> IntoHtml for (A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_)
where A_: IntoHtml, B_: IntoHtml, C_: IntoHtml, D_: IntoHtml, E_: IntoHtml, F_: IntoHtml, G_: IntoHtml, H_: IntoHtml, I_: IntoHtml, J_: IntoHtml, K_: IntoHtml,



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



fn size_hint(&self) -> usize



impl<B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_> IntoHtml for (B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_)
where B: IntoHtml, C: IntoHtml, D: IntoHtml, E: IntoHtml, F: IntoHtml, G: IntoHtml, H: IntoHtml, I: IntoHtml, J: IntoHtml, K: IntoHtml, L: IntoHtml, M: IntoHtml, N: IntoHtml, O: IntoHtml, P: IntoHtml, Q: IntoHtml, R: IntoHtml, S: IntoHtml, T: IntoHtml, U: IntoHtml, V: IntoHtml, W: IntoHtml, X: IntoHtml, Y: IntoHtml, Z: IntoHtml, A_: IntoHtml, B_: IntoHtml, C_: IntoHtml, D_: IntoHtml, E_: IntoHtml, F_: IntoHtml, G_: IntoHtml, H_: IntoHtml, I_: IntoHtml, J_: IntoHtml, K_: IntoHtml,



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



fn size_hint(&self) -> usize



impl<B_, C_, D_, E_, F_, G_, H_, I_, J_, K_> IntoHtml for (B_, C_, D_, E_, F_, G_, H_, I_, J_, K_)
where B_: IntoHtml, C_: IntoHtml, D_: IntoHtml, E_: IntoHtml, F_: IntoHtml, G_: IntoHtml, H_: IntoHtml, I_: IntoHtml, J_: IntoHtml, K_: IntoHtml,



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



fn size_hint(&self) -> usize



impl<C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_> IntoHtml for (C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_)
where C: IntoHtml, D: IntoHtml, E: IntoHtml, F: IntoHtml, G: IntoHtml, H: IntoHtml, I: IntoHtml, J: IntoHtml, K: IntoHtml, L: IntoHtml, M: IntoHtml, N: IntoHtml, O: IntoHtml, P: IntoHtml, Q: IntoHtml, R: IntoHtml, S: IntoHtml, T: IntoHtml, U: IntoHtml, V: IntoHtml, W: IntoHtml, X: IntoHtml, Y: IntoHtml, Z: IntoHtml, A_: IntoHtml, B_: IntoHtml, C_: IntoHtml, D_: IntoHtml, E_: IntoHtml, F_: IntoHtml, G_: IntoHtml, H_: IntoHtml, I_: IntoHtml, J_: IntoHtml, K_: IntoHtml,



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



fn size_hint(&self) -> usize



impl<C_, D_, E_, F_, G_, H_, I_, J_, K_> IntoHtml for (C_, D_, E_, F_, G_, H_, I_, J_, K_)
where C_: IntoHtml, D_: IntoHtml, E_: IntoHtml, F_: IntoHtml, G_: IntoHtml, H_: IntoHtml, I_: IntoHtml, J_: IntoHtml, K_: IntoHtml,



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



fn size_hint(&self) -> usize



impl<D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_> IntoHtml for (D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_)
where D: IntoHtml, E: IntoHtml, F: IntoHtml, G: IntoHtml, H: IntoHtml, I: IntoHtml, J: IntoHtml, K: IntoHtml, L: IntoHtml, M: IntoHtml, N: IntoHtml, O: IntoHtml, P: IntoHtml, Q: IntoHtml, R: IntoHtml, S: IntoHtml, T: IntoHtml, U: IntoHtml, V: IntoHtml, W: IntoHtml, X: IntoHtml, Y: IntoHtml, Z: IntoHtml, A_: IntoHtml, B_: IntoHtml, C_: IntoHtml, D_: IntoHtml, E_: IntoHtml, F_: IntoHtml, G_: IntoHtml, H_: IntoHtml, I_: IntoHtml, J_: IntoHtml, K_: IntoHtml,



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



fn size_hint(&self) -> usize



impl<D_, E_, F_, G_, H_, I_, J_, K_> IntoHtml for (D_, E_, F_, G_, H_, I_, J_, K_)
where D_: IntoHtml, E_: IntoHtml, F_: IntoHtml, G_: IntoHtml, H_: IntoHtml, I_: IntoHtml, J_: IntoHtml, K_: IntoHtml,



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



fn size_hint(&self) -> usize



impl<E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_> IntoHtml for (E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_)
where E: IntoHtml, F: IntoHtml, G: IntoHtml, H: IntoHtml, I: IntoHtml, J: IntoHtml, K: IntoHtml, L: IntoHtml, M: IntoHtml, N: IntoHtml, O: IntoHtml, P: IntoHtml, Q: IntoHtml, R: IntoHtml, S: IntoHtml, T: IntoHtml, U: IntoHtml, V: IntoHtml, W: IntoHtml, X: IntoHtml, Y: IntoHtml, Z: IntoHtml, A_: IntoHtml, B_: IntoHtml, C_: IntoHtml, D_: IntoHtml, E_: IntoHtml, F_: IntoHtml, G_: IntoHtml, H_: IntoHtml, I_: IntoHtml, J_: IntoHtml, K_: IntoHtml,



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



fn size_hint(&self) -> usize



impl<E_, F_, G_, H_, I_, J_, K_> IntoHtml for (E_, F_, G_, H_, I_, J_, K_)
where E_: IntoHtml, F_: IntoHtml, G_: IntoHtml, H_: IntoHtml, I_: IntoHtml, J_: IntoHtml, K_: IntoHtml,



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



fn size_hint(&self) -> usize



impl<F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_> IntoHtml for (F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_)
where F: IntoHtml, G: IntoHtml, H: IntoHtml, I: IntoHtml, J: IntoHtml, K: IntoHtml, L: IntoHtml, M: IntoHtml, N: IntoHtml, O: IntoHtml, P: IntoHtml, Q: IntoHtml, R: IntoHtml, S: IntoHtml, T: IntoHtml, U: IntoHtml, V: IntoHtml, W: IntoHtml, X: IntoHtml, Y: IntoHtml, Z: IntoHtml, A_: IntoHtml, B_: IntoHtml, C_: IntoHtml, D_: IntoHtml, E_: IntoHtml, F_: IntoHtml, G_: IntoHtml, H_: IntoHtml, I_: IntoHtml, J_: IntoHtml, K_: IntoHtml,



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



fn size_hint(&self) -> usize



impl<F_, G_, H_, I_, J_, K_> IntoHtml for (F_, G_, H_, I_, J_, K_)
where F_: IntoHtml, G_: IntoHtml, H_: IntoHtml, I_: IntoHtml, J_: IntoHtml, K_: IntoHtml,



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



fn size_hint(&self) -> usize



impl<G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_> IntoHtml for (G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_)
where G: IntoHtml, H: IntoHtml, I: IntoHtml, J: IntoHtml, K: IntoHtml, L: IntoHtml, M: IntoHtml, N: IntoHtml, O: IntoHtml, P: IntoHtml, Q: IntoHtml, R: IntoHtml, S: IntoHtml, T: IntoHtml, U: IntoHtml, V: IntoHtml, W: IntoHtml, X: IntoHtml, Y: IntoHtml, Z: IntoHtml, A_: IntoHtml, B_: IntoHtml, C_: IntoHtml, D_: IntoHtml, E_: IntoHtml, F_: IntoHtml, G_: IntoHtml, H_: IntoHtml, I_: IntoHtml, J_: IntoHtml, K_: IntoHtml,



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



fn size_hint(&self) -> usize



impl<G_, H_, I_, J_, K_> IntoHtml for (G_, H_, I_, J_, K_)
where G_: IntoHtml, H_: IntoHtml, I_: IntoHtml, J_: IntoHtml, K_: IntoHtml,



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



fn size_hint(&self) -> usize



impl<H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_> IntoHtml for (H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_)
where H: IntoHtml, I: IntoHtml, J: IntoHtml, K: IntoHtml, L: IntoHtml, M: IntoHtml, N: IntoHtml, O: IntoHtml, P: IntoHtml, Q: IntoHtml, R: IntoHtml, S: IntoHtml, T: IntoHtml, U: IntoHtml, V: IntoHtml, W: IntoHtml, X: IntoHtml, Y: IntoHtml, Z: IntoHtml, A_: IntoHtml, B_: IntoHtml, C_: IntoHtml, D_: IntoHtml, E_: IntoHtml, F_: IntoHtml, G_: IntoHtml, H_: IntoHtml, I_: IntoHtml, J_: IntoHtml, K_: IntoHtml,



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



fn size_hint(&self) -> usize



impl<H_, I_, J_, K_> IntoHtml for (H_, I_, J_, K_)
where H_: IntoHtml, I_: IntoHtml, J_: IntoHtml, K_: IntoHtml,



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



fn size_hint(&self) -> usize



impl<I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_> IntoHtml for (I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_)
where I: IntoHtml, J: IntoHtml, K: IntoHtml, L: IntoHtml, M: IntoHtml, N: IntoHtml, O: IntoHtml, P: IntoHtml, Q: IntoHtml, R: IntoHtml, S: IntoHtml, T: IntoHtml, U: IntoHtml, V: IntoHtml, W: IntoHtml, X: IntoHtml, Y: IntoHtml, Z: IntoHtml, A_: IntoHtml, B_: IntoHtml, C_: IntoHtml, D_: IntoHtml, E_: IntoHtml, F_: IntoHtml, G_: IntoHtml, H_: IntoHtml, I_: IntoHtml, J_: IntoHtml, K_: IntoHtml,



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



fn size_hint(&self) -> usize



impl<I_, J_, K_> IntoHtml for (I_, J_, K_)
where I_: IntoHtml, J_: IntoHtml, K_: IntoHtml,



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



fn size_hint(&self) -> usize



impl<J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_> IntoHtml for (J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_)
where J: IntoHtml, K: IntoHtml, L: IntoHtml, M: IntoHtml, N: IntoHtml, O: IntoHtml, P: IntoHtml, Q: IntoHtml, R: IntoHtml, S: IntoHtml, T: IntoHtml, U: IntoHtml, V: IntoHtml, W: IntoHtml, X: IntoHtml, Y: IntoHtml, Z: IntoHtml, A_: IntoHtml, B_: IntoHtml, C_: IntoHtml, D_: IntoHtml, E_: IntoHtml, F_: IntoHtml, G_: IntoHtml, H_: IntoHtml, I_: IntoHtml, J_: IntoHtml, K_: IntoHtml,



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



fn size_hint(&self) -> usize



impl<J_, K_> IntoHtml for (J_, K_)
where J_: IntoHtml, K_: IntoHtml,



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



fn size_hint(&self) -> usize



impl<K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_> IntoHtml for (K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_)
where K: IntoHtml, L: IntoHtml, M: IntoHtml, N: IntoHtml, O: IntoHtml, P: IntoHtml, Q: IntoHtml, R: IntoHtml, S: IntoHtml, T: IntoHtml, U: IntoHtml, V: IntoHtml, W: IntoHtml, X: IntoHtml, Y: IntoHtml, Z: IntoHtml, A_: IntoHtml, B_: IntoHtml, C_: IntoHtml, D_: IntoHtml, E_: IntoHtml, F_: IntoHtml, G_: IntoHtml, H_: IntoHtml, I_: IntoHtml, J_: IntoHtml, K_: IntoHtml,



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



fn size_hint(&self) -> usize



impl<K_> IntoHtml for (K_,)
where K_: IntoHtml,



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



fn size_hint(&self) -> usize



impl<L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_> IntoHtml for (L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_)
where L: IntoHtml, M: IntoHtml, N: IntoHtml, O: IntoHtml, P: IntoHtml, Q: IntoHtml, R: IntoHtml, S: IntoHtml, T: IntoHtml, U: IntoHtml, V: IntoHtml, W: IntoHtml, X: IntoHtml, Y: IntoHtml, Z: IntoHtml, A_: IntoHtml, B_: IntoHtml, C_: IntoHtml, D_: IntoHtml, E_: IntoHtml, F_: IntoHtml, G_: IntoHtml, H_: IntoHtml, I_: IntoHtml, J_: IntoHtml, K_: IntoHtml,



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



fn size_hint(&self) -> usize



impl<M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_> IntoHtml for (M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_)
where M: IntoHtml, N: IntoHtml, O: IntoHtml, P: IntoHtml, Q: IntoHtml, R: IntoHtml, S: IntoHtml, T: IntoHtml, U: IntoHtml, V: IntoHtml, W: IntoHtml, X: IntoHtml, Y: IntoHtml, Z: IntoHtml, A_: IntoHtml, B_: IntoHtml, C_: IntoHtml, D_: IntoHtml, E_: IntoHtml, F_: IntoHtml, G_: IntoHtml, H_: IntoHtml, I_: IntoHtml, J_: IntoHtml, K_: IntoHtml,



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



fn size_hint(&self) -> usize



impl<N, O, P, Q, R, S, T, U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_> IntoHtml for (N, O, P, Q, R, S, T, U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_)
where N: IntoHtml, O: IntoHtml, P: IntoHtml, Q: IntoHtml, R: IntoHtml, S: IntoHtml, T: IntoHtml, U: IntoHtml, V: IntoHtml, W: IntoHtml, X: IntoHtml, Y: IntoHtml, Z: IntoHtml, A_: IntoHtml, B_: IntoHtml, C_: IntoHtml, D_: IntoHtml, E_: IntoHtml, F_: IntoHtml, G_: IntoHtml, H_: IntoHtml, I_: IntoHtml, J_: IntoHtml, K_: IntoHtml,



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



fn size_hint(&self) -> usize



impl<O, P, Q, R, S, T, U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_> IntoHtml for (O, P, Q, R, S, T, U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_)
where O: IntoHtml, P: IntoHtml, Q: IntoHtml, R: IntoHtml, S: IntoHtml, T: IntoHtml, U: IntoHtml, V: IntoHtml, W: IntoHtml, X: IntoHtml, Y: IntoHtml, Z: IntoHtml, A_: IntoHtml, B_: IntoHtml, C_: IntoHtml, D_: IntoHtml, E_: IntoHtml, F_: IntoHtml, G_: IntoHtml, H_: IntoHtml, I_: IntoHtml, J_: IntoHtml, K_: IntoHtml,



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



fn size_hint(&self) -> usize



impl<P, Q, R, S, T, U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_> IntoHtml for (P, Q, R, S, T, U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_)
where P: IntoHtml, Q: IntoHtml, R: IntoHtml, S: IntoHtml, T: IntoHtml, U: IntoHtml, V: IntoHtml, W: IntoHtml, X: IntoHtml, Y: IntoHtml, Z: IntoHtml, A_: IntoHtml, B_: IntoHtml, C_: IntoHtml, D_: IntoHtml, E_: IntoHtml, F_: IntoHtml, G_: IntoHtml, H_: IntoHtml, I_: IntoHtml, J_: IntoHtml, K_: IntoHtml,



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



fn size_hint(&self) -> usize



impl<Q, R, S, T, U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_> IntoHtml for (Q, R, S, T, U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_)
where Q: IntoHtml, R: IntoHtml, S: IntoHtml, T: IntoHtml, U: IntoHtml, V: IntoHtml, W: IntoHtml, X: IntoHtml, Y: IntoHtml, Z: IntoHtml, A_: IntoHtml, B_: IntoHtml, C_: IntoHtml, D_: IntoHtml, E_: IntoHtml, F_: IntoHtml, G_: IntoHtml, H_: IntoHtml, I_: IntoHtml, J_: IntoHtml, K_: IntoHtml,



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



fn size_hint(&self) -> usize



impl<R, S, T, U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_> IntoHtml for (R, S, T, U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_)
where R: IntoHtml, S: IntoHtml, T: IntoHtml, U: IntoHtml, V: IntoHtml, W: IntoHtml, X: IntoHtml, Y: IntoHtml, Z: IntoHtml, A_: IntoHtml, B_: IntoHtml, C_: IntoHtml, D_: IntoHtml, E_: IntoHtml, F_: IntoHtml, G_: IntoHtml, H_: IntoHtml, I_: IntoHtml, J_: IntoHtml, K_: IntoHtml,



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



fn size_hint(&self) -> usize



impl<S, T, U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_> IntoHtml for (S, T, U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_)
where S: IntoHtml, T: IntoHtml, U: IntoHtml, V: IntoHtml, W: IntoHtml, X: IntoHtml, Y: IntoHtml, Z: IntoHtml, A_: IntoHtml, B_: IntoHtml, C_: IntoHtml, D_: IntoHtml, E_: IntoHtml, F_: IntoHtml, G_: IntoHtml, H_: IntoHtml, I_: IntoHtml, J_: IntoHtml, K_: IntoHtml,



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



fn size_hint(&self) -> usize



impl<T, U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_> IntoHtml for (T, U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_)
where T: IntoHtml, U: IntoHtml, V: IntoHtml, W: IntoHtml, X: IntoHtml, Y: IntoHtml, Z: IntoHtml, A_: IntoHtml, B_: IntoHtml, C_: IntoHtml, D_: IntoHtml, E_: IntoHtml, F_: IntoHtml, G_: IntoHtml, H_: IntoHtml, I_: IntoHtml, J_: IntoHtml, K_: IntoHtml,



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



fn size_hint(&self) -> usize



impl<T, const N: usize> IntoHtml for [T; N]
where T: IntoHtml,



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



fn size_hint(&self) -> usize



impl<U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_> IntoHtml for (U, V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_)
where U: IntoHtml, V: IntoHtml, W: IntoHtml, X: IntoHtml, Y: IntoHtml, Z: IntoHtml, A_: IntoHtml, B_: IntoHtml, C_: IntoHtml, D_: IntoHtml, E_: IntoHtml, F_: IntoHtml, G_: IntoHtml, H_: IntoHtml, I_: IntoHtml, J_: IntoHtml, K_: IntoHtml,



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



fn size_hint(&self) -> usize



impl<V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_> IntoHtml for (V, W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_)
where V: IntoHtml, W: IntoHtml, X: IntoHtml, Y: IntoHtml, Z: IntoHtml, A_: IntoHtml, B_: IntoHtml, C_: IntoHtml, D_: IntoHtml, E_: IntoHtml, F_: IntoHtml, G_: IntoHtml, H_: IntoHtml, I_: IntoHtml, J_: IntoHtml, K_: IntoHtml,



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



fn size_hint(&self) -> usize



impl<W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_> IntoHtml for (W, X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_)
where W: IntoHtml, X: IntoHtml, Y: IntoHtml, Z: IntoHtml, A_: IntoHtml, B_: IntoHtml, C_: IntoHtml, D_: IntoHtml, E_: IntoHtml, F_: IntoHtml, G_: IntoHtml, H_: IntoHtml, I_: IntoHtml, J_: IntoHtml, K_: IntoHtml,



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



fn size_hint(&self) -> usize



impl<X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_> IntoHtml for (X, Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_)
where X: IntoHtml, Y: IntoHtml, Z: IntoHtml, A_: IntoHtml, B_: IntoHtml, C_: IntoHtml, D_: IntoHtml, E_: IntoHtml, F_: IntoHtml, G_: IntoHtml, H_: IntoHtml, I_: IntoHtml, J_: IntoHtml, K_: IntoHtml,



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



fn size_hint(&self) -> usize



impl<Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_> IntoHtml for (Y, Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_)
where Y: IntoHtml, Z: IntoHtml, A_: IntoHtml, B_: IntoHtml, C_: IntoHtml, D_: IntoHtml, E_: IntoHtml, F_: IntoHtml, G_: IntoHtml, H_: IntoHtml, I_: IntoHtml, J_: IntoHtml, K_: IntoHtml,



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



fn size_hint(&self) -> usize



impl<Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_> IntoHtml for (Z, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_)
where Z: IntoHtml, A_: IntoHtml, B_: IntoHtml, C_: IntoHtml, D_: IntoHtml, E_: IntoHtml, F_: IntoHtml, G_: IntoHtml, H_: IntoHtml, I_: IntoHtml, J_: IntoHtml, K_: IntoHtml,



fn into_html(self) -> impl IntoHtml



fn escape_and_write(self, buf: &mut String)



fn size_hint(&self) -> usize

Implementors



impl IntoHtml for &String



impl IntoHtml for &ArcStr



impl IntoHtml for &Substr



impl IntoHtml for &SmolStr



impl IntoHtml for &NonEmptyStr



impl IntoHtml for Cow<'static, str>



impl IntoHtml for String



impl IntoHtml for ArcStr



impl IntoHtml for Substr



impl IntoHtml for SmolStr



impl IntoHtml for NonEmptyStr



impl IntoHtml for PreEscaped<&str>



impl IntoHtml for PreEscaped<Cow<'static, str>>



impl IntoHtml for PreEscaped<char>



impl IntoHtml for PreEscaped<String>



impl IntoHtml for PreEscaped<ArcStr>



impl IntoHtml for PreEscaped<Substr>



impl IntoHtml for PreEscaped<SmolStr>



impl IntoHtml for PreEscaped<NonEmptyStr>



impl<A> IntoHtml for SmallVec<A>
where A: Array, <A as Array>::Item: IntoHtml,



impl<A, B> IntoHtml for Either<A, B>
where A: IntoHtml, B: IntoHtml,



impl<A, B, C> IntoHtml for Either3<A, B, C>
where A: IntoHtml, B: IntoHtml, C: IntoHtml,



impl<A, B, C, D> IntoHtml for Either4<A, B, C, D>
where A: IntoHtml, B: IntoHtml, C: IntoHtml, D: IntoHtml,



impl<A, B, C, D, E> IntoHtml for Either5<A, B, C, D, E>
where A: IntoHtml, B: IntoHtml, C: IntoHtml, D: IntoHtml, E: IntoHtml,



impl<A, B, C, D, E, F> IntoHtml for Either6<A, B, C, D, E, F>
where A: IntoHtml, B: IntoHtml, C: IntoHtml, D: IntoHtml, E: IntoHtml, F: IntoHtml,



impl<A, B, C, D, E, F, G> IntoHtml for Either7<A, B, C, D, E, F, G>
where A: IntoHtml, B: IntoHtml, C: IntoHtml, D: IntoHtml, E: IntoHtml, F: IntoHtml, G: IntoHtml,



impl<A, B, C, D, E, F, G, H> IntoHtml for Either8<A, B, C, D, E, F, G, H>
where A: IntoHtml, B: IntoHtml, C: IntoHtml, D: IntoHtml, E: IntoHtml, F: IntoHtml, G: IntoHtml, H: IntoHtml,



impl<A, B, C, D, E, F, G, H, I> IntoHtml for Either9<A, B, C, D, E, F, G, H, I>
where A: IntoHtml, B: IntoHtml, C: IntoHtml, D: IntoHtml, E: IntoHtml, F: IntoHtml, G: IntoHtml, H: IntoHtml, I: IntoHtml,



impl<B, I, F> IntoHtml for Map<I, F>
where B: IntoHtml, I: ExactSizeIterator, F: FnMut(<I as Iterator>::Item) -> B,



impl<F> IntoHtml for F
where F: FnOnce(&mut String),



impl<T> IntoHtml for Option<T>
where T: IntoHtml,



impl<T> IntoHtml for Vec<T>
where T: IntoHtml,



impl<T> IntoHtml for HtmlBuf<T>
where T: IntoHtml,



impl<const N: usize, T> IntoHtml for NonEmptySmallVec<N, T>
where T: IntoHtml, [T; N]: Array<Item = T>,