Struct Decompression
pub struct Decompression<S, M = DefaultDecompressionMatcher> { /* private fields */ }Expand description
Decompresses response bodies of the underlying service.
This adds the Accept-Encoding header to requests and transparently decompresses response
bodies based on the Content-Encoding header.
See the module docs for more details.
Implementations
impl<S> Decompression<S>
impl<S> Decompression<S>
pub fn new(service: S) -> Decompression<S>
pub fn new(service: S) -> Decompression<S>
Creates a new Decompression wrapping the service.
impl<S, M> Decompression<S, M>
impl<S, M> Decompression<S, M>
pub fn into_inner(self) -> S
pub fn into_inner(self) -> S
Consumes self, returning the underlying service.
pub fn with_insert_accept_encoding_header(
self,
insert: bool,
) -> Decompression<S, M>
pub fn with_insert_accept_encoding_header( self, insert: bool, ) -> Decompression<S, M>
Sets whether the layer inserts Accept-Encoding into requests when it is absent.
When disabled, the request header is forwarded as-is and the layer only advertises
supported encodings if the request already contains an Accept-Encoding header.
pub fn set_insert_accept_encoding_header(
&mut self,
insert: bool,
) -> &mut Decompression<S, M>
pub fn set_insert_accept_encoding_header( &mut self, insert: bool, ) -> &mut Decompression<S, M>
Sets whether the layer inserts Accept-Encoding into requests when it is absent.
When disabled, the request header is forwarded as-is and the layer only advertises
supported encodings if the request already contains an Accept-Encoding header.
pub fn with_matcher<T>(self, matcher: T) -> Decompression<S, T>
pub fn with_matcher<T>(self, matcher: T) -> Decompression<S, T>
Replaces the request/response decompression matcher.
The matcher runs at request time and may select a second matcher to evaluate the response after the inner service returns. If no response matcher is selected or if the selected response matcher does not match, the response is left compressed even when Rama supports decompressing it.
pub fn with_gzip(self, enable: bool) -> Decompression<S, M>
pub fn with_gzip(self, enable: bool) -> Decompression<S, M>
Sets whether to request the gzip encoding.
pub fn set_gzip(&mut self, enable: bool) -> &mut Decompression<S, M>
pub fn set_gzip(&mut self, enable: bool) -> &mut Decompression<S, M>
Sets whether to request the gzip encoding.
pub fn with_deflate(self, enable: bool) -> Decompression<S, M>
pub fn with_deflate(self, enable: bool) -> Decompression<S, M>
Sets whether to request the Deflate encoding.
pub fn set_deflate(&mut self, enable: bool) -> &mut Decompression<S, M>
pub fn set_deflate(&mut self, enable: bool) -> &mut Decompression<S, M>
Sets whether to request the Deflate encoding.
pub fn with_br(self, enable: bool) -> Decompression<S, M>
pub fn with_br(self, enable: bool) -> Decompression<S, M>
Sets whether to request the Brotli encoding.
pub fn set_br(&mut self, enable: bool) -> &mut Decompression<S, M>
pub fn set_br(&mut self, enable: bool) -> &mut Decompression<S, M>
Sets whether to request the Brotli encoding.
pub fn with_zstd(self, enable: bool) -> Decompression<S, M>
pub fn with_zstd(self, enable: bool) -> Decompression<S, M>
Sets whether to request the Zstd encoding.
pub fn set_zstd(&mut self, enable: bool) -> &mut Decompression<S, M>
pub fn set_zstd(&mut self, enable: bool) -> &mut Decompression<S, M>
Sets whether to request the Zstd encoding.