remove_hop_by_hop_request_headers

Function remove_hop_by_hop_request_headers 

pub fn remove_hop_by_hop_request_headers(headers: &mut HeaderMap)
Available on crate feature http only.
Remove hop by hop headers from an outbound request.

This function applies the rules from RFC 9110 for hop by hop headers before forwarding a request to another hop.

This should be called when acting as a forward proxy, reverse proxy, or gateway that forwards requests to an upstream server.