Function remove_hop_by_hop_response_headers
pub fn remove_hop_by_hop_response_headers(headers: &mut HeaderMap)Available on crate feature
http only.Expand description
Remove hop by hop headers from an outbound response.
This function applies the rules from RFC 9110 for hop by hop headers before forwarding a response to a downstream client.
This should be called when relaying responses received from an upstream server to a client.