Struct ResponseWriterService
pub struct ResponseWriterService<S, W> { /* private fields */ }http and std only.Expand description
Middleware to print Http responses in std format.
Response bodies are observed while they stream to the caller. The writer receives an owned body stream and processes frames concurrently.
See the module docs for more details.
Implementations
impl<S, W> ResponseWriterService<S, W>
impl<S, W> ResponseWriterService<S, W>
pub fn new(writer: W, inner: S) -> ResponseWriterService<S, W>
pub fn new(writer: W, inner: S) -> ResponseWriterService<S, W>
Create a new ResponseWriterService with a custom ResponseWriter.
Use Self::new_with_executor when streaming writer tasks must participate
in graceful shutdown.
pub fn new_with_executor(
writer: W,
inner: S,
executor: Executor,
) -> ResponseWriterService<S, W>
pub fn new_with_executor( writer: W, inner: S, executor: Executor, ) -> ResponseWriterService<S, W>
Create a new ResponseWriterService with a custom ResponseWriter
and executor for streaming writer tasks.
pub fn into_inner(self) -> S
pub fn into_inner(self) -> S
Consumes self, returning the underlying service.
impl<S> ResponseWriterService<S, UnboundedSender<Response>>
impl<S> ResponseWriterService<S, UnboundedSender<Response>>
pub fn writer_unbounded<W>(
executor: &Executor,
writer: W,
mode: Option<WriterMode>,
inner: S,
) -> ResponseWriterService<S, UnboundedSender<Response>>
pub fn writer_unbounded<W>( executor: &Executor, writer: W, mode: Option<WriterMode>, inner: S, ) -> ResponseWriterService<S, UnboundedSender<Response>>
Create a new ResponseWriterService that prints responses to an [AsyncWrite]r
over an unbounded channel
pub fn stdout_unbounded(
executor: &Executor,
mode: Option<WriterMode>,
inner: S,
) -> ResponseWriterService<S, UnboundedSender<Response>>
pub fn stdout_unbounded( executor: &Executor, mode: Option<WriterMode>, inner: S, ) -> ResponseWriterService<S, UnboundedSender<Response>>
Create a new ResponseWriterService that prints responses to stdout
over an unbounded channel.
pub fn stderr_unbounded(
executor: &Executor,
mode: Option<WriterMode>,
inner: S,
) -> ResponseWriterService<S, UnboundedSender<Response>>
pub fn stderr_unbounded( executor: &Executor, mode: Option<WriterMode>, inner: S, ) -> ResponseWriterService<S, UnboundedSender<Response>>
Create a new ResponseWriterService that prints responses to stderr
over an unbounded channel.
impl<S> ResponseWriterService<S, PerMessageFileWriter>
impl<S> ResponseWriterService<S, PerMessageFileWriter>
pub async fn file_per_response(
executor: &Executor,
directory: impl Into<PathBuf>,
prefix: impl AsRef<str>,
mode: Option<WriterMode>,
inner: S,
) -> Result<ResponseWriterService<S, PerMessageFileWriter>, Error>
pub async fn file_per_response( executor: &Executor, directory: impl Into<PathBuf>, prefix: impl AsRef<str>, mode: Option<WriterMode>, inner: S, ) -> Result<ResponseWriterService<S, PerMessageFileWriter>, Error>
Create a service that streams every response into a unique file below
directory using the portable filename prefix.
impl<S> ResponseWriterService<S, Sender<Response>>
impl<S> ResponseWriterService<S, Sender<Response>>
pub fn writer<W>(
executor: &Executor,
writer: W,
buffer_size: usize,
mode: Option<WriterMode>,
inner: S,
) -> ResponseWriterService<S, Sender<Response>>
pub fn writer<W>( executor: &Executor, writer: W, buffer_size: usize, mode: Option<WriterMode>, inner: S, ) -> ResponseWriterService<S, Sender<Response>>
Create a new ResponseWriterService that prints responses to an [AsyncWrite]r
over a bounded channel with a fixed buffer size.
pub fn stdout(
executor: &Executor,
buffer_size: usize,
mode: Option<WriterMode>,
inner: S,
) -> ResponseWriterService<S, Sender<Response>>
pub fn stdout( executor: &Executor, buffer_size: usize, mode: Option<WriterMode>, inner: S, ) -> ResponseWriterService<S, Sender<Response>>
Create a new ResponseWriterService that prints responses to stdout
over a bounded channel with a fixed buffer size.
pub fn stderr(
executor: &Executor,
buffer_size: usize,
mode: Option<WriterMode>,
inner: S,
) -> ResponseWriterService<S, Sender<Response>>
pub fn stderr( executor: &Executor, buffer_size: usize, mode: Option<WriterMode>, inner: S, ) -> ResponseWriterService<S, Sender<Response>>
Create a new ResponseWriterService that prints responses to stderr
over a bounded channel with a fixed buffer size.