Struct Upgraded

pub struct Upgraded { /* private fields */ }
Available on crate features http and http-full only.
An upgraded HTTP connection.

This type holds a trait object internally of the original IO that was used to speak HTTP before the upgrade. It can be used directly as a [Read] or [Write] for convenience.

Alternatively, if the exact type is known, this can be deconstructed into its parts.

Implementations

Source

impl Upgraded

pub fn downcast<T>(self) -> Result<Parts<T>, Upgraded>
where T: AsyncRead + AsyncWrite + Unpin + 'static,

Tries to downcast the internal trait object to the type passed.

On success, returns the downcasted parts. On error, returns the Upgraded back.