Function encode_int
pub fn encode_int<B>(dst: &mut B, value: u64, prefix_bits: u8, flags: u8)where
B: BufMut,Available on crate features
http and std only.Expand description
Encode value as a prefixed integer with an prefix_bits-bit prefix, OR-ing flags into the
high 8 - prefix_bits bits of the first byte (RFC 9204 4.1.1).
flags must not set any of the low prefix_bits bits.