Struct Selector
pub struct Selector { /* private fields */ }Available on crate features
html and http only.Expand description
A parsed CSS selector string.
A selector string may contain a comma-separated list of complex
selectors (e.g. "a, .b > c"); the Selector matches an element if
any of those complex selectors matches it.
Implementations
impl Selector
impl Selector
pub fn tag(name: impl AsRef<str>) -> Selector
pub fn tag(name: impl AsRef<str>) -> Selector
A type (tag) selector, e.g. div. Shorthand for
Selector::of(Compound::tag(name)).
pub fn child(self, compound: Compound) -> Selector
pub fn child(self, compound: Compound) -> Selector
Extends the current complex selector with a child combinator:
self > compound.
pub fn descendant(self, compound: Compound) -> Selector
pub fn descendant(self, compound: Compound) -> Selector
Extends the current complex selector with a descendant combinator:
self compound.