Trait IntoHeaderValue
pub trait IntoHeaderValue: IntoHeaderValueSealed { }Available on crate feature
http only.Expand description
A trait to try to convert some type into a HeaderValue.
This trait is “sealed”, such that only types within rama can implement it.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".