Struct RequestBuilder
pub struct RequestBuilder<'a, S, Response> { /* private fields */ }http and std only.Expand description
A builder to construct the properties of a Request.
Constructed using HttpClientExt.
Implementations
impl<S, Body> RequestBuilder<'_, S, Response<Body>>
impl<S, Body> RequestBuilder<'_, S, Response<Body>>
pub fn header<K, V>(
self,
key: K,
value: V,
) -> RequestBuilder<'_, S, Response<Body>>where
K: IntoHeaderName,
V: IntoHeaderValue,
pub fn header<K, V>(
self,
key: K,
value: V,
) -> RequestBuilder<'_, S, Response<Body>>where
K: IntoHeaderName,
V: IntoHeaderValue,
Add a Header to this Request.
pub fn typed_header<H>(self, header: H) -> RequestBuilder<'_, S, Response<Body>>where
H: HeaderEncode,
pub fn typed_header<H>(self, header: H) -> RequestBuilder<'_, S, Response<Body>>where
H: HeaderEncode,
Add a typed HeaderEncode to this Request.
pub fn headers(
self,
headers: HeaderMap,
) -> RequestBuilder<'_, S, Response<Body>>
pub fn headers( self, headers: HeaderMap, ) -> RequestBuilder<'_, S, Response<Body>>
pub fn overwrite_header<K, V>(
self,
key: K,
value: V,
) -> RequestBuilder<'_, S, Response<Body>>where
K: IntoHeaderName,
V: IntoHeaderValue,
pub fn overwrite_header<K, V>(
self,
key: K,
value: V,
) -> RequestBuilder<'_, S, Response<Body>>where
K: IntoHeaderName,
V: IntoHeaderValue,
Overwrite a Header to this Request.
pub fn overwrite_typed_header<H>(
self,
header: H,
) -> RequestBuilder<'_, S, Response<Body>>where
H: HeaderEncode,
pub fn overwrite_typed_header<H>(
self,
header: H,
) -> RequestBuilder<'_, S, Response<Body>>where
H: HeaderEncode,
Overwrite a typed HeaderEncode to this Request.
pub fn auth(
self,
credentials: impl Credentials,
) -> RequestBuilder<'_, S, Response<Body>>
pub fn auth( self, credentials: impl Credentials, ) -> RequestBuilder<'_, S, Response<Body>>
Enable HTTP authentication.
pub fn extension<T>(self, extension: T) -> RequestBuilder<'_, S, Response<Body>>where
T: Extension,
pub fn extension<T>(self, extension: T) -> RequestBuilder<'_, S, Response<Body>>where
T: Extension,
Adds an extension to this builder
pub fn extensions(&self) -> Option<&Extensions>
pub fn extensions(&self) -> Option<&Extensions>
Get access to the underlying Extensions
This function will return None if Extensions are not available,
or if this builder is in an error state
pub fn body<T>(self, body: T) -> RequestBuilder<'_, S, Response<Body>>
pub fn body<T>(self, body: T) -> RequestBuilder<'_, S, Response<Body>>
pub fn form<T>(self, form: &T) -> RequestBuilder<'_, S, Response<Body>>
pub fn form<T>(self, form: &T) -> RequestBuilder<'_, S, Response<Body>>
pub fn json<T>(self, json: &T) -> RequestBuilder<'_, S, Response<Body>>
pub fn json<T>(self, json: &T) -> RequestBuilder<'_, S, Response<Body>>
pub fn multipart(self, form: Form) -> RequestBuilder<'_, S, Response<Body>>
Available on crate feature multipart only.
pub fn multipart(self, form: Form) -> RequestBuilder<'_, S, Response<Body>>
multipart only.Set a multipart::Form as the body of this
Request.
Sets the Content-Type header to
multipart/form-data; boundary={boundary} and, when every part has a
known size, the Content-Length header. An existing Content-Type
header is overwritten.
pub fn octet_stream<T>(self, bytes: T) -> RequestBuilder<'_, S, Response<Body>>
pub fn octet_stream<T>(self, bytes: T) -> RequestBuilder<'_, S, Response<Body>>
pub fn version(self, version: Version) -> RequestBuilder<'_, S, Response<Body>>
pub fn version(self, version: Version) -> RequestBuilder<'_, S, Response<Body>>
pub async fn send_with_timeout(
self,
t: Duration,
) -> Result<Response<Body>, Box<dyn Error + Sync + Send>>
pub async fn send_with_timeout( self, t: Duration, ) -> Result<Response<Body>, Box<dyn Error + Sync + Send>>
Constructs the Request and sends it to the target Uri,
returning a Response with a timeout that aborts with an error if
the roundtrip does not complete in time.
Note that this does not apply to the collection of the response payload, if there is any at all. The roundtrip is considered complete after the response headers are received.
Errors
This method fails if there was an error while sending Request.