Function apply_response_data_to_base_websocket_config
pub fn apply_response_data_to_base_websocket_config<Body>(
base_cfg: Option<WebSocketConfig>,
res: &mut Response<Body>,
) -> Option<WebSocketConfig>Expand description
Utility which can be used my Mitm proxies to update the base config of a client websocket config.