Struct WebSocketRelayService
pub struct WebSocketRelayService<S = MirrorService> { /* private fields */ }Expand description
A utility that can be used by MITM services such as transparent proxies, in order to relay WebSocket messages.
By default they get mirrored but the logic is fully up to you.
KISS
This service is for simple DPI purposes.
Fork or create your own relay service for more advanced purposes, such as the possibility to side-channel messages, or even route messages via external services.
Implementations
impl<S> WebSocketRelayService<S>
impl<S> WebSocketRelayService<S>
pub fn new(middleware: S) -> WebSocketRelayService<S>
pub fn new(middleware: S) -> WebSocketRelayService<S>
Create a new WebSocketRelayService