Struct OptionsCacheConfig
pub struct OptionsCacheConfig { /* private fields */ }icap and std only.Expand description
OPTIONS cache bounds and refresh behavior.
Implementations
impl OptionsCacheConfig
impl OptionsCacheConfig
pub const fn new() -> OptionsCacheConfig
pub const fn new() -> OptionsCacheConfig
Create the RFC-preserving cache policy.
pub const fn with_max_entries(self, max_entries: usize) -> OptionsCacheConfig
pub const fn with_max_entries(self, max_entries: usize) -> OptionsCacheConfig
Set the bounded number of service-policy entries.
pub fn set_max_entries(&mut self, max_entries: usize) -> &mut OptionsCacheConfig
pub fn set_max_entries(&mut self, max_entries: usize) -> &mut OptionsCacheConfig
Set the bounded number of service-policy entries.
pub const fn with_max_in_flight(
self,
max_in_flight: usize,
) -> OptionsCacheConfig
pub const fn with_max_in_flight( self, max_in_flight: usize, ) -> OptionsCacheConfig
Set the number of distinct concurrent OPTIONS exchanges.
pub fn set_max_in_flight(
&mut self,
max_in_flight: usize,
) -> &mut OptionsCacheConfig
pub fn set_max_in_flight( &mut self, max_in_flight: usize, ) -> &mut OptionsCacheConfig
Set the number of distinct concurrent OPTIONS exchanges.
pub const fn with_missing_ttl(self, ttl: Option<Duration>) -> OptionsCacheConfig
pub const fn with_missing_ttl(self, ttl: Option<Duration>) -> OptionsCacheConfig
Override the RFC’s non-expiring default for a missing Options-TTL.
pub fn set_missing_ttl(
&mut self,
ttl: Option<Duration>,
) -> &mut OptionsCacheConfig
pub fn set_missing_ttl( &mut self, ttl: Option<Duration>, ) -> &mut OptionsCacheConfig
Override the RFC’s non-expiring default for a missing Options-TTL.
pub const fn with_max_ttl(self, ttl: Option<Duration>) -> OptionsCacheConfig
pub const fn with_max_ttl(self, ttl: Option<Duration>) -> OptionsCacheConfig
Clamp a peer-supplied Options-TTL.
pub fn set_max_ttl(&mut self, ttl: Option<Duration>) -> &mut OptionsCacheConfig
pub fn set_max_ttl(&mut self, ttl: Option<Duration>) -> &mut OptionsCacheConfig
Clamp a peer-supplied Options-TTL.
pub const fn with_stale_if_error(
self,
duration: Option<Duration>,
) -> OptionsCacheConfig
pub const fn with_stale_if_error( self, duration: Option<Duration>, ) -> OptionsCacheConfig
Permit an expired snapshot during refresh and after failure.
The duration is measured from normal expiry. The default is
None, so an expired snapshot is never served.
pub fn set_stale_if_error(
&mut self,
duration: Option<Duration>,
) -> &mut OptionsCacheConfig
pub fn set_stale_if_error( &mut self, duration: Option<Duration>, ) -> &mut OptionsCacheConfig
Permit an expired snapshot during refresh and after failure.
The duration is measured from normal expiry. The default is
None, so an expired snapshot is never served.
pub const fn with_failure_backoff(
self,
duration: Duration,
) -> OptionsCacheConfig
pub const fn with_failure_backoff( self, duration: Duration, ) -> OptionsCacheConfig
Suppress repeated refresh attempts after one completed failure.
pub fn set_failure_backoff(
&mut self,
duration: Duration,
) -> &mut OptionsCacheConfig
pub fn set_failure_backoff( &mut self, duration: Duration, ) -> &mut OptionsCacheConfig
Suppress repeated refresh attempts after one completed failure.
pub const fn max_entries(&self) -> usize
pub const fn max_entries(&self) -> usize
Return the maximum entry count.
pub const fn max_in_flight(&self) -> usize
pub const fn max_in_flight(&self) -> usize
Return the maximum distinct concurrent OPTIONS exchanges.
pub const fn missing_ttl(&self) -> Option<Duration>
pub const fn missing_ttl(&self) -> Option<Duration>
Return the local lifetime for a missing peer TTL.
pub const fn stale_if_error(&self) -> Option<Duration>
pub const fn stale_if_error(&self) -> Option<Duration>
Return the bounded stale-on-error horizon.
pub const fn failure_backoff(&self) -> Duration
pub const fn failure_backoff(&self) -> Duration
Return the completed-refresh failure backoff.