Struct EncapsulatedParts
pub struct EncapsulatedParts { /* private fields */ }Available on crate features
icap and std only.Expand description
Owned non-body sections and body kind of an ICAP message.
The HTTP header sections remain opaque bytes here, apart from validating
their terminating empty line. The http feature will provide typed
conversion without coupling the transport core to an HTTP implementation.
Implementations
impl EncapsulatedParts
impl EncapsulatedParts
pub fn parse_http(&self) -> Result<Encapsulated, Error>
pub fn parse_http(&self) -> Result<Encapsulated, Error>
Parse the encapsulated HTTP heads with the default bounded parser.
pub fn parse_http_with(
&self,
parser: &HeadParser,
) -> Result<Encapsulated, Error>
pub fn parse_http_with( &self, parser: &HeadParser, ) -> Result<Encapsulated, Error>
Parse the encapsulated HTTP heads with explicit parser bounds.
impl EncapsulatedParts
impl EncapsulatedParts
pub fn new(
request_header: Option<Bytes>,
response_header: Option<Bytes>,
body_kind: EncapsulatedKind,
) -> Result<EncapsulatedParts, BuildError>
pub fn new( request_header: Option<Bytes>, response_header: Option<Bytes>, body_kind: EncapsulatedKind, ) -> Result<EncapsulatedParts, BuildError>
Construct and validate encapsulated message sections.
pub fn null() -> EncapsulatedParts
pub fn null() -> EncapsulatedParts
Construct Encapsulated: null-body=0.
pub fn request_header(&self) -> Option<&Bytes>
pub fn request_header(&self) -> Option<&Bytes>
Return the raw encapsulated HTTP request head, when present.
pub fn response_header(&self) -> Option<&Bytes>
pub fn response_header(&self) -> Option<&Bytes>
Return the raw encapsulated HTTP response head, when present.
pub const fn body_kind(&self) -> EncapsulatedKind
pub const fn body_kind(&self) -> EncapsulatedKind
Return the terminal body kind.
pub const fn has_body(&self) -> bool
pub const fn has_body(&self) -> bool
Return whether an ICAP chunk stream follows the header sections.
pub fn sections(&self) -> impl ExactSizeIterator
pub fn sections(&self) -> impl ExactSizeIterator
Iterate over the derived Encapsulated sections.