Struct OptionsResponse
pub struct OptionsResponse<'a> { /* private fields */ }icap and std only.Expand description
Builder for a standard ICAP OPTIONS response.
Implementations
impl<'a> OptionsResponse<'a>
impl<'a> OptionsResponse<'a>
pub fn new<ServiceTag, Methods>(
service_tag: &'a ServiceTag,
methods: &'a Methods,
) -> OptionsResponse<'a>
pub fn new<ServiceTag, Methods>( service_tag: &'a ServiceTag, methods: &'a Methods, ) -> OptionsResponse<'a>
Create an OPTIONS response with its required fields.
Both fields are borrowed and may be supplied as text or bytes.
pub fn with_service_id(
self,
service_id: &'a (impl AsRef<[u8]> + ?Sized),
) -> OptionsResponse<'a>
pub fn with_service_id( self, service_id: &'a (impl AsRef<[u8]> + ?Sized), ) -> OptionsResponse<'a>
Set the optional opaque service identifier.
pub fn set_service_id(
&mut self,
service_id: &'a (impl AsRef<[u8]> + ?Sized),
) -> &mut OptionsResponse<'a>
pub fn set_service_id( &mut self, service_id: &'a (impl AsRef<[u8]> + ?Sized), ) -> &mut OptionsResponse<'a>
Set the optional opaque service identifier.
pub fn with_service(
self,
service: &'a (impl AsRef<[u8]> + ?Sized),
) -> OptionsResponse<'a>
pub fn with_service( self, service: &'a (impl AsRef<[u8]> + ?Sized), ) -> OptionsResponse<'a>
Set the optional service description.
pub fn set_service(
&mut self,
service: &'a (impl AsRef<[u8]> + ?Sized),
) -> &mut OptionsResponse<'a>
pub fn set_service( &mut self, service: &'a (impl AsRef<[u8]> + ?Sized), ) -> &mut OptionsResponse<'a>
Set the optional service description.
pub const fn with_preview(self, preview: Preview) -> OptionsResponse<'a>
pub const fn with_preview(self, preview: Preview) -> OptionsResponse<'a>
Advertise the maximum supported Preview size.
pub fn set_preview(&mut self, preview: Preview) -> &mut OptionsResponse<'a>
pub fn set_preview(&mut self, preview: Preview) -> &mut OptionsResponse<'a>
Advertise the maximum supported Preview size.
pub const fn with_allow_204(self, allow: bool) -> OptionsResponse<'a>
pub const fn with_allow_204(self, allow: bool) -> OptionsResponse<'a>
Advertise support for 204 responses outside Preview.
pub fn set_allow_204(&mut self, allow: bool) -> &mut OptionsResponse<'a>
pub fn set_allow_204(&mut self, allow: bool) -> &mut OptionsResponse<'a>
Advertise support for 204 responses outside Preview.
pub const fn with_allow_206(self, allow: bool) -> OptionsResponse<'a>
pub const fn with_allow_206(self, allow: bool) -> OptionsResponse<'a>
Advertise support for the 206 Partial Content extension.
RFC negotiation requires the OPTIONS request to offer 206. Pass
false when the current request did not offer it.
pub fn set_allow_206(&mut self, allow: bool) -> &mut OptionsResponse<'a>
pub fn set_allow_206(&mut self, allow: bool) -> &mut OptionsResponse<'a>
Advertise support for the 206 Partial Content extension.
RFC negotiation requires the OPTIONS request to offer 206. Pass
false when the current request did not offer it.
pub fn with_allow_extensions(
self,
extensions: &'a (impl AsRef<[u8]> + ?Sized),
) -> OptionsResponse<'a>
pub fn with_allow_extensions( self, extensions: &'a (impl AsRef<[u8]> + ?Sized), ) -> OptionsResponse<'a>
Set additional comma-separated Allow feature tokens.
For example, trailers advertises the ICAP trailers extension.
The managed 204 and 206 tokens are rejected; use their
dedicated setters so negotiation cannot be bypassed.
pub fn set_allow_extensions(
&mut self,
extensions: &'a (impl AsRef<[u8]> + ?Sized),
) -> &mut OptionsResponse<'a>
pub fn set_allow_extensions( &mut self, extensions: &'a (impl AsRef<[u8]> + ?Sized), ) -> &mut OptionsResponse<'a>
Set additional comma-separated Allow feature tokens.
For example, trailers advertises the ICAP trailers extension.
The managed 204 and 206 tokens are rejected; use their
dedicated setters so negotiation cannot be bypassed.
pub const fn with_transfer_preview_all(
self,
enabled: bool,
) -> OptionsResponse<'a>
pub const fn with_transfer_preview_all( self, enabled: bool, ) -> OptionsResponse<'a>
Advertise Preview as the default for every transfer type.
This encodes Transfer-Preview: *. RFC 3507 defines * as the
default for file extensions not named by another Transfer-*
field.
pub fn set_transfer_preview_all(
&mut self,
enabled: bool,
) -> &mut OptionsResponse<'a>
pub fn set_transfer_preview_all( &mut self, enabled: bool, ) -> &mut OptionsResponse<'a>
Advertise Preview as the default for every transfer type.
This encodes Transfer-Preview: *. RFC 3507 defines * as the
default for file extensions not named by another Transfer-*
field.
pub fn with_transfer_preview(
self,
extensions: &'a (impl AsRef<[u8]> + ?Sized),
) -> OptionsResponse<'a>
pub fn with_transfer_preview( self, extensions: &'a (impl AsRef<[u8]> + ?Sized), ) -> OptionsResponse<'a>
Set the Transfer-Preview extension list.
pub fn set_transfer_preview(
&mut self,
extensions: &'a (impl AsRef<[u8]> + ?Sized),
) -> &mut OptionsResponse<'a>
pub fn set_transfer_preview( &mut self, extensions: &'a (impl AsRef<[u8]> + ?Sized), ) -> &mut OptionsResponse<'a>
Set the Transfer-Preview extension list.
pub fn with_transfer_ignore(
self,
extensions: &'a (impl AsRef<[u8]> + ?Sized),
) -> OptionsResponse<'a>
pub fn with_transfer_ignore( self, extensions: &'a (impl AsRef<[u8]> + ?Sized), ) -> OptionsResponse<'a>
Set the Transfer-Ignore extension list.
pub fn set_transfer_ignore(
&mut self,
extensions: &'a (impl AsRef<[u8]> + ?Sized),
) -> &mut OptionsResponse<'a>
pub fn set_transfer_ignore( &mut self, extensions: &'a (impl AsRef<[u8]> + ?Sized), ) -> &mut OptionsResponse<'a>
Set the Transfer-Ignore extension list.
pub fn with_transfer_complete(
self,
extensions: &'a (impl AsRef<[u8]> + ?Sized),
) -> OptionsResponse<'a>
pub fn with_transfer_complete( self, extensions: &'a (impl AsRef<[u8]> + ?Sized), ) -> OptionsResponse<'a>
Set the Transfer-Complete extension list.
pub fn set_transfer_complete(
&mut self,
extensions: &'a (impl AsRef<[u8]> + ?Sized),
) -> &mut OptionsResponse<'a>
pub fn set_transfer_complete( &mut self, extensions: &'a (impl AsRef<[u8]> + ?Sized), ) -> &mut OptionsResponse<'a>
Set the Transfer-Complete extension list.
pub const fn with_options_ttl(self, seconds: u64) -> OptionsResponse<'a>
pub const fn with_options_ttl(self, seconds: u64) -> OptionsResponse<'a>
Set the OPTIONS freshness lifetime in seconds.
pub fn set_options_ttl(&mut self, seconds: u64) -> &mut OptionsResponse<'a>
pub fn set_options_ttl(&mut self, seconds: u64) -> &mut OptionsResponse<'a>
Set the OPTIONS freshness lifetime in seconds.
pub const fn with_max_connections(self, count: u64) -> OptionsResponse<'a>
pub const fn with_max_connections(self, count: u64) -> OptionsResponse<'a>
Advertise a maximum connection count.
pub fn set_max_connections(&mut self, count: u64) -> &mut OptionsResponse<'a>
pub fn set_max_connections(&mut self, count: u64) -> &mut OptionsResponse<'a>
Advertise a maximum connection count.
pub fn with_date(
self,
date: &'a (impl AsRef<[u8]> + ?Sized),
) -> OptionsResponse<'a>
pub fn with_date( self, date: &'a (impl AsRef<[u8]> + ?Sized), ) -> OptionsResponse<'a>
Set the optional server Date field value.
pub fn set_date(
&mut self,
date: &'a (impl AsRef<[u8]> + ?Sized),
) -> &mut OptionsResponse<'a>
pub fn set_date( &mut self, date: &'a (impl AsRef<[u8]> + ?Sized), ) -> &mut OptionsResponse<'a>
Set the optional server Date field value.
pub fn with_opt_body(
self,
body_type: &'a (impl AsRef<[u8]> + ?Sized),
body: &'a (impl AsRef<[u8]> + ?Sized),
) -> OptionsResponse<'a>
pub fn with_opt_body( self, body_type: &'a (impl AsRef<[u8]> + ?Sized), body: &'a (impl AsRef<[u8]> + ?Sized), ) -> OptionsResponse<'a>
Set an opaque OPTIONS body and its required type token.
pub fn set_opt_body(
&mut self,
body_type: &'a (impl AsRef<[u8]> + ?Sized),
body: &'a (impl AsRef<[u8]> + ?Sized),
) -> &mut OptionsResponse<'a>
pub fn set_opt_body( &mut self, body_type: &'a (impl AsRef<[u8]> + ?Sized), body: &'a (impl AsRef<[u8]> + ?Sized), ) -> &mut OptionsResponse<'a>
Set an opaque OPTIONS body and its required type token.
pub fn build(self) -> Result<OutgoingResponse, BuildError>
pub fn build(self) -> Result<OutgoingResponse, BuildError>
Build the complete OPTIONS response.