Function matches_hex_reader
pub async fn matches_hex_reader(
reader: impl AsyncRead + Unpin,
needle: &str,
) -> Result<bool, Error>Available on crate feature
inspect only.Expand description
Search the hex display of bytes, including when the payload is valid UTF-8. This is useful when a protocol explicitly classifies a payload as binary.