Io

Trait Io 

pub trait Io:
    AsyncRead
    + AsyncWrite
    + Send
    + 'static { }
A generic transport of bytes is a type that implements AsyncRead, AsyncWrite and Send. This is specific to Rama and is directly linked to the supertraits of Tokio.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors



impl<T> Io for T
where T: AsyncRead + AsyncWrite + Send + 'static,