Trait Io
pub trait Io:
AsyncRead
+ AsyncWrite
+ Send
+ 'static { }Expand description
A generic transport of bytes is a type that implements AsyncRead, AsyncWrite and Send.
This is specific to Rama and is directly linked to the supertraits of Tokio.