JsValue

Enum JsValue 

pub enum JsValue {
    Undefined,
    Null,
    Bool(bool),
    Number(f64),
    String(JsStr),
    Array(JsArray),
    Object(JsObject),
}
Available on crate features js and std only.
An engine-agnostic js value.

This is the type in which values cross the js boundary in both directions: script results, host function arguments and return values, and configured globals.

Function values cannot cross the boundary: a top-level function result is a JsErrorKind::Conversion error, and function properties are skipped when snapshotting objects (mirroring JSON.stringify semantics).

Variants



Undefined

undefined



Null

null



Bool(bool)

true / false



Number(f64)

any js number (always an f64, like in js itself)



String(JsStr)

a string value



Array(JsArray)

an array snapshot



Object(JsObject)

an object snapshot

Implementations



impl JsValue

pub fn deserialize_into<T>(&self) -> Result<T, JsError>

Deserialize this value into any serde-capable type.



impl JsValue

pub fn is_undefined(&self) -> bool

Returns true if this value is undefined.

pub fn is_null(&self) -> bool

Returns true if this value is null.

pub fn is_null_or_undefined(&self) -> bool

Returns true if this value is null or undefined.

pub fn as_bool(&self) -> Option<bool>

The inner bool, if this value is a boolean.

pub fn as_f64(&self) -> Option<f64>

The inner number, if this value is a number.

pub fn as_str(&self) -> Option<&str>

The inner string as a str, if this value is a string.

pub fn as_string(&self) -> Option<&JsStr>

The inner JsStr, if this value is a string.

pub fn as_array(&self) -> Option<&JsArray>

The inner JsArray, if this value is an array.

pub fn as_object(&self) -> Option<&JsObject>

The inner JsObject, if this value is an object.

pub fn type_name(&self) -> &'static str

The js name of this value’s type, useful in error messages.