Struct JsError
pub struct JsError { /* private fields */ }Available on crate features
js and std only.Expand description
Error returned by all fallible operations in this crate.
A JsError either originates from the script side
(e.g. JsErrorKind::Throw, JsErrorKind::Parse) or from the
host side (e.g. JsErrorKind::Conversion). Host functions can
return a JsError to throw an error into the running script.
Implementations
impl JsError
impl JsError
pub fn conversion(message: impl Into<Box<str>>) -> JsError
pub fn conversion(message: impl Into<Box<str>>) -> JsError
Create a new JsErrorKind::Conversion error.
This is the error to return from custom
JsArg implementations.
pub fn throw(message: impl Into<Box<str>>) -> JsError
pub fn throw(message: impl Into<Box<str>>) -> JsError
Create a new JsErrorKind::Throw error.
When returned from a host function it is thrown as an error inside the running script.
pub fn kind(&self) -> JsErrorKind
pub fn kind(&self) -> JsErrorKind
The kind of this error.
pub fn thrown(&self) -> Option<&JsValue>
pub fn thrown(&self) -> Option<&JsValue>
The thrown script value, if this error
carries one (only for JsErrorKind::Throw).