Struct JsRuntimeBuilder
pub struct JsRuntimeBuilder { /* private fields */ }js and std only.Expand description
Implementations
impl JsRuntimeBuilder
impl JsRuntimeBuilder
pub const DEFAULT_RECURSION_LIMIT: usize = 512
pub const DEFAULT_RECURSION_LIMIT: usize = 512
Default limit for the depth of recursive calls within scripts.
pub const DEFAULT_LOOP_ITERATION_LIMIT: u64 = 1_000_000
pub const DEFAULT_LOOP_ITERATION_LIMIT: u64 = 1_000_000
Default limit for the number of loop iterations one function activation may run.
pub const DEFAULT_STACK_SIZE_LIMIT: usize
pub const DEFAULT_STACK_SIZE_LIMIT: usize
Default limit for the size of the script value stack.
pub fn with_strict(self, strict: bool) -> JsRuntimeBuilder
pub fn with_strict(self, strict: bool) -> JsRuntimeBuilder
Evaluate all scripts in strict mode,
regardless of "use strict" directives.
pub fn set_strict(&mut self, strict: bool) -> &mut JsRuntimeBuilder
pub fn set_strict(&mut self, strict: bool) -> &mut JsRuntimeBuilder
Evaluate all scripts in strict mode,
regardless of "use strict" directives.
pub fn maybe_with_recursion_limit(
self,
limit: Option<usize>,
) -> JsRuntimeBuilder
pub fn maybe_with_recursion_limit( self, limit: Option<usize>, ) -> JsRuntimeBuilder
Limit the depth of recursive calls within scripts.
Defaults to Self::DEFAULT_RECURSION_LIMIT; None removes
the limit entirely. Exceeding it fails the evaluation with
JsErrorKind::LimitExceeded.
pub fn maybe_set_recursion_limit(
&mut self,
limit: Option<usize>,
) -> &mut JsRuntimeBuilder
pub fn maybe_set_recursion_limit( &mut self, limit: Option<usize>, ) -> &mut JsRuntimeBuilder
Limit the depth of recursive calls within scripts.
Defaults to Self::DEFAULT_RECURSION_LIMIT; None removes
the limit entirely. Exceeding it fails the evaluation with
JsErrorKind::LimitExceeded.
pub fn with_recursion_limit(self, limit: usize) -> JsRuntimeBuilder
pub fn with_recursion_limit(self, limit: usize) -> JsRuntimeBuilder
Limit the depth of recursive calls within scripts.
Defaults to Self::DEFAULT_RECURSION_LIMIT; None removes
the limit entirely. Exceeding it fails the evaluation with
JsErrorKind::LimitExceeded.
pub fn set_recursion_limit(&mut self, limit: usize) -> &mut JsRuntimeBuilder
pub fn set_recursion_limit(&mut self, limit: usize) -> &mut JsRuntimeBuilder
Limit the depth of recursive calls within scripts.
Defaults to Self::DEFAULT_RECURSION_LIMIT; None removes
the limit entirely. Exceeding it fails the evaluation with
JsErrorKind::LimitExceeded.
pub fn without_recursion_limit(self) -> JsRuntimeBuilder
pub fn without_recursion_limit(self) -> JsRuntimeBuilder
Limit the depth of recursive calls within scripts.
Defaults to Self::DEFAULT_RECURSION_LIMIT; None removes
the limit entirely. Exceeding it fails the evaluation with
JsErrorKind::LimitExceeded.
pub fn unset_recursion_limit(&mut self) -> &mut JsRuntimeBuilder
pub fn unset_recursion_limit(&mut self) -> &mut JsRuntimeBuilder
Limit the depth of recursive calls within scripts.
Defaults to Self::DEFAULT_RECURSION_LIMIT; None removes
the limit entirely. Exceeding it fails the evaluation with
JsErrorKind::LimitExceeded.
pub fn maybe_with_loop_iteration_limit(
self,
limit: Option<u64>,
) -> JsRuntimeBuilder
pub fn maybe_with_loop_iteration_limit( self, limit: Option<u64>, ) -> JsRuntimeBuilder
Limit the number of loop iterations one function activation may run, cumulative across all loops in that call frame.
Each function call gets a fresh budget: this stops a runaway loop, not the total work a script performs across many calls (see the crate docs on the reach of these limits).
Defaults to Self::DEFAULT_LOOP_ITERATION_LIMIT; None removes
the limit entirely. Exceeding it fails the evaluation with
JsErrorKind::LimitExceeded.
pub fn maybe_set_loop_iteration_limit(
&mut self,
limit: Option<u64>,
) -> &mut JsRuntimeBuilder
pub fn maybe_set_loop_iteration_limit( &mut self, limit: Option<u64>, ) -> &mut JsRuntimeBuilder
Limit the number of loop iterations one function activation may run, cumulative across all loops in that call frame.
Each function call gets a fresh budget: this stops a runaway loop, not the total work a script performs across many calls (see the crate docs on the reach of these limits).
Defaults to Self::DEFAULT_LOOP_ITERATION_LIMIT; None removes
the limit entirely. Exceeding it fails the evaluation with
JsErrorKind::LimitExceeded.
pub fn with_loop_iteration_limit(self, limit: u64) -> JsRuntimeBuilder
pub fn with_loop_iteration_limit(self, limit: u64) -> JsRuntimeBuilder
Limit the number of loop iterations one function activation may run, cumulative across all loops in that call frame.
Each function call gets a fresh budget: this stops a runaway loop, not the total work a script performs across many calls (see the crate docs on the reach of these limits).
Defaults to Self::DEFAULT_LOOP_ITERATION_LIMIT; None removes
the limit entirely. Exceeding it fails the evaluation with
JsErrorKind::LimitExceeded.
pub fn set_loop_iteration_limit(&mut self, limit: u64) -> &mut JsRuntimeBuilder
pub fn set_loop_iteration_limit(&mut self, limit: u64) -> &mut JsRuntimeBuilder
Limit the number of loop iterations one function activation may run, cumulative across all loops in that call frame.
Each function call gets a fresh budget: this stops a runaway loop, not the total work a script performs across many calls (see the crate docs on the reach of these limits).
Defaults to Self::DEFAULT_LOOP_ITERATION_LIMIT; None removes
the limit entirely. Exceeding it fails the evaluation with
JsErrorKind::LimitExceeded.
pub fn without_loop_iteration_limit(self) -> JsRuntimeBuilder
pub fn without_loop_iteration_limit(self) -> JsRuntimeBuilder
Limit the number of loop iterations one function activation may run, cumulative across all loops in that call frame.
Each function call gets a fresh budget: this stops a runaway loop, not the total work a script performs across many calls (see the crate docs on the reach of these limits).
Defaults to Self::DEFAULT_LOOP_ITERATION_LIMIT; None removes
the limit entirely. Exceeding it fails the evaluation with
JsErrorKind::LimitExceeded.
pub fn unset_loop_iteration_limit(&mut self) -> &mut JsRuntimeBuilder
pub fn unset_loop_iteration_limit(&mut self) -> &mut JsRuntimeBuilder
Limit the number of loop iterations one function activation may run, cumulative across all loops in that call frame.
Each function call gets a fresh budget: this stops a runaway loop, not the total work a script performs across many calls (see the crate docs on the reach of these limits).
Defaults to Self::DEFAULT_LOOP_ITERATION_LIMIT; None removes
the limit entirely. Exceeding it fails the evaluation with
JsErrorKind::LimitExceeded.
pub fn maybe_with_stack_size_limit(
self,
limit: Option<usize>,
) -> JsRuntimeBuilder
pub fn maybe_with_stack_size_limit( self, limit: Option<usize>, ) -> JsRuntimeBuilder
Limit the size of the script value stack.
Defaults to Self::DEFAULT_STACK_SIZE_LIMIT; None removes
the limit entirely. Exceeding it fails the evaluation with
JsErrorKind::LimitExceeded.
pub fn maybe_set_stack_size_limit(
&mut self,
limit: Option<usize>,
) -> &mut JsRuntimeBuilder
pub fn maybe_set_stack_size_limit( &mut self, limit: Option<usize>, ) -> &mut JsRuntimeBuilder
Limit the size of the script value stack.
Defaults to Self::DEFAULT_STACK_SIZE_LIMIT; None removes
the limit entirely. Exceeding it fails the evaluation with
JsErrorKind::LimitExceeded.
pub fn with_stack_size_limit(self, limit: usize) -> JsRuntimeBuilder
pub fn with_stack_size_limit(self, limit: usize) -> JsRuntimeBuilder
Limit the size of the script value stack.
Defaults to Self::DEFAULT_STACK_SIZE_LIMIT; None removes
the limit entirely. Exceeding it fails the evaluation with
JsErrorKind::LimitExceeded.
pub fn set_stack_size_limit(&mut self, limit: usize) -> &mut JsRuntimeBuilder
pub fn set_stack_size_limit(&mut self, limit: usize) -> &mut JsRuntimeBuilder
Limit the size of the script value stack.
Defaults to Self::DEFAULT_STACK_SIZE_LIMIT; None removes
the limit entirely. Exceeding it fails the evaluation with
JsErrorKind::LimitExceeded.
pub fn without_stack_size_limit(self) -> JsRuntimeBuilder
pub fn without_stack_size_limit(self) -> JsRuntimeBuilder
Limit the size of the script value stack.
Defaults to Self::DEFAULT_STACK_SIZE_LIMIT; None removes
the limit entirely. Exceeding it fails the evaluation with
JsErrorKind::LimitExceeded.
pub fn unset_stack_size_limit(&mut self) -> &mut JsRuntimeBuilder
pub fn unset_stack_size_limit(&mut self) -> &mut JsRuntimeBuilder
Limit the size of the script value stack.
Defaults to Self::DEFAULT_STACK_SIZE_LIMIT; None removes
the limit entirely. Exceeding it fails the evaluation with
JsErrorKind::LimitExceeded.
pub fn maybe_with_execution_time_limit(
self,
limit: Option<Duration>,
) -> JsRuntimeBuilder
pub fn maybe_with_execution_time_limit( self, limit: Option<Duration>, ) -> JsRuntimeBuilder
Best-effort wall-clock limit on each evaluation or call.
Checked between VM instructions while scripts run, so it also bounds work the per-frame limits cannot: loops spread across many function calls. A single native operation (a huge string operation, a pathological regex, …) is not interrupted mid-flight, and getters running while result values are snapshotted fall outside the limit.
Exceeding it fails the evaluation with
JsErrorKind::LimitExceeded
and poisons the runtime (JsRuntime::is_poisoned): the script
was aborted mid-execution, so every later operation fails with
JsErrorKind::Setup. A
JsWorker whose runtime got poisoned exits,
failing pending jobs fast (fail-loud, like a panicking host
function).
Calls run through an internal dispatch script, as the engine
can only interrupt script evaluation: this reserves the frozen
__rama_js_call__ global, which never exposes host data and
cannot be registered as a global name yourself.
Defaults to None: no time limit.
pub fn maybe_set_execution_time_limit(
&mut self,
limit: Option<Duration>,
) -> &mut JsRuntimeBuilder
pub fn maybe_set_execution_time_limit( &mut self, limit: Option<Duration>, ) -> &mut JsRuntimeBuilder
Best-effort wall-clock limit on each evaluation or call.
Checked between VM instructions while scripts run, so it also bounds work the per-frame limits cannot: loops spread across many function calls. A single native operation (a huge string operation, a pathological regex, …) is not interrupted mid-flight, and getters running while result values are snapshotted fall outside the limit.
Exceeding it fails the evaluation with
JsErrorKind::LimitExceeded
and poisons the runtime (JsRuntime::is_poisoned): the script
was aborted mid-execution, so every later operation fails with
JsErrorKind::Setup. A
JsWorker whose runtime got poisoned exits,
failing pending jobs fast (fail-loud, like a panicking host
function).
Calls run through an internal dispatch script, as the engine
can only interrupt script evaluation: this reserves the frozen
__rama_js_call__ global, which never exposes host data and
cannot be registered as a global name yourself.
Defaults to None: no time limit.
pub fn with_execution_time_limit(self, limit: Duration) -> JsRuntimeBuilder
pub fn with_execution_time_limit(self, limit: Duration) -> JsRuntimeBuilder
Best-effort wall-clock limit on each evaluation or call.
Checked between VM instructions while scripts run, so it also bounds work the per-frame limits cannot: loops spread across many function calls. A single native operation (a huge string operation, a pathological regex, …) is not interrupted mid-flight, and getters running while result values are snapshotted fall outside the limit.
Exceeding it fails the evaluation with
JsErrorKind::LimitExceeded
and poisons the runtime (JsRuntime::is_poisoned): the script
was aborted mid-execution, so every later operation fails with
JsErrorKind::Setup. A
JsWorker whose runtime got poisoned exits,
failing pending jobs fast (fail-loud, like a panicking host
function).
Calls run through an internal dispatch script, as the engine
can only interrupt script evaluation: this reserves the frozen
__rama_js_call__ global, which never exposes host data and
cannot be registered as a global name yourself.
Defaults to None: no time limit.
pub fn set_execution_time_limit(
&mut self,
limit: Duration,
) -> &mut JsRuntimeBuilder
pub fn set_execution_time_limit( &mut self, limit: Duration, ) -> &mut JsRuntimeBuilder
Best-effort wall-clock limit on each evaluation or call.
Checked between VM instructions while scripts run, so it also bounds work the per-frame limits cannot: loops spread across many function calls. A single native operation (a huge string operation, a pathological regex, …) is not interrupted mid-flight, and getters running while result values are snapshotted fall outside the limit.
Exceeding it fails the evaluation with
JsErrorKind::LimitExceeded
and poisons the runtime (JsRuntime::is_poisoned): the script
was aborted mid-execution, so every later operation fails with
JsErrorKind::Setup. A
JsWorker whose runtime got poisoned exits,
failing pending jobs fast (fail-loud, like a panicking host
function).
Calls run through an internal dispatch script, as the engine
can only interrupt script evaluation: this reserves the frozen
__rama_js_call__ global, which never exposes host data and
cannot be registered as a global name yourself.
Defaults to None: no time limit.
pub fn without_execution_time_limit(self) -> JsRuntimeBuilder
pub fn without_execution_time_limit(self) -> JsRuntimeBuilder
Best-effort wall-clock limit on each evaluation or call.
Checked between VM instructions while scripts run, so it also bounds work the per-frame limits cannot: loops spread across many function calls. A single native operation (a huge string operation, a pathological regex, …) is not interrupted mid-flight, and getters running while result values are snapshotted fall outside the limit.
Exceeding it fails the evaluation with
JsErrorKind::LimitExceeded
and poisons the runtime (JsRuntime::is_poisoned): the script
was aborted mid-execution, so every later operation fails with
JsErrorKind::Setup. A
JsWorker whose runtime got poisoned exits,
failing pending jobs fast (fail-loud, like a panicking host
function).
Calls run through an internal dispatch script, as the engine
can only interrupt script evaluation: this reserves the frozen
__rama_js_call__ global, which never exposes host data and
cannot be registered as a global name yourself.
Defaults to None: no time limit.
pub fn unset_execution_time_limit(&mut self) -> &mut JsRuntimeBuilder
pub fn unset_execution_time_limit(&mut self) -> &mut JsRuntimeBuilder
Best-effort wall-clock limit on each evaluation or call.
Checked between VM instructions while scripts run, so it also bounds work the per-frame limits cannot: loops spread across many function calls. A single native operation (a huge string operation, a pathological regex, …) is not interrupted mid-flight, and getters running while result values are snapshotted fall outside the limit.
Exceeding it fails the evaluation with
JsErrorKind::LimitExceeded
and poisons the runtime (JsRuntime::is_poisoned): the script
was aborted mid-execution, so every later operation fails with
JsErrorKind::Setup. A
JsWorker whose runtime got poisoned exits,
failing pending jobs fast (fail-loud, like a panicking host
function).
Calls run through an internal dispatch script, as the engine
can only interrupt script evaluation: this reserves the frozen
__rama_js_call__ global, which never exposes host data and
cannot be registered as a global name yourself.
Defaults to None: no time limit.
pub fn with_snapshot_limits(self, limits: JsSnapshotLimits) -> JsRuntimeBuilder
pub fn with_snapshot_limits(self, limits: JsSnapshotLimits) -> JsRuntimeBuilder
Configure resource limits for values copied out of the JS engine.
These limits apply to results, thrown values, and host-function
arguments. The safe defaults are defined by JsSnapshotLimits.
pub fn set_snapshot_limits(
&mut self,
limits: JsSnapshotLimits,
) -> &mut JsRuntimeBuilder
pub fn set_snapshot_limits( &mut self, limits: JsSnapshotLimits, ) -> &mut JsRuntimeBuilder
Configure resource limits for values copied out of the JS engine.
These limits apply to results, thrown values, and host-function
arguments. The safe defaults are defined by JsSnapshotLimits.
pub fn with_global(
self,
name: impl Into<JsStr>,
global: impl IntoJsGlobal,
) -> JsRuntimeBuilder
pub fn with_global( self, name: impl Into<JsStr>, global: impl IntoJsGlobal, ) -> JsRuntimeBuilder
Register a global: a value convertible Into<JsValue>,
or a JsNamespace host object.
pub fn set_global(
&mut self,
name: impl Into<JsStr>,
global: impl IntoJsGlobal,
) -> &mut JsRuntimeBuilder
pub fn set_global( &mut self, name: impl Into<JsStr>, global: impl IntoJsGlobal, ) -> &mut JsRuntimeBuilder
Register a global: a value convertible Into<JsValue>,
or a JsNamespace host object.
pub fn with_fn<A, F>(self, name: impl Into<JsStr>, f: F) -> JsRuntimeBuilderwhere
F: JsFn<A>,
pub fn with_fn<A, F>(self, name: impl Into<JsStr>, f: F) -> JsRuntimeBuilderwhere
F: JsFn<A>,
Register a global host function with typed,
extractor-style arguments (see JsFn).