Function serde_json_value
pub const fn serde_json_value<T>(value: T) -> SerdeJson<T>Expand description
Wraps a value that should be encoded as JSON through serde.
pub const fn serde_json_value<T>(value: T) -> SerdeJson<T>Wraps a value that should be encoded as JSON through serde.