Trait IntoDomain
pub trait IntoDomain: IntoDomainImpl { }Available on crate feature
net only.Expand description
A trait which can be use by crates where a Domain is expected, it can however only be implemented by the rama-net rate.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".