Enum MuxSelection
#[non_exhaustive]pub enum MuxSelection {
LeastLoaded,
FirstAvailable,
RoundRobin,
}Available on crate feature
net only.Expand description
Strategy used to pick a connection among several that share the same
ConnID and still have stream capacity.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
LeastLoaded
Pick the connection with the most free stream slots (best spread).
FirstAvailable
Pick the first connection with a free stream slot.
RoundRobin
Cycle through the eligible connections.