Struct LruDropPool
pub struct LruDropPool<C, ID> { /* private fields */ }net only.Expand description
Connection pool that uses LRU to evict connections
Implementations
impl<C, ID> LruDropPool<C, ID>
impl<C, ID> LruDropPool<C, ID>
pub fn try_new( max_active: usize, max_total: usize, ) -> Result<LruDropPool<C, ID>, Box<dyn Error + Send + Sync>>
pub fn retire(&self)
pub fn retire(&self)
Retire this pool generation and close every idle connection.
Connections that are currently leased are closed when returned. New acquisitions fail, including acquisitions through another clone of this pool.
pub fn maybe_with_idle_timeout(
self,
timeout: Option<Duration>,
) -> LruDropPool<C, ID>
pub fn maybe_with_idle_timeout( self, timeout: Option<Duration>, ) -> LruDropPool<C, ID>
If connections have been idle for longer then the provided timeout they will be dropped and removed from the pool
Note: timeout is only checked when a connection is requested from the pool, it is not something that is done periodically
pub fn maybe_set_idle_timeout(
&mut self,
timeout: Option<Duration>,
) -> &mut LruDropPool<C, ID>
pub fn maybe_set_idle_timeout( &mut self, timeout: Option<Duration>, ) -> &mut LruDropPool<C, ID>
If connections have been idle for longer then the provided timeout they will be dropped and removed from the pool
Note: timeout is only checked when a connection is requested from the pool, it is not something that is done periodically
pub fn with_idle_timeout(self, timeout: Duration) -> LruDropPool<C, ID>
pub fn with_idle_timeout(self, timeout: Duration) -> LruDropPool<C, ID>
If connections have been idle for longer then the provided timeout they will be dropped and removed from the pool
Note: timeout is only checked when a connection is requested from the pool, it is not something that is done periodically
pub fn set_idle_timeout(&mut self, timeout: Duration) -> &mut LruDropPool<C, ID>
pub fn set_idle_timeout(&mut self, timeout: Duration) -> &mut LruDropPool<C, ID>
If connections have been idle for longer then the provided timeout they will be dropped and removed from the pool
Note: timeout is only checked when a connection is requested from the pool, it is not something that is done periodically
pub fn without_idle_timeout(self) -> LruDropPool<C, ID>
pub fn without_idle_timeout(self) -> LruDropPool<C, ID>
If connections have been idle for longer then the provided timeout they will be dropped and removed from the pool
Note: timeout is only checked when a connection is requested from the pool, it is not something that is done periodically
pub fn unset_idle_timeout(&mut self) -> &mut LruDropPool<C, ID>
pub fn unset_idle_timeout(&mut self) -> &mut LruDropPool<C, ID>
If connections have been idle for longer then the provided timeout they will be dropped and removed from the pool
Note: timeout is only checked when a connection is requested from the pool, it is not something that is done periodically
pub fn with_reuse_strategy(self, strategy: ReuseStrategy) -> LruDropPool<C, ID>
pub fn set_reuse_strategy( &mut self, strategy: ReuseStrategy, ) -> &mut LruDropPool<C, ID>
pub fn with_drop_connection_if_no_response(
self,
drop_connection_if_no_response: bool,
) -> LruDropPool<C, ID>
pub fn with_drop_connection_if_no_response( self, drop_connection_if_no_response: bool, ) -> LruDropPool<C, ID>
If enabled (the default), connections that did not receive a response will be evicted from the pool instead of being returned for reuse.
This includes timeouts, cancellations, and errors.
pub fn set_drop_connection_if_no_response(
&mut self,
drop_connection_if_no_response: bool,
) -> &mut LruDropPool<C, ID>
pub fn set_drop_connection_if_no_response( &mut self, drop_connection_if_no_response: bool, ) -> &mut LruDropPool<C, ID>
If enabled (the default), connections that did not receive a response will be evicted from the pool instead of being returned for reuse.
This includes timeouts, cancellations, and errors.
pub fn maybe_with_metrics( self, metrics: Option<Arc<PoolMetrics>>, ) -> LruDropPool<C, ID>
pub fn maybe_set_metrics( &mut self, metrics: Option<Arc<PoolMetrics>>, ) -> &mut LruDropPool<C, ID>
pub fn with_metrics(self, metrics: Arc<PoolMetrics>) -> LruDropPool<C, ID>
pub fn set_metrics( &mut self, metrics: Arc<PoolMetrics>, ) -> &mut LruDropPool<C, ID>
pub fn without_metrics(self) -> LruDropPool<C, ID>
pub fn unset_metrics(&mut self) -> &mut LruDropPool<C, ID>