Struct ConnectionError
pub struct ConnectionError { /* private fields */ }net only.Expand description
A classified error produced while establishing a client connection.
The original error remains available as the source. Adding context only wraps that source and therefore preserves the classification.
Implementations
impl ConnectionError
impl ConnectionError
pub fn new(
source: impl Into<Box<dyn Error + Send + Sync>>,
domain: ConnectionErrorDomain,
kind: ConnectionErrorKind,
) -> ConnectionError
pub fn new( source: impl Into<Box<dyn Error + Send + Sync>>, domain: ConnectionErrorDomain, kind: ConnectionErrorKind, ) -> ConnectionError
Create a classified connection error.
pub fn transport(
source: impl Into<Box<dyn Error + Send + Sync>>,
kind: ConnectionErrorKind,
) -> ConnectionError
pub fn transport( source: impl Into<Box<dyn Error + Send + Sync>>, kind: ConnectionErrorKind, ) -> ConnectionError
Create an error which occurred while establishing the transport path.
pub fn application(
source: impl Into<Box<dyn Error + Send + Sync>>,
kind: ConnectionErrorKind,
) -> ConnectionError
pub fn application( source: impl Into<Box<dyn Error + Send + Sync>>, kind: ConnectionErrorKind, ) -> ConnectionError
Create an error which occurred while establishing the end-to-end connection.
This includes intermediate end-to-end protocols such as TLS to the origin, not only the final application protocol.
pub fn local(
source: impl Into<Box<dyn Error + Send + Sync>>,
kind: ConnectionErrorKind,
) -> ConnectionError
pub fn local( source: impl Into<Box<dyn Error + Send + Sync>>, kind: ConnectionErrorKind, ) -> ConnectionError
Create an error produced by client-local acquisition or orchestration machinery.
pub fn unknown(
source: impl Into<Box<dyn Error + Send + Sync>>,
) -> ConnectionError
pub fn unknown( source: impl Into<Box<dyn Error + Send + Sync>>, ) -> ConnectionError
Create an unclassified connection error.
pub fn domain(&self) -> ConnectionErrorDomain
pub fn domain(&self) -> ConnectionErrorDomain
Return the architectural domain in which the failure occurred.
pub fn kind(&self) -> ConnectionErrorKind
pub fn kind(&self) -> ConnectionErrorKind
Return the protocol-independent kind of failure.
pub fn get_ref(&self) -> &(dyn Error + Send + Sync + 'static)
pub fn get_ref(&self) -> &(dyn Error + Send + Sync + 'static)
Return the original error, including any attached context.
pub fn into_source(self) -> Box<dyn Error + Send + Sync>
pub fn into_source(self) -> Box<dyn Error + Send + Sync>
Consume this error and return its boxed source.
pub fn into_box_error(self) -> Box<dyn Error + Send + Sync>
pub fn into_box_error(self) -> Box<dyn Error + Send + Sync>
Convert this error into a BoxError without losing its classification.
pub fn into_opaque_error(self) -> OpaqueError
pub fn into_opaque_error(self) -> OpaqueError
Convert this error into an OpaqueError without losing its classification.
pub fn context<M>(self, value: M) -> ConnectionError
pub fn context<M>(self, value: M) -> ConnectionError
Add context to the source error.
pub fn context_hex<M>(self, value: M) -> ConnectionError
pub fn context_hex<M>(self, value: M) -> ConnectionError
Add context using fmt::LowerHex for its formatting.
pub fn context_debug<M>(self, value: M) -> ConnectionError
pub fn context_debug<M>(self, value: M) -> ConnectionError
Add context using fmt::Debug for its display formatting.
pub fn context_field<M>(self, key: &'static str, value: M) -> ConnectionError
pub fn context_field<M>(self, key: &'static str, value: M) -> ConnectionError
Add keyed context to the source error.
pub fn context_str_field<M>(
self,
key: &'static str,
value: M,
) -> ConnectionError
pub fn context_str_field<M>( self, key: &'static str, value: M, ) -> ConnectionError
Add a keyed string-like context value to the source error.
pub fn context_hex_field<M>(
self,
key: &'static str,
value: M,
) -> ConnectionError
pub fn context_hex_field<M>( self, key: &'static str, value: M, ) -> ConnectionError
Add keyed context using fmt::LowerHex for its formatting.
pub fn context_debug_field<M>(
self,
key: &'static str,
value: M,
) -> ConnectionError
pub fn context_debug_field<M>( self, key: &'static str, value: M, ) -> ConnectionError
Add keyed context using fmt::Debug for its display formatting.
pub fn with_context<C, F>(self, create: F) -> ConnectionError
pub fn with_context<C, F>(self, create: F) -> ConnectionError
Lazily add context to the source error.
pub fn with_context_hex<C, F>(self, create: F) -> ConnectionError
pub fn with_context_hex<C, F>(self, create: F) -> ConnectionError
Lazily add context using fmt::LowerHex for its formatting.
pub fn with_context_debug<C, F>(self, create: F) -> ConnectionError
pub fn with_context_debug<C, F>(self, create: F) -> ConnectionError
Lazily add context using fmt::Debug for its display formatting.
pub fn with_context_field<C, F>(
self,
key: &'static str,
create: F,
) -> ConnectionError
pub fn with_context_field<C, F>( self, key: &'static str, create: F, ) -> ConnectionError
Lazily add keyed context to the source error.
pub fn with_context_str_field<C, F>(
self,
key: &'static str,
create: F,
) -> ConnectionError
pub fn with_context_str_field<C, F>( self, key: &'static str, create: F, ) -> ConnectionError
Lazily add a keyed string-like context value to the source error.
pub fn with_context_hex_field<C, F>(
self,
key: &'static str,
create: F,
) -> ConnectionError
pub fn with_context_hex_field<C, F>( self, key: &'static str, create: F, ) -> ConnectionError
Lazily add keyed context using fmt::LowerHex for its formatting.
pub fn with_context_debug_field<C, F>(
self,
key: &'static str,
create: F,
) -> ConnectionError
pub fn with_context_debug_field<C, F>( self, key: &'static str, create: F, ) -> ConnectionError
Lazily add keyed context using fmt::Debug for its display formatting.
pub fn backtrace(self) -> ConnectionError
pub fn backtrace(self) -> ConnectionError
Capture a backtrace and attach it to the source error.