Struct ProxyRouteFailureCachedError
pub struct ProxyRouteFailureCachedError { /* private fields */ }Available on crate feature
net only.Expand description
Error returned when a proxy route is still inside its failure backoff.
Implementations
impl ProxyRouteFailureCachedError
impl ProxyRouteFailureCachedError
pub const fn retry_after(&self) -> Duration
pub const fn retry_after(&self) -> Duration
Remaining duration before this route can be probed again.