Struct ConnectionHealthWatcher
pub struct ConnectionHealthWatcher { /* private fields */ }Available on crate feature
net only.Expand description
Watcher that can update and read the ConnectionHealth
Note: this should only be added once to extensions and be used by all connection / health checks.
Implementations
impl ConnectionHealthWatcher
impl ConnectionHealthWatcher
pub fn new() -> ConnectionHealthWatcher
pub fn mark_healthy(&self)
pub fn mark_healthy(&self)
Set the ConnectionHealth to health
pub fn mark_broken(&self)
pub fn mark_broken(&self)
Set the ConnectionHealth to broken
pub fn update_health(&self, health: ConnectionHealth)
pub fn update_health(&self, health: ConnectionHealth)
Set the ConnectionHealth
pub fn health(&self) -> ConnectionHealth
pub fn health(&self) -> ConnectionHealth
Get the ConnectionHealth
pub fn sender(&self) -> &Sender<ConnectionHealth>
pub fn sender(&self) -> &Sender<ConnectionHealth>
Reference the [watch::Sender<ConnectionHealth>]
pub fn receiver(&self) -> &Receiver<ConnectionHealth>
pub fn receiver(&self) -> &Receiver<ConnectionHealth>
Reference the [watch::Sender<ConnectionHealth>]
Note: for keeping track of changes, prefer to clone this receiver so it has it’s own subscribe logic