Struct BloomTokenLog
pub struct BloomTokenLog(/* private fields */);Available on crate features
quic and std only.Expand description
Bloom filter-based TokenLog
Parameterizable over an approximate maximum number of bytes to allocate. Starts out by storing used tokens in a hash set. Once the hash set becomes too large, converts it to a bloom filter. This achieves a memory profile of linear growth with an upper bound.
Divides time into periods based on lifetime and stores two filters at any given moment, for
each of the two periods currently non-expired tokens could expire in. As such, turns over
filters as time goes on to avoid bloom filter false positive rate increasing infinitely over
time.