RuntimeBuilder

Struct RuntimeBuilder 

pub struct RuntimeBuilder { /* private fields */ }
Available on crate feature std only.
Builder for a dedicated blocking-boundary Runtime.

Implementations



impl RuntimeBuilder

pub fn new() -> RuntimeBuilder

Create a runtime builder with default settings.

pub fn with_thread_name(self, name: impl Into<String>) -> RuntimeBuilder

Set the name of the dedicated runtime owner thread.

pub fn set_thread_name( &mut self, name: impl Into<String>, ) -> &mut RuntimeBuilder

Set the name of the dedicated runtime owner thread.

pub fn with_shutdown_timeout(self, timeout: Duration) -> RuntimeBuilder

Set the maximum time spent shutting down Tokio work when the final runtime lease is dropped.

pub fn set_shutdown_timeout(&mut self, timeout: Duration) -> &mut RuntimeBuilder

Set the maximum time spent shutting down Tokio work when the final runtime lease is dropped.

pub fn with_current_thread(self) -> RuntimeBuilder

Use a current-thread Tokio scheduler.

With the dial9 feature, this overrides the implicit environment config when telemetry is disabled. An enabled environment config or an explicitly supplied dial9 config owns its scheduler and conflicts with this setting.

pub fn set_current_thread(&mut self) -> &mut RuntimeBuilder

Use a current-thread Tokio scheduler.

With the dial9 feature, this overrides the implicit environment config when telemetry is disabled. An enabled environment config or an explicitly supplied dial9 config owns its scheduler and conflicts with this setting.

pub fn with_worker_threads(self, worker_threads: usize) -> RuntimeBuilder

Use a multi-thread Tokio scheduler.

With the dial9 feature, this overrides the implicit environment config when telemetry is disabled. An enabled environment config or an explicitly supplied dial9 config owns its scheduler and conflicts with this setting.

pub fn set_worker_threads( &mut self, worker_threads: usize, ) -> &mut RuntimeBuilder

Use a multi-thread Tokio scheduler.

With the dial9 feature, this overrides the implicit environment config when telemetry is disabled. An enabled environment config or an explicitly supplied dial9 config owns its scheduler and conflicts with this setting.

pub fn maybe_with_dial9_config( self, dial9_config: Option<Dial9Config>, ) -> RuntimeBuilder

Set the dial9 runtime configuration.

With the dial9 feature, this defaults to resolving Dial9Config::from_env when the runtime is built. An enabled dial9 config owns its Tokio scheduler configuration. Combining an explicitly supplied config with with_current_thread or with_worker_threads is rejected by try_build. An implicit environment config yields to an explicit Rama scheduler when telemetry is disabled. Use without_dial9_config to explicitly select a Rama-configured scheduler without dial9.

An enabled config must produce a multi-thread runtime because dial9 installs ambient telemetry handles on Tokio-owned worker threads.

pub fn maybe_set_dial9_config( &mut self, dial9_config: Option<Dial9Config>, ) -> &mut RuntimeBuilder

Set the dial9 runtime configuration.

With the dial9 feature, this defaults to resolving Dial9Config::from_env when the runtime is built. An enabled dial9 config owns its Tokio scheduler configuration. Combining an explicitly supplied config with with_current_thread or with_worker_threads is rejected by try_build. An implicit environment config yields to an explicit Rama scheduler when telemetry is disabled. Use without_dial9_config to explicitly select a Rama-configured scheduler without dial9.

An enabled config must produce a multi-thread runtime because dial9 installs ambient telemetry handles on Tokio-owned worker threads.

pub fn with_dial9_config(self, dial9_config: Dial9Config) -> RuntimeBuilder

Set the dial9 runtime configuration.

With the dial9 feature, this defaults to resolving Dial9Config::from_env when the runtime is built. An enabled dial9 config owns its Tokio scheduler configuration. Combining an explicitly supplied config with with_current_thread or with_worker_threads is rejected by try_build. An implicit environment config yields to an explicit Rama scheduler when telemetry is disabled. Use without_dial9_config to explicitly select a Rama-configured scheduler without dial9.

An enabled config must produce a multi-thread runtime because dial9 installs ambient telemetry handles on Tokio-owned worker threads.

pub fn set_dial9_config( &mut self, dial9_config: Dial9Config, ) -> &mut RuntimeBuilder

Set the dial9 runtime configuration.

With the dial9 feature, this defaults to resolving Dial9Config::from_env when the runtime is built. An enabled dial9 config owns its Tokio scheduler configuration. Combining an explicitly supplied config with with_current_thread or with_worker_threads is rejected by try_build. An implicit environment config yields to an explicit Rama scheduler when telemetry is disabled. Use without_dial9_config to explicitly select a Rama-configured scheduler without dial9.

An enabled config must produce a multi-thread runtime because dial9 installs ambient telemetry handles on Tokio-owned worker threads.

pub fn without_dial9_config(self) -> RuntimeBuilder

Set the dial9 runtime configuration.

With the dial9 feature, this defaults to resolving Dial9Config::from_env when the runtime is built. An enabled dial9 config owns its Tokio scheduler configuration. Combining an explicitly supplied config with with_current_thread or with_worker_threads is rejected by try_build. An implicit environment config yields to an explicit Rama scheduler when telemetry is disabled. Use without_dial9_config to explicitly select a Rama-configured scheduler without dial9.

An enabled config must produce a multi-thread runtime because dial9 installs ambient telemetry handles on Tokio-owned worker threads.

pub fn unset_dial9_config(&mut self) -> &mut RuntimeBuilder

Set the dial9 runtime configuration.

With the dial9 feature, this defaults to resolving Dial9Config::from_env when the runtime is built. An enabled dial9 config owns its Tokio scheduler configuration. Combining an explicitly supplied config with with_current_thread or with_worker_threads is rejected by try_build. An implicit environment config yields to an explicit Rama scheduler when telemetry is disabled. Use without_dial9_config to explicitly select a Rama-configured scheduler without dial9.

An enabled config must produce a multi-thread runtime because dial9 installs ambient telemetry handles on Tokio-owned worker threads.

pub fn try_build(self) -> Result<Runtime, Error>

Build the dedicated runtime.