Trait TraceField
pub trait TraceField {
// Required methods
fn field_type() -> FieldType;
fn encode<W>(&self, enc: &mut EventEncoder<'_, W>) -> Result<(), Error>
where W: Write;
// Provided method
fn is_optional() -> bool { ... }
}Available on crate feature
dial9 only.Expand description
Trait for types that can be used as trace fields.
Provides schema metadata (field_type), encoding (encode), and
Required Methods
fn field_type() -> FieldType
Provided Methods
fn is_optional() -> bool
fn is_optional() -> bool
Whether this field is optional on the wire (high-bit modifier).
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".