Function apply
pub fn apply(key: &[u8; 32], nonce: &[u8; 12], counter: u32, buffer: &mut [u8])Available on crate feature
boring only.Expand description
Apply ChaCha20 in place. The key, nonce and block counter must not be reused. Panics if processing the buffer would wrap the block counter.