Trait BoringMitmRevocation
pub trait BoringMitmRevocation:
Send
+ Sync
+ 'static {
// Required methods
fn leaf_extensions(
&self,
ctx: &MitmRevocationCtx<'_>,
) -> Result<Vec<X509Extension>, Box<dyn Error + Sync + Send>>;
fn serve(
&self,
fetch: RevocationFetch<'_>,
) -> Result<RevocationArtifact, Box<dyn Error + Sync + Send>>;
}Available on crate feature
boring only.Expand description
Revocation behaviour for a MITM issuer: which pointers to stamp on the re-signed leaf, and how to serve the artifacts they reference.
Required Methods
fn leaf_extensions(
&self,
ctx: &MitmRevocationCtx<'_>,
) -> Result<Vec<X509Extension>, Box<dyn Error + Sync + Send>>
fn leaf_extensions( &self, ctx: &MitmRevocationCtx<'_>, ) -> Result<Vec<X509Extension>, Box<dyn Error + Sync + Send>>
Extensions to add to the re-signed leaf (empty adds none).
fn serve(
&self,
fetch: RevocationFetch<'_>,
) -> Result<RevocationArtifact, Box<dyn Error + Sync + Send>>
fn serve( &self, fetch: RevocationFetch<'_>, ) -> Result<RevocationArtifact, Box<dyn Error + Sync + Send>>
Produce the artifact for a fetch routed in from the HTTP edge.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".