Struct TlsMitmRelay
pub struct TlsMitmRelay<Issuer> { /* private fields */ }Expand description
A utility that can be used by MITM services such as transparent proxies, in order to relay (and MITM a TLS connection between a client and server, as part of a deep protocol inspection protocol (DPI) flow.
Implementations
impl<Issuer> TlsMitmRelay<Issuer>
impl<Issuer> TlsMitmRelay<Issuer>
pub fn new(issuer: Issuer) -> TlsMitmRelay<Issuer>
pub fn new(issuer: Issuer) -> TlsMitmRelay<Issuer>
Create a new TlsMitmRelay.
pub fn with_grease_enabled(self, enabled: bool) -> TlsMitmRelay<Issuer>
pub fn with_grease_enabled(self, enabled: bool) -> TlsMitmRelay<Issuer>
Set whether GREASE should be enabled for the ingress-side TLS acceptor.
By default is is enabled (true).
pub fn set_grease_enabled(&mut self, enabled: bool) -> &mut TlsMitmRelay<Issuer>
pub fn set_grease_enabled(&mut self, enabled: bool) -> &mut TlsMitmRelay<Issuer>
Set whether GREASE should be enabled for the ingress-side TLS acceptor.
By default is is enabled (true).
pub fn with_keylog_intent(self, intent: KeyLogIntent) -> TlsMitmRelay<Issuer>
pub fn with_keylog_intent(self, intent: KeyLogIntent) -> TlsMitmRelay<Issuer>
Set the [keylog_intent].
By default KeyLogIntent::Environment is used.
pub fn set_keylog_intent(
&mut self,
intent: KeyLogIntent,
) -> &mut TlsMitmRelay<Issuer>
pub fn set_keylog_intent( &mut self, intent: KeyLogIntent, ) -> &mut TlsMitmRelay<Issuer>
Set the [keylog_intent].
By default KeyLogIntent::Environment is used.
impl<Issuer> TlsMitmRelay<CachedBoringMitmCertIssuer<Issuer>>
impl<Issuer> TlsMitmRelay<CachedBoringMitmCertIssuer<Issuer>>
pub fn new_with_cached_issuer(
issuer: Issuer,
) -> TlsMitmRelay<CachedBoringMitmCertIssuer<Issuer>>
pub fn new_with_cached_issuer( issuer: Issuer, ) -> TlsMitmRelay<CachedBoringMitmCertIssuer<Issuer>>
Create a new TlsMitmRelay,
with a cache layer on top top of the provided issuer
toprovide reuse functionality of previously issued certs.
pub fn new_with_cached_issuer_and_config(
issuer: Issuer,
cfg: BoringMitmCertIssuerCacheConfig,
) -> TlsMitmRelay<CachedBoringMitmCertIssuer<Issuer>>
pub fn new_with_cached_issuer_and_config( issuer: Issuer, cfg: BoringMitmCertIssuerCacheConfig, ) -> TlsMitmRelay<CachedBoringMitmCertIssuer<Issuer>>
Create a new TlsMitmRelay,
with a cache layer (created by given config)
on top of the provided issuer to provide reuse functionality of previously issued certs.
impl TlsMitmRelay<InMemoryBoringMitmCertIssuer>
impl TlsMitmRelay<InMemoryBoringMitmCertIssuer>
pub fn try_new_with_self_signed_issuer(
data: &SelfSignedData,
) -> Result<TlsMitmRelay<InMemoryBoringMitmCertIssuer>, Box<dyn Error + Send + Sync>>
pub fn try_new_with_self_signed_issuer( data: &SelfSignedData, ) -> Result<TlsMitmRelay<InMemoryBoringMitmCertIssuer>, Box<dyn Error + Send + Sync>>
Create a new TlsMitmRelay with self-signed CA using the given data.
pub fn new_in_memory(
crt: X509,
key: PKey<Private>,
) -> TlsMitmRelay<InMemoryBoringMitmCertIssuer>
pub fn new_in_memory( crt: X509, key: PKey<Private>, ) -> TlsMitmRelay<InMemoryBoringMitmCertIssuer>
Create a new TlsMitmRelay with the provided CA pair.
impl TlsMitmRelay<CachedBoringMitmCertIssuer<InMemoryBoringMitmCertIssuer>>
impl TlsMitmRelay<CachedBoringMitmCertIssuer<InMemoryBoringMitmCertIssuer>>
pub fn try_new_with_cached_self_signed_issuer(
data: &SelfSignedData,
) -> Result<TlsMitmRelay<CachedBoringMitmCertIssuer<InMemoryBoringMitmCertIssuer>>, Box<dyn Error + Send + Sync>>
pub fn try_new_with_cached_self_signed_issuer( data: &SelfSignedData, ) -> Result<TlsMitmRelay<CachedBoringMitmCertIssuer<InMemoryBoringMitmCertIssuer>>, Box<dyn Error + Send + Sync>>
Create a new TlsMitmRelay with self-signed CA using the given data,
with a cache layer on top to provide reuse functionality of previously issued certs.
pub fn try_new_with_cached_self_signed_issuer_and_config(
data: &SelfSignedData,
cfg: BoringMitmCertIssuerCacheConfig,
) -> Result<TlsMitmRelay<CachedBoringMitmCertIssuer<InMemoryBoringMitmCertIssuer>>, Box<dyn Error + Send + Sync>>
pub fn try_new_with_cached_self_signed_issuer_and_config( data: &SelfSignedData, cfg: BoringMitmCertIssuerCacheConfig, ) -> Result<TlsMitmRelay<CachedBoringMitmCertIssuer<InMemoryBoringMitmCertIssuer>>, Box<dyn Error + Send + Sync>>
Create a new TlsMitmRelay with self-signed CA using the given data,
with a cache layer (created by given config)
on top to provide reuse functionality of previously issued certs.
pub fn new_cached_in_memory(
crt: X509,
key: PKey<Private>,
) -> TlsMitmRelay<CachedBoringMitmCertIssuer<InMemoryBoringMitmCertIssuer>>
pub fn new_cached_in_memory( crt: X509, key: PKey<Private>, ) -> TlsMitmRelay<CachedBoringMitmCertIssuer<InMemoryBoringMitmCertIssuer>>
Create a new TlsMitmRelay with the provided CA pair,
with a cache layer on top to provide reuse functionality of previously issued certs.
pub fn new_cached_in_memory_with_config(
crt: X509,
key: PKey<Private>,
cfg: BoringMitmCertIssuerCacheConfig,
) -> TlsMitmRelay<CachedBoringMitmCertIssuer<InMemoryBoringMitmCertIssuer>>
pub fn new_cached_in_memory_with_config( crt: X509, key: PKey<Private>, cfg: BoringMitmCertIssuerCacheConfig, ) -> TlsMitmRelay<CachedBoringMitmCertIssuer<InMemoryBoringMitmCertIssuer>>
Create a new TlsMitmRelay with the provided CA pair,
with a cache layer (created by given config)
on top to provide reuse functionality of previously issued certs.
impl<Issuer> TlsMitmRelay<Issuer>where
Issuer: BoringMitmCertIssuer,
<Issuer as BoringMitmCertIssuer>::Error: Into<Box<dyn Error + Send + Sync>>,
impl<Issuer> TlsMitmRelay<Issuer>where
Issuer: BoringMitmCertIssuer,
<Issuer as BoringMitmCertIssuer>::Error: Into<Box<dyn Error + Send + Sync>>,
pub async fn handshake<Ingress, Egress>(
&self,
__arg1: BridgeIo<Ingress, Egress>,
connector_data: Option<TlsConnectorData>,
) -> Result<BridgeIo<TlsStream<Ingress>, TlsStream<Egress>>, TlsMitmRelayError>
pub async fn handshake<Ingress, Egress>( &self, __arg1: BridgeIo<Ingress, Egress>, connector_data: Option<TlsConnectorData>, ) -> Result<BridgeIo<TlsStream<Ingress>, TlsStream<Egress>>, TlsMitmRelayError>
Establish and MITM an handshake between the client (ingress) and server (egress).