Enum SupportedCipherSuite
pub enum SupportedCipherSuite {
Tls12(&'static Tls12CipherSuite),
Tls13(&'static Tls13CipherSuite),
}Available on crate feature
rustls only.Expand description
A cipher suite supported by rustls.
This type carries both configuration and implementation. Compare with
CipherSuite, which carries solely a cipher suite identifier.
Variants
Tls12(&'static Tls12CipherSuite)
Available on crate feature
tls12 only.A TLS 1.2 cipher suite
Tls13(&'static Tls13CipherSuite)
A TLS 1.3 cipher suite
Implementations
impl SupportedCipherSuite
impl SupportedCipherSuite
pub fn suite(&self) -> CipherSuite
pub fn suite(&self) -> CipherSuite
The cipher suite’s identifier
pub fn tls13(&self) -> Option<&'static Tls13CipherSuite>
pub fn tls13(&self) -> Option<&'static Tls13CipherSuite>
Return the inner Tls13CipherSuite for this suite, if it is a TLS1.3 suite.
pub fn version(&self) -> &'static SupportedProtocolVersion
pub fn version(&self) -> &'static SupportedProtocolVersion
Return supported protocol version for the cipher suite.
pub fn usable_for_signature_algorithm(
&self,
_sig_alg: SignatureAlgorithm,
) -> bool
pub fn usable_for_signature_algorithm( &self, _sig_alg: SignatureAlgorithm, ) -> bool
Return true if this suite is usable for a key only offering sig_alg
signatures. This resolves to true for all TLS1.3 suites.