pub struct ClientHello { /* private fields */ }rustls or boring) and crate feature rustls only.Expand description
When a client first connects to a server, it is required to send the ClientHello as its first message.
The ClientHello contains random data, cipher suites, legacy content from <= TLS.12 and extensions.
For Rama however we only focus on the parts which a user might want to inspect and/or set.
Implementations
Sourceimpl ClientHello
impl ClientHello
pub fn new( protocol_version: ProtocolVersion, cipher_suites: Vec<CipherSuite>, compression_algorithms: Vec<CompressionAlgorithm>, extensions: Vec<ClientHelloExtension>, ) -> ClientHello
boring only.Sourcepub fn protocol_version(&self) -> ProtocolVersion
Available on crate feature boring only.
pub fn protocol_version(&self) -> ProtocolVersion
boring only.Return all ProtocolVersions defined in this ClientHello.
Sourcepub fn cipher_suites(&self) -> &[CipherSuite]
Available on crate feature boring only.
pub fn cipher_suites(&self) -> &[CipherSuite]
boring only.Return all CipherSuites defined in this ClientHello.
Sourcepub fn compression_algorithms(&self) -> &[CompressionAlgorithm]
Available on crate feature boring only.
pub fn compression_algorithms(&self) -> &[CompressionAlgorithm]
boring only.Return all CompressionAlgorithms defined in this ClientHello.
Sourcepub fn extensions(&self) -> &[ClientHelloExtension]
Available on crate feature boring only.
pub fn extensions(&self) -> &[ClientHelloExtension]
boring only.Return all ClientHelloExtensions defined in this ClientHello.
Sourcepub fn ext_server_name(&self) -> Option<&Host>
Available on crate feature boring only.
pub fn ext_server_name(&self) -> Option<&Host>
boring only.Return the server name (SNI) if it is set in the ClientHelloExtension defined in this ClientHello.
See ClientHelloExtension::ServerName for more information about the server name.
Sourcepub fn ext_supported_groups(&self) -> Option<&[SupportedGroup]>
Available on crate feature boring only.
pub fn ext_supported_groups(&self) -> Option<&[SupportedGroup]>
boring only.Return the elliptic curves supported by this client
if it is set in the ClientHelloExtension defined in this ClientHello.
See ClientHelloExtension::SupportedGroups for more information about these curves.
Sourcepub fn ext_ec_point_formats(&self) -> Option<&[ECPointFormat]>
Available on crate feature boring only.
pub fn ext_ec_point_formats(&self) -> Option<&[ECPointFormat]>
boring only.Return the EC point formats supported by this client
if it is set in the ClientHelloExtension defined in this ClientHello.
See ClientHelloExtension::ECPointFormats for more information about this.
Sourcepub fn ext_signature_algorithms(&self) -> Option<&[SignatureScheme]>
Available on crate feature boring only.
pub fn ext_signature_algorithms(&self) -> Option<&[SignatureScheme]>
boring only.Return the signature algorithms supported by this client
if it is set in the ClientHelloExtension defined in this ClientHello.
See ClientHelloExtension::SignatureAlgorithms for more information about these algorithms
Sourcepub fn ext_alpn(&self) -> Option<&[ApplicationProtocol]>
Available on crate feature boring only.
pub fn ext_alpn(&self) -> Option<&[ApplicationProtocol]>
boring only.Return the application layer protocols supported for negotiation by this client
if it is set in the ClientHelloExtension defined in this ClientHello.
See ClientHelloExtension::ApplicationLayerProtocolNegotiation for more information about these protocols (ALPN).
Sourcepub fn supported_versions(&self) -> Option<&[ProtocolVersion]>
Available on crate feature boring only.
pub fn supported_versions(&self) -> Option<&[ProtocolVersion]>
boring only.Return the TLS versions supported by this client
if it is set in the ClientHelloExtension defined in this ClientHello.
See ClientHelloExtension::SupportedVersions for more information about these versions