Trait BlockingService
pub trait BlockingService<Input>:
Sized
+ Send
+ Sync
+ 'static {
type Output: Send + 'static;
type Error: Send + 'static;
// Required method
fn serve(&self, input: Input) -> Result<Self::Output, Self::Error>;
}Expand description
A synchronous Service boundary.
Rama stacks remain asynchronous internally. Implementations of this trait expose a blocking outer boundary to callers that cannot or do not want to run an async runtime themselves.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".