Struct UdpSocketConfig
pub struct UdpSocketConfig { /* private fields */ }std and udp only.Expand description
Configuration shared by UDP packet-socket factories.
Implementations
impl UdpSocketConfig
impl UdpSocketConfig
pub fn new() -> UdpSocketConfig
pub fn new() -> UdpSocketConfig
Construct default UDP socket configuration.
pub fn with_socket_options(self, options: SocketOptions) -> UdpSocketConfig
pub fn with_socket_options(self, options: SocketOptions) -> UdpSocketConfig
Replace Rama’s general platform socket options.
The address supplied to bind takes precedence over options.address.
On Apple platforms the packet adapter can raise an explicitly small
send buffer to avoid a kernel sendmsg ancillary-data defect.
pub fn set_socket_options(
&mut self,
options: SocketOptions,
) -> &mut UdpSocketConfig
pub fn set_socket_options( &mut self, options: SocketOptions, ) -> &mut UdpSocketConfig
Replace Rama’s general platform socket options.
The address supplied to bind takes precedence over options.address.
On Apple platforms the packet adapter can raise an explicitly small
send buffer to avoid a kernel sendmsg ancillary-data defect.
pub fn socket_options(&self) -> &SocketOptions
pub fn socket_options(&self) -> &SocketOptions
Inspect the general platform socket options.
pub fn required_features(&self) -> &[DatagramFeature]
pub fn required_features(&self) -> &[DatagramFeature]
Features that socket creation must provide.
pub fn with_receive_original_destination(self, enabled: bool) -> UdpSocketConfig
pub fn with_receive_original_destination(self, enabled: bool) -> UdpSocketConfig
Enable transparent-proxy original-destination metadata when supported.
pub fn set_receive_original_destination(
&mut self,
enabled: bool,
) -> &mut UdpSocketConfig
pub fn set_receive_original_destination( &mut self, enabled: bool, ) -> &mut UdpSocketConfig
Enable transparent-proxy original-destination metadata when supported.
pub fn with_required_feature(self, feature: DatagramFeature) -> UdpSocketConfig
pub fn with_required_feature(self, feature: DatagramFeature) -> UdpSocketConfig
Require feature, failing socket creation when it is unavailable.
pub fn set_required_feature(
&mut self,
feature: DatagramFeature,
) -> &mut UdpSocketConfig
pub fn set_required_feature( &mut self, feature: DatagramFeature, ) -> &mut UdpSocketConfig
Require feature, failing socket creation when it is unavailable.