Function decode_write
pub fn decode_write<W>(
input: impl AsRef<[u8]>,
output: &mut W,
) -> Result<usize, DecodeWriteError>Available on crate feature
std only.Expand description
Decode into a byte writer without allocating an intermediate vector.
All input is validated before writing. On an I/O error, the writer may have received a partial result. This function does not flush the writer.