Struct Dir
pub struct Dir<'a> { /* private fields */ }std only.Expand description
A directory.
Implementations
impl<'a> Dir<'a>
impl<'a> Dir<'a>
pub const fn new(path: &'a str, entries: &'a [DirEntry<'a>]) -> Dir<'a>
Available on crate features grpc and http only.
pub const fn new(path: &'a str, entries: &'a [DirEntry<'a>]) -> Dir<'a>
grpc and http only.Create a new Dir.
pub fn path(&self) -> &'a Path
Available on crate features grpc and http only.
pub fn path(&self) -> &'a Path
grpc and http only.The full path for this Dir, relative to the directory passed to
include_dir.
pub const fn entries(&self) -> &'a [DirEntry<'a>]
Available on crate features grpc and http only.
pub const fn entries(&self) -> &'a [DirEntry<'a>]
grpc and http only.The entries within this Dir.
pub fn files(&self) -> impl Iterator<Item = &'a File<'a>> + 'a
Available on crate features grpc and http only.
pub fn files(&self) -> impl Iterator<Item = &'a File<'a>> + 'a
grpc and http only.Get a list of the files in this directory.
pub fn dirs(&self) -> impl Iterator<Item = &'a Dir<'a>> + 'a
Available on crate features grpc and http only.
pub fn dirs(&self) -> impl Iterator<Item = &'a Dir<'a>> + 'a
grpc and http only.Get a list of the sub-directories inside this directory.
pub fn get_entry<S>(&self, path: S) -> Option<&'a DirEntry<'a>>
Available on crate features grpc and http only.
pub fn get_entry<S>(&self, path: S) -> Option<&'a DirEntry<'a>>
grpc and http only.Recursively search for a DirEntry with a particular path.
pub fn get_file<S>(&self, path: S) -> Option<&'a File<'a>>
Available on crate features grpc and http only.
pub fn get_file<S>(&self, path: S) -> Option<&'a File<'a>>
grpc and http only.Look up a file by name.
pub fn get_dir<S>(&self, path: S) -> Option<&'a Dir<'a>>
Available on crate features grpc and http only.
pub fn get_dir<S>(&self, path: S) -> Option<&'a Dir<'a>>
grpc and http only.Look up a dir by name.
pub fn contains<S>(&self, path: S) -> bool
Available on crate features grpc and http only.
pub fn contains<S>(&self, path: S) -> bool
grpc and http only.Does this directory contain path?
pub fn extract<S>(&self, base_path: S) -> Result<(), Error>
Available on crate features grpc and http only.
pub fn extract<S>(&self, base_path: S) -> Result<(), Error>
grpc and http only.Create directories and extract all files to real filesystem.
Creates parent directories of path if they do not already exist.
Fails if some files already exist.
In case of error, partially extracted directory may remain on the filesystem.
Security
This method validates that all entry paths are relative, do not escape the extraction directory through path traversal, and do not follow symlinks outside the extraction directory.